/*-- Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/ 
/*
Model         Creditrisk 48pup Datamodel

Subject Area  Staging
Model Version 
Macro Name    ddl_script_staging.sas
DBMS          SAS
Created       02/24/14  
     Copyright (c) 2014 by SAS Institute Inc., Cary, NC 27513    */

/* Assign a libname to the location to store the staging tables   */
/* and set the macro var LIBNAME to the libref name               */


PROC SQL;

CREATE TABLE &LIBNAME..ANALYTICAL_MODEL_X_RISK_FACTOR
(
   MODEL_RK             NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   RISK_FACTOR_ID       VARCHAR(32)
      LABEL = 'Risk Factor Id',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_RK,RISK_FACTOR_ID)
);


CREATE TABLE &LIBNAME..CASHFLOW_DETAILS

(
   INSTID      CHARACTER(20)
       LABEL = 'InstId',
    CASHFLOW_DT    DATE
       FORMAT = NLDATE.
       INFORMAT = NLDATE.
       LABEL = 'Cashflow Date',
    CASHFLOW_AMT          Numeric(8)
       LABEL = 'Cashflow Amount',
    CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID,CASHFLOW_DT)

);


CREATE TABLE &LIBNAME..COUNTERPARTY_MART
(
   ANNUAL_SALES         Numeric(8)
      LABEL = 'Annual Sales',
   COUNTERPARTY_COUNTRY CHARACTER(3)
      LABEL = 'Counterparty Country',
   COUNTERPARTY_GROUP   CHARACTER(32)
      LABEL = 'Counterparty Group',
   COUNTERPARTY_ID      CHARACTER(32)
      LABEL = 'Counterparty Id',
   COUNTERPARTY_PD_MODEL_ID CHARACTER(32)
      LABEL = 'Counterparty Pd Model Id',
   COUNTERPARTY_PD_RATING_GRADE CHARACTER(20)
      LABEL = 'Counterparty Pd Rating Grade',
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   COUNTERPARTY_NAME    CHARACTER(150)
      LABEL = 'Counterparty Name',
   COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Counterparty Type Code',
   INDUSTRY             CHARACTER(32)
      LABEL = 'Industry',
   SECTOR               CHARACTER(32)
      LABEL = 'Sector',
   COUNTERPARTY_REGION_CD CHARACTER(4)
      LABEL = 'Counterparty Region Code',
   REGLTRY_COUNTERPARTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regltry Counterparty Type Code' NOT NULL ,
   TOTAL_ASSETS         Numeric(8)
      LABEL = 'Total Assets',
   CORE_MARKET_PARTICIPANT_FLG Numeric(8)
      LABEL = 'Core Market Participant Flag',
   REPORTING_CURRENCY_CD CHARACTER(3)
      LABEL = 'Reporting Currency Code',
   SOVEREIGN_COUNTERPARTY_RK Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Sovereign Counterparty Key',
   RISK_WEIGHT          Numeric(8)
      LABEL = 'Risk Weight',
   COUNTERPARTY_RELATION_TYPE_CD CHARACTER(3)
      LABEL = 'Counterparty Relation Type Code',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   ELIG_CCR_CENTRAL_CPTY_FLG NUMERIC(8)
      LABEL = 'Elig Ccredit Central Cpty Flag',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag',
   STD_ZERO_RW_FLG  NUMERIC(8)
      LABEL = 'STD Zero Risk Weight Flag',
   CENTGOV_TREAT_FLG NUMERIC(8)
      LABEL = 'Treat counterparty as central government',
   STD_REGGOV_TREAT_FLG NUMERIC(8)
      LABEL = 'STD regional government treatment Flag',   
   NACE               CHARACTER(32)
      LABEL = 'NACE Code',
   LEGAL_ENTITY_ID    CHARACTER(32)
      LABEL = 'Legal Entity  ID',
   COUNTERPARTY_GROUP_PARENT_FLG Numeric(8)
      LABEL = 'Counterparty Group Parent Flag',
   LE_EXCESS_DAYS_NUM    NUMERIC(8)
      LABEL = 'Number of days the counterparty has been over the  Large Exposure limit',
   SME_SUPPORTING_FACTOR_FLG    NUMERIC(8)
      LABEL = 'SME Supporting Factor Flag',
   CONNECTION_TYPE_CD CHARACTER(1)
      LABEL = 'Type of connection to counterparty group',
   FINANCIAL_ENTITY_TYPE_CD CHARACTER(3)
      LABEL = 'Financial entity type',
   COUNTERPARTY_CD CHARACTER(32)
      LABEL = 'Code of counterparty used in Large Exposures reporting',
   CONSTRAINT PRIM_KEY PRIMARY KEY (COUNTERPARTY_RK)
);



CREATE TABLE &LIBNAME..COUNTERPARTY_RATINGS
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   RATING               CHARACTER(20)
      LABEL = 'Rating',
   RATING_AGENCY        CHARACTER(10)
      LABEL = 'Rating Agency',
   DOMESTIC_CURR_ASSESSMENT_FLG NUMERIC(8)
      LABEL = 'Domestic Curr Assessment Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (COUNTERPARTY_RK,RATING_AGENCY)
);



CREATE TABLE &LIBNAME..COUNTERPARTY_X_INTERNAL_ORG
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (COUNTERPARTY_RK,INTERNAL_ORG_RK)
);



CREATE TABLE &LIBNAME..CRM_ACCOUNT
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   ELIGIBLE_CRM_TYPE_CD Char(3)
      LABEL = 'Eligible Crm Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_DERIVATIVE
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   UNFUNDED_FLG         Numeric(8)
      LABEL = 'Unfunded Flag',
   FIRST_TO_DEFAULT_PROT_FLG Numeric(8)
      LABEL = 'First To Default Prot Flag',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_GUARANTEE
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(10)
      LABEL = 'Crm Subtype Code',
   UNFUNDED_FLG         Numeric(8)
      LABEL = 'Unfunded Flag',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_INSTRUMENT
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_INSURANCE
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   SURRENDER_VALUE      Numeric(8)
      LABEL = 'Surrender Value',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   UNFUNDED_FLG         Numeric(8)
      LABEL = 'Unfunded Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_PHYSICAL
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   IRB_ALTER_TREAT_ELIGIB_TYPE_CD CHARACTER(3)
      LABEL = 'IRB Alter Treat Eligib Type Code',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_RECEIVABLE
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   PROTECTION_VALUE_AMT Numeric(8)
      LABEL = 'Protection Value Amount',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible Crm Type Code',
   USED_AMOUNT          Numeric(8)
      LABEL = 'Used Amount',
   CRM_EFFECTIVE_DATE   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Effective Date',
   CRM_EXPIRATION_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Crm Expiration Date',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'Crm Type Code',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'Crm Subtype Code',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..CRM_SEGMENT
(
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Segment Id',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   CRM_EFFECTIVE_DATE   DATE
      LABEL = 'CRM Effective Date',
   CRM_EXPIRATION_DATE  DATE
      LABEL = 'CRM Expiration Date',
   CRM_SUBTYPE_CD       CHARACTER(3)
      LABEL = 'CRM Sub Type Code',
   CRM_TYPE_CD          CHARACTER(3)
      LABEL = 'CRM Type Code',
   ELIGIBLE_CRM_TYPE_CD CHARACTER(3)
      LABEL = 'Eligible CRM Type Code',
   PROTECTION_VALUE_AMT NUMERIC(8)
      LABEL = 'Protection Value Amount',
   USED_AMOUNT          NUMERIC(8)
      LABEL = 'Used Amount',
   CONSTRAINT PRIM_KEY PRIMARY KEY (SEGMENT_ID)
);



CREATE TABLE &LIBNAME..DATA_ITEM
(
   DATA_ITEM_CD         VARCHAR(10)
      LABEL = '',
   DATA_ITEM_DESC       VARCHAR(100)
      LABEL = '',
   ITEM_NO              VARCHAR(10)
      LABEL = '',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = '',
   CONSTRAINT PRIM_KEY PRIMARY KEY (DATA_ITEM_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..EXPOSURE_ACCOUNT
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   REFERENCED_ISSUE_KEY CHARACTER(32)
      LABEL = 'Referenced Issue Key',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   DAYS_PAST_DUE_NO        Numeric(8)
      LABEL = 'Days Past Due',
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   EAD_AMT              NUMERIC(8)
      LABEL = 'Ead Amount',
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off-balance-sheet type code',
   NON_MAT_EXP_FLG      NUMERIC(8)
      LABEL = 'Non Mat Exposure Flag',
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Segment Id',
   REPO_TRANSACTION_FLG NUMERIC(8)
      LABEL = 'Repo Transaction Flag',
   REPO_INCEPTION_DT    DATE
      LABEL = 'Repo Inception Date',
   REPO_MATURITY_DT     DATE
      LABEL = 'Repo Maturity Date',
   MKT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Market Risk charge',
   SETT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Settlement Risk charge',   
  FREE_DELIVERY_FLG    NUMERIC(8) 
   label='Free Delivery Flag',   
  TRADE_EXP_FLG    NUMERIC(8) 
   label='Trade Exposure Flag', 
  BANKRUPTCY_REMOTE_FLG    CHAR(1) 
   label='Asset Bankruptcy Remote Flag', 
  ASSET_TRANSFERRABLE_FLG    NUMERIC(8) 
   label='Asset Transferrable Flag', 
  NO_LOSS_FROM_CM_BANKRUPTCY_FLG    NUMERIC(8) 
   label='No Loss from Clearing Member Bankruptcy Flag', 
   CCP_COUNTERPARTY_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Central Counterparty Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..EXPOSURE_CF_LINK
(
   EXPOSURE_ID          CHARACTER(20)
      LABEL = 'Exposure Id',
   CREDIT_FACILITY_ID   CHARACTER(20)
      FORMAT = $20.
      LABEL = 'Credit Facility Id',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EXPOSURE_ID,CREDIT_FACILITY_ID)
);



CREATE TABLE &LIBNAME..EXPOSURE_CRM_LINK
(
   EXPOSURE_ID          CHARACTER(20)
      LABEL = 'Exposure Id',
   CRM_ID               CHARACTER(20)
      FORMAT = $20.
      LABEL = 'Crm Id',
   EXPOSURE_RANK        Numeric(8)
      LABEL = 'Exposure Rank',
   CRM_RANK             Numeric(8)
      LABEL = 'Crm Rank',
   USED_TO_COVER_RISK_TYPE_CD CHARACTER(3)
      LABEL = 'Used To Cover Risk Type Code',
   COVERED_VALUE_AMT    NUMERIC(8)
      LABEL = 'Covered Value Amount',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   CONSTRAINT PRIM_KEY PRIMARY KEY (EXPOSURE_ID,CRM_ID)
);



CREATE TABLE &LIBNAME..EXPOSURE_FACILITY
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   REFERENCED_ISSUE_KEY CHARACTER(32)
      LABEL = 'Referenced Issue Key',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   MASTER_NETTING_AGRMNT_FLG Numeric(8)
      LABEL = 'Master Netting Agrmnt Flag',
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   EAD_AMT              NUMERIC(8)
      LABEL = 'Ead Amount',
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   NON_MAT_EXP_FLG      NUMERIC(8)
      LABEL = 'Non Mat Exposure Flag',
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Segment Id',
   DAYS_PAST_DUE_NO        Numeric(8) 
      LABEL = 'Days Past Due',
   MKT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Market Risk charge',
   SETT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Settlement Risk charge',    
   SEC_INFRINGEMENT_FLG      NUMERIC(8)
      LABEL = 'Securitization Infrigement Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..EXPOSURE_INSTRUMENT
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   REFERENCED_ISSUE_KEY CHARACTER(32)
      LABEL = 'Referenced Issue Key',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   MASTER_NETTING_AGRMNT_FLG Numeric(8)
      LABEL = 'Master Netting Agrmnt Flag',
   EFFECTIVE_FROM_DATE  DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Effective From Date',
   EQUITY_POSITION_TYPE_CD CHARACTER(3)
      LABEL = 'Equity Position Type Code',
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   EAD_AMT              NUMERIC(8)
      LABEL = 'Ead Amount',
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   CCP_COUNTERPARTY_RK      NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Central Counterparty Key',
   PAYMENT_LEG_CD       VARCHAR(3)
      LABEL = 'Payment Leg Code',
   REPO_TRANSACTION_FLG NUMERIC(8)
      LABEL = 'Repo Transaction Flag',
   HEDGE_EFF_VAL        NUMERIC(8)
      LABEL = 'Hedge EFF Value',
   HEDGE_MATURITY_DT    DATE
      LABEL = 'Hedge Maturity Date',
   HEDGING_INST_ID      CHARACTER(32)
      LABEL = 'Hedge Instrument Id',
   HEDGING_PCT          NUMERIC(8)
      LABEL = 'Hedge Percent',
   NON_MAT_EXP_FLG      NUMERIC(8)
      LABEL = 'Non Mat Exposure Flag',
   REPO_MATURITY_DT     DATE
      LABEL = 'Repo Maturity Date',
   REPO_INCEPTION_DT    DATE
      LABEL = 'Repo Inception Date',
   DAYS_PAST_DUE_NO        Numeric(8) 
      LABEL = 'Days Past Due',
   MKT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Market Risk charge',
   SETT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Settlement Risk charge',       
  TRADE_EXP_FLG     NUMERIC(8)
      LABEL = 'Trade Exposure Flag',
  BANKRUPTCY_REMOTE_FLG   CHAR(1)
      LABEL = 'Bankruptcy Remote Flag',
  FREE_DELIVERY_FLG    NUMERIC(8) 
      label='Free Delivery Flag',
  ASSET_TRANSFERRABLE_FLG    NUMERIC(8) 
      label='Asset Transferrable Flag',
  NO_LOSS_FROM_CM_BANKRUPTCY_FLG    NUMERIC(8) 
      label='No Loss from Clearing Member Bankruptcy Flag',
  EQ_EXP_FIN_SECT_NO_DEDUCT_FLG   NUMERIC(8) 
      label='Equity Exposure to Financial Sector Entity No Deduction Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..EXPOSURE_RECEIVABLE
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   REFERENCED_ISSUE_KEY CHARACTER(32)
      LABEL = 'Referenced Issue Key',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   MASTER_NETTING_AGRMNT_FLG Numeric(8)
      LABEL = 'Master Netting Agrmnt Flag',
   RECEIVABLE_POOL_RK   Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Receivable Pool Key',
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   EAD_AMT              NUMERIC(8)
      LABEL = 'Ead Amount',
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   NON_MAT_EXP_FLG      NUMERIC(8)
      LABEL = 'Non Mat Exposure Flag',
   DAYS_PAST_DUE_NO        Numeric(8)  
      LABEL = 'Days Past Due',
   MKT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Market Risk charge',
   SETT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Settlement Risk charge' ,   
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..EXPOSURE_SECURITIZATION
(
   COUNTERPARTY_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Counterparty Key',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   HOLDING              Numeric(8)
      LABEL = 'Holding',
   INSTID               CHARACTER(20)
      LABEL = 'Instid',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   REFERENCED_ISSUE_KEY CHARACTER(32)
      LABEL = 'Referenced Issue Key',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   SOURCE_SYSTEM_CODE   CHARACTER(32)
      LABEL = 'Source System Code',
   MASTER_NETTING_AGRMNT_FLG Numeric(8)
      LABEL = 'Master Netting Agrmnt Flag',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off Balance Sheet Type Code',
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   EAD_AMT              NUMERIC(8)
      LABEL = 'Ead Amount',
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   NON_MAT_EXP_FLG      NUMERIC(8)
      LABEL = 'Non Mat Exposure Flag',
   DAYS_PAST_DUE_NO        Numeric(8)  
      LABEL = 'Days Past Due',   
   MKT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Market Risk charge',
   SETT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Settlement Risk charge',      
  FREE_DELIVERY_FLG    NUMERIC(8) 
   label='Free Delivery Flag',   
   SEC_INFRINGEMENT_FLG      NUMERIC(8)
      LABEL = 'Securitization Infrigement Flag',
   DEDUCT_FROM_OWN_FUNDS_FLG      NUMERIC(8)
      LABEL = 'Flag indicating the Institution chooses to deduct a securitization exposure from own funds in the case where a 1250% RW has been calculated',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INSTID)
);



CREATE TABLE &LIBNAME..EXPOSURE_SEGMENT
(
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Segment Id',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   POSITION_TYPE_CD     CHARACTER(5)
      LABEL = 'Position Type Code',
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   EAD_AMT              NUMERIC(8)
      LABEL = 'Ead Amount',
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   OFF_BALANCE_SHEET_TYPE_CD CHARACTER(3)
      LABEL = 'Off-balance-sheet type code',
   NON_MAT_EXP_FLG      NUMERIC(8)
      LABEL = 'Non-material Exposure Flag',
   MKT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Market Risk charge',
   SETT_RISK_CHG_AMT     NUMERIC(8)
      LABEL = 'Settlement Risk charge',   
   CONSTRAINT PRIM_KEY PRIMARY KEY (SEGMENT_ID)
);



CREATE TABLE &LIBNAME..FACILITY_GROUP_MART
(
   FACILITY_GROUP_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Facility Group Key',
   PARENT_FACILITY_GROUP_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Parent Facility Group Key',
   GROUP_LIMIT_AMT      NUMERIC(8)
      LABEL = 'Group Limit Amount',
   GROUP_LIMIT_CURRENCY CHARACTER(3)
      LABEL = 'Group Limit Currency',
   CONSTRAINT PRIM_KEY PRIMARY KEY (FACILITY_GROUP_RK)
);



CREATE TABLE &LIBNAME..FINANCIAL_BOOK_MART
(
   FINANCIAL_BOOK_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Financial Book Key',
   BOOK_ID              CHARACTER(32)
      LABEL = 'Book Id',
   TRADING_BOOK_FLG     NUMERIC(8)
      LABEL = 'Trading Book Flag',
  CORRELATION_TRADING_PORT_FLG     NUMERIC(8)
      LABEL = 'Correlation Trading Portfolio Flag',
  EXP_NOT_OWNED_FLG     NUMERIC(8)
      LABEL = 'Exposure Not Owned By Reporting Institution Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (FINANCIAL_BOOK_RK)
);



CREATE TABLE &LIBNAME..FINANCIAL_REPORTING_DATA
(
      INTERNAL_ORG_RK      Numeric(8) FORMAT=12. INFORMAT=12. label='Internal Org Key',
      ELIGC_INSTR_NONINN_LIMIT_AMT NUMERIC(8) label='Eligc Instr Noninn Limit Amount',
      ELIGC_INSTR_INN_LIMIT_AMT NUMERIC(8) label='Eligc Instr Inn Limit Amount',
      ELIGC_PAID_UP_CAPITAL_AMT NUMERIC(8) label='Eligc Paid Up Capital Amount',
      ELIGC_SHARE_VALUE_AMT NUMERIC(8) label='Eligc Share Value Amount',
      ELIGC_SHARE_PREMIUM_AMT NUMERIC(8) label='Eligc Share Premium Amount',
      ELIGC_INSTR_OTHER_AMT NUMERIC(8) label='Eligc Instr Other Amount',
      ER_RESERVES_AMT      NUMERIC(8) label='Er Reserves Amount',
      ER_MINORITY_INTEREST_AMT NUMERIC(8) label='Er Minority Interest Amount',
      ER_INSTR_NONINN_LIMIT_AMT NUMERIC(8) label='Er Instr Noninn Limit Amount',
      ER_INSTR_INN_LIMIT_AMT NUMERIC(8) label='Er Instr Inn Limit Amount',
      ER_IP_CURR_YEAR_AMT  NUMERIC(8) label='Er Ip Curr Year Amount',
      ER_IP_CURR_YEAR_VAL_AMT NUMERIC(8) label='Er Ip Curr Year Val Amount',
      ER_ML_INCOME_CURR_YEAR_AMT NUMERIC(8) label='Er Ml Income Curr Year Amount',
      ER_ML_INCOME_CURR_YEAR_VAL_AMT NUMERIC(8) label='Er Ml Income Curr Year Val Amount',
      ER_ML_IP_CURR_YEAR_AMT NUMERIC(8) label='Er Ml Ip Curr Year Amount',
      ER_ML_IP_CURR_YEAR_VAL_AMT NUMERIC(8) label='Er Ml Ip Curr Year Val Amount',
      ER_ML_IP_INC_SEC_AMT NUMERIC(8) label='Er Ml Ip Inc Sec Amount',
      ER_VD_AFS_EQUITY_AMT NUMERIC(8) label='Er Vd Afs Equity Amount',
      ER_VD_AFS_EQUITY_ADJ_AMT NUMERIC(8) label='Er Vd Afs Equity Adj Amount',
      ER_VD_AFS_RECEIVABLES_AMT NUMERIC(8) label='Er Vd Afs Receivables Amount',
      ER_VD_AFS_RECEIVABLES_ADJ_AMT NUMERIC(8) label='Er Vd Afs Receivables Adj Amount',
      ER_VD_AFS_AMT        NUMERIC(8) label='Er Vd Afs Amount',
      ER_VD_AFS_ADJ_AMT    NUMERIC(8) label='Er Vd Afs Adj Amount',
      ER_VD_FVO_FIN_LIAB_AMT NUMERIC(8) label='Er Vd Fvo Financial Liab Amount',
      ER_VD_FVO_FIN_LIAB_ADJ_AMT NUMERIC(8) label='Er Vd Fvo Financial Liab Adj Amount',
      ER_VD_NONAFS_AMT     NUMERIC(8) label='Er Vd Nonafs Amount',
      ER_VD_NONAFS_ADJ_AMT NUMERIC(8) label='Er Vd Nonafs Adj Amount',
      ER_VD_PROPERTY_AMT   NUMERIC(8) label='Er Vd Property Amount',
      ER_VD_PROPERTY_ADJ_AMT NUMERIC(8) label='Er Vd Property Adj Amount',
      ER_VD_PPE_AMT        NUMERIC(8) label='Er Vd Ppe Amount',
      ER_VD_PPE_ADJ_AMT    NUMERIC(8) label='Er Vd Ppe Adj Amount',
      ER_VD_ER_AMT         NUMERIC(8) label='Er Vd Er Amount',
      ER_VD_OTHER_ADJ_AMT  NUMERIC(8) label='Er Vd Other Adj Amount',
      BR_FUND_AMT          NUMERIC(8) label='Br Fund Amount',
      CSF_INSTR_NONINN_LIMIT_AMT NUMERIC(8) label='Csf Instr Noninn Limit Amount',
      CSF_INSTR_INN_LIMIT_AMT NUMERIC(8) label='Csf Instr Inn Limit Amount',
      CSF_INSTR_IAS_AMT    NUMERIC(8) label='Csf Instr Ias Amount',
      CSF_OTHER_AMT        NUMERIC(8) label='Csf Other Amount',
      ODF_INTNGBL_ASSETS_AMT NUMERIC(8) label='Odf Intngbl Assets Amount',
      ODF_INSTR_NONINN_LIMIT_AMT NUMERIC(8) label='Odf Instr Noninn Limit Amount',
      ODF_INSTR_INN_LIMIT_AMT NUMERIC(8) label='Odf Instr Inn Limit Amount',
      ODF_CSF_IAS_OTHER_AMT NUMERIC(8) label='Odf Csf Ias Other Amount',
      ODF_CSF_OTHER_AMT    NUMERIC(8) label='Odf Csf Other Amount',
      AOF_VD_AFS_ADJ_AMT   NUMERIC(8) label='Aof Vd Afs Adj Amount',
      AOF_VD_AFS_OTHER_ADJ_AMT NUMERIC(8) label='Aof Vd Afs Other Adj Amount',
      AOF_VD_INVS_ADJ_AMT  NUMERIC(8) label='Aof Vd Invs Adj Amount',
      AOF_VD_PPE_ADJ_AMT   NUMERIC(8) label='Aof Vd Ppe Adj Amount',
      AOF_VD_OTHER_ADJ_AMT NUMERIC(8) label='Aof Vd Other Adj Amount',
      AOF_REVAL_RESERVES_AMT NUMERIC(8) label='Aof Reval Reserves Amount',
      AOF_VCR_STD_ADJ_AMT  NUMERIC(8) label='Aof Vcredit Std Adj Amount',
      AOF_OTHER_AMT        NUMERIC(8) label='Aof Other Amount',
      AOF_SID_INSTR_OTHER_AMT NUMERIC(8) label='Aof Sid Instr Other Amount',
      AOF_IRBP_EXCESS_AMT  NUMERIC(8) label='Aof Irbp Excess Amount',
      AOF_CSF_FUND_AMT     NUMERIC(8) label='Aof Csf Fund Amount',
      AOF_COMMIT_CREDIT_INST_AMT NUMERIC(8) label='Aof Commit Credit Inst Amount',
      AOF_FIX_TERM_SHARES_AMT NUMERIC(8) label='Aof Fix Term Shares Amount',
      AOF_LOAN_CAPITAL_AMT NUMERIC(8) label='Aof Loan Capital Amount',
      AOF_SUPPL_AMT        NUMERIC(8) label='Aof Suppl Amount',
      AOF_EXCESS_LIMIT_SUPPL_AMT NUMERIC(8) label='Aof Excess Limit Suppl Amount',
      AOF_EXCESS_LIMIT_FUND_AMT NUMERIC(8) label='Aof Excess Limit Fund Amount',
      AOF_CSF_DED_OTHER_AMT NUMERIC(8) label='Aof Csf Ded Other Amount',
      DOF_FUND_AMT         NUMERIC(8) label='Dof Fund Amount',
      DOF_ADDL_FUND_AMT    NUMERIC(8) label='Dof Addl Fund Amount',
      DOF_HOLDINGS_10_CAPITAL_AMT NUMERIC(8) label='Dof Holdings 10 Capital Amount',
      DOF_SUBORD_CLAIM_AMT NUMERIC(8) label='Dof Subord Claim Amount',
      DOF_EXCESS_LIMIT_10_CAP_AMT NUMERIC(8) label='Dof Excess Limit 10 Cap Amount',
      DOF_INSTR_AMT        NUMERIC(8) label='Dof Instr Amount',
      DOF_INSTR_OTHER_AMT  NUMERIC(8) label='Dof Instr Other Amount',
      DOF_CSF_ORIGINAL_AMT NUMERIC(8) label='Dof Csf Original Amount',
      DOF_SECU_EXPO_RWA_AMT NUMERIC(8) label='Dof Secu Expo Rwa Amount',
      DOF_IRB_PROV_SF_AMT  NUMERIC(8) label='Dof IRB Provision Sf Amount',
      DOF_QUAL_INTEREST_NONFIN_AMT NUMERIC(8) label='Dof Qual Interest Nonfinancial Amt',
      DOF_FREE_DELIV_AMT   NUMERIC(8) label='Dof Free Deliv Amount',
      DOF_CSF_OTHER_AMT    NUMERIC(8) label='Dof Csf Other Amount',
      TOF_EXCESS_LIMIT_ADDL_AMT NUMERIC(8) label='Tof Excess Limit Addl Amount',
      TOF_PROFITS_AMT      NUMERIC(8) label='Tof Profits Amount',
      TOF_ST_SUBORD_CAPITAL_AMT NUMERIC(8) label='Tof St Subord Capital Amount',
      TOF_ILLIQUID_ASSEST_AMT NUMERIC(8) label='Tof Illiquid Assest Amount',
      TOF_EXCESS_LIMIT_SPCFC_AMT NUMERIC(8) label='Tof Excess Limit Spcfc Amount',
      TOF_CSF_DED_AMT      NUMERIC(8) label='Tof Csf Ded Amount',
      DTF_CSF_TOTAL_AMT    NUMERIC(8) label='Dtf Csf Total Amount',
      DTF_INSURANCE_AMT    NUMERIC(8) label='Dtf Insurance Amount',
      M_IRBP_AMT           NUMERIC(8) label='M Irbp Amount',
      M_IRBP_GEN_COLL_IMP_AMT NUMERIC(8) label='M Irbp General Coll Imp Amount',
      M_IRBP_SPCFC_INDV_IMP_AMT NUMERIC(8) label='M Irbp Spcfc Indv Imp Amount',
      M_IRBP_REVAL_RESERVES_AMT NUMERIC(8) label='M Irbp Reval Reserves Amount',
      M_IRBP_EXPEC_LOSS_AMT NUMERIC(8) label='M Irbp Expec Loss Amount',
      M_LOAN_CAPITAL_AMT   NUMERIC(8) label='M Loan Capital Amount',
      M_INITIAL_CAPITAL_REQM_AMT NUMERIC(8) label='M Initial Capital Reqm Amount',
      SETTLEMENT_RISK_AMT  NUMERIC(8) label='Settlement Risk Amount',
      TCR_TRD_DEBT_INSTR_AMT NUMERIC(8) label='Tcredit Trd Debt Instr Amount',
      TCR_EQUITY_AMT       NUMERIC(8) label='Tcredit Equity Amount',
      TCR_FOREIGN_EXCHANGE_AMT NUMERIC(8) label='Tcredit Foreign Exchange Amount',
      TCR_COMMODITIES_AMT  NUMERIC(8) label='Tcredit Commodities Amount',
      CAPITAL_REQM_FIXED_AMT NUMERIC(8) label='Capital Reqm Fixed Amount',
      OCR_FLOOR_AMT        NUMERIC(8) label='Ocredit Floor Amount',
      OCR_INVESTMENT_45B_AMT NUMERIC(8) label='Ocredit Investment 45b Amount',
      OCR_CSF_OTHER_AMT    NUMERIC(8) label='Ocredit Csf Other Amount',
      M_SURPLUS_FUND_AMT   NUMERIC(8) label='M Surplus Fund Amount',
      M_SURPLUS_SOLV_IDX_RATIO_AMT NUMERIC(8) label='M Surplus Solv Idx Ratio Amount',
      IA_CAPITAL_AMT       NUMERIC(8) label='Ia Capital Amount',
      IA_CAPITAL_NEEDS_AMT NUMERIC(8) label='Ia Capital Needs Amount',
      ELIGC_TIER1_AMT      NUMERIC(8) label='ELIGC Tier 1',
      ELIGC_TIER2_AMT      NUMERIC(8) label='ELIGC Tier 2',
      SECURITISATION_SA_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Securitisation positions SA',
      RESECURITISATION_SA_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='of which: resecuritisation',
      SECURITISATION_IRB_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Securitisation positions IRB',
      RESECURITISATION_IRB_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='of which: resecuritisation',
      OTHER_NON_CR_OBLIG_ASSET_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Other non credit-obligation assets',
      CAPITAL_REQM_ALL_CCP_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Risk exposure amount for exposures to all CCPs',
      CAPITAL_REQM_COMPLY_CCP_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Risk exposure amount for exposures to complying CCPs',
      CAPITAL_REQM_NONCMPLY_CCP_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Risk exposure amount for exposures to non-complying CCPs',
      SETTLEMENT_NON_TRADING_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Settlement/delivery risk in the non-Trading book',
      SETTLEMENT_TRADING_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Settlement/delivery risk in the Trading book',
      MKT_RISK_IM_AMT      NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Risk exposure amount for Position, foreign exchange and commodities risks under internal models (IM)',
      OP_RISK_BIA_AMT      NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='OpR Basic indicator approach (BIA)',
      OP_RISK_STA_AMT      NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='OpR Standardised (STA) / Alternative Standardised (ASA) approaches',
      OP_RISK_AMA_AMT      NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='OpR Advanced measurement approaches (AMA)',
      CVA_RISK_AM_AMT      NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Advanced method',
      CVA_RISK_STD_METHOD_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='tandardised method',
      CVA_RISK_OEM_AMT     NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Based on OEM',
      OCR_STRICT_PRDNTL_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Stricter prudential requirements based on Commission delegated acts',
      OCR_STRICT_PRDNTL_LRG_EXP_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Of which: requirements for large exposures',
      OCR_STRICT_PRDNTL_MOD_RW_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Securitisation positions SA',
      OCR_STRCT_PRDNTL_INTRA_FIN_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='due to modified risk weights for targeting asset bubbles in the residential and commercial property',
      OCR_ADDTNL_STRICT_PRDNTL_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Additional stricter prudential requirements based on Art 443b',
      LE_LIMITS_NON_INST_AMT NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Large Exposures Limit for Firms Other Than Institutions',
      LE_LIMITS_INST_AMT   NUMERIC(18,5) FORMAT=NLNUM18.5 INFORMAT=NLNUM18.5 label='Large Exposures Limit for Institutions',
   
   PREV_YEARS_FIXED_OVERHEAD_AMT  numeric(8) label='Fixed Overhead Amount from the Previous Year',
   EXCESS_OWN_FUNDS_AMT  numeric(8) label='Excess Own Funds Tthat are Held Due to Institution Applying Stricter
Requirements Than Those Outlined in The Regulation',
     CONSTRAINT PRIM_KEY PRIMARY KEY (INTERNAL_ORG_RK)
);



CREATE TABLE &LIBNAME..FINANCIAL_REPORTING_PERIOD
(
   FINANCIAL_REPORTING_PERIOD_RK NUMERIC(10)
      LABEL = 'Financial Reporting Period Key',
   REPORTING_DT         DATE
      LABEL = 'Reporting Date',
   TIME_FREQUENCY_CD    VARCHAR(3)
      LABEL = 'Time Frequency Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (FINANCIAL_REPORTING_PERIOD_RK)
);



CREATE TABLE &LIBNAME..FINANCIAL_RPT_PERIOD_X_INT_ORG
(
   FINANCIAL_REPORTING_PERIOD_RK NUMERIC(10)
      LABEL = 'Financial Reporting Period Key',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (FINANCIAL_REPORTING_PERIOD_RK,INTERNAL_ORG_RK)
);



CREATE TABLE &LIBNAME..FUND_INSTRUMENT_POSITION_INFO
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   AS_OF_DT             NUMERIC(8)
      FORMAT = DATE9.
      INFORMAT = DATE9.
      LABEL = 'AS OF date',
   UNDERLYING_FND_ASSET_TYPE_CD CHARACTER(3)
      LABEL = 'Underlying assets code of Investment Funds',
   CONCENTRATION_PCT    NUMERIC(8)
      LABEL = 'Concentration Percent value of the investment fund',
   PERMISSIBLE_PCT      NUMERIC(8)
      LABEL = 'Permissable Percent value for the investment fund',
   VALID_FROM_DTTM      NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid From Datetime',
   VALID_TO_DTTM        NUMERIC(8)
      FORMAT = NLDATM21.
      INFORMAT = NLDATM21.
      LABEL = 'Valid To Datetime'
);



CREATE TABLE &LIBNAME..GENERAL_PROVISION_MART
(
   GENERAL_PROVISION    Numeric(8)
      LABEL = 'General Provision',
   GENERAL_PROVISION_CURRENCY_CD CHARACTER(3)
      LABEL = 'General Provision Currency Code',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   APPROACH_TYPE_CD     CHARACTER(3)
      LABEL = 'Approach Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INTERNAL_ORG_RK,APPROACH_TYPE_CD)
);



CREATE TABLE &LIBNAME..HEDGING_SET
(
   HEDGING_SET_RK       NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Hedging Set Key',
   HEDGING_SET_ID       VARCHAR(20)
      LABEL = 'Hedging Set Id',
   CURRENCY_CD          CHARACTER(3)
      LABEL = 'Currency Code',
   HEDGING_SET_TYPE_CD  VARCHAR(3)
      LABEL = 'Hedging Set Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (HEDGING_SET_RK)
);



CREATE TABLE &LIBNAME..INTERNAL_ORG_ASSOCIATION
(
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   PARENT_INTERNAL_ORG_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Parent Internal Org Key',
   ASSOCIATION_TYPE_CD  CHARACTER(3)
      LABEL = 'Association Type Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INTERNAL_ORG_RK,PARENT_INTERNAL_ORG_RK,ASSOCIATION_TYPE_CD)
);



CREATE TABLE &LIBNAME..INTERNAL_ORG_MART
(
   BUSINESS_UNIT        CHARACTER(40)
      LABEL = 'Business Unit',
   COUNTRY              VARCHAR(3)
      LABEL = 'Country',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   BUSINESS_LINE_TYPE_CD     CHARACTER(40)
      LABEL = 'Business Line Type Code',
   BUSINESS_TYPE_CD     CHARACTER(40)
      LABEL = 'Code Identifying Type of Business, Such as Investment Firm With Limited
Authorization to Provide Service',
   MANAGER              CHARACTER(150)
      LABEL = 'Manager',
   CONSTRAINT PRIM_KEY PRIMARY KEY (INTERNAL_ORG_RK)
);




CREATE TABLE &LIBNAME..ISSUE_ACCOUNT
(
   BALANCE_AMT          Numeric(8)
      LABEL = 'Balance Amount',
   INTEREST_AMT         Numeric(8)
      LABEL = 'Interest Amount',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   PAYMENT_PER_ANNUM_NO Numeric(8)
      LABEL = 'Payment Per Annum No',
   DAY_BASIS_CD         VARCHAR(10)
      LABEL = 'Day Basis Code',
   PAYMENT_AMT          Numeric(8)
      LABEL = 'Payment Amount',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   PD_MODEL_ID          CHARACTER(32)
      LABEL = 'Pd Model Id',
   PD_CRM_ADJUSTED_FLG  Numeric(8)
      LABEL = 'Pd Crm Adjusted Flag',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_CRM_ADJUSTED_FLG Numeric(8)
      LABEL = 'LGD Crm Adjusted Flag',
   HOLDING_PERIOD_DAYS  Numeric(8)
      LABEL = 'Holding Period Days',
   HAIRCUT_VALUE        Numeric(8)
      LABEL = 'Haircut Value',
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   REVALUATION_FREQ_DAYS Numeric(8)
      LABEL = 'Revaluation Freq Days',
   RISK_WEIGHT          Numeric(8)
      LABEL = 'Risk Weight',
   IN_DEFAULT_FLG       Numeric(8)
      LABEL = 'In Default Flag',
   PRODUCT_CD           CHARACTER(5)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(3)
      LABEL = 'Subproduct Code',
   INCEPTION_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Inception Date',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   GRACE_PERIOD_DAYS    Numeric(8)
      LABEL = 'Grace Period Days',
   LEASE_RESIDUAL_VALUE_AMT Numeric(8)
      LABEL = 'Lease Residual Value Amount',
   EFFECTIVE_MATURITY_YEAR NUMERIC(8)
      LABEL = 'Effective Maturity Year',
   EXPECTED_LOSS_PERCENT Numeric(8)
      LABEL = 'Expected Loss Percent',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   PD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'Pd Model Rating Grade',
   EL_MODEL_ID          VARCHAR(32)
      FORMAT = $32.
      INFORMAT = $32.
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       VARCHAR(20)
      FORMAT = $20.
      INFORMAT = $20.
      LABEL = 'El Model Grade',
   ASSESSMENT_AGENCY_NM CHARACTER(100)
      LABEL = 'Assessment Agency Name',
   ASSESSMENT_SCORE_NO  NUMERIC(8)
      LABEL = 'Assessment Score Number',
   FIRST_LIEN_FLG       NUMERIC(8)
      LABEL = 'First Lien Flag',
   LTV_PCT              NUMERIC(8)
      LABEL = 'LTV Percent',
   LTV_UPDATED_FLG      NUMERIC(8)
      LABEL = 'LTV Updated Flag',
   LGD_OTHER_PCT        NUMERIC(8)
      LABEL = 'LGD Other Percent',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag',      
   DEFAULT_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Default Event Date',
   FIRST_DUE_SETT_DT       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'First Due Settlement Date',
   SECOND_DUE_SETT_DT       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Second Due Settlement Date',   
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY)
);



CREATE TABLE &LIBNAME..ISSUE_ASSET_MART
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   PRODUCT_CD           CHARACTER(5)
      LABEL = 'Product Code' NOT NULL ,
   SUBPRODUCT_CD        CHARACTER(3)
      LABEL = 'Subproduct Code' NOT NULL ,
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   CURRENCY             CHARACTER(3)
      LABEL = 'Currency',
   VALUE_AMT            NUMERIC(8)
      LABEL = 'Market Value Amount',
   EL_MODEL_ID          VARCHAR(32)
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       VARCHAR(20)
      LABEL = 'El Model Grade',
   ASSET_LOCATION_COUNTRY_CD VARCHAR(3)
      LABEL = 'Asset Location Country Code',
   REVALUATION_FREQ_DAYS NUMERIC(8)
      LABEL = 'Revaluation Freq Days',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag', 
   MORTGAGE_LENDING_VALUE_AMT NUMERIC(8)
      LABEL = 'Mortgage Lending Value Amount',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY)
);



CREATE TABLE &LIBNAME..ISSUE_FACILITY
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   LIMIT_AMT            Numeric(8)
      LABEL = 'Limit Amount',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   PD_MODEL_ID          CHARACTER(32)
      LABEL = 'Pd Model Id',
   PD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'Pd Model Rating Grade',
   PD_CRM_ADJUSTED_FLG  Numeric(8)
      LABEL = 'Pd Crm Adjusted Flag',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   LGD_CRM_ADJUSTED_FLG Numeric(8)
      LABEL = 'LGD Crm Adjusted Flag',
   CCF_BUCKET_CD        CHARACTER(20)
      LABEL = 'CCF Bucket Code',
   CCF_SET_ID           CHARACTER(32)
      LABEL = 'CCF Set Id',
   HOLDING_PERIOD_DAYS  Numeric(8)
      LABEL = 'Holding Period Days',
   HAIRCUT_VALUE        Numeric(8)
      LABEL = 'Haircut Value',
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   REVALUATION_FREQ_DAYS Numeric(8)
      LABEL = 'Revaluation Freq Days',
   RISK_WEIGHT          Numeric(8)
      LABEL = 'Risk Weight',
   IN_DEFAULT_FLG       Numeric(8)
      LABEL = 'In Default Flag',
   PRODUCT_CD           CHARACTER(5)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(3)
      LABEL = 'Subproduct Code',
   INCEPTION_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Inception Date',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   EXPECTED_LOSS_PERCENT Numeric(8)
      LABEL = 'Expected Loss Percent',
   CCF_PCT              NUMERIC(8)
      LABEL = 'CCF Percent',
   EFFECTIVE_MATURITY_YEAR NUMERIC(8)
      LABEL = 'Effective Maturity Year',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   FACILITY_GROUP_RK    NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Facility Group Key',
   COVER_SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Cover Securitization Pool Key',
   EL_MODEL_ID          VARCHAR(32)
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       VARCHAR(20)
      LABEL = 'El Model Grade',
   ASSESSMENT_AGENCY_NM CHARACTER(100)
      LABEL = 'Assessment Agency Name',
   ASSESSMENT_SCORE_NO  NUMERIC(8)
      LABEL = 'Assessment Score Number',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag',    
   DEFAULT_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Default Event Date',
        
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY)
);



CREATE TABLE &LIBNAME..ISSUE_INSTRUMENT
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   ISSUER_COUNTERPARTY_RK Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Issuer Counterparty Key',
   ISSUE_CODE           CHARACTER(15)
      LABEL = 'Issue Code',
   FACE_VALUE_AMT       Numeric(8)
      LABEL = 'Face Value Amount',
   PAYMENT_PER_ANNUM_NO Numeric(8)
      LABEL = 'Payment Per Annum No',
   DAY_BASIS_CD         VARCHAR(10)
      LABEL = 'Day Basis Code',
   PAYMENT_PER_ANNUM_RT Numeric(8)
      LABEL = 'Payment Per Annum Rate',
   NEXT_CONTRACT_RESET_DATE DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Next Contract Reset Date',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   PD_MODEL_ID          CHARACTER(32)
      LABEL = 'Pd Model Id',
   PD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'Pd Model Rating Grade',
   PD_CRM_ADJUSTED_FLG  Numeric(8)
      LABEL = 'Pd Crm Adjusted Flag',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   LGD_CRM_ADJUSTED_FLG Numeric(8)
      LABEL = 'LGD Crm Adjusted Flag',
   HOLDING_PERIOD_DAYS  Numeric(8)
      LABEL = 'Holding Period Days',
   HAIRCUT_VALUE        Numeric(8)
      LABEL = 'Haircut Value',
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   REVALUATION_FREQ_DAYS Numeric(8)
      LABEL = 'Revaluation Freq Days',
   RISK_WEIGHT          Numeric(8)
      LABEL = 'Risk Weight',
   IN_DEFAULT_FLG       Numeric(8)
      LABEL = 'In Default Flag',
   VALUE_AMT            Numeric(8)
      LABEL = 'Value Amount',
   PRODUCT_CD           CHARACTER(12)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(10)
      LABEL = 'Subproduct Code',
   INCEPTION_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Inception Date',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   GRACE_PERIOD_DAYS    Numeric(8)
      LABEL = 'Grace Period Days',
   EXPECTED_LOSS_PERCENT Numeric(8)
      LABEL = 'Expected Loss Percent',
   COVER_SECURITIZATION_POOL_RK Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Cover Securitization Pool Key',
   EFFECTIVE_MATURITY_YEAR NUMERIC(8)
      LABEL = 'Effective Maturity Year',
   ELIGIBLE_REPO_CARVE_OUT_FLG NUMERIC(8)
      LABEL = 'Eligible Repo Carve Out Flag',
   EXCHANGE_CD          CHARACTER(10)
      LABEL = 'Exchange Code',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   VAR_RT               NUMERIC(8)
      LABEL = 'Var Rate',
   EL_MODEL_ID          VARCHAR(32)
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       VARCHAR(20)
      LABEL = 'El Model Grade',
   CONTRACT_RATE_OR_PRICE_AMT NUMERIC(18,5)
      FORMAT = NLNUM18.5
      INFORMAT = NLNUM18.5
      LABEL = 'Contract Rate Or Price Amount',
   OPTION_TYPE_CD       VARCHAR(10)
      LABEL = 'Option Type Code',
   PAYMENT_RESET_FREQ_MONTH_NO NUMERIC(10)
      LABEL = 'Payment Reset Freq Month No',
   QUALIFYING_DEBT_SECURITY_FLG NUMERIC(8)
      LABEL = 'Qualifying Debt Security Flag',
   SETTLEMENT_DT        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Settlement Date',
   UNDERLYING_RISK_FACTOR_ID VARCHAR(32)
      LABEL = 'Underlying Risk Factor Id',
   SWAP_FLOATING_LEG_SPREAD_RT NUMERIC(9,4)
      FORMAT = NLNUM9.4
      INFORMAT = NLNUM9.4
      LABEL = 'Swap Floating Leg Spread Rate',
   SWAP_FX_REF_RISK_FACTOR_ID VARCHAR(32)
      LABEL = 'Swap Fx Ref Risk Factor Id',
   PRINCIPAL_EXCHANGE_REMAINING_NO NUMERIC(8)
      LABEL = 'Principal Exchange Remaining Number',
   LGD_OTHER_PCT        NUMERIC(8)
      LABEL = 'LGD Other Percent',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag',
   DEFAULT_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Default Event Date',
   CVA_STD_IMPLIED_RATING       VARCHAR(20)
      LABEL = 'Implied issue rating for CVA calculations',
   QUALIFYING_REFERENCE_INST_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'Qualifying Reference Inst Flag',
   FIRST_DUE_SETT_DT       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'First Due Settlement Date',
   SECOND_DUE_SETT_DT       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Second Due Settlement Date',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY)
);



CREATE TABLE &LIBNAME..ISSUE_RATINGS
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   RATING_AGENCY        CHARACTER(10)
      LABEL = 'Rating Agency',
   RATING               CHARACTER(20)
      LABEL = 'Rating',
   CRM_ADJUSTED_FLG     Numeric(8)
      LABEL = 'Crm Adjusted Flag',
   PRINCIPAL_ONLY_FLG   Numeric(8)
      LABEL = 'Principal Only Flag',
   SHORTTERM_FLG        Numeric(8)
      LABEL = 'Shortterm Flag',
   RATING_INCEPTION     CHARACTER(20)
      LABEL = 'Rating at Inception',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY,RATING_AGENCY)
);



CREATE TABLE &LIBNAME..ISSUE_RECEIVABLE
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   ISSUER_COUNTERPARTY_RK Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Issuer Counterparty Key',
   FACE_VALUE_AMT       Numeric(8)
      LABEL = 'Face Value Amount',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   PD_MODEL_ID          CHARACTER(32)
      LABEL = 'Pd Model Id',
   PD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'Pd Model Rating Grade',
   PD_CRM_ADJUSTED_FLG  Numeric(8)
      LABEL = 'Pd Crm Adjusted Flag',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   LGD_CRM_ADJUSTED_FLG Numeric(8)
      LABEL = 'LGD Crm Adjusted Flag',
   HOLDING_PERIOD_DAYS  Numeric(8)
      LABEL = 'Holding Period Days',
   HAIRCUT_VALUE        Numeric(8)
      LABEL = 'Haircut Value',
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   REVALUATION_FREQ_DAYS Numeric(8)
      LABEL = 'Revaluation Freq Days',
   RISK_WEIGHT          Numeric(8)
      LABEL = 'Risk Weight',
   IN_DEFAULT_FLG       Numeric(8)
      LABEL = 'In Default Flag',
   RECEIVABLE_POOL_RK   Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Receivable Pool Key',
   RECEIVABLE_POOL_ID   CHARACTER(32)
      LABEL = 'Receivable Pool Id',
   EXPECTED_LOSS_PERCENT Numeric(8)
      LABEL = 'Expected Loss Percent',
   DILUTION_EXPECTED_LOSS_PERCENT Numeric(8)
      LABEL = 'Dilution Expected Loss Percent',
   PRODUCT_CD           CHARACTER(12)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(10)
      LABEL = 'Subproduct Code',
   WA_CPTY_FIRM_SIZE    Numeric(8)
      LABEL = 'Wa Cpty Firm Size',
   WA_MATURITY_MONTH    Numeric(8)
      LABEL = 'Wa Maturity Month',
   PURCHASED_DISCOUNT_RT Numeric(8)
      LABEL = 'Purchased Discount Rate',
   DISCOUNT_REFUNDABLE_FLG Numeric(8)
      LABEL = 'Discount Refundable Flag',
   INCEPTION_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Inception Date',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   VALUE_AMT            Numeric(8)
      LABEL = 'Value Amount',
   GRACE_PERIOD_DAYS    Numeric(8)
      LABEL = 'Grace Period Days',
   WA_CPTY_FIRM_SIZE_CURRENCY_CD CHARACTER(3)
      LABEL = 'Wa Cpty Firm Size Currency Code',
   EFFECTIVE_MATURITY_YEAR NUMERIC(8)
      LABEL = 'Effective Maturity Year',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   REGULATORY_POOL_CPTY_TYPE_CD CHARACTER(3)
      LABEL = 'Regulatory Pool Cpty Type Code',
   EL_MODEL_ID          VARCHAR(32)
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       VARCHAR(20)
      LABEL = 'El Model Grade',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag',     
   DEFAULT_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Default Event Date',
       
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY)
);



CREATE TABLE &LIBNAME..ISSUE_RISK_FACTOR
(
   ISSUE_KEY            CHARACTER(32)
      FORMAT = $6.
      INFORMAT = $6.
      LABEL = 'Issue Key',
   RISK_FACTOR_ID       VARCHAR(32)
      FORMAT = $8.
      INFORMAT = $8.
      LABEL = 'Risk Factor Id',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY,RISK_FACTOR_ID)
);



CREATE TABLE &LIBNAME..ISSUE_SECURITIZATION
(
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   ISSUER_COUNTERPARTY_RK Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Issuer Counterparty Key',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   PRODUCT_CD           CHARACTER(12)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(10)
      LABEL = 'Subproduct Code',
   CURRENT_POOL_FACTOR  Numeric(8)
      LABEL = 'Current Pool Factor',
   TRANCHE_SENIORITY_RANK Numeric(8)
      LABEL = 'Tranche Seniority Rank',
   TRANCHE_LOSS_RANK    Numeric(8)
      LABEL = 'Tranche Loss Rank',
   TRANCHE_FACE_VALUE_AMT Numeric(8)
      LABEL = 'Tranche Face Value Amount',
   ISSUE_FACE_VALUE_AMT Numeric(8)
      LABEL = 'Issue Face Value Amount',
   THICKNESS            Numeric(8)
      LABEL = 'Thickness',
   PD_MODEL_ID          CHARACTER(32)
      LABEL = 'Pd Model Id',
   PD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'Pd Model Rating Grade',
   PD_CRM_ADJUSTED_FLG  Numeric(8)
      LABEL = 'Pd Crm Adjusted Flag',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   LGD_CRM_ADJUSTED_FLG Numeric(8)
      LABEL = 'LGD Crm Adjusted Flag',
   HOLDING_PERIOD_DAYS  Numeric(8)
      LABEL = 'Holding Period Days',
   HAIRCUT_VALUE        Numeric(8)
      LABEL = 'Haircut Value',
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   REVALUATION_FREQ_DAYS Numeric(8)
      LABEL = 'Revaluation Freq Days',
   RISK_WEIGHT          Numeric(8)
      LABEL = 'Risk Weight',
   IN_DEFAULT_FLG       Numeric(8)
      LABEL = 'In Default Flag',
   INCEPTION_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Inception Date',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   GRACE_PERIOD_DAYS    Numeric(8)
      LABEL = 'Grace Period Days',
   EXPECTED_LOSS_PERCENT Numeric(8)
      LABEL = 'Expected Loss Percent',
   VALUE_AMT            Numeric(8)
      LABEL = 'Value Amount',
   EFFECTIVE_MATURITY_YEAR NUMERIC(8)
      LABEL = 'Effective Maturity Year',
   LGD_PCT              NUMERIC(8)
      LABEL = 'LGD Percent',
   PD_PCT               NUMERIC(8)
      LABEL = 'Pd Percent',
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   CREDIT_ENHANCEMENT_LEVEL NUMERIC(8)
      LABEL = 'Credit Enhancement Level',
   EL_MODEL_ID          VARCHAR(32)
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       VARCHAR(20)
      LABEL = 'El Model Grade',
   HIGH_RISK_CATEGORY_FLG NUMERIC(8)
      FORMAT = BEST12.
      INFORMAT = F12.
      LABEL = 'High Risk Category Flag',      
   DEFAULT_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Default Event Date',
   FIRST_DUE_SETT_DT       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'First Due Settlement Date',
   SECOND_DUE_SETT_DT       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Second Due Settlement Date',
   RESECURITIZATION_FLG    Numeric(8)  
      LABEL = 'Resecuritization Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (ISSUE_KEY)
);



CREATE TABLE &LIBNAME..ISSUE_SEGMENT
(
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Issue Ke',
   BALANCE_AMT          NUMERIC(8)
      LABEL = 'Balance Amount',
   INTEREST_AMT         NUMERIC(8)
      LABEL = 'Interest Amount',
   PAYMENT_PER_ANNUM_NO NUMERIC(8)
      LABEL = 'Payment Per Annum No',
   PAYMENT_AMT          NUMERIC(8)
      LABEL = 'Payment Amount',
   REGULATORY_PRODUCT_CD CHARACTER(3)
      LABEL = 'Regulatory Product Code' NOT NULL ,
   PD_MODEL_ID          CHARACTER(32)
      LABEL = 'Pd Model Id',
   PD_CRM_ADJUSTED_FLG  NUMERIC(8)
      LABEL = 'Pd Crm Adjusted Flag',
   LGD_MODEL_ID         CHARACTER(32)
      LABEL = 'LGD Model Id',
   LGD_CRM_ADJUSTED_FLG NUMERIC(8)
      LABEL = 'LGD Crm Adjusted Flag',
   HOLDING_PERIOD_DAYS  NUMERIC(8)
      LABEL = 'Holding Period Days',
   HAIRCUT_VALUE        NUMERIC(8)
      LABEL = 'Haircut Value',
   HAIRCUT_SET_ID       CHARACTER(32)
      LABEL = 'Haircut Set Id',
   REVALUATION_FREQ_DAYS NUMERIC(8)
      LABEL = 'Revaluation Freq Days',
   RISK_WEIGHT          NUMERIC(8)
      LABEL = 'Risk Weight',
   IN_DEFAULT_FLG       NUMERIC(8)
      LABEL = 'In Default Flag',
   PRODUCT_CD           CHARACTER(5)
      LABEL = 'Product Code',
   SUBPRODUCT_CD        CHARACTER(3)
      LABEL = 'Subproduct Code',
   MATURITY_DATE        NUMERIC(8)
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   GRACE_PERIOD_DAYS    NUMERIC(8)
      LABEL = 'Grace Period Days',
   LEASE_RESIDUAL_VALUE_AMT NUMERIC(8)
      LABEL = 'Lease Residual Value Amount',
   EFFECTIVE_MATURITY_YEAR NUMERIC(8)
      LABEL = 'Effective Maturity Year',
   SEG_LGD_PCT          NUMERIC(8)
      LABEL = 'LGD Percent',
   SEG_PD_PCT           NUMERIC(8)
      LABEL = 'Pd Percent',
   SENIORITY_CD         CHARACTER(3)
      LABEL = 'Seniority Code',
   LGD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'LGD Model Rating Grade',
   PD_MODEL_RATING_GRADE CHARACTER(20)
      LABEL = 'Pd Model Rating Grade',
   EL_MODEL_ID          CHARACTER(32)
      FORMAT = $32.
      INFORMAT = $32.
      LABEL = 'El Model Id',
   EL_MODEL_GRADE       CHARACTER(20)
      FORMAT = $20.
      INFORMAT = $20.
      LABEL = 'El Model Grade',
   SEG_ASSESSMENT_SCORE_NO NUMERIC(8)
      LABEL = 'Assessment Score',
   SEG_ASSESSMENT_AGENCY_NM CHARACTER(100)
      FORMAT = $32.
      LABEL = 'Assessment Agency Name',
   ACCOUNT_LE_TWO_YR_FLG NUMERIC(8)
      LABEL = 'Account Less Than Two Years Flag',
   NUM_EXPOSURES        NUMERIC(8)
      LABEL = 'Number of Exposures in a Segment',
   AVG_AGE_MNTHS        NUMERIC(8)
      LABEL = 'Average Age of an Account in Months',
   SEG_LTV_PCT          NUMERIC(8)
      LABEL = 'LTV Percent',
   LIEN_FLG             NUMERIC(8)
      LABEL = 'First Lien Flag',
   SEG_LTV_UPDATED_FLG  NUMERIC(8)
      LABEL = 'LTV Updated Since Last Assessment of Collateral Flag',
   EML_TRANSACTION_FLG  NUMERIC(8)
      LABEL = 'EML Transaction Flag',
   INCEPTION_DATE       NUMERIC(8)
      LABEL = 'Inception Date',
   LIMIT_AMT            NUMERIC(8)
      LABEL = 'Limit Amount',
   SEG_CCF_PCT          NUMERIC(8)
      LABEL = 'Segment CCF Percent',
   SEG_EL_PCT           NUMERIC(8)
      LABEL = 'Segment EL Percent',

   CONSTRAINT PRIM_KEY PRIMARY KEY (SEGMENT_ID)
);



CREATE TABLE &LIBNAME..NETTING_SET_MART
(
   NETTING_SET_RK       NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Netting Set Key',
   NETTING_SET_ID       CHARACTER(32)
      LABEL = 'Netting Set Id',
   INCEPTION_DATE       DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Inception Date',
   MATURITY_DATE        DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Maturity Date',
   VAR_RT               NUMERIC(8)
      LABEL = 'Var Rate',
   NETTING_SETTLEMENT_CURRENCY CHARACTER(3)
      LABEL = 'Netting Settlement Currency',
   OFF_BS_NETTING_TYPE_CD CHARACTER(3)
      LABEL = 'Off Bs Netting Type Code',
   NOVATION_INSTID      CHARACTER(20)
      LABEL = 'Novation Instid',
   MARGIN_AGREEMENT_BALANCE_AMT NUMERIC(18,5)
      FORMAT = NLNUM18.5
      INFORMAT = NLNUM18.5
      LABEL = 'Margin Agreement Balance Amount',
   MARGIN_AGREEMENT_CURRENCY_CD VARCHAR(3)
      LABEL = 'Margin Agreement Currency Code',
   MARGIN_AGREEMENT_THRESHOLD_AMT NUMERIC(18,5)
      FORMAT = NLNUM18.5
      INFORMAT = NLNUM18.5
      LABEL = 'Margin Agreement Threshold Amount',
   MARGIN_PERIOD_DAYS_CNT NUMERIC(6)
      LABEL = 'Margin Period Days Count',
   MARGIN_AGREEMENT_LEG_ROLE_CD CHARACTER(3)
      LABEL = 'Margin Agreement Leg Role Code',

   CONSTRAINT PRIM_KEY PRIMARY KEY (NETTING_SET_RK)
);



CREATE TABLE &LIBNAME..OP_RISK_CATEGORY
(
   OP_RISK_CATEGORY_CD  VARCHAR(10)
      LABEL = 'OP Risk Category Code',
   PARENT_OP_RISK_CATEGORY_CD VARCHAR(10)
      LABEL = 'Parent OP Risk Category Code',
   OP_RISK_CATEGORY_DESC VARCHAR(100)
      LABEL = 'OP Risk Category Description',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (OP_RISK_CATEGORY_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..OP_RISK_FINANCIAL_DATA
(
   OP_RISK_FINANCIAL_DATA_RK NUMERIC(10)
      LABEL = 'OpRisk Financial Data Key',
   COLUMN_VALUE_TXT     VARCHAR(100)
      LABEL = 'Column Value Text',
   COLUMN_VALUE_NO      NUMERIC(18,5)
      LABEL = 'Column Value Number',
   COLUMN_VALUE_DT      DATE
      LABEL = 'Column Value Date',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   FINANCIAL_REPORTING_PERIOD_RK NUMERIC(10)
      LABEL = 'Financial Reporting Period Key',
   COLUMN_DATA_TYPE_CD  VARCHAR(3)
      LABEL = 'Column Data Type Code',
   OP_RISK_CATEGORY_CD  VARCHAR(10)
      LABEL = 'OpRisk Category Code',
   DATA_ITEM_CD         VARCHAR(10)
      LABEL = '',
   CONSTRAINT PRIM_KEY PRIMARY KEY (OP_RISK_FINANCIAL_DATA_RK)
);



CREATE TABLE &LIBNAME..PROVISIONS
(
   INSTID               CHARACTER(32)
      LABEL = 'Instid',
   PROVISION_TYPE_CD    CHARACTER(3)
      LABEL = 'Provision Type Code',
   PROVISION_AMT        Numeric(8)
      LABEL = 'Provision Amount',
   PROVISION_CURRENCY_CD CHARACTER(3)
      LABEL = 'Provision Currency Code'
);



CREATE TABLE &LIBNAME..QUOTE_COMMODITY
(
   RISK_FACTOR_ID       VARCHAR(32)
      LABEL = 'Risk Factor Id',
   QUOTE_DATE           DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Quote Date',
   ASK                  Numeric(8)
      LABEL = 'Ask',
   BID                  Numeric(8)
      LABEL = 'Bid',
   MID                  Numeric(8)
      LABEL = 'Mid',
   TYPE_CD              VARCHAR(5)
      LABEL = 'Type',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID,QUOTE_DATE)
);



CREATE TABLE &LIBNAME..QUOTE_EQUITIES
(
   BID                  Numeric(8)
      LABEL = 'Bid',
   ASK                  Numeric(8)
      LABEL = 'Ask',
   MID                  Numeric(8)
      LABEL = 'Mid',
   QUOTE_DATE           DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Quote Date',
   RISK_FACTOR_ID       CHARACTER(32)
      LABEL = 'Risk Factor Id',
   ISSUE_CODE           CHARACTER(15)
      LABEL = 'Issue Code',
   ISSUE_DESC           CHARACTER(40)
      LABEL = 'Issue Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID,QUOTE_DATE)
);



CREATE TABLE &LIBNAME..QUOTE_FUNDS
(
   RISK_FACTOR_ID       CHARACTER(32)
      LABEL = 'Risk Factor Id',
   QUOTE_DATE           NUMERIC(8)
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Quote Date',
   BID                  NUMERIC(8)
      LABEL = 'Bid',
   ASK                  NUMERIC(8)
      LABEL = 'Ask',
   MID                  NUMERIC(8)
      LABEL = 'Mid',
   ISSUE_CODE           CHARACTER(15)
      LABEL = 'Issue Code',
   ISSUE_DESC           CHARACTER(40)
      LABEL = 'Issue Description',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID,QUOTE_DATE,ISSUE_CODE)
);



CREATE TABLE &LIBNAME..QUOTE_FX
(
   ASK                  Numeric(8)
      LABEL = 'Ask',
   BID                  Numeric(8)
      LABEL = 'Bid',
   FROM_CUR             VARCHAR(3)
      LABEL = 'From Cur',
   MATURITY_LENGTH      Numeric(8)
      LABEL = 'Maturity Length',
   MATURITY_UNIT        VARCHAR(8)
      LABEL = 'Maturity Unit',
   MID                  Numeric(8)
      LABEL = 'Mid',
   QUOTE_DATE           DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Quote Date',
   RISK_FACTOR_ID       VARCHAR(32)
      LABEL = 'Risk Factor Id',
   TO_CUR               VARCHAR(3)
      FORMAT = $3.
      LABEL = 'To Cur',
   TYPE_CD              VARCHAR(5)
      LABEL = 'Type',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID,QUOTE_DATE)
);



CREATE TABLE &LIBNAME..QUOTE_IR
(
   QUOTE_DATE           DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Quote Date',
   TYPE_CD              VARCHAR(5)
      LABEL = 'Type',
   RISK_FACTOR_ID       VARCHAR(32)
      LABEL = 'Risk Factor Id',
   CURRENCY             VARCHAR(3)
      LABEL = 'Currency',
   MATURITY_LENGTH      Numeric(8)
      LABEL = 'Maturity Length',
   MATURITY_UNIT        VARCHAR(8)
      LABEL = 'Maturity Unit',
   BID                  Numeric(8)
      LABEL = 'Bid',
   ASK                  Numeric(8)
      LABEL = 'Ask',
   MID                  Numeric(8)
      LABEL = 'Mid',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID,QUOTE_DATE)
);



CREATE TABLE &LIBNAME..QUOTE_VOL
(
   QUOTE_DATE           DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Quote Date',
   TYPE_CD              CHARACTER(5)
      LABEL = 'Type',
   RISK_FACTOR_ID       CHARACTER(32)
      LABEL = 'Risk Factor Id',
   BASE_RISK_FACTOR_ID  CHARACTER(32)
      LABEL = 'Base Risk Factor Id',
   BID                  Numeric(8)
      LABEL = 'Bid',
   ASK                  Numeric(8)
      LABEL = 'Ask',
   MID                  Numeric(8)
      LABEL = 'Mid',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID,QUOTE_DATE)
);



CREATE TABLE &LIBNAME..RATING_GRADE
(
   RATING_GRADE         CHARACTER(20)
      LABEL = 'Rating Grade',
   MODEL_ID             CHARACTER(32)
      LABEL = 'Model Id',
   MODEL_TYPE           CHARACTER(3)
      LABEL = 'Model Type',
   RATING_GRADE_AVG_VALUE NUMERIC(8)
      LABEL = 'Rating Grade Average Value',
   RATING_GRADE_MAX_VALUE NUMERIC(8)
      LABEL = 'Rating Grade Max Value',
   RATING_GRADE_MIN_VALUE NUMERIC(8)
      LABEL = 'Rating Grade Min Value',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RATING_GRADE,MODEL_ID,MODEL_TYPE)
);



CREATE TABLE &LIBNAME..REGLTRY_CAPTL_REPORT_CATEGORY
(
   REGLTRY_CAPTL_RPT_CATEGORY_CD VARCHAR(10)
      LABEL = 'Regulatory Capital Report Category Code',
   PARENT_REGLTRY_CAP_RPT_CAT_CD VARCHAR(10)
      LABEL = 'Parent Regulatory Capital Report Category Code',
   REGLTRY_CAPTL_RPT_CAT_DESC VARCHAR(100)
      LABEL = 'Regulatory Capital Report Category Description',
   LANGUAGE_CD          VARCHAR(3)
      LABEL = 'Language Code',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGLTRY_CAPTL_RPT_CATEGORY_CD,LANGUAGE_CD)
);



CREATE TABLE &LIBNAME..REGULATORY_CAPITAL_MART
(
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   TIER_NO              NUMERIC(8)
      LABEL = 'Tier No',
   REGULATORY_CAPITAL_AMT NUMERIC(8)
      LABEL = 'Regulatory Capital Amount',
   CURRENCY_CD          CHARACTER(3)
      LABEL = 'Currency Code'
);



CREATE TABLE &LIBNAME..REGULATORY_CAPITAL_REPORT_DATA
(
   REGLTRY_CAPITAL_REPORT_DATA_RK NUMERIC(10)
      LABEL = 'Regulatory Capital Report Data Key',
   COLUMN_VALUE_TXT     VARCHAR(100)
      LABEL = 'Column Value Text',
   COLUMN_VALUE_NO      NUMERIC(18,5)
      LABEL = 'Column Value Number',
   COLUMN_VALUE_DT      DATE
      LABEL = 'Column Value Date',
   TIER_NO              NUMERIC(4)
      LABEL = 'Tier Number',
   INTERNAL_ORG_RK      Numeric(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Internal Org Key',
   FINANCIAL_REPORTING_PERIOD_RK NUMERIC(10)
      LABEL = 'Financial Reporting Period Key',
   COLUMN_DATA_TYPE_CD  VARCHAR(3)
      LABEL = 'Column Data Type Code',
   REGLTRY_CAPTL_RPT_CATEGORY_CD VARCHAR(10)
      LABEL = 'Regulatory Capital Report Category Code',
   DATA_ITEM_CD         VARCHAR(10)
      LABEL = '',
   CONSTRAINT PRIM_KEY PRIMARY KEY (REGLTRY_CAPITAL_REPORT_DATA_RK)
);



CREATE TABLE &LIBNAME..RISK_FACTOR
(
   RISK_FACTOR_ID       VARCHAR(32)
      LABEL = 'Risk Factor Id',
   MATURITY_LENGTH_OF_TIME_AMT NUMERIC(6,2)
      FORMAT = NLNUM6.2
      INFORMAT = NLNUM6.2
      LABEL = 'Maturity Length Of Time Amount',
   MATURITY_TIME_UOM_CD VARCHAR(3)
      FORMAT = $8.
      INFORMAT = $8.
      LABEL = 'Maturity Time UOM Code',
   CURRENCY_CD          CHARACTER(3)
      FORMAT = $3.
      LABEL = 'Currency Code',
   HEDGING_SET_RK       NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Hedging Set Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_FACTOR_ID)
);



CREATE TABLE &LIBNAME..RISK_POSITION
(
   RISK_POSITION_ID     VARCHAR(32)
      LABEL = 'Risk Position Id',
   ISSUE_KEY            CHARACTER(32)
      LABEL = 'Issue Key',
   RISK_COMPONENT_AMT   NUMERIC(18,5)
      FORMAT = NLNUM18.5
      INFORMAT = NLNUM18.5
      LABEL = 'Risk Component Amount',
   RISK_COMPONENT_CURRENCY_CD VARCHAR(3)
      LABEL = 'Risk Component Currency Code',
   RISK_FACTOR_ID       VARCHAR(32)
      LABEL = 'Risk Factor Id',
   CALCULATION_FLG      NUMERIC(8)
      LABEL = 'Calculation Flag',
   HEDGING_SET_RK       NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Hedging Set Key',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RISK_POSITION_ID)
);



CREATE TABLE &LIBNAME..SECURITIZATION_POOL_MART
(
   SECURITIZATION_POOL_RK NUMERIC(8)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Securitization Pool Key',
   AVG_THREE_MONTH_EXCESS_SPREAD NUMERIC(8)
      LABEL = 'Average Three Month Excess Spread',
   CLEAN_UP_CALL_HOLDER_FLG NUMERIC(8)
      LABEL = 'Clean Up Call Holder Flag',
   CLEAN_UP_CALL_LEVEL  NUMERIC(8)
      LABEL = 'Clean Up Call Level',
   CLEAN_UP_CALL_TYPE_CD CHARACTER(3)
      LABEL = 'Clean Up Call Type Code',
   COMM_OTHER_REVOLV_FACE_AMT NUMERIC(8)
      LABEL = 'Comm Other Revolv Face Amount',
   COMM_RETAIL_REVOLV_FACE_AMT NUMERIC(8)
      LABEL = 'Comm Retail Revolv Face Amount',
   EARLY_AMORTIZATION_TYPE_CD CHARACTER(3)
      LABEL = 'Early Amortization Type Code',
   EFFECTIVE_NUMBER_OF_EXPOSURES NUMERIC(8)
      LABEL = 'Effective Number Of Exposures',
   EXCESS_SPREAD_TRAPPING_POINT NUMERIC(8)
      LABEL = 'Excess Spread Trapping Point',
   GAIN_ON_SALE_AMT     NUMERIC(8)
      LABEL = 'Gain On Sale Amount',
   IMPLICIT_SUPPORT_FLG NUMERIC(8)
      LABEL = 'Implicit Support Flag',
   LONGEST_MATURITY_DATE DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'Longest Maturity Date',
   POOL_FACE_VALUE_AMT  NUMERIC(8)
      LABEL = 'Pool Face Value Amount',
   PRIMARY_BANK_ROLE_CD CHARACTER(3)
      LABEL = 'Primary Bank Role Code',
   SECURITIZATION_POOL_ID CHARACTER(32)
      LABEL = 'Securitization Pool Id',
   SECURITIZ_STRUC_SUBTYPE_CD CHARACTER(3)
      LABEL = 'Securitiz Struc Subtype Code',
   SECURITIZ_STRUC_TYPE_CD CHARACTER(3)
      LABEL = 'Securitiz Struc Type Code',
   UNCOMM_OTHER_REVOLV_FACE_AMT NUMERIC(8)
      LABEL = 'Uncomm Other Revolv Face Amount',
   UNCOMM_RETAIL_REVOLV_FACE_AMT NUMERIC(8)
      LABEL = 'Uncomm Retail Revolv Face Amount',
   WA_MATURITY_MONTHS   NUMERIC(8)
      LABEL = 'Weighted Average Maturity Month',
   WEIGHTED_AVG_LGD_PCT NUMERIC(8)
      LABEL = 'Weighted Average LGD Percent',
   MAX_RISK_WEIGHT      NUMERIC(8)
      LABEL = 'Max Risk Weight',
   MIN_RISK_WEIGHT      NUMERIC(8)
      LABEL = 'Min Risk Weight',
   AVG_RISK_WEIGHT      NUMERIC(8)
      LABEL = 'Average Risk Weight',
   K_IRB                NUMERIC(8)
      LABEL = 'K Irb',
   TOTAL_TRANCHE        NUMERIC(8)
      LABEL = 'Total Tranche',
   INVESTORS_INTEREST_PCT NUMERIC(8)
      LABEL = 'Investors Interest Percent',
   CRDT_ENHNC_INT_ONLY_STRIP_AMT NUMERIC(8)
      LABEL = 'Crdt Enhnc Int Only Strip Amount',
   UNDERLYING_EXPOSURE_CNT NUMERIC(8)
      LABEL = '',
   UNDERLYING_EXPOSURE_TYPE CHARACTER(32)
      LABEL = '',
   ACCTING_TREATMENT_CD CHARACTER(3)
     LABEL = 'Accounting Treatment Code',
   FINANCIAL_BOOK_TYPE_CD  CHARACTER(16)
     LABEL = 'Financial Book Type Code',
   INSTITUTION_SHARE_PCT  NUMERIC(8)
     LABEL = 'Institution Share Percent',
   RETENTION_TYPE_CD   CHARACTER(16)
     LABEL = 'Retention Type Code',
   SEC_PORTFOLIO_TYPE_CD   CHARACTER(16)
     LABEL = 'Securitization Portfolio Type Code',
   SEC_RETENTION_COMPLIANCE_FLG   NUMERIC(8)
     LABEL = 'Retention Compliance Flag',
   SEC_RETENTION_PCT   NUMERIC(8)
     LABEL = 'Securitization Retention Percent',
   ORIGINATION_COUNTRY_CD  CHARACTER(3)
     LABEL = 'Origination Country Code',
   FIRST_POSSIBLE_TERM_DT   DATE
      FORMAT = NLDATE.
      INFORMAT = NLDATE.
      LABEL = 'First Possible Termination Date',
   CONSTRAINT PRIM_KEY PRIMARY KEY (SECURITIZATION_POOL_RK)
);



CREATE TABLE &LIBNAME..SEGMENT_MART
(
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Segment Id',
   SEG_PD_PCT           NUMERIC(8)
      LABEL = 'Segment PD Percent',
   SEG_LGD_PCT          NUMERIC(8)
      LABEL = 'Segment LGD Percent',
   SEG_CCF_PCT          NUMERIC(8)
      LABEL = 'Segment CCF Percent',
   SEG_EL_PCT           NUMERIC(8)
      LABEL = 'Segment EL Percent',
   SEG_LTV_PCT          NUMERIC(8)
      LABEL = 'Segment LTV Percent',
   SEG_LTV_UPDATED_FLG  NUMERIC(8)
      LABEL = 'Segment LTV Updated Flag',
   CONSTRAINT PRIM_KEY PRIMARY KEY (SEGMENT_ID)
);



CREATE TABLE &LIBNAME..SEGMENT_RATINGS
(
   RATING_AGENCY_CD     CHARACTER(5)
      LABEL = 'Assessment Agency Code',
   SEGMENT_ID           CHARACTER(32)
      LABEL = 'Segment ID',
   SEG_ASSESSMENT_SCORE_NO NUMERIC(8)
      LABEL = 'Segment Assessment Score Number',
   SEG_ASSESSMENT_AGENCY_NM CHARACTER(100)
      LABEL = 'Segment Assessment Agency Name',
   RATING_GRADE         CHARACTER(20)
      LABEL = 'Rating Grade',
   CONSTRAINT PRIM_KEY PRIMARY KEY (RATING_AGENCY_CD,SEGMENT_ID)
);



CREATE TABLE &LIBNAME..SIMULATION_MODEL
(
   MODEL_RK             NUMERIC(10)
      FORMAT = 12.
      INFORMAT = 12.
      LABEL = 'Model Key',
   MODEL_NM             VARCHAR(40)
      LABEL = 'Model Name',
   MODEL_PACKAGE_LIBREF_NM CHARACTER(40)
      LABEL = 'Model Package Libref Name',
   MODEL_PACKAGE_NM     VARCHAR(40)
      LABEL = 'Model Package Name',
   CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_RK)
);



QUIT;
