/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a00_get_config_sets_crd4.sas
 *
 * PURPOSE: Gets configuration set and prepares parameters
 *
 *   USAGE: 
 *
 *   NOTES: The &CONFIG_SET macro variable must be pre-set.
 *
 *          
 *
 *****************************************************************************/
%macro a00_get_config_sets_crd4;
 
%global ADD_ON_SET CCF_SET CCF_SET_EAP HAIRCUT_SET HAIRCUT_FX_SET REPORT_CCY 
REGULATORY_OPTION_SET REGULATORY_PARM_SET REGULATORY_RW_SET LGD_SET_IRB_COLLATERAL
LE_CAP_MULT_SET; 

/*- clean up RD_CONF -*/
%clean_lib(lib=RD_CONF);
%macro get_config_set;
/*- get the active configuration set -*/
data RD_CONF.configuration;
set RD_STAT.configuration(where = (CONFIGURATION_ID = "&CONFIG_SET"));  
run;
 
/*- 1: create macro variables for configuration sets -*/
data _null_;
set RD_CONF.configuration;      
/*- regulatory add-on set -*/
call symput("ADD_ON_SET", trim(ADD_ON_SET_ID));
/*- regulatory CCF set -*/
call symput("CCF_SET", trim(CCF_SET_ID));
/*- regulatory ccf set for securitization exposures with early amortization provisions -*/
call symput("CCF_SET_EAP", trim(CCF_EAP_SET_ID));
/*- regulatory haircut set -*/
call symput("HAIRCUT_SET", trim(HAIRCUT_SET_ID));
/*- fx haircut set -*/
call symput("HAIRCUT_FX_SET", trim(HAIRCUT_FX_SET_ID));
/*- regulatory options set -*/
call symput("REGULATORY_OPTION_SET", trim(REGULATORY_OPTION_SET_ID));
/*- regulatory parameters set -*/
call symput("REGULATORY_PARM_SET", trim(REGULATORY_PARAMETER_SET_ID));
/*- regulatory risk weights set -*/
call symput("REGULATORY_RW_SET", trim(REGULATORY_RISK_WEIGHT_SET_ID));
/*- regulatory PD set -*/
call symput("REGULATORY_PD_SET", trim(REGULATORY_PD_SET_ID));
/*- regulatory LGD set -*/
call symput("REGULATORY_LGD_SET", trim(REGULATORY_LGD_SET_ID));
/*- minimum LGD/minimum collateralization level/over-collateralization level for IRB collateral -*/
call symput("LGD_SET_IRB_COLLATERAL", trim(MINIMUM_LGD_SET_ID));
/*- currency -*/
/*call symput("REPORT_CCY", CURRENCY);*/
/*- Large exposure capital charge multipler -*/
call symput("LE_CAP_MULT_SET", trim(LE_CAP_MULT_SET_ID));
run;

/* currency column moved from CONFIGURATION dataset to new cross ENTITY_X_CONFIGURATION dataset*/

data rd_conf.ENTITY_X_CONFIGURATION;
set rd_stat.ENTITY_X_CONFIGURATION;
where CONFIGURATION_ID = "&CONFIG_SET" and INTERNAL_ORG_RK=%trim(%left(&SYSTEM_ORG_RK));  
run;

data _null_;
set rd_conf.ENTITY_X_CONFIGURATION;
call symput("REPORT_CCY", CURRENCY);
run;


/*- get large exposure capital multipler tables -*/

data RD_CONF.map_le_cap_mult_g_10 ;
set RD_STAT.le_cap_mult;
where LE_CAP_MULT_SET_ID = "&CONFIG_SET" and  LE_CAP_MULT_SET_TYPE_CD= 'DAYS_BREACH_G_10';
run; 


data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_le_cap_mult_g_10 end=lastobs;
FMTNAME          = 'MAP_LE_CAP_CHARGE_G_TEN' ;
START            = LE_EXCESS_MIN_PCT ;
END              = LE_EXCESS_MAX_PCT;
LABEL            = LE_CAP_MULTIPLIER_RT;
TYPE             = 'N' ;
if lastobs then do;
    HLO='O' ;
end;
output ;
RUN;

proc format cntlin=fmt lib=RD_ENV; run;


data RD_CONF.map_le_cap_mult_leq_10 ;
set RD_STAT.le_cap_mult;
where LE_CAP_MULT_SET_ID = "&CONFIG_SET" and  LE_CAP_MULT_SET_TYPE_CD= 'DAYS_BREACH_LEQ_10';
run; 


data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_le_cap_mult_leq_10 end=lastobs;
FMTNAME          = 'MAP_LE_CAP_CHARGE_LEQ_TEN' ;
START            = LE_EXCESS_MIN_PCT ;
END              = LE_EXCESS_MAX_PCT;
LABEL            = LE_CAP_MULTIPLIER_RT;
TYPE             = 'N' ;
if lastobs then do;
    HLO='O' ;
end;
output ;

RUN;

proc format cntlin=fmt lib=RD_ENV; run;


/*- 2: get add-on tables -*/       

/*- format for add-on set type mapping -*/
data RD_CONF.map_add_on_set_type(drop = VALID_FROM_DTTM VALID_TO_DTTM);
set RD_MAP.map_add_on_set_type;
where (&RUNDATETIME between VALID_FROM_DTTM and VALID_TO_DTTM);
run;

data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_add_on_set_type end=lastobs;
FMTNAME          = 'MAP_ADDON_SET_TYPE' ;
START            = ADD_ON_SET_TYPE_CD ;
END              = START;
LABEL            = ADD_ON_SET_TYPE;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- current exposure method -*/

/*-  maturity band mapping table -*/
data RD_CONF.maturity_band;
set RD_STAT.maturity_band; 
where upcase(LANGUAGE_CD) = upcase("&REPORTING_LANGUAGE");
run;

/*- switch to english if empty -*/
%if %attrn(RD_CONF.maturity_band, NOBS)=0 %then %do;
data RD_CONF.maturity_band;
set RD_STAT.maturity_band; 
where upcase(LANGUAGE_CD) = "EN";
run;
%end;

proc sql;
creatE table RD_CONF.map_addon_mat_band_ce as 
select unique
       a.MATURITY_BAND_YEAR_MIN as ADDON_MAT_START,
       a.MATURITY_BAND_YEAR_MAX as ADDON_MAT_END,
       a.MATURITY_BAND_CD as ADDON_MAT_BAND
from RD_CONF.maturity_band as a, RD_STAT.add_on as b
where a.MATURITY_BAND_CD = b.MATURITY_BAND_CD and put(b.ADD_ON_SET_TYPE_CD, $MAP_ADDON_SET_TYPE.) = 'CURRENT'
order by a.MATURITY_BAND_YEAR_MAX;;
quit;         

/*- add-on table under Current Exposure method -*/
data RD_CONF.regulatory_add_ons_ce (keep=ADD_ON_SET_ID ADDON_NAME ADDON_VALUE rename=(ADDON_NAME=_NAME_));
set RD_STAT.add_on(rename = (ADD_ON_PCT = ADDON_VALUE));
where ADD_ON_SET_ID = "&ADD_ON_SET" and put(ADD_ON_SET_TYPE_CD, $MAP_ADDON_SET_TYPE.) = 'CURRENT';
ADDON_NAME = compress('ADDON_CE_' || ADD_ON_NM || '_' || MATURITY_BAND_CD);
run;   
    
/*- original exposure method -*/

/*-  maturity band mapping table -*/
proc sql;
creatE table RD_CONF.map_addon_mat_band_oe as 
select unique
       a.MATURITY_BAND_YEAR_MIN as ADDON_MAT_START,
       a.MATURITY_BAND_YEAR_MAX as ADDON_MAT_END,
       a.MATURITY_BAND_CD as ADDON_MAT_BAND
from RD_CONF.maturity_band as a, RD_STAT.add_on as b
where a.MATURITY_BAND_CD = b.MATURITY_BAND_CD and put(b.ADD_ON_SET_TYPE_CD, $MAP_ADDON_SET_TYPE.) = 'ORIGINAL'
order by a.MATURITY_BAND_YEAR_MAX;
quit;         

/*- add-on table under Original Exposure method -*/
data RD_CONF.regulatory_add_ons_oe (keep=ADD_ON_SET_ID ADD_ON_NM ADDON_NAME ADDON_VALUE MATURITY_BAND_CD);
set RD_STAT.add_on(rename = (ADD_ON_PCT = ADDON_VALUE));
where ADD_ON_SET_ID = "&ADD_ON_SET" and put(ADD_ON_SET_TYPE_CD, $MAP_ADDON_SET_TYPE.) = 'ORIGINAL';
ADDON_NAME = compress('ADDON_OE_' || ADD_ON_NM || '_' || MATURITY_BAND_CD);
run;   

proc sort data = RD_CONF.regulatory_add_ons_oe;
by MATURITY_BAND_CD;
run;

/*- find the order of each maturity band code -*/
proc sort data = RD_CONF.map_addon_mat_band_oe(rename=(ADDON_MAT_BAND=MATURITY_BAND_CD)) nodup
          out = _band_order_(keep = MATURITY_BAND_CD ADDON_MAT_START);
by ADDON_MAT_START;
run;

/*- the add-on value for the last maturity band is that for each increment beyond the next to last maturity cutoff -*/
%global NUM_ADDON_OE_BANDS;
%global MAX_MAT_CUTOFF_IN_YR_ADDON_OE;
data _band_order_(drop = ADDON_MAT_START);
set _band_order_ end = last;
ADD_ON_VALUE_NAME = compress('ADDON_VALUE_' || _N_);
if last then do;
    call symput('NUM_ADDON_OE_BANDS', left(_N_));
    call symput('MAX_MAT_CUTOFF_IN_YR_ADDON_OE', ADDON_MAT_START);
end;
run;

data RD_CONF.regulatory_add_ons_oe;
merge RD_CONF.regulatory_add_ons_oe _band_order_;
by MATURITY_BAND_CD;
run;

proc sort data = RD_CONF.regulatory_add_ons_oe;
by ADD_ON_SET_ID ADD_ON_NM MATURITY_BAND_CD;
run;

proc transpose data = RD_CONF.regulatory_add_ons_oe out = _add_ons_oe_;
var ADDON_VALUE;
id ADD_ON_VALUE_NAME;
by ADD_ON_SET_ID ADD_ON_NM;
run;

data RD_CONF.regulatory_add_ons_oe;
merge RD_CONF.regulatory_add_ons_oe _add_ons_oe_;
by ADD_ON_SET_ID ADD_ON_NM;
run;

data RD_CONF.regulatory_add_ons_oe(keep=ADD_ON_SET_ID ADDON_NAME ADDON_VALUE_: rename=(ADDON_NAME=_NAME_));
set RD_CONF.regulatory_add_ons_oe;
array ADD_ON ADDON_VALUE_1 - ADDON_VALUE_&NUM_ADDON_OE_BANDS ;
/*- find the index in the array of current band -*/
NUM = scan(ADD_ON_VALUE_NAME, 3, '_');
/*- for the last band, the value is that for each additional year beyond the band immediately before -*/
/*- so it needs to know the add-on value for the previous maturity band -*/
if NUM = &NUM_ADDON_OE_BANDS then do;
    do i= 1 to &NUM_ADDON_OE_BANDS;
        if i < NUM-1 then ADD_ON[i]=0;
    end;
end;
else do;
    do i=1 to &NUM_ADDON_OE_BANDS;
        if i NE NUM then ADD_ON[i]=0;
    end;
end;
run;

/*- 3: get CCF table -*/

/*- regulatory CCFs -*/
data RD_CONF.ccfs;
set RD_STAT.ccf(where = (CCF_SET_ID = "&CCF_SET") rename = (CCF_PCT = CCF_VALUE));
CCF_NAME = upcase(CCF_NM);
run;
    
/*- regulatory CCFs plus CCF for securitization exposures with early amortization provisions -*/    
data RD_CONF.ccf_eap;
set RD_STAT.ccf_eap(where  = (CCF_SET_ID = "&CCF_SET_EAP") 
                    rename = (CCF_EAP_SET_ID = CCF_SET_ID CCF_NM = CCF_NAME CCF_PCT = CCF_VALUE)
                    )
    ;
run;


/*- ccf bucket mapping for securitization exposures with early amortization provisions -*/
proc sql;
create table RD_CONF.map_ccf_sec_eap_bucket as
select a.EXCESS_BAND_MIN as ES_TO_TP_START,
       a.EXCESS_BAND_MAX as ES_TO_TP_END,
       a.EXCESS_SPREAD_BAND_CD  as CCF_BUCKET_SEC_EAP
from RD_STAT.excess_spread_band (where=(upcase(LANGUAGE_CD) = upcase("&REPORTING_LANGUAGE"))) as a
where a.EXCESS_SPREAD_BAND_CD in (select EXCESS_SPREAD_BAND_CD from RD_STAT.ccf_eap as b
                                  where CCF_EAP_SET_ID = "&CCF_SET_EAP")
order by a.EXCESS_BAND_MAX;
quit;

%if %attrn(RD_CONF.map_ccf_sec_eap_bucket, NOBS)=0 %then %do;
proc sql;
create table RD_CONF.map_ccf_sec_eap_bucket as
select a.EXCESS_BAND_MIN as ES_TO_TP_START,
       a.EXCESS_BAND_MAX as ES_TO_TP_END,
       a.EXCESS_SPREAD_BAND_CD  as CCF_BUCKET_SEC_EAP
from RD_STAT.excess_spread_band (where=(upcase(LANGUAGE_CD) = "EN")) as a
where a.EXCESS_SPREAD_BAND_CD in (select EXCESS_SPREAD_BAND_CD from RD_STAT.ccf_eap as b
                                  where CCF_EAP_SET_ID = "&CCF_SET_EAP")
order by a.EXCESS_BAND_MAX;
quit;
%end;

/*- all own estimated CCFs -*/
proc sql;
create table _ccfs_own_ as
select a.CCF_SET_ID, upcase(a.CCF_NM) as CCF_NAME, a.CCF_PCT as CCF_VALUE, a.SHORT_MATURITY_FLG
from RD_STAT.ccf as a
where a.CCF_SET_ID in (select CCF_SET_ID from RD_STAT.ccf_set as b
                       where b.ESTIMATION_MODEL_RK NE .
                      )
;
quit;

data RD_CONF.ccfs;
set RD_CONF.ccfs
    _ccfs_own_
    ;
run;

/*- need to create CCF_SET_INDEX -*/
proc sort data = RD_CONF.ccfs;by CCF_SET_ID;run;

data RD_CONF.ccfs;
set RD_CONF.ccfs;
by CCF_SET_ID;
retain CCF_SET_INDEX 0;
if first.CCF_SET_ID then CCF_SET_INDEX=CCF_SET_INDEX+1;
run;

/*- 4: get haircut table -*/    
/*- regulatory -*/

/*- HAIRCUT_FX set -*/
data RD_CONF.haircut_fx (keep=EXP_CURRENCY_CD CRM_CURRENCY_CD HAIRCUT_FX_PCT MIN_HOLDING_PERIOD_DAYS_CNT
                         rename = (MIN_HOLDING_PERIOD_DAYS_CNT=HOLDING_PERIOD_DAYS) );
set RD_STAT.haircut_fx (where= (HAIRCUT_FX_SET_ID = "&HAIRCUT_FX_SET"));
run;

/*- other haircuts -*/
data RD_CONF.haircuts;
set RD_STAT.haircut(where = (HAIRCUT_SET_ID = "&HAIRCUT_SET"));
run;

/*- all own estimates of haircuts -*/
proc sql;
create table _haircuts_own_ as
select * 
from RD_STAT.haircut as a
where a.HAIRCUT_SET_ID in (select HAIRCUT_SET_ID from RD_STAT.haircut_set as b
                           where b.ESTIMATION_MODEL_RK NE .
                          )
;
quit;

/*- all haircuts -*/
data RD_CONF.haircuts
     (keep = HAIRCUT_SET_ID HAIRCUT_NAME HAIRCUT_NM HAIRCUT_PCT HAIRCUT_SOV_PCT MIN_HOLDING_PERIOD_DAYS_CNT 
             REMARGIN_PERIOD_DAYS_CNT MATURITY_BAND_CD RATING_GRADE_BAND_CD
      rename = (HAIRCUT_NM = HAIRCUT_TYPE
                HAIRCUT_PCT = HAIRCUT_OTHER HAIRCUT_SOV_PCT = HAIRCUT_SOVEREIGN
                MIN_HOLDING_PERIOD_DAYS_CNT = HOLDING_PERIOD_DAYS 
                REMARGIN_PERIOD_DAYS_CNT = REVALUATION_FREQ_DAYS
               )
     );

length HAIRCUT_NAME $32.;

set RD_CONF.haircuts
    _haircuts_own_
    ;
  
HAIRCUT_NAME = compress('H_' || HAIRCUT_NM || '_' || RATING_GRADE_BAND_CD || '_' || MATURITY_BAND_CD);

run;

/*- need to get HAIRCUT_SET_INDEX -*/
proc sort data = RD_CONF.haircuts;by HAIRCUT_SET_ID;run;

data RD_CONF.haircuts;
set RD_CONF.haircuts;
by HAIRCUT_SET_ID;
retain HAIRCUT_SET_INDEX 0;
if first.HAIRCUT_SET_ID then HAIRCUT_SET_INDEX=HAIRCUT_SET_INDEX + 1;
run;

/*- haircut maturity band mapping table -*/
proc sql;
create table RD_CONF.map_haircut_mat_bands as
select unique
       b.HAIRCUT_SET_ID as HAIRCUT_SET_ID,
       b.HAIRCUT_TYPE  as HAIRCUT_TYPE,
       a.MATURITY_BAND_YEAR_MIN as HAIRCUT_MAT_START,
       a.MATURITY_BAND_YEAR_MAX as HAIRCUT_MAT_END,
       a.MATURITY_BAND_CD as HAIRCUT_MAT_BAND
from RD_CONF.maturity_band as a, RD_CONF.haircuts as b
where a.MATURITY_BAND_CD = b.MATURITY_BAND_CD 
order by HAIRCUT_MAT_END;
quit;
      
/*- haircut rating grade bucket mapping table -*/
proc sql;
create table RD_CONF.map_haircut_rating_buckets as 
select unique
       b.HAIRCUT_SET_ID as HAIRCUT_SET_ID,
       b.HAIRCUT_TYPE  as HAIRCUT_TYPE,       
       a.ASSESSMENT_RATING_GRADE_MIN_RK as BAND_MIN_GRADE_RK,
       a.ASSESSMENT_RATING_GRADE_MAX_RK as BAND_MAX_GRADE_RK,
       a.RATING_GRADE_BAND_CD as HAIRCUT_RATING_BUCKET
from RD_STAT.rating_grade_band (where=(upcase(LANGUAGE_CD) = upcase("&REPORTING_LANGUAGE"))) as a, 
     RD_CONF.haircuts as b
where a.RATING_GRADE_BAND_CD = b.RATING_GRADE_BAND_CD;
quit;    

%if %attrn(RD_CONF.map_haircut_rating_buckets, NOBS)=0 %then %do;
proc sql;
create table RD_CONF.map_haircut_rating_buckets as 
select unique
       b.HAIRCUT_SET_ID as HAIRCUT_SET_ID,
       b.HAIRCUT_TYPE  as HAIRCUT_TYPE,       
       a.ASSESSMENT_RATING_GRADE_MIN_RK as BAND_MIN_GRADE_RK,
       a.ASSESSMENT_RATING_GRADE_MAX_RK as BAND_MAX_GRADE_RK,
       a.RATING_GRADE_BAND_CD as HAIRCUT_RATING_BUCKET
from RD_STAT.rating_grade_band (where=(upcase(LANGUAGE_CD) = "EN")) as a, 
     RD_CONF.haircuts as b
where a.RATING_GRADE_BAND_CD = b.RATING_GRADE_BAND_CD;
quit;    
%end;

data RD_CONF.map_haircut_rating_buckets;
set RD_CONF.map_haircut_rating_buckets;
length RATING_AGENCY $5.;
length BUCKET_MIN_GRADE BUCKET_MAX_GRADE $20.;
RATING_AGENCY = '';
SHORT_TERM_FLG = 0;
BUCKET_MIN_GRADE = '';
BUCKET_MAX_GRADE = '';
run;

/*- get rating grades and agency -*/
/*- The end grades in a rating bucket must come from the same rating agency -*/
proc sql;
update RD_CONF.map_haircut_rating_buckets as a
set RATING_AGENCY = (select ASSESSMENT_AGENCY from RD_STAT.assessment_rating_grade as b
                     where a.BAND_MIN_GRADE_RK = b.ASSESSMENT_RATING_GRADE_RK
                    ),
                    
    SHORT_TERM_FLG = (select SHORTTERM_FLG from RD_STAT.assessment_rating_grade as b
                      where a.BAND_MIN_GRADE_RK = b.ASSESSMENT_RATING_GRADE_RK
                     ),                    

    BUCKET_MIN_GRADE = (select ASSESSMENT_GRADE from RD_STAT.assessment_rating_grade as b
                        where a.BAND_MIN_GRADE_RK = b.ASSESSMENT_RATING_GRADE_RK
                       ),                    

    BUCKET_MAX_GRADE = (select ASSESSMENT_GRADE from RD_STAT.assessment_rating_grade as b
                        where a.BAND_MAX_GRADE_RK = b.ASSESSMENT_RATING_GRADE_RK
                       )                        
;
quit;

data RD_CONF.map_haircut_rating_buckets
     (keep = HAIRCUT_SET_ID HAIRCUT_TYPE RATING_AGENCY BUCKET_MIN_GRADE BUCKET_MAX_GRADE SHORT_TERM_FLG HAIRCUT_RATING_BUCKET);
set RD_CONF.map_haircut_rating_buckets;
run;

data RD_CONF.haircuts(rename = (MATURITY_BAND_CD = HAIRCUT_MAT_BAND RATING_GRADE_BAND_CD = HAIRCUT_RATING_BUCKET));
set RD_CONF.haircuts;
run;

/*- 5: get regulatory option set -*/
data RD_CONF.regulatory_options (keep=OPTION_NAME OPTION_VALUE OPTION_DESC);
set RD_STAT.regulatory_option
    (where  = (REGULATORY_OPTION_SET_ID = "&REGULATORY_OPTION_SET")
     rename = (REGULATORY_OPTION_NM = OPTION_NAME)
    );
run;
    
/*- 6: get regulatory parameter set -*/
data RD_CONF.regulatory_parms(keep=PARAMETER_NAME PARAMETER_VALUE REGULATORY_PARAMETER_DESC PARAMETER_CURRENCY_CD);
set RD_STAT.regulatory_parameter
    (where  = (REGULATORY_PARAMETER_SET_ID = "&REGULATORY_PARM_SET") 
     rename = (REGULATORY_PARAMETER_NM = PARAMETER_NAME)
    );
run;
      
/*- 7: get regulatory risk weight set -*/
data RD_CONF.regulatory_rw(keep=RW_NAME RW_VALUE);                          
set RD_STAT.regulatory_risk_weight
    (where  = (REGULATORY_RISK_WEIGHT_SET_ID = "&REGULATORY_RW_SET")
     rename = (REGULATORY_RISK_WEIGHT_NM = RW_NAME RISK_WEIGHT_PCT = RW_VALUE)
    );
run;

/*- 8: get regulatory pd, LGD sets -*/
data RD_CONF.regulatory_pd(keep=PD_NAME PD_VALUE);
set RD_STAT.regulatory_pd
    (where = (REGULATORY_PD_SET_ID = "&REGULATORY_PD_SET")
     rename = (REGULATORY_PD_NM = PD_NAME PD_PCT = PD_VALUE)
    );
run;

data RD_CONF.regulatory_lgd(keep=LGD_NAME LGD_VALUE);
set RD_STAT.regulatory_lgd
    (where = (REGULATORY_LGD_SET_ID = "&REGULATORY_LGD_SET")
     rename = (REGULATORY_LGD_NM = LGD_NAME LGD_PCT = LGD_VALUE)
    );
run;

/*- 9: IRB collateral info -*/
data _irb_coll_ 
     _lgd_irb_coll_(keep=LGD_PCT)
     _level_irb_coll_(keep=MINIMUM_COLLATERAL_LEVEL_PCT)
     _overlevel_irb_coll_(keep=OVER_COLLATERAL_LEVEL_PCT)
     ;
set RD_STAT.minimum_lgd_irb_collateral;
where MINIMUM_LGD_SET_ID = "&LGD_SET_IRB_COLLATERAL";
run;

proc sort data=_lgd_irb_coll_ nodup;by LGD_PCT;run;
proc sort data=_level_irb_coll_ nodup;by MINIMUM_COLLATERAL_LEVEL_PCT;run;
proc sort data=_overlevel_irb_coll_ nodup;by OVER_COLLATERAL_LEVEL_PCT;run;

/*- parameter tables -*/
data min_lgd_irb_coll;
length LGD_NAME $40.;
set _lgd_irb_coll_(rename=(LGD_PCT=LGD_IRB_COLLATERAL));
LGD_NAME = compress('LGD_BUCKET' || _N_ || '_IRB_COLLATERAL');
run;

data RD_CONF.min_level_irb_coll;
length LEVEL_NAME $32.;
set _level_irb_coll_(rename=(MINIMUM_COLLATERAL_LEVEL_PCT=COLLATERAL_LEVEL));
LEVEL_NAME = compress('LEVEL_BUCKET' || _N_ || '_IRB_COLLATERAL');
run;

data RD_CONF.over_level_irb_coll;
length LEVEL_NAME $32.;
set _overlevel_irb_coll_(rename=(OVER_COLLATERAL_LEVEL_PCT=OVER_COLLATERAL_LEVEL));
LEVEL_NAME = compress('OLEVEL_BUCKET' || _N_ || '_IRB_COLLATERAL');
run;

/*- add min LGD to regulatory LGD table -*/
proc append base=RD_CONF.regulatory_lgd data=min_lgd_irb_coll(rename=(LGD_IRB_COLLATERAL=LGD_VALUE)) force;run;

/*- bucket mapping -*/
proc sql;

create table RD_CONF.map_min_lgd_irb_coll as
select a.SENIORITY_CD, a.CRM_TYPE_CD, 
       scan(b.LGD_NAME, 2, '_') as MIN_LGD_BUCKET length=8
from _irb_coll_ as a,  min_lgd_irb_coll as b
where a.LGD_PCT = b.LGD_IRB_COLLATERAL;

create table RD_CONF.map_min_level_irb_coll as
select a.SENIORITY_CD, a.CRM_TYPE_CD, 
       scan(b.LEVEL_NAME, 2, '_') as MIN_COLL_LEVEL_BUCKET length=8
from _irb_coll_ as a, RD_CONF.min_level_irb_coll as b
where a.MINIMUM_COLLATERAL_LEVEL_PCT = b.COLLATERAL_LEVEL;

create table RD_CONF.map_over_level_irb_coll as
select a.SENIORITY_CD, a.CRM_TYPE_CD, 
       scan(b.LEVEL_NAME, 2, '_') as OVER_COLL_LEVEL_BUCKET length=8
from _irb_coll_ as a, RD_CONF.over_level_irb_coll as b
where a.OVER_COLLATERAL_LEVEL_PCT = b.OVER_COLLATERAL_LEVEL;

quit;

/*- 10: hedging set maturity band -*/
data RD_CONF.hedging_set_type_x_mat_band;
set RD_STAT.hedging_set_type_x_mat_band; 
where CONFIGURATION_ID = "&CONFIG_SET" and upcase(LANGUAGE_CD) = upcase("&REPORTING_LANGUAGE"); 
run;    

%if %attrn(RD_CONF.hedging_set_type_x_mat_band, NOBS)=0 %then %do;
data RD_CONF.hedging_set_type_x_mat_band;
set RD_STAT.hedging_set_type_x_mat_band; 
where CONFIGURATION_ID = "&CONFIG_SET" and upcase(LANGUAGE_CD) = "EN"; 
run;  
%end;

proc sort data=RD_CONF.hedging_set_type_x_mat_band 
          out = hedging_set_mat_band nodupkey;
by MATURITY_BAND_CD;
run;

data hedging_set_mat_band (keep=MATURITY_BAND_CD BAND_NM);
set hedging_set_mat_band;
BAND_NM = compress("HEDGE"||_N_);
run;

proc sort data=RD_CONF.maturity_band out=maturity_band nodupkey;
by MATURITY_BAND_CD;
run;

data RD_CONF.map_hedging_set_mat_band 
     (rename=(MATURITY_BAND_YEAR_MIN=MAT_BAND_START MATURITY_BAND_YEAR_MAX=MAT_BAND_END));
merge hedging_set_mat_band (in=a) maturity_band (in=b);
by MATURITY_BAND_CD;
if a and b;
run;

/*- 11: copy mapping tables to RD_CONF -*/

/*- need to subset the following data sets according to run time and configuration set -*/
%copy_map_table(ds=map_approach_class);
%copy_map_table(ds=map_capital_scaling_factor);
%copy_map_table(ds=map_counterparty_class);
%copy_map_table(ds=map_counterparty_relation_type);
%copy_map_table(ds=map_eligible_crm_type);
%copy_map_table(ds=map_equity_position_type);
%copy_map_table(ds=Map_funds_underlying_type); /*added for investment funds : USFinal Config  */
%copy_map_table(ds=map_exchange_type);
%copy_map_table(ds=map_ext_ratings);
%copy_map_table(ds=map_ext_shortterm_ratings);
%copy_map_table(ds=map_financial_book_type); 
%copy_map_table(ds=map_irb_alternative_rw);
%copy_map_table(ds=map_lgd_buckets);
%copy_map_table(ds=map_pd_buckets);
%copy_map_table(ds=map_product_class);
%copy_map_table(ds=map_regulatory_approach);
%copy_map_table(ds=map_rw_buckets);
%copy_map_table(ds=map_clean_up_call_type);
%copy_map_table(ds=map_counterparty_type);
%copy_map_table(ds=map_cpty_sector_le); /*added for CRD4 LE report */ 
%copy_map_table(ds=map_le_class_regrpt); /*added for CRD4 LE report */ 
%copy_map_table(ds=map_le_obsi_type_regrpt); /*added for CRD4 LE report */ 
%copy_map_table(ds=map_covered_risk_type);
%copy_map_table(ds=map_crm_type);
%copy_map_table(ds=map_mtm_insttype);
%copy_map_table(ds=map_obsi_type);
%copy_map_table(ds=map_provision_type);   
%copy_map_table(ds=map_sec_structure_type);
%copy_map_table(ds=map_sec_bank_role);
%copy_map_table(ds=map_sec_acctng_treatment); 
%copy_map_table(ds=map_sec_portfolio_type); 
%copy_map_table(ds=map_sec_retention_type); 
%copy_map_table(ds=map_seniority);
%copy_map_table(ds=map_currency_group); 
%copy_map_table(ds=map_ccr_approach);
%copy_map_table(ds=map_hedging_set_type)
%copy_map_table(ds=map_config_simulation);
%copy_map_table(ds=map_obsi_sec_detail_regrpt);

/*- need to subset the following data sets according to run time -*/
%copy_map_table(ds=map_day_basis, filter_var=);
%copy_map_table(ds=map_fx_type, filter_var=);
%copy_map_table(ds=map_ir_type, filter_var=);
%copy_map_table(ds=map_position_type, filter_var=);
%copy_map_table(ds=map_time_unit, filter_var=);
%copy_map_table(ds=map_ccf_bucket_type, filter_var=);
%copy_map_table(ds=map_haircut_type, filter_var=);
%copy_map_table(ds=map_oecd_countries, filter_var=); 
%copy_map_table(ds=map_simulations_definition, filter_var=); 
%copy_map_table(ds=map_model_list, filter_var=);
%copy_map_table(ds=map_market_data, filter_var=);
%copy_map_table(ds=map_market_data_list, filter_var=);
%copy_map_table(ds=map_horizon_list, filter_var=);
%copy_map_table(ds=map_national_discretion, filter_var=);
%copy_map_table(ds=map_cva_std_rw_bucket, filter_var=); 



/*- need to subset the following data sets according to run time and their set name -*/
%copy_map_table(ds=map_addon_type, filter_var=ADD_ON_SET_ID, filter_value=&ADD_ON_SET);
%copy_map_table(ds=map_ccf_type, filter_var=CCF_SET_ID, filter_value=&CCF_SET);
%copy_map_table(ds=map_sec_eap_type, filter_var=CCF_EAP_SET_ID, filter_value=&CCF_SET_EAP);
%copy_map_table(ds=map_ccf_type_std_ccr, filter_var=CCF_SET_ID, filter_value=&CCF_SET);
%copy_map_table(ds=map_std_rw_buckets, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_std_rw_buckets_retail, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_std_rw_buckets_others, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_std_rw_buckets_rme, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_std_rw_buckets_cme, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_std_rw_buckets_pastdue, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_irb_rw_buckets, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_irb_rw_buckets_equity, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=MAP_IRB_RW_BUCKETS_INV_FUNDS,  filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);  /*Added for investment funds - USFinal config  */ 

%copy_map_table(ds=map_std_rw_buckets_hirisk_pref, filter_var=REGULATORY_RISK_WEIGHT_SET_ID,
                   filter_value=&REGULATORY_RW_SET);
%copy_map_table(ds=map_std_rw_bucket_others_asset, filter_var=REGULATORY_RISK_WEIGHT_SET_ID, 
                   filter_value=&REGULATORY_RW_SET);


/*- PD and LGD mapping for IRB equities -*/
data RD_CONF.map_pd_buckets_irb_equity(drop = VALID_FROM_DTTM VALID_TO_DTTM);
set RD_MAP.map_pd_buckets_irb_equity;
where REGULATORY_PD_SET_ID = "&REGULATORY_PD_SET" and &RUNDATETIME between VALID_FROM_DTTM and VALID_TO_DTTM;
run;

data RD_CONF.map_lgd_buckets_irb_equity(drop = VALID_FROM_DTTM VALID_TO_DTTM);
set RD_MAP.map_lgd_buckets_irb_equity;
where REGULATORY_LGD_SET_ID = "&REGULATORY_LGD_SET" and &RUNDATETIME between VALID_FROM_DTTM and VALID_TO_DTTM;
run;

/*- generate currency codes recognizable by RiskDimensions -*/

proc risk;
setoptions keeplib;
run;

data RD_CONF.rd_curtable(rename=(CODE=CURRENCY));
set RISKSAMP.currencies(keep=CODE);
run;
%mend get_config_set;

%get_config_set;
libname RISKSAMP clear; 

/*- Copy the mapping tables needed for the regulatory reports -*/
%a00_initial_regrpt;

/*- 9: delete unwanted data sets -*/
%clean_lib;
%mend a00_get_config_sets_crd4;
