/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a05_define_rw_bucket_fmt_crd4.sas
 *
 * PURPOSE: Creates formats for risk weight buckets not based on external assessment.
 *
 *   USAGE: 
 *
 *   NOTES: Some of the mapping formats are examples only.  Users are free to
 *          change them to mapping criteria they deem necessary.
 *          
 *
 *****************************************************************************/
%macro a05_define_rw_bucket_fmt_crd4;

/*- format for risk weight buckets under STD approach: retail exposures -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. TYPE $1. START END LABEL $8. HLO $1.; 
set RD_CONF.map_std_rw_buckets_retail end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_RETAIL' ;
START            = REGULATORY_PRODUCT_CD ;
END              = START          ;
LABEL            = STD_RW_BUCKET_RETAIL ;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for risk weight buckets under STD approach: claims secured by residential property -*/
/*- can be changed to be based on other variables, e.g. Loan-to-Value ratio                   -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. TYPE $1. START END LABEL $8. HLO $1.; 
set RD_CONF.map_std_rw_buckets_rme end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_RME' ;
START            = REGULATORY_PRODUCT_CD ;
END              = START          ;
LABEL            = STD_RW_BUCKET_RME ;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for risk weight buckets under STD approach: claims secured by commercial real estate -*/
/*- can be changed to be based on other variables, e.g. Loan-to-Value ratio                     -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. TYPE $1. START END LABEL $8. HLO $1.; 
set RD_CONF.map_std_rw_buckets_cme end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_CME' ;
START            = REGULATORY_PRODUCT_CD ;
END              = START          ;
LABEL            = STD_RW_BUCKET_CME ;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for risk weight buckets under STD approach: other assets -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. TYPE $1. START END LABEL $8. HLO $1.; 
set RD_CONF.map_std_rw_buckets_others end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_OTHERS' ;
START            = REGULATORY_PRODUCT_CD ;
END              = START          ;
LABEL            = STD_RW_BUCKET_OTHERS ;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for risk weight buckets under STD approach: other assets -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. TYPE $1. START END $32. LABEL $8. HLO $1.; 
set RD_CONF.map_std_rw_bucket_others_asset end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_OTHERS_ASSETS' ;
START            = STD_PRODUCT_SUBCLASS ;
END              = START          ;
LABEL            = STD_RW_BUCKET_OTHERS ;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*********************/



/*- format for risk weight buckets under STD approach: past due claims -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. TYPE $1. START END 8. LABEL $8. HLO SEXCL EEXCL $1.; 
set RD_CONF.map_std_rw_buckets_pastdue(where=(PAST_DUE_CATEGORY='WITH_ELIGIBLE_CRM')) end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_PASTDUE' ;
START            = VALUE_ADJUSTMENT_PCT_START ;
END              = VALUE_ADJUSTMENT_PCT_END ;
LABEL            = STD_RW_BUCKET_PASTDUE ;
TYPE             = 'N' ;
SEXCL            = 'N' ;
EEXCL            = 'N' ;
output ;
if lastobs then do;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for risk weight buckets under STD approach: past due claims secured by collateral ineligible under STD -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. TYPE $1. START END 8. LABEL $8. HLO SEXCL EEXCL $1.; 
set RD_CONF.map_std_rw_buckets_pastdue(where=(PAST_DUE_CATEGORY='WITH_INELIGIBLE_CRM')) end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_PASTDUE_OTH' ;
START            = VALUE_ADJUSTMENT_PCT_START ;
END              = VALUE_ADJUSTMENT_PCT_END          ;
LABEL            = STD_RW_BUCKET_PASTDUE ;
TYPE             = 'N' ;
SEXCL            = 'N' ;
EEXCL            = 'Y' ;
output ;
if lastobs then do;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for risk weight buckets under STD approach: past due claims (residential mortgage) -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. TYPE $1. START END 8. LABEL $8. HLO SEXCL EEXCL $1.; 
set RD_CONF.map_std_rw_buckets_pastdue(where=(PAST_DUE_CATEGORY='RESIDENTIAL_MORTGAGE')) end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_PASTDUE_RME' ;
START            = VALUE_ADJUSTMENT_PCT_START ;
END              = VALUE_ADJUSTMENT_PCT_END          ;
LABEL            = STD_RW_BUCKET_PASTDUE ;
TYPE             = 'N' ;
SEXCL            = 'N' ;
EEXCL            = 'N' ;
output ;
if lastobs then do;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*-  format for risk weight buckets under STD approach: past due claims (commercial mortgage) -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. TYPE $1. START END 8. LABEL $8. HLO SEXCL EEXCL $1.; 
set RD_CONF.map_std_rw_buckets_pastdue(where=(PAST_DUE_CATEGORY='COMMERCIAL_MORTGAGE')) end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_PASTDUE_CME' ;
START            = VALUE_ADJUSTMENT_PCT_START ;
END              = VALUE_ADJUSTMENT_PCT_END          ;
LABEL            = STD_RW_BUCKET_PASTDUE ;
TYPE             = 'N' ;
SEXCL            = 'N' ;
EEXCL            = 'N' ;
output ;
if lastobs then do;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for risk weight buckets under IRB approach:       -*/
/*- for IRB_SIMPLE_RW, it is the RW bucket, and for          -*/
/*- IRB_PD_LGD and IRB_INT_MODELS, it is the RW floor bucket -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME $32. TYPE $1. START END $32. LABEL $8. HLO $1.; 
set RD_CONF.map_irb_rw_buckets_equity end=lastobs;
FMTNAME          = 'MAP_IRB_RW_BUCKET_EQUITY' ;
START            = compress(REGULATORY_APPROACH || EQUITY_POSITION_TYPE_CD || REGULATORY_PRODUCT_CD) ;
END              = START          ;
LABEL            = IRB_RW_BUCKET_EQUITY ;
TYPE             = 'C' ;
output ;
if lastobs then do;
    START            ='**OTHER**' ;
    END              = START;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/* Format MAP_IRB_RW_BUCKET_FUNDS Added for ---USFinal configuration */ 
/*- format for Investment fund risk weight buckets under USfinal configuration.     -*/
   
   data fmt (keep=FMTNAME START END LABEL TYPE HLO);
   length FMTNAME $32. TYPE $1. START END $32. LABEL $8. HLO $1.; 
   set RD_CONF.map_irb_rw_buckets_inv_funds end=lastobs;
   FMTNAME          = 'MAP_IRB_RW_BUCKET_FUNDS' ;
   START            = compress(REGULATORY_APPROACH || UNDERLYING_FND_ASSET_TYPE_CD|| REGULATORY_PRODUCT_CD) ;
   END              = START          ;
   LABEL            = IRB_RW_BUCKET_FUNDS ;
   TYPE             = 'C' ;
   output ;
   if lastobs then do;
       START            ='**OTHER**' ;
       END              = START;
       HLO              ='O' ;
       LABEL            ='';
       output ;
   end;
   run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for risk weight buckets under STD approach: preferential RWs for high risk categories -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME $32. TYPE $1. START END 8. LABEL $8. HLO SEXCL EEXCL $1.; 
set RD_CONF.map_std_rw_buckets_hirisk_pref end=lastobs;
FMTNAME          = 'MAP_STD_RW_BUCKET_HIGHRISK' ;
START            = VALUE_ADJUSTMENT_START_PCT ;
END              = VALUE_ADJUSTMENT_END_PCT ;
LABEL            = STD_RW_BUCKET_HIGH_RISK ;
TYPE             = 'N' ;
SEXCL            = 'N' ;
EEXCL            = 'Y' ;
output ;
if lastobs then do;
    HLO              ='O' ;
    LABEL            ='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- Format for weights for CVA standardized approach calculations -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE HLO); 
length FMTNAME $32. TYPE $1. START END LABEL $8. HLO $1.;  
set RD_CONF.map_cva_std_rw_bucket end=lastobs; 
FMTNAME          = 'MAP_CVA_STD_RW_BUCKET' ; 
START            = EXT_MAP_RATING ; 
END              = START          ; 
LABEL            = CVA_STD_BUCKET ; 
TYPE             = 'C' ; 
output ; 
if lastobs then do; 
    START            ='**OTHER**' ; 
    END              = START; 
    HLO              ='O' ; 
    LABEL            =''; 
    output ; 
end; 
run; 
 
proc format cntlin=fmt lib=RD_ENV; run; 

%mend a05_define_rw_bucket_fmt_crd4;
