
/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a05_define_type_fmt_crd4 .sas
 *
 * PURPOSE: Creates formats for various type codes for enriching position data.
 *          Specific to the CRD4 configuration.
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/
%macro a05_define_type_fmt_crd4 ;
/*- format for mtm INSTTYPE mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_mtm_insttype end=lastobs;
      FMTNAME          = 'MAP_MTM_INSTTYPE' ;
      START            = compress(PRODUCT_CD || SUBPRODUCT_CD) ;
      END              = START;
      LABEL            = INSTTYPE;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for risk position INSTTYPE mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.MAP_HEDGING_SET_TYPE end=lastobs;
      FMTNAME          = 'MAP_RISK_POSITION_INSTTYPE' ;
      START            = compress(HEDGING_SET_TYPE_CD) ;
      END              = START;
      LABEL            = RISK_POSITION_INSTTYPE;
      TYPE             = 'C' ;
      output ;
      if lastobs then do;
         START            ='**OTHER**' ;
         END              = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for counterparty type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_counterparty_type end=lastobs;
FMTNAME            = 'MAP_COUNTERPARTY_TYPE' ;
START              = COUNTERPARTY_TYPE_CD;
END                = START;
LABEL              = COUNTERPARTY_TYPE;
TYPE               = 'C' ;
output ;
if lastobs then do;
    START           ='**OTHER**' ;
    END             = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for counterparty relation type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length FMTNAME LABEL $32. START END $3. TYPE HLO $1.;
set RD_CONF.map_counterparty_relation_type end=lastobs;
FMTNAME = 'MAP_COUNTERPARTY_RELATION_TYPE';
TYPE = 'C';
START = COUNTERPARTY_RELATION_TYPE_CD;
END = START;
LABEL = COUNTERPARTY_RELATION_TYPE;
output ;
if lastobs then do;
    START           ='**OTHER**' ;
    END             = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for CRM type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_crm_type end=lastobs;
      FMTNAME            = 'MAP_CRM_TYPE' ;
      START              = compress(CRM_TYPE_CD || CRM_SUBTYPE_CD) ;
      END                = START;
      LABEL              = CRM_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for CRM subtype mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_crm_type end=lastobs;
      FMTNAME            = 'MAP_CRM_SUBTYPE' ;
      START              = compress(CRM_TYPE_CD || CRM_SUBTYPE_CD) ;
      END                = START;
      LABEL              = CRM_SUBTYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for eligible for double default treatment -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_crm_type end=lastobs;
      FMTNAME            = 'MAP_ELIGIBLE_DD_TREAT_CRM' ;
      START              = compress(CRM_TYPE_CD || CRM_SUBTYPE_CD) ;
      END                = START;
      LABEL              = ELIGIBLE_DD_TREAT_CRM;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='N';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for eligible CRM type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_eligible_crm_type end=lastobs;
      FMTNAME            = 'MAP_ELIGIBLE_CRM_TYPE' ;
      START              = ELIGIBLE_CRM_TYPE_CD;
      END                = START;
      LABEL              = ELIGIBLE_CRM_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for off-balance-sheet type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_obsi_type end=lastobs;
      FMTNAME            = 'MAP_OBSI_TYPE' ;
      START              = OFF_BALANCE_SHEET_TYPE_CD;
      END                = START;
      LABEL              = OFF_BALANCE_SHEET_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for facility type mapping -*/
/*
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_facility_type end=lastobs;
      FMTNAME            = 'MAP_FACILITY_TYPE' ;
      START              = FACILITY_TYPE_CD;
      END                = START;
      LABEL              = FACILITY_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;
*/

/*- format for position type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_position_type end=lastobs;
      FMTNAME            = 'MAP_POSITION_TYPE' ;
      START              = POSITION_TYPE_CD ;
      END                = START ;
      LABEL              = SHORTPOSITION;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL=.;
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for securitization position -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_position_type end=lastobs;
      FMTNAME            = 'MAP_SECURITIZATION_POSITION' ;
      START              = POSITION_TYPE_CD ;
      END                = START ;
      LABEL              = SECURITIZATION_POSITION;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='N';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for equity position type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_equity_position_type end=lastobs;
FMTNAME = 'MAP_EQUITY_POSITION_TYPE' ;
START   = EQUITY_POSITION_TYPE_CD ;
END     = START ;
LABEL   = EQUITY_POSITION_TYPE;
TYPE    = 'C' ;
output ;
if lastobs then do;
    START ='**OTHER**' ;
    END = START;
    HLO='O' ;
    LABEL='';
    output ;
end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for haircut type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_haircut_type end=lastobs;
      FMTNAME            = 'MAP_HAIRCUT_TYPE' ;
      START              = compress(HAIRCUT_SET_ID || PRODUCT_CD || SUBPRODUCT_CD) ;
      END                = START ;
      LABEL              = HAIRCUT_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for add-on type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_addon_type end=lastobs;
      FMTNAME            = 'MAP_ADDON_TYPE' ;
      START              = OFF_BALANCE_SHEET_TYPE_CD ;
      END                = START ;
      LABEL              = ADDON_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for ccf type mapping: for regulatory sets -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_ccf_type end=lastobs;
      FMTNAME            = 'MAP_CCF_TYPE' ;
      START              = compress(CCF_SET_ID || OFF_BALANCE_SHEET_TYPE_CD) ;
      END                = START ;
      LABEL              = CCF_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for CCF bucket type mapping: for own estimates -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_ccf_bucket_type end=lastobs;
      FMTNAME            = 'MAP_CCF_BUCKET_TYPE' ;
      START              = compress(CCF_SET_ID || CCF_BUCKET_TYPE_CD) ;
      END                = START ;
      LABEL              = CCF_BUCKET_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for CCF bucket type mapping for securitization exposures with early amortization provisions -*/
data fmt (keep=FMTNAME START END LABEL TYPE EEXCL);
set RD_CONF.map_ccf_sec_eap_bucket end=lastobs;
      FMTNAME            = 'MAP_CCF_SEC_EAP_BUCKET_TYPE' ;
      START              = ES_TO_TP_START ;
      END                = ES_TO_TP_END ;
      LABEL              = CCF_BUCKET_SEC_EAP;
      TYPE               = 'N' ;
      EEXCL              = 'Y';
      output ;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for CCR STD ccf type mapping: for regulatory sets -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_ccf_type_std_ccr end=lastobs;
      FMTNAME            = 'MAP_CCF_TYPE_STD_CCR' ;
      START              = compress(CCF_SET_ID || HEDGING_SET_TYPE_CD) ;
      END                = START ;
      LABEL              = CCF_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for exposure-specific provision type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_provision_type end=lastobs;
      FMTNAME            = 'MAP_PROVISION_TYPE' ;
      START              = compress(PROVISION_TYPE_CD) ;
      END                = START ;
      LABEL              = PROVISION_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for covered risk type mapping, i.e. default and dilution risk for purchased receivables -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_covered_risk_type end=lastobs;
      FMTNAME            = 'MAP_COVERED_RISK_TYPE' ;
      START              = compress(COVERED_RISK_TYPE_CD) ;
      END                = START ;
      LABEL              = COVERED_RISK_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for early amortization type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_eap_type end=lastobs;
      FMTNAME            = 'MAP_SEC_EAP_TYPE' ;
      START              = compress(EARLY_AMORTIZATION_TYPE_CD) ;
      END                = START ;
      LABEL              = EARLY_AMORTIZATION_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for early amortization provision that requires capital charge -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_eap_type end=lastobs;
      FMTNAME            = 'MAP_EAP_CAPITAL_REQUIRED' ;
      START              = compress(EARLY_AMORTIZATION_TYPE_CD) ;
      END                = START ;
      LABEL              = EAP_CAPITAL_REQUIRED;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='Y';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for day basis mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_day_basis end=lastobs;
      FMTNAME            = 'MAP_DAY_BASIS' ;
      START              = compress(DAY_BASIS_CD) ;
      END                = START ;
      LABEL              = DAY_BASIS;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for securitization bank role mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_bank_role end=lastobs;
      FMTNAME            = 'MAP_SEC_BANK_ROLE' ;
      START              = compress(BANK_ROLE_CD) ;
      END                = START ;
      LABEL              = BANK_ROLE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for securitization structure type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_structure_type end=lastobs;
      FMTNAME            = 'MAP_SEC_STRUCTURE_TYPE' ;
      START              = compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD) ;
      END                = START ;
      LABEL              = SEC_STRUCTURE_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for securitization structure subtype mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_structure_type end=lastobs;
      FMTNAME            = 'MAP_SEC_STRUCTURE_SUBTYPE' ;
      START              = compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD) ;
      END                = START ;
      LABEL              = SEC_STRUCTURE_SUBTYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for securitization accounting treatment mapping -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_acctng_treatment end=lastobs;
      FMTNAME            = 'MAP_SEC_ACCTING_TREATMENT' ;
      START              = ACCTING_TREATMENT_CD ;
      END                = START ;
      LABEL              = SEC_ACCTING_TREATMENT ;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for financial book type for securitization reporting -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_financial_book_type end=lastobs;
      FMTNAME            = 'MAP_FINANCIAL_BOOK_TYPE' ;
      START              = FINANCIAL_BOOK_TYPE_CD ;
      END                = START ;
      LABEL              = SECURITIZATION_TREATMENT_TYPE ;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for securitization portfolio type -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_portfolio_type end=lastobs;
      FMTNAME            = 'MAP_SEC_PORTFOLIO_TYPE' ;
      START              = SEC_PORTFOLIO_TYPE_CD ;
      END                = START ;
      LABEL              = SEC_PORTFOLIO_TYPE ;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for securitization portfolio type -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_retention_type end=lastobs;
      FMTNAME            = 'MAP_SEC_RETENTION_TYPE' ;
      START              = RETENTION_TYPE_CD  ;
      END                = START ;
      LABEL              = SEC_RETENTION_TYPE ;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for eligible securitization flag mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_sec_structure_type end=lastobs;
      FMTNAME            = 'MAP_ELIGIBLE_SECURITIZATION' ;
      START              = compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD) ;
      END                = START ;
      LABEL              = ELIGIBLE_SECURITIZATION;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='N';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for clean-up call type mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_clean_up_call_type end=lastobs;
      FMTNAME            = 'MAP_CLEAN_UP_CALL_TYPE' ;
      START              = compress(CLEAN_UP_CALL_TYPE_CD) ;
      END                = START ;
      LABEL              = CLEAN_UP_CALL_TYPE;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL='';
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;


/*- format for eligible clean-up call flag mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_CONF.map_clean_up_call_type end=lastobs;
      FMTNAME            = 'MAP_ELIGIBLE_CLEAN_UP_CALL_FLG' ;
      START              = compress(CLEAN_UP_CALL_TYPE_CD) ;
      END                = START ;
      LABEL              = ELIGIBLE_CLEAN_UP_CALL_FLG;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL=.;
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- create format for trading book flag from the financial_book_mart -*/
data fmt (keep=FMTNAME START END LABEL TYPE);
set RD_stage.financial_book_mart end=lastobs;
      FMTNAME            = 'MAP_TRADING_BOOK_FLG' ;
      START              = FINANCIAL_BOOK_RK ;
      END                = START ;
      LABEL              = TRADING_BOOK_FLG;
      TYPE               = 'N' ;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- create format for correlation trading from the financial_book_mart -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE);
set RD_stage.financial_book_mart end=lastobs;
      FMTNAME            = 'MAP_CORR_TRADING_FLG' ;
      START              = FINANCIAL_BOOK_RK ;
      END                = START ;
      LABEL              = CORRELATION_TRADING_PORT_FLG;
      TYPE               = 'N' ;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for investment grade category mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_MAP.MAP_EXT_RATINGS_SEC_CATEGORY end=lastobs;
      FMTNAME            = 'MAP_EXT_RATINGS_SEC_CATEGORY' ;
      START              = compress(EXT_MAP_RATING) ;
      END                = START ;
      LABEL              = EXT_RATING_CATEGORY;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL=.;
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- format for Deduction flag mapping -*/
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
set RD_MAP.MAP_EXT_RATINGS_SEC_CATEGORY end=lastobs;
      FMTNAME            = 'MAP_DEDUCTION_FLG' ;
      START              = compress(EXT_MAP_RATING) ;
      END                = START ;
      LABEL              = DEDUCTION_FLG;
      TYPE               = 'C' ;
      output ;
      if lastobs then do;
         START           ='**OTHER**' ;
         END             = START;
         HLO='O' ;
         LABEL=.;
         output ;
      end;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*Format for Large Financial Entity */ 
data fmt (keep=FMTNAME START END LABEL TYPE HLO);
length START end $10.;
set RD_CONF.MAP_COUNTERPARTY_TYPE  end=lastobs;
      FMTNAME            = 'MAP_LARGE_FI_ENTITY_FLG' ;
      START              = compress(COUNTERPARTY_TYPE_CD) ;
      END                = START ;
      LABEL              = LARGE_FI_ENTITY_FLAG;
      TYPE               = 'C' ;
	  output;
      if lastobs then do;
         HLO='O' ;
         LABEL=. ;
         output ;
      end;

run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- create format for EXP_NOT_OWNED_FLG from the financial_book_mart -*/ 
data fmt (keep=FMTNAME START END LABEL TYPE);
set RD_stage.financial_book_mart end=lastobs;
      FMTNAME            = 'MAP_EXP_NOT_OWNED_FLG' ;
      START              = FINANCIAL_BOOK_RK ;
      END                = START ;
      LABEL              = EXP_NOT_OWNED_FLG;
      TYPE               = 'N' ;
run;

proc format cntlin=fmt lib=RD_ENV; run;

/*- delete unwanted data sets -*/
proc datasets library = work memtype = data nolist nodetails kill;
quit;



%mend a05_define_type_fmt_crd4 ;
