/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: a05_get_eea_currency_crd4.sas
 *
 * PURPOSE: Get the currency list of EEA member countries
 *          
 *
 *   USAGE: %a05_get_eea_currency_crd4;
 *
 *  
 *          
 *   NOTES: 
 *   4/17/2013: Created for crd4    
 *          
 *****************************************************************************/
 
/* get the currency list of the EEA member countries, used for RW calculation for Central Government/bank exposures: CRR Article 114 */

%macro a05_get_eea_currency_crd4(rd_map=rd_map) ;

   %global eea_currency_list ;
   %let eea_currency_list = ; 
   
   data eea_currency (keep=COUNTRY_CD currency EEA_MEMBER_FLG);
   set &rd_map..Map_national_discretion (rename=(COUNTRY_CURRENCY_1_CD=currency));
   output;
   if not missing(COUNTRY_CURRENCY_2_CD) then do;
      currency=COUNTRY_CURRENCY_2_CD;
      output;
   end;
   if not missing(COUNTRY_CURRENCY_3_CD) then do;
      currency=COUNTRY_CURRENCY_3_CD;
      output;
   end;
   run;

   proc sql noprint;
   select distinct currency into :_tmp_list_ separated by " "
   from eea_currency
   where upcase(EEA_MEMBER_FLG) ='YES'
   ;
   quit;

   /*- Quote the list for use in an INDEX() call -*/
   /* %let eea_currency_list = %quote_list(list=&_tmp_list_,case=) ; */
   %let eea_currency_list = %quote(&_tmp_list_) ; 

   %put NOTE: eea_currency_list=&eea_currency_list;


%EXIT:

   %put NOTE:  a05_get_eea_currency_crd4 finished;  
%mend a05_get_eea_currency_crd4 ;
