/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: apply_system_filter_staging.sas
 *
 * PURPOSE: Apply system filter for the given system hierarchy. 
 *
 *
 *   USAGE: %apply_system_filter_stage(hierarchy_file)
 *          hierarchy_file : Hierarchy file created according to the system id
 *
 *   NOTES: This macro filters out related staging data for the given hierarchy
 *          
 *
 *****************************************************************************/

%macro apply_system_filter_staging(HIERARCHY_FILE=rd_stat.system_hierarchy);
%local SYSTEM_FILTER;

/*- all data sets should be moved for MAIN -*/
%if "&SYSTEM_ID"="main" %then %do;
    proc copy in=STAGING outlib=RD_STAGE
              NOCLONE CONSTRAINT=YES INDEX=YES;
    run;
%end;

/*- check for existence of the hierarchy file -*/
%else %if %dsexist(&HIERARCHY_FILE) EQ 1 %then %do;

/*- create filter from the hierarchy -*/
/*    proc sql noprint;*/
/*    select CHILD into : SYSTEM_FILTER separated by ","*/
/*    from &HIERARCHY_FILE;*/
/*    quit;*/
   
/*    %let SYSTEM_FILTER=%str(where INTERNAL_ORG_RK in (&SYSTEM_FILTER););*/

/*get count of total entities in system_hierarchy*/
proc sql;
select count(child) into :child_count from rd_stat.system_hierarchy; 
quit;
/*create macro variables and assign value of entity to them*/
data _null_;
set rd_stat.system_hierarchy;
call symputx('sys_filt'||left(trim(put(_n_,8.))),child);
run;

/*where clause for filter*/
%macro where_filter;
where INTERNAL_ORG_RK in
(%do i=1 %to &child_count; 
 &&SYS_FILT&i
%end;
);
%mend;

/*%let SYSTEM_FILTER=%nrstr(%where_filter);*/
/*%macro apply_df(INLIB=rd_stage, DATA=, OUTLIB=work, FILTER=);*/
/*data &OUTLIB..&DATA;*/
/* set &INLIB..&DATA;*/
/*&FILTER;*/
/*run;*/
/*%mend;*/
    
    /*- apply filter directly -*/
    %apply_data_filter(DATA=exposure_account, FILTER=%where_filter);
    %apply_data_filter(DATA=exposure_instrument, FILTER=%where_filter);
    %apply_data_filter(DATA=exposure_facility, FILTER=%where_filter);
    %apply_data_filter(DATA=exposure_receivable, FILTER=%where_filter);
    %apply_data_filter(DATA=exposure_securitization, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_account, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_instrument, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_derivative, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_insurance, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_physical, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_receivable, FILTER=%where_filter);
    %apply_data_filter(DATA=crm_guarantee, FILTER=%where_filter);
    %apply_data_filter(DATA=general_provision_mart, FILTER=%where_filter);
    %apply_data_filter(DATA=internal_org_mart, FILTER=%where_filter);
    %apply_data_filter(DATA=internal_org_association, FILTER=%where_filter);
    %apply_data_filter(DATA=financial_reporting_data, FILTER=%where_filter);
    %apply_data_filter(DATA=regulatory_capital_report_data, FILTER=%where_filter);
    %apply_data_filter(DATA=financial_rpt_period_x_int_org, FILTER=%where_filter);
    /*- no filter needed -*/
    %apply_data_filter(DATA=quote_equities, FILTER= );
    %apply_data_filter(DATA=quote_ir, FILTER=);
    %apply_data_filter(DATA=quote_fx, FILTER=);
    %apply_data_filter(DATA=quote_vol, FILTER=);
    %apply_data_filter(DATA=rating_grade, FILTER=);
    %apply_data_filter(DATA=financial_book_mart, FILTER=);
    %apply_data_filter(DATA=facility_group_mart, FILTER=);
    %apply_data_filter(DATA=risk_factor, FILTER=);
    %apply_data_filter(DATA=hedging_set, FILTER=);
    %apply_data_filter(DATA=financial_reporting_period, FILTER=);
    %apply_data_filter(DATA=regltry_captl_report_category, FILTER=);
/*for CRD4 and USFINAL */    	
    %apply_data_filter(DATA=counterparty_x_internal_org, FILTER= );
    %apply_data_filter(DATA=crm_segment, FILTER= );
    %apply_data_filter(DATA=data_item, FILTER= );
    %apply_data_filter(DATA=exposure_segment, FILTER= );
    %apply_data_filter(DATA=issue_segment, FILTER= );
    %apply_data_filter(DATA=op_risk_category, FILTER= );
    %apply_data_filter(DATA=op_risk_financial_data, FILTER= );
    %apply_data_filter(DATA=quote_commodity, FILTER= );
    %apply_data_filter(DATA=quote_funds, FILTER= );
    %apply_data_filter(DATA=regulatory_capital_mart, FILTER= );
    %apply_data_filter(DATA=segment_mart, FILTER= );
    %apply_data_filter(DATA=segment_ratings, FILTER= );
	%apply_data_filter(DATA=fund_instrument_position_info, FILTER= );
    	

    /*- get all the instid's -*/
    data _instid_;
    set RD_STAGE.exposure_account (keep=INSTID)
        RD_STAGE.exposure_instrument (keep=INSTID)
        RD_STAGE.exposure_facility (keep=INSTID)
        RD_STAGE.exposure_receivable (keep=INSTID)
        RD_STAGE.exposure_securitization (keep=INSTID)
        RD_STAGE.crm_account (keep=INSTID)
        RD_STAGE.crm_guarantee (keep=INSTID)
        RD_STAGE.crm_derivative (keep=INSTID)
        RD_STAGE.crm_instrument (keep=INSTID)
        RD_STAGE.crm_insurance (keep=INSTID)
        RD_STAGE.crm_receivable (keep=INSTID)
        RD_STAGE.crm_physical (keep=INSTID);
    run;
    
    /*- all instid should be unique -*/

    /*- process link tables -*/
    /*- may need more logic to get the ghost exposures regarding the links later -*/
    proc sql;
    create table rd_stage.exposure_crm_link as select a.*
    from staging.exposure_crm_link as a
    right join _instid_ as b
    on a.EXPOSURE_ID=b.INSTID;

    /*- may need more logical to get the ghost exposures regarding the facility later -*/
    create table rd_stage.exposure_cf_link as select a.*
    from staging.exposure_cf_link as a
    right join _instid_ as b
    on a.EXPOSURE_ID=b.INSTID;
    
    create table RD_STAGE.provisions as select a.*
    from STAGING.provisions as a
    inner join _instid_ as b 
    on a.INSTID = b.INSTID;
    quit;

    data _all_issues_;
    set RD_STAGE.exposure_account (keep=ISSUE_KEY)
        RD_STAGE.exposure_instrument (keep=ISSUE_KEY)
        RD_STAGE.exposure_facility (keep=ISSUE_KEY)
        RD_STAGE.exposure_receivable (keep=ISSUE_KEY)
        RD_STAGE.exposure_securitization (keep=ISSUE_KEY)
        RD_STAGE.crm_account (keep=ISSUE_KEY)
        RD_STAGE.crm_guarantee (keep=ISSUE_KEY)
        RD_STAGE.crm_derivative (keep=ISSUE_KEY)
        RD_STAGE.crm_instrument (keep=ISSUE_KEY)
        RD_STAGE.crm_insurance (keep=ISSUE_KEY)
        RD_STAGE.crm_receivable (keep=ISSUE_KEY)
        RD_STAGE.crm_physical (keep=ISSUE_KEY);
    run;
    
    /*- make sure issues are unique -*/
    proc sort data=_all_issues_ nodupkey;
    by ISSUE_KEY;
    run;
    
    proc sql;
    create table RD_STAGE.issue_account as select a.*
    from STAGING.issue_account as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;

    create table RD_STAGE.issue_instrument as select a.*
    from STAGING.issue_instrument as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;

    create table RD_STAGE.issue_facility as select a.*
    from STAGING.issue_facility as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;

    create table RD_STAGE.issue_receivable as select a.*
    from STAGING.issue_receivable as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;

    create table RD_STAGE.issue_securitization as select a.*
    from STAGING.issue_securitization as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;
    
    create table RD_STAGE.issue_asset_mart as select a.*
    from STAGING.issue_asset_mart as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;

    create table RD_STAGE.issue_ratings as select a.*
    from STAGING.issue_ratings as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;
    
    create table RD_STAGE.issue_risk_factor as select a.*
    from STAGING.issue_risk_factor as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;
    
    create table RD_STAGE.risk_position as select a.*
    from STAGING.risk_position as a
    inner join _all_issues_ as b 
    on a.ISSUE_KEY = b.ISSUE_KEY;
    quit;


    /*- more complicated filtrations *-/
    /*- select all related counterparties -*/
    data _cpty_;
    set 
        RD_STAGE.issue_instrument (keep=ISSUER_COUNTERPARTY_RK rename=(ISSUER_COUNTERPARTY_RK=COUNTERPARTY_RK)) 
	RD_STAGE.exposure_account (keep=COUNTERPARTY_RK)
        RD_STAGE.exposure_instrument (keep=COUNTERPARTY_RK)
        RD_STAGE.exposure_facility (keep=COUNTERPARTY_RK)
        RD_STAGE.exposure_receivable (keep=COUNTERPARTY_RK)
        RD_STAGE.exposure_securitization (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_account (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_guarantee (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_derivative (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_instrument (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_insurance (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_receivable (keep=COUNTERPARTY_RK)
        RD_STAGE.crm_physical (keep=COUNTERPARTY_RK)
        STAGING.counterparty_mart (keep=SOVEREIGN_COUNTERPARTY_RK 
                                    rename=(SOVEREIGN_COUNTERPARTY_RK=COUNTERPARTY_RK)
                                    where=(not missing(COUNTERPARTY_RK)));
    run;
    
    /*- make sure counterparties are unique -*/
    proc sort data=_cpty_ nodupkey;
    by COUNTERPARTY_RK;
    run;
    
    data RD_STAGE.counterparty_mart;
    merge STAGING.counterparty_mart (in=a)
          _cpty_ (in=b);
    by COUNTERPARTY_RK;
    if a and b;
    run;
     
    data RD_STAGE.counterparty_ratings;
    merge STAGING.counterparty_ratings (in=a)
          _cpty_ (in=b);
    by COUNTERPARTY_RK;
    if a and b;
    run;

    /*- select all related issues -*/

    
    /*- select all netting sets -*/
    data _all_netting_;
    set RD_STAGE.exposure_account (keep=NETTING_SET_RK)
        RD_STAGE.exposure_instrument (keep=NETTING_SET_RK)
        RD_STAGE.exposure_facility (keep=NETTING_SET_RK)
        RD_STAGE.exposure_receivable (keep=NETTING_SET_RK)
        RD_STAGE.exposure_securitization (keep=NETTING_SET_RK);
    run;    
    
    proc sort data=_all_netting_ nodupkey;
    by NETTING_SET_RK;
    run;
    
    proc sql;
    create table RD_STAGE.netting_set_mart as select a.*
    from STAGING.netting_set_mart as a
    inner join _all_netting_ as b
    on a.NETTING_SET_RK=b.NETTING_SET_RK;
    quit;
    
    /*- receivable pool -*/
    data _rec_pools_;
    set RD_STAGE.exposure_receivable (keep=RECEIVABLE_POOL_RK);
    run;
    
    proc sql;
    create table rec_pools as select a.*
    from STAGING.issue_receivable as a 
    inner join _rec_pools_ as b
    on a.RECEIVABLE_POOL_RK = b.RECEIVABLE_POOL_RK;
    quit;
    
    proc append base=RD_STAGE.issue_receivable data=rec_pools;
    proc sort data=RD_STAGE.issue_receivable nodupkey; by ISSUE_KEY; run;
    
    /*- securitization pool -*/
    data _all_pools_;
    set RD_STAGE.issue_securitization (keep=SECURITIZATION_POOL_RK where=(not missing(SECURITIZATION_POOL_RK)))
        RD_STAGE.issue_facility (keep=COVER_SECURITIZATION_POOL_RK 
                                 rename=(COVER_SECURITIZATION_POOL_RK=SECURITIZATION_POOL_RK)
                                 where=(not missing(SECURITIZATION_POOL_RK)));
    run;
    
    proc sort data=_all_pools_ nodupkey;
    by SECURITIZATION_POOL_RK;
    run;
    
    proc sql;
    create table RD_STAGE.securitization_pool_mart as select a.*
    from STAGING.securitization_pool_mart as a 
    inner join _all_pools_ as b
    on a.SECURITIZATION_POOL_RK=b.SECURITIZATION_POOL_RK;
    quit;
    
    /*- model information -*/
    proc sql;
    create table RD_STAGE.simulation_model as select a.*
    from STAGING.simulation_model as a
    inner join RD_MAP.map_model_list as b
    on a.MODEL_RK=b.MODEL_RK;
    
    create table RD_STAGE.analytical_model_x_risk_factor as select a.*
    from STAGING.analytical_model_x_risk_factor as a
    inner join RD_MAP.map_model_list as b
    on a.MODEL_RK=b.MODEL_RK;
    quit;
%end;

%else %do;
    %print_msg(error, 2, 227);
    %let SYSTEM_FATAL_ERROR=Y;
%end;

%mend apply_system_filter_staging;
