/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b20_prep_regrpt_port_sec_sa_crd4.sas
 *
 * PURPOSE: Create portoflio data for Corep CR SEC IRB report
 *
 *****************************************************************************/


%macro b20_prep_regrpt_port_sec_sa_crd4;
 
/*---------------------------------------------------------------------------
 * Step 1.
 *
 * Check to see if we user has requested SEC data
 * -------------------------------------------------------------------------*/    


%let HAVEDATA=NO;

   %if %UPCASE(&REGPROJECTNAME) EQ SEC or 
       %UPCASE(&REGPROJECTNAME) EQ ALL or
       %UPCASE(&REGPROJECTNAME) EQ STD or
       %UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRSEC_SA_CRD4 %then %goto check;
   %else %goto SKIP;;

/*---------------------------------------------------------------------------
 * Step 2.
 *
 * Check to see if we user has requested securitization data
 * -------------------------------------------------------------------------*/   


%SKIP:

%print_msg(NOTE,3,64);
%return;

%CHECK:

%let inputds = crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail; 

%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then %do;
   libname _detail  "&REGPATH";
   %let COSTVAR = _COST_;
/*   %let inputds = all_exposures_before_rollup; */

%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
   libname _detail  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
   %let COSTVAR = _WEIGHT_;
%end;

%checkdata(_detail, &inputds , (INDEX(APPROACH, 'STD') NE 0) AND 
                               ((upcase(IRB_PRODUCT_CLASS) EQ 'SEC') OR 
                                (upcase(IRB_PRODUCT_CLASS) EQ 'SECURITIZATION')));
%put &HAVEDATA;
/* If no data then return*/
  %if   (&HAVEDATA = NO)  %then %do;
    %print_msg (NOTE,3,66);  
    %return;   
%end;

/*---------------------------------------------------------------------------
 * Step 3. Creating portfolio for SEC SA report 
 * -------------------------------------------------------------------------*/
 %if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,112);
 
 DATA WORK._SECDATA;
   set _detail.&inputds;
   where (INDEX(APPROACH, 'STD') NE 0) AND (upcase(STD_PRODUCT_CLASS) IN ('SEC','SECURITIZATION'));
   %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK %then %do; 
     if not missing(CRM_ID) then _weight_ = _weight_ ;
     else _weight_ = RW_EXP ;
   %end;
RUN;
 
 



 /* The first cross-class is SEC_STRUCTURE_TYPE (already in the dataset) */
 /* The second cross-class is PRIMARY_BANK_ROLE (already in the dataset) */
 DATA _INTDS.CAPITAL_CRSEC_SA_CRD4;
    length CQS_BUCKET $16. EXPOSURE_TYPE $16. EXPOSURE_SUBTYPE $16. SENIORITY_STATUS CRM_PRODUCT CRM_CLASS_SA_LEVEL_1 $32. 
	REGRPT_CCF_BUCKET REGRPT_RW_BUCKET CQS_BUCKET $25.
	CRM_CLASS_LEVEL_1 CRM_CLASS_LEVEL_2 $16.;
    set work._secdata;

	if CRM_ID NE '' then 
	do;
 
		CRM_CLASS_LEVEL_1 =
		put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_EXPOSURE_CLASS_1_REGRPT.);
 
		CRM_CLASS_LEVEL_2 =
		put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_EXPOSURE_CLASS_2_REGRPT.);

		CRM_CLASS_SA_LEVEL_1 =
        put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_SA_EXPOSURE_CLASS.);

		IF ELIGIBLE_CRM_TYPE NE 'FINANCIAL_COMPREHENSIVE' AND CRM_TYPE NOT IN ('FINANCIAL_COLLATERAL', 'NETTING') then
		do;
		  IF CRM_TYPE = 'CREDIT_DERIVATIVE' then 
				CRM_PRODUCT = 'UNFUNDED';
		  ELSE IF CRM_TYPE = 'GUARANTEE' THEN
				CRM_PRODUCT = 'UNFUNDED';
		END;
		ELSE IF CRM_TYPE IN ('FINANCIAL_COLLATERAL') then
          do;
                if  "&STD_CRM_APPROACH" EQ "SIMPLE"  and  ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_SIMPLE' and CRM_SUBTYPE not in ('LIFE_INSURANCE','CASH_3RD_PARTY') THEN
                            CRM_PRODUCT = 'FIN_COLL_SIMPLE';	
				else if "&STD_CRM_APPROACH" NE "SIMPLE" and CRM_COMP_FLG = 1 then
                            CRM_PRODUCT = 'FIN_COLL_COMPREH';
		  end;
		  
	end;						  
    /*Define the EXPOSURE_TYPE cross-class*/
    if OFF_BALANCE_SHEET_TYPE_CD = '' then EXPOSURE_TYPE = 'ON_BALANCE';
    else EXPOSURE_TYPE = 'OFF_BALANCE';
    if early_amortization_type ne '' then EXPOSURE_TYPE='EARLY_AMT';

	/*Define the EXPOSURE_SUBTYPE cross-class*/
	if RESECURITIZATION_FLG=1 then
	do;
		EXPOSURE_SUBTYPE="RESECURITIZATION";
		/* RW_BUCKET: Used for subsetting the output variables*/
		if EXT_ISSUE_MAP_RATING = 'MISS' AND APPROACH = "STD_IAA" then
		do;
			REGRPT_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
			CQS_BUCKET=put(INT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
		end;
		ELSE
		do;
			REGRPT_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
			CQS_BUCKET=put(EXT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
		end;
	end;
	else
	do;
		EXPOSURE_SUBTYPE="SECURITIZATION";
		/* RW_BUCKET: Used for subsetting the output variables*/
		if EXT_ISSUE_MAP_RATING = 'MISS' AND APPROACH = "STD_IAA" then
		DO;
			REGRPT_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
			CQS_BUCKET       = put(INT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
		END;
		ELSE
		do;
			REGRPT_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
			CQS_BUCKET=put(EXT_ISSUE_INCEP_MAP_RATING, $MAP_CQS_EXT_RATING_STD.);
		end;
		
	end;
		

    /* Define the SENIORITY_STATUS cross-class*/
    if TRANCHE_SENIORITY_RANK = 1 then SENIORITY_STATUS = '1_Senior';
    else if TRANCHE_LOSS_RANK=1 then SENIORITY_STATUS='3_First losses';
    else SENIORITY_STATUS = '2_Mezanine';

    /* CCF BUCKET: Used for subsetting the output variables*/
    if EXPOSURE_TYPE EQ 'ON_BALANCE' then   
    REGRPT_CCF_BUCKET = 'NOT_APPLICABLE';
    else 
    REGRPT_CCF_BUCKET = put(CCF, MAP_CCF_REGRPT_SEC.);


	

    /* Map rated/unrated into cross-classification variable */
    if EXT_ISSUE_MAP_RATING NE 'MISS' then RATING_STATUS='RATED';
    else if INT_ISSUE_MAP_RATING NE 'MISS' and SEC_STRUCTURE_SUBTYPE = 'ABCP' then RATING_STATUS='RATED';
    else RATING_STATUS='UNRATED';

    INSTID = compress('crsec_sa'||_n_);
    INSTTYPE = 'regrpt_crsec_sa';
	
	_COSTVAR_ = &COSTVAR;
	
 RUN;     
/*---------------------------------------------------------------------------
* Step 4. Adjust portfolio with retained amount
* -------------------------------------------------------------------------*/  
data _all_exposures_(rename=(INSTID=EXP_ID));
set _detail.instvals(where=( 
    (POSITION_CATEGORY='EXPOSURE') AND 
    (INDEX(APPROACH, 'STD') NE 0) AND 
    (upcase(STD_PRODUCT_CLASS) IN ('SEC','SECURITIZATION'))
));
run;

data work._synthetic_pool_(keep=securitization_pool_rk SEC_STRUCTURE_TYPE);
  length SEC_STRUCTURE_TYPE $12.;
  set rd_stage.Securitization_pool_mart;
  SEC_STRUCTURE_TYPE=put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_SEC_STRUCTURE_TYPE.);
  if SEC_STRUCTURE_TYPE='SYNTHETIC' then output;
run;

proc sql; create table work.retained_exp(rename=(INSTID=EXP_ID)) as
select t1.instid, sum(t3.exp_value) as retained_amt
from rd_pos.Exposure_securitization as t1, 
              work._synthetic_pool_ as t2,
              work._all_exposures_  as t3
where 
t1.securitization_pool_rk = t2.securitization_pool_rk AND
t1.POSITION_CATEGORY = 'EXPOSURE' AND
upcase(t1.PRIMARY_BANK_ROLE) IN ('ORIGINATOR', 'INVESTOR') AND
t1.instid = t3.exp_id
group t1.instid
order by t1.instid;
quit;

PROC SORT DATA=_INTDS.CAPITAL_CRSEC_SA_CRD4; BY exp_id;RUN;
PROC SORT DATA=retained_exp; BY exp_id;RUN;

data _INTDS.CAPITAL_CRSEC_SA_CRD4;
 merge _INTDS.CAPITAL_CRSEC_SA_CRD4
         work.retained_exp ;
 by exp_id;
 if EXPOSURE_TYPE='' then delete; /* The EXPOSURE_TYPE is missing only if an EXP_ID  */
                                  /* doesn't exist in _INTDS.CAPITAL_CRSEC_SA_CRD4. These */
                                  /* records can be deleted                          */
run;

/*---------------------------------------------------------------------------
* Step 5. Adjust portfolio to include inflow/outflow information through
*         the inclusion of two instrument types
* -------------------------------------------------------------------------*/   
    
/*-Separate the mitigants from the exposures and assign them an insttype -*/
data work.only_crm work.only_exp;
length INSTTYPE $16.;
set _INTDS.CAPITAL_CRSEC_SA_CRD4;
INSTID = compress('crsec_sa'||_n_);
INSTTYPE = 'regrpt_crsec_sa';
if crm_id ne '' and exp_id ne '' and upcase(insttype)eq "REGRPT_CRSEC_SA" then
do;
	SEC_TOTAL_AMT_ORIGINATED =0;RETAINED_AMT=0;EXP_VALUE=0; SEC_DEDUCTION_AMT=0;SEC_INFRINGE_ADJUST_AMT=0;RWA_SEC_MEMO_AMT=0;;
end;

output only_exp;
 
if CRM_ID NE '' then
do;
COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
INSTID = compress('crsec_crm'||_n_);
INSTTYPE = 'regrpt_crsec_crm';

EXP_VALUE=0;
EAD=0;
EAD_ADJ=0;
EAD_PORTION=0;
RWA_SEC_MAT_MIS_ADJ_AMT=0;
output only_crm;
end;
run;


/*-Merge the mitigants with all the exposures
* and assign an insttype to the exposure. -*/
data _intds.CAPITAL_CRSEC_SA_CRD4;
set work.only_crm(rename=(INTERNAL_ORG_RK=INT_ORG_RK))
work.only_exp(rename=(INTERNAL_ORG_RK=INT_ORG_RK));     
INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
run;


/*-Remove duplicate Total Securitization amount originated 
* and assign an insttype to the exposure. -*/
proc sort data=_intds.CAPITAL_CRSEC_SA_CRD4;
by SECURITIZATION_POOL_RK descending SEC_TOTAL_AMT_ORIGINATED ;
run;

data _intds.CAPITAL_CRSEC_SA_CRD4;
 set _intds.CAPITAL_CRSEC_SA_CRD4;
 by SECURITIZATION_POOL_RK;
 if not first.SECURITIZATION_POOL_RK then SEC_TOTAL_AMT_ORIGINATED=0;
run;

/* Check to see if data was created */
%checkdata  (_detail,&inputds , (INDEX(APPROACH, 'STD') NE 0) AND 
                                ( (upcase(STD_PRODUCT_CLASS) EQ 'SEC') OR 
                                  (upcase(STD_PRODUCT_CLASS) EQ 'SECURITIZATION'))
             );
   %if &HAVEDATA = YES %then %status(CAPITAL_CRSEC_SA_CRD4,SUCCESS,Created portfolio,CAPITAL_CRSEC_SA_CRD4);%else
   %status(CAPITAL_CRSEC_SA_CRD4,FAILED,Exposures for securization under standardized approach,CAPITAL_CRSEC_SA_CRD4);

options notes source;    
%mend b20_prep_regrpt_port_sec_sa_crd4;
