/*****************************************************************************
* Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b25_prepare_regrpt_port_le_crd4.sas
*
* PURPOSE: Create portoflio data for CR regulatory reports (LE Template )
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
 
/*---------------------------------------------------------------------------
* Step 1. Check to see if the user has requested CR-IRBA data
* -------------------------------------------------------------------------*/
 
%macro b25_prepare_regrpt_port_le_crd4;
%global le_cpty_all le_cpty_i le_cpty_u le_cpty_irb;
%macro prepare_regrpt_port_le (inputds);
/*libname _rg_calc "&REGPATH";*/
%let HAVEDATA=NO;
 
%if  
     (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE1_CRD4) OR
     (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE2_CRD4) OR
	 (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE3_CRD4) OR
     (%UPCASE(&REGPROJECTNAME) EQ ALL) 
/*OR */
/*     (%UPCASE(&REGPROJECTNAME) EQ IRB)*/

%then %do;
 
%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then %do;
 
libname _incrlib  "&REGPATH";
%goto checkirba_opt;
 
%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
 
libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
%goto checkirba_rnk;
 
%end;
 
%end;
    
%else %goto SKIP;
 
 
/*---------------------------------------------------------------------------
* Step 2. Check to see if we have data
* -------------------------------------------------------------------------*/
 
%SKIP:
/* User did not request LE portfolio - skip */
%put WARNING: User did not request Large exposure template;
%return;
 
 
%CHECKIRBA_OPT:
%checkdata (_incrlib, &INPUTDS , LE_COUNTERPARTY_RK ne .);
 
%CHECKIRBA_RNK:
%checkdata (_incrlib, &INPUTDS , LE_COUNTERPARTY_RK ne .);
 
 
/* If no data then return*/
%if   (&HAVEDATA = NO)  %then %do;
%print_msg (WARNING,3,1);/*------------------------>Change this message*/
%return;
%end;
 
/*---------------------------------------------------------------------------
* Step 3. Creating portfolio for LE counterparties
* -------------------------------------------------------------------------*/
 
%print_msg(note,3,26);
%if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,108);
/*Filter out data on the basis of LE_COUNTERPARTY_RK*/ 
/*calculate the obligor_pd buckets (by counterparty) */

data work._inputs_;
set _incrlib.&INPUTDS(where=(LE_COUNTERPARTY_RK NE .));
if CRM_ID NE '' then _pd_val_ = PD_CRM_COUNTERPARTY;
else _pd_val_ = PD_EXP;
run;

proc sort data=work._inputs_;
by LE_COUNTERPARTY_RK;
run;



/****************************below code snippet not reqd for LE? */
/*proc summary data=work._inputs_;*/
/*var _pd_val_;*/
/*by COUNTERPARTY_ID;*/
/*weight EAD_PORTION;*/
/*output out=_obligor_pd_ mean=obligor_pd_avg;*/
/*run;*/
/*******************************below code snippet not reqd for LE? */ 
/*data work._inputs_;*/
/*length OBLIGOR_GRADE $32.;*/
/*label obligor_pd_avg="AVERAGE_OBLIGOR_PD";*/
/*merge work._inputs_*/
/*_obligor_pd_(drop=_type_ _freq_);*/
/*by COUNTERPARTY_ID;*/
/*OBLIGOR_GRADE = put(obligor_pd_avg, MAP_PD_BUCKET.);*/
/*run;*/

 
/*Make sure that the SPECIFIC_PROVISIONS will be nullified for duplicate EXP_ID records*/

proc sort data=work._inputs_;
by EXP_ID;
run;


data work._inputs_;
set work._inputs_;
if FIRST.EXP_ID then VALID_PROVISION = 1;
else VALID_PROVISION = 0;
by exp_id;
run;

/* In IRB and IRBA Case get CRM Values for LGD_CRM_ADJUSTED_FLG=1*/

/*data work._inputs_ (DROP=CRM_VALUE_B) ;*/
/* merge work._inputs_(in=a) _rg_calc.Lgd_adjusted_crm_IRB (in=b rename= (CRM_VALUE= CRM_VALUE_B));*/
/* by EXP_ID;*/
/* if a;*/
/* if a and b then  */
/* CRM_USED_AMT_EFF = CRM_VALUE_B ; */
/*run; */
 
/* Code to create CRM_FLG */ 
proc sort data=_inputs_ out=exp_wt_crm(where=(crm_id ne "") keep=crm_id exp_id  CRM_USED_AMT_EFF CRM_TYPE ELIGIBLE_CRM_TYPE);
by exp_id;
run;
proc sort data=_inputs_ out=_capital_le;
by exp_id;
run;

data work._inputs_ (drop=CRM_USED_AMT_EFF1 CRM_TYPE1 ELIGIBLE_CRM_TYPE1 );
 merge exp_wt_crm(in=a rename=(CRM_USED_AMT_EFF=CRM_USED_AMT_EFF1 CRM_TYPE = CRM_TYPE1 ELIGIBLE_CRM_TYPE= ELIGIBLE_CRM_TYPE1 ))
       _capital_le(in=b);
 by exp_id;
 if a then do;
	CRM_FLG=1;
	CRM_USED_AMT_EFF_EXP=CRM_USED_AMT_EFF1;
	CRM_TYPE = CRM_TYPE1 ; 
	ELIGIBLE_CRM_TYPE= ELIGIBLE_CRM_TYPE1 ; 
 end;
 if b;
 if not missing(crm_id) then CRM_USED_AMT_EFF_EXP=0;
run; 

 
/*Continue with the creation of other cross-class variables*/
 
data _intds.CAPITAL_LE;
length INTERNAL_ORG_RK LECPTYID $25.;
set work._inputs_(rename=(INTERNAL_ORG_RK=INT_ORG_RK));
*length  GUAR_FLAG SL_FLAG $8.
EXPOSURE_CLASS_LEVEL_1 EXPOSURE_CLASS_LEVEL_2
EXPOSURE_TYPE OTHER_CR_CLASSES CRM_CLASS_LEVEL_1
CRM_CLASS_LEVEL_2 CRM_GROUP SL_TYPE $16.
CRM_PRODUCT $32.
DIR_EXPOSURE INDIR_EXPOSURE 8.
;
if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) ); 

/* 3e. Define the CRM groups and products */
IF CRM_ID NE '' then DO;
SPECIFIC_PROVISION = 0;
/*if put(put(cats(CRM_REG_COUNTERPARTY_TYPE_CD, CRM_REG_PRODUCT_CD), $MAP_APPROACH_CLASS.), $MAP_APPROACH.) in ('STD') then */
/*	do;*/
/*	CRM_USED_AMT=0;*/
/*	CRM_USED_AMT_EFF=0;*/
/*	end;*/
 
END;
    *INSTTYPE = 'regrpt_le';
    INSTID = compress('INSTID_'||_n_);
    if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) );

 INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
/* LE_COUNTERPARTY_RK = put(LE_CPTY_RK, MAP_INTERNAL_ORG_RK_CARPT.);*/
IF (NOT MISSING(LE_COUNTERPARTY_RK)) THEN LECPTYID = compress('LE' || input(LE_COUNTERPARTY_RK, $30.));

if DIRECT_EXP_FLG = 'Y' then 
	do;

            if RW_EXP = 0 then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT ;
            if TRADING_BOOK_FLG = '1' then 
			do;
                if TRADE_EXP_FLG = 1 or (COUNTERPARTY_SUBCLASS ='CCP' and BANKRUPTCY_REMOTE_FLG = '1') 
				then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT ;
            end;
            if CCF = 0 then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT ;
	end;
else do;
            if RW_CRM = 0 then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT;
	 end;
/*MAT_EFF_MONTH= put(RESIDUAL_MATURITY_MONTH,MAP_MAT_BUCKETS_LE.);*/ /*MATURITY IN MONTHS*/
run;


/*Part 2: Calculate Individual column values */
/*NO TRANSPOSE*/
/*data _INTDS.crm_Alloc_le1 */
/*data _intds.capital_le;*/
/*SET _INTDS._TEMP_GROUP _INTDS._TEMP_IND ;*/
/*run;*/
data _intds.capital_le;
set _intds.capital_le;
/*set _INTDS.CAPITAL_LE;*/
/*	CPTY_NM=COUNTERPARTY_NAME;*/
/*	CPTY_CD=COUNTERPARTY_TYPE_CD;*/
/*	LEI=LEGAL_ENTITY_ID;*/
/*		cpty_group=counterparty_group;*/
/*	IF counterparty_group ='' THEN CPTY_TYPE='INDIVIDUAL';*/
/*	ELSE CPTY_TYPE='GROUP';*/
/**/
/*	CPTY_RES=COUNTERPARTY_COUNTRY;*/
/*	CPTY_SECTOR=SECTOR;*/
/*	NACE=NACE;*/
if direct_exp_flg='Y'  then
do;
	IF LE_PRODUCT_CLASS='EQUITY_INSTRUMENT' THEN 
		DIR_EXP_EQU=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_PRODUCT_CLASS = 'DEBT_INSTRUMENT' THEN 
		DIR_EXP_DEBT=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_PRODUCT_CLASS = 'DERIVATIVE' THEN 
		DIR_EXP_DERIV =LE_ORIG_EXPOSURE_AMT;
end;
else do;
	IF LE_PRODUCT_CLASS='EQUITY_INSTRUMENT' THEN 
		IND_EXP_EQU=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_PRODUCT_CLASS = 'DEBT_INSTRUMENT' THEN 
		IND_EXP_DEBT=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_PRODUCT_CLASS = 'DERIVATIVE' THEN 
		IND_EXP_DERIV =LE_ORIG_EXPOSURE_AMT;
end;

if direct_exp_flg='Y'  then
do;
	IF LE_OBSI_TYPE='OBSI_LOAN_COM' THEN 
			DIR_EXP_OBSI_LOAN=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_OBSI_TYPE = 'OBSI_FIN_GUARANTEE' THEN 
			DIR_EXP_OBSI_GUAR=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_OBSI_TYPE = 'OBSI_OTHER' THEN 
			DIR_EXP_OBSI_OTHER =LE_ORIG_EXPOSURE_AMT;
end;
else do;
	IF LE_OBSI_TYPE='OBSI_LOAN_COM' THEN 
			IND_EXP_OBSI_LOAN=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_OBSI_TYPE = 'OBSI_FIN_GUARANTEE' THEN 
			IND_EXP_OBSI_GUAR=LE_ORIG_EXPOSURE_AMT;
	ELSE IF LE_OBSI_TYPE = 'OBSI_OTHER' THEN 
			IND_EXP_OBSI_OTHER =LE_ORIG_EXPOSURE_AMT;
end;
/*COL 200 AND FLAG ON COL 025*/
	IF	UNDERLYING_EXP_EAD NOT IN (.,0) THEN 
	DO;
	UNDERLYING_FLG='YES';
	END;
	ELSE DO;
	UNDERLYING_FLG='NO';
	END;
/*col 70*/

if not (UNDERLYING_EXP_EAD in (.,0))then 
TOT_ORIG_EXP= SUM(LE_ORIG_EXPOSURE_AMT,UNDERLYING_EXP_EAD);
ELSE TOT_ORIG_EXP=LE_ORIG_EXPOSURE_AMT; /*COL 70*/


/*col 80*/
if IN_DEFAULT_FLG=1 THEN
TOT_ORIG_EXP_DEF = LE_ORIG_EXPOSURE_AMT;


VALUE_ADJ_AMT = sum(0, SPECIFIC_PROVISION); /*col 210*/
/*col 220- not to be implemented. COL 230, 240 computed in d00_pm_regrpt*/
/*COL 260 TO 300*/
/*As per the CP50, those columns should get reflected in the Exposures values
  for Substitution effect of eligible credit risk mitigation techniques  */

/*  
IF CRM_ID NE '' THEN 
DO;
*/
 IF "&STD_CRM_APPROACH" NE "COMPREHENSIVE"	THEN DO ; 
		IF LE_PRODUCT_CLASS='EQUITY_INSTRUMENT' THEN 
			/*CRM_EXP_EQU=CRM_USED_AMT_EFF;*/
			CRM_EXP_EQU=CRM_USED_AMT_EFF_EXP; 
		ELSE IF LE_PRODUCT_CLASS = 'DEBT_INSTRUMENT' THEN 
			/*CRM_EXP_DEBT=CRM_USED_AMT_EFF;*/
			CRM_EXP_DEBT=CRM_USED_AMT_EFF_EXP;
		ELSE IF LE_PRODUCT_CLASS = 'DERIVATIVE' THEN 
			/*CRM_EXP_DERIV =CRM_USED_AMT_EFF;*/
			CRM_EXP_DERIV =CRM_USED_AMT_EFF_EXP;
	END;
/*	
END;

IF CRM_ID NE '' THEN
DO;
*/
	IF "&STD_CRM_APPROACH" NE "COMPREHENSIVE"	THEN DO ; 
		IF LE_OBSI_TYPE='OBSI_LOAN_COM' THEN 
				/*CRM_EXP_OBSI_LOAN=CRM_USED_AMT_EFF;*/
				CRM_EXP_OBSI_LOAN=CRM_USED_AMT_EFF_EXP;
		ELSE IF LE_OBSI_TYPE = 'OBSI_FIN_GUARANTEE' THEN 
				/*CRM_EXP_OBSI_GUAR=CRM_USED_AMT_EFF;*/
				CRM_EXP_OBSI_GUAR=CRM_USED_AMT_EFF_EXP;
		ELSE IF LE_OBSI_TYPE = 'OBSI_OTHER' THEN 
				/*CRM_EXP_OBSI_OTHER =CRM_USED_AMT_EFF;*/
				CRM_EXP_OBSI_OTHER =CRM_USED_AMT_EFF_EXP;
	END ; 
/*	
END;
*/

/*col 310*/
/*If CRM_TYPE IN ('FINANCIAL_COLLATERAL') and ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_COMPREHENSIVE' and "&STD_CRM_APPROACH" NE "SIMPLE"
then CREDIT_PROT_NOT_SUB_EFFECT = CRM_VALUE*(1 - max(HAIRCUT_CRM/100,0) - max(HAIRCUT_FX/100,0) )*MAT_MISMATCH_WEIGHT_CRM;*/ 
If CRM_TYPE IN ('FINANCIAL_COLLATERAL') and ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_COMPREHENSIVE' and "&STD_CRM_APPROACH" NE "SIMPLE"
then CREDIT_PROT_NOT_SUB_EFFECT = CRM_USED_AMT_EFF_EXP ; /* CRM_USED_AMT_EFF; */ 

IF CRM_SUBTYPE IN ('CRE','RRE') THEN ELIG_CRM_RE=CRM_USED_AMT_EFF_EXP ; /* CRM_USED_AMT_EFF;*/  /*COL 320*/
/*col 330 */
/*if DIRECT_EXP_FLG = 'Y' and RW_EXP = 0 then LE_EXEMPTED_AM = EXP_VALUE; */
/*ELSE if DIRECT_EXP_FLG = 'N' and RW_CRM = 0 then LE_EXEMPTED_AM = CRM_USED_AMT_EFF; */
/*if DIRECT_EXP_FLG = 'Y' then */
/*	do;*/
/**/
/*            if RW_EXP = 0 then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT;*/
/*            if TRADING_BOOK_FLG = '1' then */
/*			do;*/
/*                if TRADE_EXP_CLEARED_THRU_CCP_FLG = 1 or (COUNTERPARTY_SUBCLASS ='CCP' and MARGIN_BANKRUPTCY_REMOTE_FLG = '1') */
/*				then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT;*/
/*            end;*/
/*            if CCF = 0 then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT;*/
/*	end;*/
/*else do;*/
/*            if RW_CRM = 0 then LE_EXEMPTED_AM = LE_ORIG_EXPOSURE_AMT;*/
/*	 end;*/

/*COL 340,350 COMPUTED IN D00_PM_REGRPT*/
/* LE capital charge for CA report */
LE_CAP_CHG=LE_CAP_CHG;
run;


proc sql noprint;
create table _intds.capital_le_group as 
select instid, counterpartyid,internal_org_rk,le_counterparty_rk, counterparty_group,counterparty_group_parent_flg,approach, lecptyid, trading_book_flg,
sum(DIR_EXP_DEBT)  as  DIR_EXP_DEBT,
sum(DIR_EXP_EQU)  as  DIR_EXP_EQU,
sum(DIR_EXP_DERIV)  as  DIR_EXP_DERIV,
sum(IND_EXP_EQU)  as  IND_EXP_EQU,
sum(IND_EXP_DEBT)  as  IND_EXP_DEBT,
sum(IND_EXP_DERIV)  as  IND_EXP_DERIV,
sum(DIR_EXP_OBSI_LOAN)  as  DIR_EXP_OBSI_LOAN,
sum(DIR_EXP_OBSI_GUAR)  as  DIR_EXP_OBSI_GUAR,
sum(DIR_EXP_OBSI_OTHER)  as  DIR_EXP_OBSI_OTHER,
sum(IND_EXP_OBSI_LOAN)  as  IND_EXP_OBSI_LOAN,
sum(IND_EXP_OBSI_GUAR)  as  IND_EXP_OBSI_GUAR,
sum(IND_EXP_OBSI_OTHER)  as  IND_EXP_OBSI_OTHER,
UNDERLYING_FLG  as  UNDERLYING_FLG,
sum(TOT_ORIG_EXP)  as  TOT_ORIG_EXP,
sum(TOT_ORIG_EXP_DEF)  as  TOT_ORIG_EXP_DEF,
sum(VALUE_ADJ_AMT)  as  VALUE_ADJ_AMT,
sum(CRM_EXP_EQU)  as  CRM_EXP_EQU,
sum(CRM_EXP_DEBT)  as  CRM_EXP_DEBT,
sum(CRM_EXP_DERIV)  as  CRM_EXP_DERIV,
sum(CRM_EXP_OBSI_LOAN)  as  CRM_EXP_OBSI_LOAN,
sum(CRM_EXP_OBSI_GUAR)  as  CRM_EXP_OBSI_GUAR,
sum(CRM_EXP_OBSI_OTHER)  as  CRM_EXP_OBSI_OTHER,
sum(CREDIT_PROT_NOT_SUB_EFFECT)  as  CREDIT_PROT_NOT_SUB_EFFECT,
sum(ELIG_CRM_RE)  as  ELIG_CRM_RE,
sum(LE_EXEMPTED_AM) as LE_EXEMPTED_AM,
sum(LE_CAP_CHG)  as  LE_CAP_CHG,
EAD
FROM _INTDS.CAPITAL_LE 
where COUNTERPARTY_GROUP is not missing
%if %upcase(&REGPROJECTNAME) = CAPITAL_LE1_CRD4 or %upcase(&REGPROJECTNAME) = CAPITAL_LE2_CRD4 %then %do;
GROUP BY COUNTERPARTY_GROUP ;
%end;
%else %if %upcase(&REGPROJECTNAME)=CAPITAL_LE3_CRD4 %then %do;
GROUP BY LE_COUNTERPARTY_RK ;
%end;
%else %do;
;
%end;

QUIT;

PROC SQL NOPRINT;
CREATE TABLE _INTDS.capital_le_IND AS 
SELECT instid, counterpartyid,internal_org_rk,le_counterparty_rk, counterparty_group,counterparty_group_parent_flg,approach, lecptyid,trading_book_flg,
sum(DIR_EXP_DEBT)  as  DIR_EXP_DEBT,
sum(DIR_EXP_EQU)  as  DIR_EXP_EQU,
sum(DIR_EXP_DERIV)  as  DIR_EXP_DERIV,
sum(IND_EXP_EQU)  as  IND_EXP_EQU,
sum(IND_EXP_DEBT)  as  IND_EXP_DEBT,
sum(IND_EXP_DERIV)  as  IND_EXP_DERIV,
sum(DIR_EXP_OBSI_LOAN)  as  DIR_EXP_OBSI_LOAN,
sum(DIR_EXP_OBSI_GUAR)  as  DIR_EXP_OBSI_GUAR,
sum(DIR_EXP_OBSI_OTHER)  as  DIR_EXP_OBSI_OTHER,
sum(IND_EXP_OBSI_LOAN)  as  IND_EXP_OBSI_LOAN,
sum(IND_EXP_OBSI_GUAR)  as  IND_EXP_OBSI_GUAR,
sum(IND_EXP_OBSI_OTHER)  as  IND_EXP_OBSI_OTHER,
UNDERLYING_FLG,
sum(TOT_ORIG_EXP)  as  TOT_ORIG_EXP,
sum(TOT_ORIG_EXP_DEF)  as  TOT_ORIG_EXP_DEF,
sum(VALUE_ADJ_AMT)  as  VALUE_ADJ_AMT,
sum(CRM_EXP_EQU)  as  CRM_EXP_EQU,
sum(CRM_EXP_DEBT)  as  CRM_EXP_DEBT,
sum(CRM_EXP_DERIV)  as  CRM_EXP_DERIV,
sum(CRM_EXP_OBSI_LOAN)  as  CRM_EXP_OBSI_LOAN,
sum(CRM_EXP_OBSI_GUAR)  as  CRM_EXP_OBSI_GUAR,
sum(CRM_EXP_OBSI_OTHER)  as  CRM_EXP_OBSI_OTHER,
sum(CREDIT_PROT_NOT_SUB_EFFECT)  as  CREDIT_PROT_NOT_SUB_EFFECT,
sum(ELIG_CRM_RE)  as  ELIG_CRM_RE,
sum(LE_EXEMPTED_AM) as LE_EXEMPTED_AM,
sum(LE_CAP_CHG)  as  LE_CAP_CHG,
EAD
FROM _INTDS.CAPITAL_LE 
where COUNTERPARTY_GROUP is missing
GROUP BY LECPTYID ;
QUIT;

data _intds.capital_le_temp;
set  _INTDS.capital_le_group _INTDS.capital_le_IND ;
run;


/*Calculate Eligible capital for current entity*/
/*Part 3: Calculate all largest exposres, 20 largest (IRB) + 10 largest (URE, FI)*/

data fin_rep_data;
length elig_capital 8.;
set rd_stage.financial_reporting_data;
elig_capital=ELIGC_TIER1_AMT+ max(1/3*(ELIGC_TIER1_AMT),ELIGC_TIER2_AMT);
le_exp_elig_capital=0.1*elig_capital;
run;

data _null_;
set fin_rep_data;
call symputx("TOT_ELIG_CAP",elig_capital,'G');
call symputx("VALID_LE_EXP",le_exp_elig_capital,'G');
/*call symput("NON_INST_LIMIT",LE_LIMITS_NON_INST_AMT);*/
/*call symput("INST_LIMIT",LE_LIMITS_INST_AMT);*/
where internal_org_rk=&SYSTEM_ORG_RK;
run;

/*to calculate all largest exposures i.e. those exposures that have value that is > 10% of ead*/
PROC SQL ;
CREATE table all_largest as 
SELECT distinct LE_COUNTERPARTY_RK,counterparty_group, counterparty_group_parent_flg, TOT_ORIG_EXP as sum_ead_portion
FROM _INTDS.CAPITAL_LE_temp
GROUP BY counterparty_group
having sum_ead_portion gt &VALID_LE_EXP
ORDER BY SUM_EAD_PORTION DESC
;
quit;

%if %attrn(all_largest, NOBS) NE 0 %then %do;

proc sql noprint;
select le_counterparty_rk into :le_cpty_all separated by ',' from 
all_largest
where counterparty_group='' or counterparty_group_parent_flg=1;
;
quit;
%end;
%else %do;
  %let le_cpty_all=0;
%end;


/*to calculate 20 largest exposures under IRB approach*/

/*(SUM(SUM_EAD_PORTION,-VALUE_ADJ_AMT)-LE_EXEMPTED_AM)*/

/*PROC SQL noprint ;*/
/*CREATE table twenty_largest_irb as */
/*SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, SUM(TOT_ORIG_EXP) as sum_ead_portion*/
/*FROM _INTDS.CAPITAL_LE*/
/*where approach IN ("IRB","IRBF","IRBA")*/
/*GROUP BY counterparty_group*/
/*;*/
/*quit;*/
/*data twenty_largest_irb;*/
/*set twenty_largest_irb;*/
/*large_exp_twenty=(SUM(SUM_EAD_PORTION,-VALUE_ADJ_AMT)-LE_EXEMPTED_AM);*/
/*run;*/
/*proc sort data = twenty_largest_irb;*/
/*by large_exp_twenty;*/
/*run;*/


PROC SQL noprint;
create table twenty_largest_irb as 
SELECT *
/*distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, TOT_ORIG_EXP as SUM_EAD_PORTION*/
/*,sum(VALUE_ADJ_AMT) as sum_value_adj */
/*,sum(LE_EXEMPTED_AM) as sum_le_exempt*/
from _intds.capital_le_temp
where approach IN ("IRB","IRBF","IRBA")
GROUP BY counterparty_group;
quit;

data twenty_largest_irb;
set twenty_largest_irb;
large_exp_twenty=SUM(TOT_ORIG_EXP,-value_adj_amt,-le_exempted_AM);
run;

proc sort data = twenty_largest_irb;
by large_exp_twenty;
run; 

/*PROC SQL noprint ;*/
/*CREATE table twenty_largest_irb as */
/*SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, SUM(TOT_ORIG_EXP,-VALUE_ADJ_AMT,-LE_EXEMPTED_AM) as large_exp_twenty*/
/*FROM _INTDS.CAPITAL_LE*/
/*where approach IN ("IRB","IRBF","IRBA")*/
/*GROUP BY counterparty_group*/
/*having sum_ead_portion gt &VALID_LE_EXP c*/
/*ORDER BY large_exp_twenty */
/*DESC c*/
/*;*/
/*quit;*/

data twenty_largest_irb;
set twenty_largest_irb;
where counterparty_group='' or counterparty_group_parent_flg=1;
run;
proc rank data = twenty_largest_irb  out=twenty_largest_irb ties=dense descending ;
var large_exp_twenty;
ranks rank;
run;
%if %attrn(twenty_largest_irb, NOBS) NE 0 %then %do;
proc sql noprint;
select le_counterparty_rk into :le_cpty_irb separated by ',' from twenty_largest_irb
where rank between 1 and 20;
quit;
%end;
%else %do;
  %let le_cpty_irb=0;
%end;

/*to calculate 10 largest for financial and unregulated entities*/
/*SUM(SUM_EAD_PORTION,-VALUE_ADJ_AMT)*/

PROC SQL noprint;
create table ten_largest_fi as 
SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
,sum(VALUE_ADJ_AMT) as sum_value_adj
from _intds.capital_le
where financial_entity_type_cd="I"
GROUP BY counterparty_group;
quit;

data ten_largest_fi;
set ten_largest_fi;
large_exp_ten_fi=SUM(SUM_EAD_PORTION,-sum_value_adj);
run;

proc sort data = ten_largest_fi;
by large_exp_ten_fi;
run; 

/*PROC SQL noprint ;*/
/*CREATE table ten_largest_fi as */
/*SELECT distinct LE_COUNTERPARTY_RK, counterparty_group,counterparty_group_parent_flg, SUM(SUM_EAD_PORTION,-VALUE_ADJ_AMT) as large_exp_ten*/
/*FROM _INTDS.CAPITAL_LE*/
/*where financial_entity_type_cd="I"*/
/*GROUP BY counterparty_group*/
/*having sum_ead_portion gt &VALID_LE_EXP c*/
/*ORDER BY large_exp_ten */
/*DESC c*/
/*;*/
/*quit;*/

data ten_largest_fi;
set ten_largest_fi;
where counterparty_group='' or counterparty_group_parent_flg=1;
run;
proc rank data = ten_largest_fi  out=ten_largest_fi ties=dense descending ;
var large_exp_ten_fi;
ranks rank;
run;
%if %attrn(ten_largest_fi, NOBS) NE 0 %then %do;
proc sql noprint;
select le_counterparty_rk into :le_cpty_i separated by ',' from ten_largest_fi
where rank between 1 and 10;
quit;
/*%put &le_cpty_i;*/
%end;
%else %do;
  %let le_cpty_i=0;
%end;

PROC SQL noprint ;
CREATE table  ten_largest_ure as 
SELECT distinct LE_COUNTERPARTY_RK, counterparty_group, counterparty_group_parent_flg, sum(TOT_ORIG_EXP) as SUM_EAD_PORTION
,sum(VALUE_ADJ_AMT) as sum_value_adj
FROM _INTDS.CAPITAL_LE
where financial_entity_type_cd="U"
GROUP BY counterparty_group
;
quit;

data ten_largest_ure;
set ten_largest_ure;
large_exp_ten_ure=SUM(SUM_EAD_PORTION,-sum_value_adj);
run;

proc sort data = ten_largest_ure;
by large_exp_ten_ure;
run; 

data ten_largest_ure;
set ten_largest_ure;
where counterparty_group='' or counterparty_group_parent_flg=1;
run;
proc rank data = ten_largest_ure  out=ten_largest_ure ties=dense descending ;
var large_exp_ten_ure;
ranks rank;
run;
%if %attrn(ten_largest_ure, NOBS) NE 0 %then %do;
proc sql outobs=10 nowarn noprint;
select le_counterparty_rk into :le_cpty_u  separated by ',' from 
ten_largest_ure
where rank between 1 and 10;
;
quit;
/*%put &le_cpty_u;*/
%end;
%else %do;
  %let le_cpty_u=0;
%end;

/*PROC SQL;*/
/*CREATE TABLE RD_ROOT.CPTY_DETAILS_LE1 AS*/
/*SELECT *,SUM(LE_ORIG_EXPOSURE_AMT) as sum_ead_portion, 'regrpt_le1' as INSTTYPE, &TOT_ELIG_CAP as TOT_ELIG_CAP*/
/*FROM _INTDS.CAPITAL_LE*/
/*where le_counterparty_rk in (&le_cpty_all,&le_cpty_i,&le_cpty_u,&le_cpty_irb)*/
/*GROUP BY LE_COUNTERPARTY_RK*/
/*having sum_ead_portion ge &VALID_LE_EXP;*/
/*quit;*/
%get_cpty_details_le1_crd4; 

/*LE2 report: for  large exposures that belong to a group AND individual large exposures*/

/*PROC SQL NOPRINT;*/
/*CREATE TABLE _INTDS.CAPITAL_LE2 AS*/
/*SELECT *,SUM(LE_ORIG_EXPOSURE_AMT) as sum_ead_portion, 'regrpt_le2' as INSTTYPE, &TOT_ELIG_CAP as TOT_ELIG_CAP*/
/*FROM _INTDS.CAPITAL_LE*/
/*where le_counterparty_rk in (&le_cpty_all,&le_cpty_i,&le_cpty_u,&le_cpty_irb)*/
/*   GROUP BY LE_COUNTERPARTY_RK*/
/*having sum_ead_portion ge &VALID_LE_EXP;*/
/*quit;*/

PROC SQL;
CREATE TABLE _INTDS.CAPITAL_LE2 AS
SELECT *, TOT_ORIG_EXP as SUM_EAD_PORTION, 'regrpt_le2' as INSTTYPE, &TOT_ELIG_CAP as TOT_ELIG_CAP
FROM _INTDS.CAPITAL_LE_temp
/*group by counterparty_group*/
;
QUIT;

data _INTDS.CAPITAL_LE2;
set _INTDS.CAPITAL_LE2;
where le_counterparty_rk in (&le_cpty_all,&le_cpty_i,&le_cpty_u,&le_cpty_irb);
run;

proc sort data = _INTDS.CAPITAL_LE2 nodupkey;
by LECPTYID;
run;


proc sort data=_INTDS.CAPITAL_LE2 out= _INTDS.groups (keep=counterparty_group) nodupkey;
where counterparty_group ne "";
by counterparty_group;
run;


/*PROC SQL;*/
/*CREATE TABLE _INTDS.CAPITAL_LE2 AS*/
/*SELECT *,SUM(LE_ORIG_EXPOSURE_AMT) as sum_ead_portion, 'regrpt_le2' as INSTTYPE, &TOT_ELIG_CAP as TOT_ELIG_CAP*/
/*FROM _INTDS.CAPITAL_LE*/
/*WHERE le_counterparty_rk in (&le_cpty_all,&le_cpty_i,&le_cpty_u,&le_cpty_irb);*/
/*QUIT;*/

/*LE 3 report: for  individual large exposures under a group */

PROC SQL;
CREATE TABLE _INTDS.CAPITAL_LE3 AS
SELECT *, TOT_ORIG_EXP as SUM_EAD_PORTION, 'regrpt_le3' as INSTTYPE, &TOT_ELIG_CAP as TOT_ELIG_CAP
FROM _INTDS.CAPITAL_LE_temp
where counterparty_group in (select counterparty_group from _intds.groups)
group by LECPTYID;
QUIT;

proc sort data = _INTDS.CAPITAL_LE3 nodupkey;
by LECPTYID;
run;

/*PROC SQL NOPRINT;*/
/*CREATE TABLE _INTDS.CAPITAL_LE3 AS*/
/*  SELECT *,SUM(LE_ORIG_EXPOSURE_AMT) as sum_ead_portion,'regrpt_le3' as INSTTYPE, &TOT_ELIG_CAP as TOT_ELIG_CAP*/
/*	,&NON_INST_LIMIT AS NON_INST_LIMIT, &INST_LIMIT AS INST_LIMIT */
/*FROM _INTDS.CAPITAL_LE*/
/*  WHERE COUNTERPARTY_GROUP NE '' */
/*  and le_counterparty_rk in (&le_cpty_all,&le_cpty_i,&le_cpty_u,&le_cpty_irb)*/
/*   GROUP BY LE_COUNTERPARTY_RK*/
/*having sum(LE_ORIG_EXPOSURE_AMT) ge &VALID_LE_EXP;*/
/*quit;*/


/*---------------------------------------------------------------------------
* Step 5. Check to see if data was created
* -------------------------------------------------------------------------*/
 

%checkdata (_intds,CAPITAL_LE2, LE_COUNTERPARTY_RK NE . );
data _intds.CAPITAL_LE2_CRD4;
	set _intds.CAPITAL_LE2;
run; 

proc sql; 
	drop table _intds.CAPITAL_LE2;
quit;	

%if &HAVEDATA = YES %then
%do;
%status(CAPITAL_LE2_CRD4,SUCCESS,Large Exposures,CAPITAL_LE2_CRD4);
%end;
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_LE2_CRD4,ERROR,Problems creating input data for portfolio,CAPITAL_LE2_CRD4);
%end;

%checkdata (_intds,CAPITAL_LE3, LE_COUNTERPARTY_RK NE . );
data _intds.CAPITAL_LE3_CRD4;
	set _intds.CAPITAL_LE3;
run; 
proc sql; 
	drop table _intds.CAPITAL_LE3;
quit;	

%if &HAVEDATA = YES %then
%do;
%status(CAPITAL_LE3_CRD4,SUCCESS,Large Exposures,CAPITAL_LE3_CRD4);
%end;
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_LE3_CRD4,ERROR,Problems creating input data for portfolio,CAPITAL_LE3_CRD4);
%end;

/*deassign the library */ 
/*libname _rg_calc ; */
%mend prepare_regrpt_port_le;
 
 
%prepare_regrpt_port_le(crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
options notes source;


%mend b25_prepare_regrpt_port_le_crd4;
