/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b30_prep_regrpt_port_crsa_crd4.sas
*
* PURPOSE: Create portoflio data for CR regulatory reports
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
 %macro b30_prep_regrpt_port_crsa_crd4;
/*---------------------------------------------------------------------------
* Step 1. Check to see if we user has requested SA data
* -------------------------------------------------------------------------*/
%get_regrpt_nls_strings;
%macro prepare_regrpt_port_cr_sa (inputds);
 
%let HAVEDATA=NO;
 
%if (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRSA_CRD4) OR (%UPCASE(&REGPROJECTNAME) EQ ALL)
OR  (%UPCASE(&REGPROJECTNAME) EQ STD)               OR (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CRGB_SA_CRD4)
%then %do;
 
%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then  %do;
 
libname _incrlib  "&REGPATH";
%let COSTVAR = _COST_;
%goto checksa_opt;
 
%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
 
libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
%let COSTVAR = _WEIGHT_;
%goto checksa_rnk;
 
%end;
 
%end;
    
%else %goto SKIP;
 
 
/*---------------------------------------------------------------------------
* Step 2. Check to see if we have data
* -------------------------------------------------------------------------*/
 
%SKIP:
/* User did not request CRIRB portfolio - skip */
%print_msg (NOTE,3,60);/*-------------------------->Add another message*/
%return;
 
 
%CHECKSA_OPT:
%checkdata (_incrlib, &INPUTDS , APPROACH in ('STD'));
 
%CHECKSA_RNK:
%checkdata (_incrlib, &INPUTDS , APPROACH in ('STD'));
 
 
/* If no data then return*/
%if   (&HAVEDATA = NO)  %then %do;
%print_msg (WARNING,3,1);/*------------------------>Change this message*/
%return;
%end;

 
/*---------------------------------------------------------------------------
* Step 3. Creating portfolio for SA approach
* -------------------------------------------------------------------------*/
 
%print_msg(note,3,26);
%if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,110);
 
/*Nullify the duplicate (by EXP_ID) records of provisions */
proc sort data=_incrlib.&INPUTDS(where=(INDEX(APPROACH, 'STD') NE 0 )) out=work._inputs_;
by EXP_ID;
run;
 
data work._inputs_;
set work._inputs_;
if FIRST.EXP_ID then VALID_PROVISION = 1;
else VALID_PROVISION = 0;
by exp_id;

   %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK %then %do; 
     if not missing(CRM_ID) then _weight_ = _weight_ ;
     else _weight_ = RW_EXP ;
   %end;
run;
 
data _intds.CAPITAL_CRSA;
 
set work._inputs_ (where=(INDEX(APPROACH, 'STD') NE 0 ));
 
length  GUAR_FLAG $8.
EXPOSURE_CLASS_LEVEL_1 EXPOSURE_CLASS_LEVEL_2
IMPLIED_CPTY_CD IMPLIED_PRODUCT_CD
CRM_CLASS_LEVEL_1 CRM_CLASS_LEVEL_2
EXPOSURE_TYPE RW_GROUPS RW_SUB_GROUP SME_SUPPORT_FACTOR COLLATERAL_TYPE$16.
REGRPT_CCF_BUCKET CRM_PRODUCT
EXPOSURE_CLASS_SA_LEVEL_1
CRM_CLASS_SA_LEVEL_1 DEFAULT_STATUS COUNTERPARTY_TYPE $32.
CPTY_COUNTRY $25;
 

 if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) ); 

/* 3a. Define the top hierarchy of CR_SA */
    
/* The exposure classes are calculated using both EXP and CRM info */
/* That way the inflow/outflow specification can be defined        */
 
/*First, get the implied CPTY and PRODUCT codes from the classes-subclasses*/

/*    IMPLIED_CPTY_CD    = put(compress(COUNTERPARTY_CLASS||'_'||COUNTERPARTY_SUBCLASS), $MAPPED_CPTY_CD.);*/
if COUNTERPARTY_SUBCLASS ne '' then
IMPLIED_CPTY_CD    = put(compress(COUNTERPARTY_CLASS||'_'||COUNTERPARTY_SUBCLASS), $MAPPED_CPTY_CD.);
else IMPLIED_CPTY_CD    = put(compress(COUNTERPARTY_CLASS), $MAPPED_CPTY_CD.);
/*IMPLIED_PRODUCT_CD = put(compress(STD_PRODUCT_CLASS||'_'||STD_PRODUCT_SUBCLASS), $MAPPED_STD_PRODUCT_CD.);*/
if STD_PRODUCT_SUBCLASS ne '' then
IMPLIED_PRODUCT_CD = put(compress(STD_PRODUCT_CLASS||'_'||STD_PRODUCT_SUBCLASS),$MAPPED_STD_PRODUCT_CD.);
else IMPLIED_PRODUCT_CD = put(compress(STD_PRODUCT_CLASS),$MAPPED_STD_PRODUCT_CD.);


EXPOSURE_CLASS_LEVEL_1 =
put(compress(IMPLIED_CPTY_CD||IMPLIED_PRODUCT_CD),$MAP_EXPOSURE_CLASS_1_REGRPT.);
 
EXPOSURE_CLASS_LEVEL_2 =
put(compress(IMPLIED_CPTY_CD||IMPLIED_PRODUCT_CD),$MAP_EXPOSURE_CLASS_2_REGRPT.);
 
EXPOSURE_CLASS_SA_LEVEL_1 =
put(compress(IMPLIED_CPTY_CD||IMPLIED_PRODUCT_CD),$MAP_SA_EXPOSURE_CLASS.);

EXPOSURE_CLASS_SA_LEVEL_2 = EXPOSURE_CLASS_SA_LEVEL_1;

if CRM_ID NE '' then do;
 
CRM_CLASS_LEVEL_1 =
put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_EXPOSURE_CLASS_1_REGRPT.);
 
CRM_CLASS_LEVEL_2 =
put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_EXPOSURE_CLASS_2_REGRPT.);

CRM_CLASS_SA_LEVEL_1 =
  put(compress(CRM_REG_COUNTERPARTY_TYPE_CD || CRM_REG_PRODUCT_CD), $MAP_SA_EXPOSURE_CLASS.);
  
end;


/*-Additional adjustments to the SA class */
/* Central Counterparty */

if TRADE_EXP_FLG =1 and BANKRUPTCY_REMOTE_FLG =1 and ASSET_TRANSFERRABLE_FLG =1 and
CCP_CPTY_SUBCLASS='QCCP'  then
	do;
	COUNTERPARTY_TYPE='CCP';
	end;
else
	COUNTERPARTY_TYPE='OTHER';
/* Reassign Exposure class to Equity Exposures */
IF IRB_PRODUCT_CLASS EQ 'EQUITY' THEN
DO;
		EXPOSURE_CLASS_SA_LEVEL_1  = 'EQUITY';
		CRM_CLASS_SA_LEVEL_1  = 'EQUITY';
END;
 
/* Categorize Exposures In Default */
/* if PAST_DUE_CLAIM_FLG EQ 1 or IN_DEFAULT_FLG EQ 1 then do;
  EXPOSURE_CLASS_SA_LEVEL_1  = 'IN_DEFAULT'; 
  CRM_CLASS_SA_LEVEL_1  = 'IN_DEFAULT';*/
  
if PAST_DUE_CLAIM_FLG EQ 1 or IN_DEFAULT_FLG EQ 1 then
	do;
		EXPOSURE_CLASS_SA_LEVEL_1  = 'PAST_DUE';
		CRM_CLASS_SA_LEVEL_1  = 'PAST_DUE';
		
		if (DEFAULT_DATE <= &RUNDATE AND DEFAULT_DATE > = DATEPART(&LAST_REPORTING_DATE)) THEN

		DO;
			IN_DEFAULT_STATUS='NEW';
		END;
		else
			IN_DEFAULT_STATUS='OLD';
	end;

/* Categorize 'Items associated with particularly High Risk' Exposures */
/* if HIGH_RISK_EXPOSURE_FLG EQ 1 then 
   do;
	EXPOSURE_CLASS_SA_LEVEL_1  = 'HIGH_RISK';
	CRM_CLASS_SA_LEVEL_1 = 'HIGH_RISK';
   end;*/

else if (HIGH_RISK_CATEGORY_FLG eq 1) then
	do;
		EXPOSURE_CLASS_SA_LEVEL_1  = 'HIGH_RISK';
		CRM_CLASS_SA_LEVEL_1 = 'HIGH_RISK';
	end;

/* Categorize short term claim on Institutions exposures*/
else
	do;
		if (EXPOSURE_CLASS_SA_LEVEL_1 EQ 'INSTITUTIONS' or EXPOSURE_CLASS_SA_LEVEL_1 EQ 'CORPORATES') and SHORT_TERM_ASSESS_FLG EQ 1 then
			EXPOSURE_CLASS_SA_LEVEL_1 = 'SHORT_CLAIM';

		if (CRM_CLASS_SA_LEVEL_1 EQ 'INSTITUTIONS' or CRM_CLASS_SA_LEVEL_1 EQ 'CORPORATES')
			and SHORT_TERM_ASSESS_FLG EQ 1 then
			CRM_CLASS_SA_LEVEL_1 = 'SHORT_CLAIM';

		if CRM_TYPE = "IRB_COLLATERAL" and CRM_SUBTYPE in ("RRE", "CRE") then
			do;
				EXPOSURE_CLASS_SA_LEVEL_1 = "RETAIL_SEC_IMOV";
				CRM_CLASS_SA_LEVEL_1 = "RETAIL_SEC_IMOV";
			end;
	end;    
/* 3b. Breakdown of exposures by exposure type */
 
IF IRB_PRODUCT_CLASS EQ 'REPO_STYLE' THEN EXPOSURE_TYPE = 'REPOS';
ELSE IF IRB_PRODUCT_CLASS EQ 'DERIVATIVE' THEN EXPOSURE_TYPE = 'DERIVATIVES';
ELSE IF OFF_BALANCE_SHEET_TYPE_CD NE '' THEN EXPOSURE_TYPE = 'OFF_BALANCE';
ELSE EXPOSURE_TYPE = 'ON_BALANCE';
 
/* 3c. Breakdown of Exposures by Risk Weight */
 
/*RW_GROUPS = put(RW_EXP, MAP_RW_GROUP.);*/

RW_GROUPS = put(&COSTVAR, MAP_RW_GROUP.);

/* SME supporting factor cross class */
if SME_SUPPORTING_FACTOR_FLG eq 1 then
	SME_SUPPORT_FACTOR="SME_SUPPORT";
else
	SME_SUPPORT_FACTOR="NOTAPP";

if CRM_TYPE = "IRB_COLLATERAL" then /* Residential Property is one of the sub types*/
	COLLATERAL_TYPE = CRM_SUBTYPE;

	
IF RW_GROUPS in ('RW_SA_50', 'RW_SA_100') THEN
DO;
if EXT_ISSUE_RATING EQ 'MISS' AND EXT_ISSUE_MAP_RATING EQ 'MISS' then RW_SUB_GROUP = 'NO_CR_ASSESS';
END;
 
IF RW_GROUPS EQ 'RW_SA_50' THEN
DO;
  if CRM_STD_PRODUCT_SUBCLASS eq 'COMMERCIAL' then RW_SUB_GROUP = 'COMM_REAL_EST';     
END;
 
IF RW_GROUPS EQ 'RW_SA_100' THEN
DO;
  if CRM_STD_PRODUCT_SUBCLASS eq 'RESIDENTIAL' then RW_SUB_GROUP = 'REAL_EST';     
END;
 
if PAST_DUE_CLAIM_FLG  = 1 then RW_SUB_GROUP = 'PAST_DUE';
 
 
/* 3d. Define the CRM groups and products */
 
IF CRM_ID NE '' then
DO;
 
SPECIFIC_PROVISION = 0;/*Nullify provisions in the case of mitigants*/
SPECIFIC_WRITEOFF = 0;/*Nullify writeoff in the case of mitigants*/  
 
IF ELIGIBLE_CRM_TYPE NE 'FINANCIAL_COMPREHENSIVE' AND CRM_TYPE NOT IN ('FINANCIAL_COLLATERAL', 'NETTING') then
do;
  IF CRM_TYPE = 'CREDIT_DERIVATIVE' then 
	do; 
		if CRM_SUBTYPE = 'UNFUNDED' THEN CRM_PRODUCT = 'DER_UNFUNDED';
		ELSE if CRM_SUBTYPE = 'FUNDED' THEN CRM_PRODUCT = 'OTHER_FUNDED';
	end;
  ELSE IF CRM_TYPE = 'GUARANTEE' THEN
	  DO;
		GUAR_FLAG = put(UNFUNDED_FLG,MAP_GUARANTEE_FLAG_REGRPT.);
		if GUAR_FLAG = 'FUNDED' then CRM_PRODUCT = 'OTHER_FUNDED';
		else CRM_PRODUCT = compress('GUAR_'||GUAR_FLAG);
	  END;
END;
ELSE IF CRM_TYPE IN ('FINANCIAL_COLLATERAL') then
          do;
                 if  "&STD_CRM_APPROACH" EQ "SIMPLE"  and  ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_SIMPLE' and CRM_SUBTYPE not in ('LIFE_INSURANCE','CASH_3RD_PARTY') THEN
                              CRM_PRODUCT = 'FIN_COLL_SIMPLE';
                 else IF  "&STD_CRM_APPROACH" EQ "SIMPLE"  and  ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_SIMPLE' and CRM_SUBTYPE IN ('LIFE_INSURANCE','CASH_3RD_PARTY') then
                              CRM_PRODUCT = 'OTHER_FUNDED';
                 else if "&STD_CRM_APPROACH" NE "SIMPLE" and CRM_COMP_FLG = 1 then
                              CRM_PRODUCT = 'FIN_COLL_COMPREH';
          end;
END;
 
    
/* 3e. Breakdown of exposures by conversion factors */
REGRPT_CCF_BUCKET = put(CCF, MAP_CCF_BUCKET_REGRPT.);
if REGRPT_CCF_BUCKET EQ "&regport_undef" then REGRPT_CCF_BUCKET='UNDEF';
if REGRPT_CCF_BUCKET EQ 'CCF1=0%' then REGRPT_CCF_BUCKET='CCF1';
if REGRPT_CCF_BUCKET EQ 'CCF2=20%' then REGRPT_CCF_BUCKET='CCF2';
if REGRPT_CCF_BUCKET EQ 'CCF3=50%' then REGRPT_CCF_BUCKET='CCF3';
if REGRPT_CCF_BUCKET EQ 'CCF4=100%' then REGRPT_CCF_BUCKET='CCF4';
if OFF_BALANCE_SHEET_TYPE_CD EQ '' then REGRPT_CCF_BUCKET='NO_CCF';
run;
 
/*---------------------------------------------------------------------------
* Step 4. Adjust portfolio to include inflow/outflow information through
*         the inclusion of two instrument types
* -------------------------------------------------------------------------*/   
    
/*-Separate the mitigants from the exposures and assign them an insttype -*/
data work.only_crm work.only_exp;
length INSTTYPE $16.;
set _intds.CAPITAL_CRSA;
 
INSTID = compress('INSTEXP_'||_n_);
INSTTYPE = 'regrpt_crsa_exp';
output only_exp;
 
if CRM_ID NE '' then
do;
COUNTERPARTY_RK = CRM_COUNTERPARTY_RK;
INSTID = compress('INSTCRM_'||_n_);
INSTTYPE = 'regrpt_crsa_crm';

EXP_VALUE=0;
EAD=0;
EAD_ADJ=0;
EAD_PORTION=0;
output only_crm;
end;
run;
 
/*-Merge the mitigants with all the exposures
* and assign an insttype to the exposure. -*/
data _intds.CAPITAL_CRSA (drop = EXP_ID CRM_ID);
set work.only_crm(rename=(INTERNAL_ORG_RK=INT_ORG_RK))
work.only_exp(rename=(INTERNAL_ORG_RK=INT_ORG_RK));     
INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
run;
 
/*---------------------------------------------------------------------------
* Step 5. Check to see if data was created
* -------------------------------------------------------------------------*/
 
%checkdata (_intds,CAPITAL_CRSA, APPROACH in ('STD') );

data _intds.CAPITAL_CRSA_CRD4;
	set _intds.CAPITAL_CRSA;
run; 

proc sql; 
	drop table _intds.CAPITAL_CRSA;
quit;	
 
%if &HAVEDATA = YES %then 
%do;
	%status(CAPITAL_CRSA_CRD4,SUCCESS,Exposures for SA approach,CAPITAL_CRSA_CRD4);
	/* Copy the same portfolio for CR-GB (SA) REPORT */
	data _intds.CAPITAL_CRGB_SA_CRD4;
	set _intds.CAPITAL_CRSA_CRD4;
	run;
	/* Insert the status for dynamic portfolio creation */
	%status(CAPITAL_CRGB_SA_CRD4,SUCCESS,Exposures for GB-SA approach,CAPITAL_CRGB_SA_CRD4);
%end;
%else %do;
%print_msg (WARNING,3,62);
%status(CAPITAL_CRSA_CRD4,Problems creating input data for portfolio,CAPITAL_CRSA_CRD4);
%end;
 
 
%mend prepare_regrpt_port_cr_sa;
 
 
%prepare_regrpt_port_cr_sa (crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
options notes source;

%mend b30_prep_regrpt_port_crsa_crd4;
