/*****************************************************************************
* Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b25_prepare_regrpt_port_le_crd4.sas
*
* PURPOSE: Create portoflio data for CR regulatory reports (LE Template )
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
 
/*---------------------------------------------------------------------------
* Step 1. Check to see if the user has requested CR-IRBA data
* -------------------------------------------------------------------------*/
 
%macro b30_prep_regrpt_port_le45_crd4;
%macro prepare_regrpt_port_le45 (inputds);
%let HAVEDATA=NO;
 
%if  
	 (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE4_CRD4) OR
	 (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LE5_CRD4) OR
     (%UPCASE(&REGPROJECTNAME) EQ ALL) 
/*OR */
/*     (%UPCASE(&REGPROJECTNAME) EQ IRB)*/

%then %do;
 
%if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
%then %do;
 
libname _incrlib  "&REGPATH";
%goto checkirba_opt;
 
%end;
 
%else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
%then %do;
 
libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
%goto checkirba_rnk;
 
%end;
 
%end;
    
%else %goto SKIP;
 
 
/*---------------------------------------------------------------------------
* Step 2. Check to see if we have data
* -------------------------------------------------------------------------*/
 
%SKIP:
/* User did not request LE portfolio - skip */
%put WARNING: User did not request Large exposure template;
%return;
 
 
%CHECKIRBA_OPT:
%checkdata (_incrlib, &INPUTDS , LE_COUNTERPARTY_RK ne .);
 
%CHECKIRBA_RNK:
%checkdata (_incrlib, &INPUTDS , LE_COUNTERPARTY_RK ne .);
 
 
/* If no data then return*/
%if   (&HAVEDATA = NO)  %then %do;
%print_msg (WARNING,3,1);/*------------------------>Change this message*/
%return;
%end;
 
/*---------------------------------------------------------------------------
* Step 3. Creating portfolio for LE counterparties
* -------------------------------------------------------------------------*/
 
%print_msg(note,3,26);
%if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,108);
/*Filter out data on the basis of LE_COUNTERPARTY_RK*/ 
/*calculate the obligor_pd buckets (by counterparty) */

data work._inputs_;
set _incrlib.&INPUTDS(where=(LE_COUNTERPARTY_RK NE .));
if CRM_ID NE '' then _pd_val_ = PD_CRM_COUNTERPARTY;
else _pd_val_ = PD_EXP;
run;

proc sort data=work._inputs_ ;
by LE_COUNTERPARTY_RK;
run;


/*Make sure that the SPECIFIC_PROVISIONS will be nullified for duplicate EXP_ID records*/
proc sort data=work._inputs_;
by EXP_ID;
run;


data work._inputs_;
set work._inputs_;
if FIRST.EXP_ID then VALID_PROVISION = 1;
else VALID_PROVISION = 0;
by exp_id;
run;


data _intds.CAPITAL_LE45;
length INTERNAL_ORG_RK LECPTYID $25.;
set work._inputs_(rename=(INTERNAL_ORG_RK=INT_ORG_RK));
if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) ); 
/* 3e. Define the CRM groups and products */
IF CRM_ID NE '' then DO;
SPECIFIC_PROVISION = 0;
 
END;
    INSTID = compress('INSTID_'||_n_);
    if not missing(COUNTERPARTY_RK) then COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) );
	INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
/* LE_COUNTERPARTY_RK = put(LE_CPTY_RK, MAP_INTERNAL_ORG_RK_CARPT.);*/
IF (NOT MISSING(LE_COUNTERPARTY_RK)) THEN LECPTYID = compress('LE' || input(LE_COUNTERPARTY_RK, $30.));
VALUE_ADJ_AMT = sum(0, SPECIFIC_PROVISION); /*col 210*/
	IF	UNDERLYING_EXP_EAD NOT IN (.,0) THEN 
	DO;
	UNDERLYING_FLG='YES';
	END;
	ELSE DO;
	UNDERLYING_FLG='NO';
	END;
/*RESIDUAL_MATURITY_MTH=INTCK('month',"&RUNDATE1"d,MATURITY_DATE);*/
	RESIDUAL_MATURITY_MTH1=RESIDUAL_MATURITY*12;
	
run;

 /*enrichment of crm allocation with cashflow information begins*/
proc sql;
create table  _intds.cashflow_cpty_details as
select  a.LE_counterparty_rk, a.counterparty_id, a.counterparty_group,
a.counterparty_cd, b.* from _intds.CAPITAL_LE45 as a join rd_stage.cashflow_details as b
on a.exp_id=b.instid
;
quit;
%let rundate1=%sysfunc(putn(&rundate,date9.));
/*%put &rundate1;*/

data _intds.cashflow_cpty_details;
set _intds.cashflow_cpty_details;
/*le_maturity_date=cashflow_dt-&rundate;*/
RESIDUAL_MATURITY = max(0, YRDIF(&RUNDATE, cashflow_dt, "&DAY_BASIS"));
/*RESIDUAL_MATURITY_MTH = INTCK('month',"&RUNDATE1"d,cashflow_dt);*/
/*RESIDUAL_MATURITY_MTH=0;*/
run;


data _intds.cashflow_cpty_details;
set _intds.cashflow_cpty_details;
RESIDUAL_MATURITY_MTH=RESIDUAL_MATURITY*12;
run;


DATA _intds.cashflow_capital_le;
/*(keep=CASHFLOW_AMOUNT LE_COUNTERPARTY_RK LE_ORIG_EXPOSURE_AMT EXP_ID MATURITY_DESCRIPTION);*/
merge _intds.cashflow_cpty_details(rename=(instid=exp_id)) _intds.CAPITAL_LE45;
by exp_id;
/*if missing(LE_ORIG_EXPOSURE_AMT) then LE_ORIG_EXPOSURE_AMT=CASHFLOW_AMOUNT;*/
/*if counterparty_group="GROUP_1_BANK";*/
/*if counterparty_group="Bank of New York";*/
RUN;
/*data _testinputs_;*/
/*set _inputs_;*/
/*run;*/
/**/
/*proc append base= work._testinputs_ data= _inputs_ force;*/
/*run;*/
data _intds.cashflow_capital_le;
set _intds.cashflow_capital_le;
if missing(cashflow_dt) then RESIDUAL_MATURITY_MTH=RESIDUAL_MATURITY_MTH1;
run;

data _intds.cashflow_capital_le;
set _intds.cashflow_capital_le;
MATURITY_DESCRIPTION =  put(RESIDUAL_MATURITY_MTH,MAP_MAT_BUCKETS_LE.);
run;

DATA _intds.cashflow_capital_le;
set  _intds.cashflow_capital_le;
if missing (CASHFLOW_AMT) then CASHFLOW_AMT=LE_ORIG_EXPOSURE_AMT;
run;

proc sort data=_intds.cashflow_capital_le;
by exp_id;
run;

data _intds.cashflow_capital_le ;
/*(keep=CASHFLOW_AMOUNT LE_COUNTERPARTY_RK LE_ORIG_EXPOSURE_AMT EXP_ID MATURITY_DESCRIPTION);*/
set _intds.cashflow_capital_le;
by exp_id;
if (first.exp_id*last.exp_id) eq 1 or cashflow_amt ne .;
run;
/*enrichment of crm allocation with cashflow information ends*/
*%get_cpty_details_le1_crd4;

%macro get_cpty_le_4_5;/*retrieve top 10 FI  counterparties*/
%global le4_cpty_groups_fi le4_cpty_ind_fi le4_cpty_groups_ure le4_cpty_ind_ure;
PROC SQL noprint;
create table ten_largest_fi as 
SELECT *, sum(le_orig_exposure_amt) as sum_le_orig_exp_amt, sum(value_adj_amt) as sum_value_adj_amt
from _intds.capital_le45
where financial_entity_type_cd="I"
GROUP BY counterparty_group;
quit;

data ten_largest_fi_ind;
set ten_largest_fi ;
where counterparty_group ='';
run;

data ten_largest_fi_group;
set ten_largest_fi;
where counterparty_group NE '';
run;
proc sort data =ten_largest_fi_group  nodupkey;
by counterparty_group;
run;

data ten_largest_fi_all;
set ten_largest_fi_group ten_largest_fi_ind;
run;

data ten_largest_fi_all;
set ten_largest_fi_all;
large_exp_ten_fi=SUM(sum_le_orig_exp_amt,-sum_value_adj_amt);
run;


proc sort data = ten_largest_fi_all;
by large_exp_ten_fi;
run; 
proc rank data = ten_largest_fi_all  out=ten_largest_fi ties=dense descending ;
var large_exp_ten_fi;
ranks rank;
run;

data ten_largest_fi;
set ten_largest_fi;
where rank between 1 and 10;
run;
%if %attrn(ten_largest_fi, NOBS) NE 0 %then %do;
proc sql noprint;
select "'"||strip(counterparty_group)||"'" into :le4_cpty_groups_fi separated by ',' from ten_largest_fi
where counterparty_group ne '';
select count(counterparty_group) into :cnt_grp  from ten_largest_fi
where counterparty_group ne '';
quit;
/*%put &le4_cpty_groups_FI;*/
/*%put &le4_cpty_IND_FI;*/
proc sql noprint;
select le_counterparty_rk into :le4_cpty_ind_fi separated by ',' from ten_largest_fi
where counterparty_group = '';
select count(le_counterparty_rk) into :cnt_ind  from ten_largest_fi
where counterparty_group = '';
quit;

%if &cnt_grp = 0 %then
		%do;
  %let le4_cpty_groups_fi="";
  		%end;
%else %if &cnt_ind=0 %then
		%do;
  %let le4_cpty_ind_fi=0;
		%end;
%end;
%else %do;
  %let le4_cpty_ind_fi=0;
  %let le4_cpty_groups_fi="";
%end;

/*retrieve top 10 URE counterparties*/

PROC SQL noprint;
create table ten_largest_ure as 
SELECT *, sum(le_orig_exposure_amt) as sum_le_orig_exp_amt, sum(value_adj_amt) as sum_value_adj_amt
from _intds.capital_le45
where financial_entity_type_cd="U"
GROUP BY counterparty_group;
quit;

data ten_largest_ure_ind;
set ten_largest_ure ;
where counterparty_group ='';
run;

data ten_largest_ure_group;
set ten_largest_ure;
where counterparty_group NE '';
run;
proc sort data =ten_largest_ure_group  nodupkey;
by counterparty_group;
run;

data ten_largest_ure_all;
set ten_largest_ure_group ten_largest_ure_ind;
run;

data ten_largest_ure_all;
set ten_largest_ure_all;
large_exp_ten_ure=SUM(sum_le_orig_exp_amt,-sum_value_adj_amt);
run;


proc sort data = ten_largest_ure_all;
by large_exp_ten_ure;
run; 
proc rank data = ten_largest_ure_all  out=ten_largest_ure ties=dense descending ;
var large_exp_ten_ure;
ranks rank;
run;

data ten_largest_ure;
set ten_largest_ure;
where rank between 1 and 10;
run;
%if %attrn(ten_largest_ure, NOBS) NE 0 %then %do;
proc sql noprint;
select "'"||strip(counterparty_group)||"'" into :le4_cpty_groups_ure separated by ',' from ten_largest_ure
where counterparty_group ne '';
select count(counterparty_group) into :cnt_grp  from ten_largest_ure
where counterparty_group ne '';
quit;

/*%put &le4_cpty_groups_URE;*/
/*%put &le4_cpty_IND_URE;*/

proc sql noprint;
select le_counterparty_rk into :le4_cpty_ind_ure separated by ',' from ten_largest_ure
where counterparty_group = '';
select count(le_counterparty_rk) into :cnt_ind  from ten_largest_ure
where counterparty_group = '';
quit;

%if &cnt_grp = 0 %then
		%do;
  %let le4_cpty_groups_ure="";
  		%end;
%else %if &cnt_ind=0 %then
		%do;
  %let le4_cpty_ind_ure=0;
		%end;

%end;
%else %do;
  %let le4_cpty_ind_ure=0;
  %let le4_cpty_groups_ure="";
%end;
%mend get_cpty_le_4_5;


%get_cpty_le_4_5;

data _intds.capital_le4;
set _intds.cashflow_capital_le;
insttype='regrpt_le4';
where le_counterparty_rk in (&le4_cpty_ind_fi,&le4_cpty_ind_ure) 
or  counterparty_group in (&le4_cpty_groups_fi,&le4_cpty_groups_ure)
;
run;

data _intds.capital_le5;
set _intds.cashflow_capital_le;
insttype='regrpt_le5';
where le_counterparty_rk in (&le4_cpty_ind_fi,&le4_cpty_ind_ure) 
or  counterparty_group in (&le4_cpty_groups_fi,&le4_cpty_groups_ure)
;
run;

data _intds.capital_le5;
set _intds.capital_le5;
insttype='regrpt_le5';
where counterparty_group ne ''
;
run;

/*%put &le4_cpty_ind_fi;*/
/*%put &le4_cpty_ind_ure;*/
/*%put &le4_cpty_groups_fi;*/
/*%put &le4_cpty_groups_ure;*/
/*---------------------------------------------------------------------------
* Step 5. Check to see if data was created
* -------------------------------------------------------------------------*/
 

%checkdata (_intds,CAPITAL_LE4, LE_COUNTERPARTY_RK NE . );
data _intds.CAPITAL_LE4_CRD4;
	set _intds.CAPITAL_LE4;
run; 

proc sql; 
	drop table _intds.CAPITAL_LE4;
quit;	

%if &HAVEDATA = YES %then
%do;
%status(CAPITAL_LE4_CRD4,SUCCESS,Large Exposures,CAPITAL_LE4_CRD4);
%end;
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_LE4_CRD4,ERROR,Problems creating input data for portfolio,CAPITAL_LE4_CRD4);
%end;


%checkdata (_intds,CAPITAL_LE5, LE_COUNTERPARTY_RK NE . );
data _intds.CAPITAL_LE5_CRD4;
	set _intds.CAPITAL_LE5;
run; 

proc sql; 
	drop table _intds.CAPITAL_LE5;
quit;	

%if &HAVEDATA = YES %then
%do;
%status(CAPITAL_LE5_CRD4,SUCCESS,Large Exposures,CAPITAL_LE5_CRD4);
%end;
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_LE5_CRD4,ERROR,Problems creating input data for portfolio,CAPITAL_LE5_CRD4);
%end;

/*deassign the library */ 
%mend prepare_regrpt_port_le45;
 
 
%prepare_regrpt_port_le45(crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
options notes source;


%mend b30_prep_regrpt_port_le45_crd4;
