/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: b35_prep_regrpt_port_ca_crd4.sas
 *
 * PURPOSE: Create portoflio data for CA regulatory reports
 *
 *   USAGE:
 *
 *   NOTES:
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 * Step 1. Check to see if we user has requested the CA report
 * --------------------------------------------------------------------------*/
%macro b35_prep_regrpt_port_ca_crd4;
	%if (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_CA_CRD4 OR  %UPCASE(&REGPROJECTNAME) EQ ALL) %then
		%goto CONTINUE;
	%else  %goto SKIP;

	/*---------------------------------------------------------------------------
	 * Step 2. Check to see if we have data
 * -------------------------------------------------------------------------*/
%SKIP:

	/* User did not request CA portfolio - skip */
	%print_msg(WARNING,3,120);
	%return;

	/*---------------------------------------------------------------------------
	 * Step 3. Check if the appropriate data exist
	 *         Collect data, if they exist
 * -------------------------------------------------------------------------*/
%CONTINUE:

%macro where_clause(prefix, start, end, value);
	%do i=&start %to &end;
		%if &i NE &end %then
			%do;
				(&&&prefix&i EQ &value) AND
			%end;
		%else
			%do;
				(&&&prefix&i EQ &value)
			%end;
	%end;
%mend where_clause;

%macro get_fact_data (proj_name= , fact_table= , variable= , first_ccvar= , last_ccvar= , out_ds= , out_name_prefix= );
	/* 1. Create the current_* table, that contains info from the latest proj. */
	%create_risk_repository_views
		(Project_name=&proj_name, Fact_table=&fact_table, Current=YES, Year=NO, Allhistory=NO, where=NONE, obs=0);

	/* 2. If the regulatory table (or the data) do not exist, exit */
	%if %dsexist(work.current_&fact_table) EQ 0 %then
		%goto EXIT;
	%else %if %attrn (work.current_&fact_table,NOBS) EQ 0 %then
		%goto EXIT;
	%else
		%do;
			/*3. If the data exist, compare the base_date_dt with the given threshold date
			 *   Also, keep track of succesfully created datasets (IRBA, IRBF, SA, etc)
		 *   using the set_string macro variable                                   */
			%let set_string =;

			data _null_;
				set rd_nls.regulatory_report_list_en
					(where = ( (rpt_cd eq 'capital_ca_crd4') and (allocation_method eq %lowcase("&MITIGANTS_ALLOCATION_METHOD")) and (system_id eq %upcase(%trim(%left("&system_id"))))));
				call symput('thres_date', Thres_date);

				/* call symput('equ_type', Equity_type); */
			run;

			data _null_(keep=base_dt);
				set work.current_regulatory(obs=1);

				/*if juldate("&thres_date"d) GE juldate(base_date_dt) then*/
				if &thres_date GE base_dt then
					do;
						call symput("constr_active", "YES");
					end;
				else
					do;
						call symput("constr_active", "NO");
					end;
			run;

			%if  "&constr_active" EQ "YES" %then
				%do;
					%print_msg(WARNING,3,114);
					%print_msg(WARNING,3,115);
					%goto EXIT;
				%end;
		%end;

	/*4. From the current_* table, select only the records used by the reports  */
	data work.&out_ds (keep = NAME &variable);
		set work.current_&fact_table;
		FORMAT NAME $32.;

		%if &first_ccvar EQ NONE %then
			%do;
				%if &out_name_prefix EQ CVA %then
					%do;
						outv_rwa=&variable;
						WHERE 1=1;
					%END;
				%ELSE %if &out_name_prefix EQ SA_SECURITIZATION %then
					%do;
						outv_rwa=&variable;
						where %where_clause(rptvar, 1, 3, '+')
							and &rptvar4 in ('+','RESECURITIZATION') and 
							%where_clause(rptvar, 5, &nrptvar, '+');
					%END;
				%ELSE %if &out_name_prefix EQ CR_SEC_IRB %then
					%do;
						outv_rwa=&variable;
						where %where_clause(rptvar, 1, 3, '+')
							and &rptvar4 in ('+','RESECURITIZATION') and 
							%where_clause(rptvar, 5, &nrptvar, '+');
					%END;
				%ELSE
					%DO;
						where %where_clause(rptvar, 1, &nrptvar, '+');
					%END;
			%end;
		%else %if &first_ccvar EQ 1 %then
			%do;
				%if &out_name_prefix =IRBA %then
					%do;
						where %where_clause(rptvar, %eval(&last_ccvar +1), %eval(&nrptvar-1), '+') and &&rptvar&nrptvar='YES';
					%end;
				%else %if &out_name_prefix =IRBF %then
					%do;
						where %where_clause(rptvar, %eval(&last_ccvar +1), %eval(&nrptvar-1), '+') and &&rptvar&nrptvar='NO';
					%end;
				%else
					%do;
						where %where_clause(rptvar, %eval(&last_ccvar +1), &nrptvar, '+');
					%end;
			%end;
		%else %if &first_ccvar EQ &nrptvar %then
			%do;
				where %where_clause(rptvar, 1, &nrptvar, '+');
			%end;
		%else %if &first_ccvar EQ 2 %then
			%do;
				where %where_clause(rptvar, 3, &nrptvar, '+') AND &RPTVAR1='+';
			%end;

		/*%else %do;*/
		/*where %where_clause(rptvar, 1, %eval(&first_ccvar - 1) , '+') AND*/
		/*%where_clause(rptvar, %eval(&last_ccvar + 1), &nrptvar, '+');*/
		/*%end;*/

		/* We don't need any rollup of the first cross class,
		e.g. "+ SME" or "+ OTHERS"                       */
		%if &first_ccvar NE NONE %then
			%do;
				if &&rptvar&first_ccvar = '+' then
					delete;
				NM=compress(&&rptvar&first_ccvar);

				/*Finalize the NM by concatenating the NM with the rest of the rptvars  */
				%do numcc=(&first_ccvar + 1) %to &last_ccvar;
					if &&rptvar&numcc EQ '+' then
						&&rptvar&numcc = 'TOTAL';
					NM=compress(NM||'_'||&&rptvar&numcc);
				%end;

				NAME = compress("&out_name_prefix"||'_'||NM);
			%end;
		%else
			%do;
				%if &out_name_prefix EQ CVA %then
					%do;
						if &rptvar1 = '+' then
							delete;

						IF &rptvar1 eq 'STD' THEN
							NAME = compress("&out_name_prefix"||"_RISK_STD_METHOD_AMT");
						ELSE if &rptvar1 = 'ALT' THEN
							NAME = compress("&out_name_prefix"||"_RISK_OEM_AMT");
					%end;
				%else
					%do;
						%if &out_name_prefix EQ SA_SECURITIZATION %then
							%do;
								IF  &rptvar4="+" THEN
									NAME = compress("&out_name_prefix"||'_TOTAL');
								ELSE IF &rptvar4="RESECURITIZATION" THEN
									NAME = "SA_RESECURITIZATION";
							%END;
						%ELSE %if &out_name_prefix EQ CR_SEC_IRB  %then
							%do;
								IF  &rptvar4="+" THEN
									NAME = compress("&out_name_prefix"||'_TOTAL');
								ELSE IF &rptvar4="RESECURITIZATION" THEN
									NAME = "IRB_RESECURITIZATION";
							%END;
						%else
							%do;
								NAME = "&out_name_prefix";
							%end;

						outv_rwa=&variable;
					%end;
			%end;
	run;

%EXIT:
%mend get_fact_data;

data _null_;
	set rd_nls.regulatory_report_list_en
		(where = ( (rpt_cd eq 'capital_ca_crd4') and (allocation_method eq %lowcase("&MITIGANTS_ALLOCATION_METHOD")) and (system_id eq %upcase(%trim(%left("&system_id"))))));
	call symput('equ_type', Equity_type);
run;

/*Get the data of interest*/
/* With own estimates - IRBA*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CRIRBA_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=regulatory, variable=outv_RWA , first_ccvar=1, last_ccvar=2 , out_ds=irba_part, out_name_prefix=IRBA);

/* Without own estimates - IRBF*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CRIRBA_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=regulatory, variable=outv_RWA , first_ccvar=1, last_ccvar=2 , out_ds=irbf_part, out_name_prefix=IRBF);

/* STD approach*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CRSA_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)) ,
	fact_table=regulatory, variable=outv_RWA , first_ccvar=2, last_ccvar=2 , out_ds=sa_part, out_name_prefix=SA);

/* Equity*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CREQU_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=REGULATORY, variable=outv_RWA, first_ccvar=NONE, last_ccvar=NONE, out_ds=equ_part, 
	out_name_prefix = CR_EQU);

/* Large Exposures*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_LE3_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=REGULATORY, variable=OUTV_CAP_REQM_LRG_EXP_TB_AMT, first_ccvar=NONE, last_ccvar=NONE, out_ds=le_part, 
	out_name_prefix = CR_LE);

/* CVA*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CVA_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=REGULATORY, variable=OUTV_CVA_TOTAL_RISK_EXP_AMT, first_ccvar=NONE, last_ccvar=NONE, out_ds=cva_part, 
	out_name_prefix = CVA);

/* Securitization - STD*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CRSEC_SA_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=REGULATORY, variable=outv_rwa, first_ccvar=NONE, last_ccvar=NONE, out_ds=sec_sa_part, out_name_prefix = SA_SECURITIZATION);

/* Securitization - IRB*/
%get_fact_data(proj_name=&PROJECT_SET._CAPITAL_CRSEC_IRB_CRD4_&MITIGANTS_ALLOCATION_METHOD._%trim(%left(&system_id)),
	fact_table=REGULATORY, variable=outv_RWA, first_ccvar=NONE, last_ccvar=NONE, out_ds=sec_irb_part,out_name_prefix = CR_SEC_IRB);

%let set_string=;

%if %eval( %dsexist(work.irba_part) + %dsexist(work.irbf_part) + %dsexist(work.sa_irb_part) + %dsexist(work.sa_part) +
	%dsexist(work.equ_part) + %dsexist(work.sec_irb_part) + %dsexist(work.sec_std_part) ) LE 0 %then
	%do;
		%print_msg(WARNING,3,116);
		%goto FINFACT;
	%end;

%if %dsexist(work.irba_part) %then
	%do;
		%let set_string = &set_string  work.irba_part;
	%end;

%if %dsexist(work.irbf_part) %then
	%do;
		%let set_string = &set_string  work.irbf_part;
	%end;

%if %dsexist(work.sa_irb_part) %then
	%do;
		%let set_string = &set_string  work.sa_irb_part;
	%end;

%if %dsexist(work.sa_part) %then
	%do;
		%let set_string = &set_string  work.sa_part;
	%end;

%if %dsexist(work.equ_part) %then
	%do;
		%let set_string = &set_string  work.equ_part;
	%end;

%if %dsexist(work.le_part) %then
	%do;
		%let set_string = &set_string  work.le_part;
	%end;

%if %dsexist(work.cva_part) %then
	%do;
		%let set_string = &set_string  work.cva_part;
	%end;

%if %dsexist(work.sec_irb_part) %then
	%do;
		%let set_string = &set_string  work.sec_irb_part;
	%end;

%if %dsexist(work.sec_sa_part) %then
	%do;
		%let set_string = &set_string  work.sec_sa_part;
	%end;

data _ca_data_;
	length name $39.;
	set &set_string;
run;

/*------------------------------------------------------------------------------------------
 * Note: Check if the rd_stage.financial_reporting_data exists and copy to the intds library
 * ----------------------------------------------------------------------------------------*/
%FINFACT:

/* Check if the data were created succesfully */
%if %dsexist(rd_stage.financial_reporting_data) LE 0 %then
	%do;
		%print_msg(WARNING,3,117);
		%status(CAPITAL_CA_CRD4,Problems creating input data for portfolio,CAPITAL_CA_CRD4);
		%return;
	%end;
%else
	%do;
		%if %attrn(rd_stage.financial_reporting_data,NOBS)=0 %then
			%do;
				%print_msg(WARNING,3,118);
				%status(CAPITAL_CA_CRD4,Problems creating input data for portfolio,CAPITAL_CA_CRD4);
				%return;
			%end;
		%else
			%do;

				data _intds.CAPITAL_CA_CRD4;
					length INTERNAL_ORG_RK $25.;
					set RD_STAGE.financial_reporting_data(rename=(INTERNAL_ORG_RK=INT_ORG_RK));

					if not missing(COUNTERPARTY_RK) then
						COUNTERPARTYID = compress( 'CPTY_' || put( COUNTERPARTY_RK, 20. ) );
					INSTID = 'INSTID'||compress(_n_);
					INSTTYPE ='regrpt_ca';
					INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);
				run;

				%status(CAPITAL_CA_CRD4,SUCCESS,Exposures for CA template,CAPITAL_CA_CRD4);
				%print_msg(NOTE,3,119);
			%end;
	%end;

options notes source;
%mend b35_prep_regrpt_port_ca_crd4;

/*
%b35_prep_regrpt_port_ca_crd4;
*/
