/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: b40_prepare_regrpt_port_lr_crd4.sas
*
* PURPOSE: Create portoflio data for LR regulatory reports
*
*   USAGE:
*
*   NOTES:
*
*****************************************************************************/
 
 
%macro b40_prepare_regrpt_port_lr_crd4;
%macro prepare_regrpt_port_lr (inputds);


/*---------------------------------------------------------------------------
* Step 1. Check to see if the user has requested the report 
* -------------------------------------------------------------------------*/
 
 %let HAVEDATA=NO;
  
 %if  
      (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LR2) OR
      (%UPCASE(&REGPROJECTNAME) EQ CAPITAL_LR4) OR
      (%UPCASE(&REGPROJECTNAME) EQ ALL) 
 
 %then %do;
  
         %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ OPTIMAL
         %then %do;

         libname _incrlib  "&REGPATH";
         %goto checkirba_opt;
  
 %end;
  
 %else %if %UPCASE(&MITIGANTS_ALLOCATION_METHOD) EQ BY_RANK          
 %then %do;
  
         libname _incrlib  "!CRISKMRES&PATHSEP.&PROJECT_SET&PATHSEP.&PROJECT_SET._rnk";
         %goto checkirba_rnk;
  
 %end;
  
 %end;
     
 %else %goto SKIP;

 
 
/*---------------------------------------------------------------------------
* Step 2. Check to see if we have data
* -------------------------------------------------------------------------*/

%SKIP:
%print_msg (NOTE,3,60);/*-------------------------->Add another message*/
%return;

 
%CHECKIRBA_OPT:
%checkdata (_incrlib, &INPUTDS , );

%CHECKIRBA_RNK:
%checkdata (_incrlib, &INPUTDS , );

 
/* If no data then return*/
%if   (&HAVEDATA = NO)  %then %do;
%print_msg (WARNING,3,1);/*------------------------>Change this message*/
%return;
%end;

/*---------------------------------------------------------------------------
* Step 3a. Creating portfolio for LR2 report
* -------------------------------------------------------------------------*/

%print_msg(note,3,26);
%if &APPLY_CCF_AFTER_CRM EQ NO %then %print_msg (warning,3,108);


data _intds.CAPITAL_LR2;
    length INTERNAL_ORG_RK $25.;
    set _incrlib.&INPUTDS(rename=(INTERNAL_ORG_RK=INT_ORG_RK));

    INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);   
    INSTTYPE = 'regrpt_lr2';
    INSTID = EXP_ID;
    
    LR_RW_BUCKET = put(RW_EXP, MAP_RW_BUCKETS_REGRPT_LR.);
    if RW_EXP = 0 then LR_RW_BUCKET = 'RW1:0%';
    if IN_DEFAULT_FLG = 1 or PAST_DUE_CLAIM_FLG = 1 then LR_RW_BUCKET = 'RW9:Defaulted';  
    if CCF=0 then LR_RW_BUCKET = 'RW10:CCF = 0% ';
run;
/*---------------------------------------------------------------------------
* Step 3b. Creating portfolio for LR4 report
* -------------------------------------------------------------------------*/




data _intds.CAPITAL_LR4;
    length INTERNAL_ORG_RK EXPOSURE_TYPE LR_EXPOSURE_CLASS_LEV_1 LR_EXPOSURE_CLASS_LEV_2 LR_EXPOSURE_CLASS_LEV_3 LR_EXPOSURE_CLASS_LEV_4 LR_EXPOSURE_CLASS_LEV_5 $25.;
    set _incrlib.&INPUTDS(rename=(INTERNAL_ORG_RK=INT_ORG_RK));

    INTERNAL_ORG_RK = put(INT_ORG_RK, MAP_INTERNAL_ORG_RK_CARPT.);   
    INSTTYPE = 'regrpt_lr4';
    INSTID = EXP_ID;
    
    
    EXPOSURE_TYPE = 'ON_BALANCE';
    
    if index(APPROACH, 'IRB') > 0 and IRB_PRODUCT_CLASS in ('EQUITY', 'SECURITIZATION', 'OTHER_ASSETS') then do;
        LR_EXPOSURE_CLASS_LEV_1 = 'OTHER_EXPOSURE'; /* 290 */
        if IRB_PRODUCT_CLASS = 'SECURITIZATION' then 
            LR_EXPOSURE_CLASS_LEV_2 = 'SECURITIZATION';      /* 300 */ 
    end;   
    else if index(APPROACH, 'STD') > 0 and (STD_PRODUCT_CLASS in ('EQUITY', 'SECURITIZATION', 'CIU', 'HIGH_RISK', 'OTHER_ASSETS') or HIGH_RISK_CATEGORY_FLG = 1) then do;
        LR_EXPOSURE_CLASS_LEV_1 = 'OTHER_EXPOSURE'; /* 290 */
        if IRB_PRODUCT_CLASS = 'SECURITIZATION' then 
            LR_EXPOSURE_CLASS_LEV_2 = 'SECURITIZATION';      /* 300 */     
    end;
    
    else if IN_DEFAULT_FLG = 1 or PAST_DUE_CLAIM_FLG = 1 then LR_EXPOSURE_CLASS_LEV_1 = 'DEFAULTED'; /*280 */
    
    else if STD_PRODUCT_CLASS = 'COVERED_BOND' then LR_EXPOSURE_CLASS_LEV_1 = 'COV_BOND';  /* 080 */
    
    else if STD_PRODUCT_CLASS in ('MORTGAGE','LEASE_IMM_PROPERTY', 'IMM_PROPERTY') then do;
            LR_EXPOSURE_CLASS_LEV_1 = 'MORTGAGE'; /* 190 */
            if STD_PRODUCT_SUBCLASS in ('RESIDENTIAL', 'RME') then LR_EXPOSURE_CLASS_LEV_2 = 'RRE'; /* 200 */
    end;
    
    else if NETTING_SET_RK NE '' and STD_PRODUCT_CLASS  in ('REPO_STYLE' , 'DERIVATIVE') then EXPOSURE_TYPE = 'NETTING'; /* 040 */
    
    else if STD_PRODUCT_CLASS EQ 'REPO_STYLE' then EXPOSURE_TYPE = 'REPOS'; /* 060 */
    
    else if STD_PRODUCT_CLASS EQ 'DERIVATIVE' then EXPOSURE_TYPE = 'DERIVATIVES';  /* 050 */   
    
    else if OFF_BALANCE_SHEET_TYPE_CD NE '' then DO;
            EXPOSURE_TYPE = 'OFF_BALANCE'; /* 080 */
            if STD_PRODUCT_CLASS = 'TRADE_FIN' then LR_EXPOSURE_CLASS_LEV_4 = 'TRADE_FIN';  /* 020 */
            if STD_PRODUCT_SUBCLASS = 'EXP_CREDIT_INS' then LR_EXPOSURE_CLASS_LEV_5 = 'EXP_CREDIT_INS';  /* 030 */
    end;
    
    else if TRADING_BOOK_FLG = '1'  then EXPOSURE_TYPE = 'OTHER_TB'; /* 070 */
    
    else if COUNTERPARTY_CLASS = 'SOVEREIGN' then do;
        if COUNTERPARTY_SUBCLASS in ('CENTRAL_GOV','CENTRAL_BANK') then do;
            LR_EXPOSURE_CLASS_LEV_1 = 'SOVEREIGN';
            LR_EXPOSURE_CLASS_LEV_2 = 'CENT_GOV_CENT_BANK'; /* 100 */
        end;
        else if COUNTERPARTY_SUBCLASS in ('REGIONAL_GOV','LOCAL_GOV') then do;
            if CENTGOV_TRT_FLG =1 then do;
                LR_EXPOSURE_CLASS_LEV_1 = 'SOVEREIGN';
                LR_EXPOSURE_CLASS_LEV_2 = 'REG_GOV'; /* 110 */
            end;
            else do;
                LR_EXPOSURE_CLASS_LEV_1 = 'NON_SOVEREIGN';
                LR_EXPOSURE_CLASS_LEV_2 = 'REG_GOV'; /* 150 */
            end;
        end; 
        else if COUNTERPARTY_SUBCLASS = 'RELIGIOUS_ORG' then do;
            LR_EXPOSURE_CLASS_LEV_1 = 'NON_SOVEREIGN';
            LR_EXPOSURE_CLASS_LEV_2 = 'REG_GOVT'; /* 150 */    
        end;
        else if COUNTERPARTY_SUBCLASS = 'PSE' then do;
            if CENTGOV_TRT_FLG = 1 then do;
                LR_EXPOSURE_CLASS_LEV_1 = 'SOVEREIGN';
                LR_EXPOSURE_CLASS_LEV_2 = 'PSE'; /* 130 */
            end;
            else do;
                LR_EXPOSURE_CLASS_LEV_1 = 'NON_SOVEREIGN';
                LR_EXPOSURE_CLASS_LEV_2 = 'PSE'; /* 170 */
            end;
        end;
        else if COUNTERPARTY_SUBCLASS in ('INT_ORG', 'HR_MDB') then do;
            LR_EXPOSURE_CLASS_LEV_1 = 'SOVEREIGN';            
            LR_EXPOSURE_CLASS_LEV_2 = 'MDB'; /* 120 */   
         end;
        else if COUNTERPARTY_SUBCLASS ='MDB' then do;
            LR_EXPOSURE_CLASS_LEV_1 = 'NON_SOVEREIGN';
            LR_EXPOSURE_CLASS_LEV_2 = 'MDB'; /* 160 */
        end;

    end;
    
    else if COUNTERPARTY_CLASS = 'INSTITUTION' then LR_EXPOSURE_CLASS_LEV_1 = 'INSTITUTION'; /* 180 */
    
    else if COUNTERPARTY_CLASS = 'CORPORATE' then do;
        LR_EXPOSURE_CLASS_LEV_1 = 'CORPORATE'; /* 230 */
        if COUNTERPARTY_SUBCLASS = 'SEC' then
           LR_EXPOSURE_CLASS_LEV_2 = 'FINANCIAL'; /* 240 */
        else do;
            LR_EXPOSURE_CLASS_LEV_2 = 'NONFINANCIAL'; /* 250 */
            if COUNTERPARTY_SUBCLASS = 'SME' then   
                LR_EXPOSURE_CLASS_LEV_3 = 'SME';  /* 260 */
            else LR_EXPOSURE_CLASS_LEV_3 = 'NONSME'; /* 270 */
        end;       
    end;
    
    else if COUNTERPARTY_CLASS = 'RETAIL' then do;
            LR_EXPOSURE_CLASS_LEV_1 = 'RETAIL'; /* 210 */
            if COUNTERPARTY_SUBCLASS = 'SME' then LR_EXPOSURE_CLASS_LEV_3 = 'SME'; /*220*/
    end;
    
    /*- special case for 'other exposures' -*/
    if index(APPROACH, 'STD') > 0 and LR_EXPOSURE_CLASS_LEV_1 in ('CORPORATE', 'INSTITUTION') and (SHORT_TERM_CLAIM_FLG = 1 OR SHORT_TERM_ASSESS_FLG = 1) then do;
        LR_EXPOSURE_CLASS_LEV_1 = 'OTHER_EXPOSURE'; /* 290 */
    end;
    /*- on-balance sheet trade finance exposures -*/
    
    if STD_PRODUCT_CLASS = 'TRADE_FIN' and EXPOSURE_TYPE = 'ON_BALANCE' then do;
            LR_EXPOSURE_CLASS_LEV_4 = 'TRADE_FIN';  /* Memo Item: 310 */
            if STD_PRODUCT_SUBCLASS = 'EXP_CREDIT_INS' then LR_EXPOSURE_CLASS_LEV_5 = 'EXP_CREDIT_INS';  /* Memo Item: 320 */
    
    end;
    
run;


/*---------------------------------------------------------------------------
* Step 4. Check to see if data was created
* -------------------------------------------------------------------------*/

%checkdata (_intds,CAPITAL_LR2,   );
%checkdata (_intds,CAPITAL_LR4,  );

%if &HAVEDATA = YES %then
%do;
%status(CAPITAL_LR2,SUCCESS,Leverage Ratio 2,CAPITAL_LR2);
%status(CAPITAL_LR4,SUCCESS,Leverage Ratio 4,CAPITAL_LR4);
%end;
%else
%do;
%print_msg (WARNING,3,62);
%status(CAPITAL_LR2,Problems creating input data for portfolio,CAPITAL_LR2);
%status(CAPITAL_LR4,Problems creating input data for portfolio,CAPITAL_LR4);
%end;


%mend prepare_regrpt_port_lr;

%prepare_regrpt_port_lr (crm_allocation_&MITIGANTS_ALLOCATION_METHOD._detail);
options notes source;

%mend b40_prepare_regrpt_port_lr_crd4;