/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: c05_create_inst_var_usfinal.sas
 *
 * PURPOSE: Create instrument variables registration data set for RiskDimensions
 *
 *   USAGE: 
 *
 *   NOTES:
 *          
 *
 *****************************************************************************/

%macro c05_create_inst_var_usfinal;

%macro get_mtm_inst_vars;
/*- get instrument variable attributes -*/
%create_instvar_def_data(RD_POS.exposure_instrument, RD_TEMP.instvar_exp_instrument);
%create_instvar_def_data(RD_POS.exposure_account, RD_TEMP.instvar_exp_account);
%create_instvar_def_data(RD_POS.exposure_segment, RD_TEMP.instvar_exp_segment);
%create_instvar_def_data(RD_POS.exposure_receivable, RD_TEMP.instvar_exp_receivable);
%create_instvar_def_data(RD_POS.exposure_securitization, RD_TEMP.instvar_exp_securitization);
%create_instvar_def_data(RD_POS.exposure_facility, RD_TEMP.instvar_exp_facility);
%create_instvar_def_data(RD_POS.exposure_facility_securitization, RD_TEMP.instvar_exp_facility_sec);
%create_instvar_def_data(RD_POS.exposure_securitization_pool, RD_TEMP.instvar_exp_sec_pool);
%create_instvar_def_data(RD_POS.crm_instrument, RD_TEMP.instvar_crm_instrument);
%create_instvar_def_data(RD_POS.crm_account, RD_TEMP.instvar_crm_account);
%create_instvar_def_data(RD_POS.crm_segment, RD_TEMP.instvar_crm_segment);
%create_instvar_def_data(RD_POS.crm_receivable, RD_TEMP.instvar_crm_receivable);
%create_instvar_def_data(RD_POS.crm_derivative, RD_TEMP.instvar_crm_derivative);
%create_instvar_def_data(RD_POS.crm_insurance, RD_TEMP.instvar_crm_insurance);
%create_instvar_def_data(RD_POS.crm_guarantee, RD_TEMP.instvar_crm_guarantee);
%create_instvar_def_data(RD_POS.crm_physical, RD_TEMP.instvar_crm_physical);
%create_instvar_def_data(RD_POS.general_provision, RD_TEMP.instvar_general_provision);
%create_instvar_def_data(RD_POS.exposure_provision, RD_TEMP.instvar_exposure_provision);
%create_instvar_def_data(RD_POS.facility_group, RD_TEMP.instvar_facility_group);
%if &N_TRADING_BOOK_EXP GT 0 %then %do;
%create_instvar_def_data(RD_POS.exposure_trading_book, RD_TEMP.instvar_exposure_tb);
%create_instvar_def_data(RD_POS.crm_instrument, RD_TEMP.instvar_crm_instrument_tb);
%create_instvar_def_data(RD_POS.crm_account, RD_TEMP.instvar_crm_account_tb);
%create_instvar_def_data(RD_POS.crm_derivative, RD_TEMP.instvar_crm_derivative_tb);
%create_instvar_def_data(RD_POS.netting_exposures, RD_TEMP.instvar_exp_netting_tb);
%end;

data RD_TEMP.mtm_inst_var;
set RD_TEMP.instvar_exp_instrument RD_TEMP.instvar_exp_account RD_TEMP.instvar_exp_segment
    RD_TEMP.instvar_exp_receivable RD_TEMP.instvar_exp_securitization RD_TEMP.instvar_exp_facility 
    RD_TEMP.instvar_exp_facility_sec RD_TEMP.instvar_exp_sec_pool RD_TEMP.instvar_crm_instrument
    RD_TEMP.instvar_crm_account RD_TEMP.instvar_crm_segment RD_TEMP.instvar_crm_receivable RD_TEMP.instvar_crm_derivative 
    RD_TEMP.instvar_crm_insurance RD_TEMP.instvar_crm_guarantee RD_TEMP.instvar_crm_physical
    RD_TEMP.instvar_general_provision RD_TEMP.instvar_exposure_provision
    RD_TEMP.instvar_facility_group 
    %if &N_TRADING_BOOK_EXP GT 0 %then %do;
    RD_TEMP.instvar_exposure_tb RD_TEMP.instvar_crm_instrument_tb RD_TEMP.instvar_crm_account_tb
    RD_TEMP.instvar_crm_derivative_tb RD_TEMP.instvar_exp_netting_tb
    %end;
    ; 
run;
%mend;

%get_mtm_inst_vars;
/*- Create instruments variables to hold output variables after MtM calculations -*/
/*- datalines statement replaced with file infile statements while moving to MVA code -*/
data _null_;
file f1 temp;
file f1;
put "CRM_VALUE               , NUM , VAR  , 8, CRM Mark to Market Value       , NLNUM, 20, 4";
put "EXP_VALUE               , NUM , VAR  , 8, Exposure Mark to Market Value  , NLNUM, 20, 4";
put "RESIDUAL_VALUE          , NUM , VAR  , 8, Residual Value for lease       , NLNUM, 20, 4";
put "CCF                     , NUM , VAR  , 8, Credit Conversion Factor Used  , NLNUM, 20, 4";
put "ADD_ON                  , NUM , VAR  , 8, Add-on applied                 , NLNUM, 20, 4";
put "HAIRCUT                 , NUM , VAR  , 8, Haircut                        , NLNUM, 20, 4";
put "MAT_EFF                 , NUM , VAR  , 8, Effective Maturity             , NLNUM, 20, 4";
put "CCY                     , CHAR, CLASS, 3, Exposure Original Currency     , $    ,  3, 0";
put "EAD                     , NUM , VAR  , 8, Exposure At Default            , NLNUM, 20, 4";
put "EAD_ADJ                 , NUM , VAR  , 8, Exposure At Default Adjusted for CRM, NLNUM, 20, 4";
put "SPECIFIC_PROVISION      , NUM , VAR  , 8, Exposure-Specific Provisions   , NLNUM, 20, 4     ";
put "IRB_SCALING_FACTOR      , NUM , VAR  , 8, IRB Scaling Factor Applied     , NLNUM,  5, 2  ";
put "HAIRCUT_SCALE           , NUM , VAR  , 8, Scaling value for haircuts     , NLNUM,  5, 2";
put "HAIRCUT_HOLDING_DAYS    , NUM , VAR  , 8, Transaction min holding days   , NLNUM,  5, 0";
put "HEDGING_SET_ID          , CHAR, CLASS, 32,Hedging Set ID                 , $    , 32, 0";
put "DELTA                   , NUM , VAR  , 8, Computed delta for a risk postn, NLNUM, 20, 4";
put "MTM_VALUE               , NUM , VAR  , 8, Computed current value         , NLNUM, 20, 4";
put "RISK_FACTOR_ID          , CHAR , VAR  , 32,Risk factor ID in a risk postn , $    , 32, 0 ";
/*put "RISK_FACTOR_ID          , CHAR, VAR  , 32,Risk Factor ID used in CCR STD , NLNUM, 32, 0";*/
put "UNSECURED_RM_RETAIL_CRITERIA         , CHAR, VAR  ,20, Criteria satisfied             , $    , 20, 0";
put "BALANCE_AMT_SEG         , NUM , VAR  , 8, Drawn Amount for a Segment          , NLNUM, 20, 4";
put "EAD_SEG                 , NUM , VAR  , 8, EAD Amount for a Segment          , NLNUM, 20, 4";
put "EAD_TWO_YEARS                 , NUM , VAR  , 8, EAD for accounts le 2 yrs           , NLNUM, 20, 4";
put "UNDRAWN_AMT_SEG         , NUM , VAR  , 8, Undrawn Amount for a Segment          , NLNUM, 20, 4";
/*put "AVG_ACCOUNT_AGE         , NUM , VAR  , 8, Avg account age in mnths for a Segment, NLNUM, 20, 4";*/ 
put "EAD_REG_Y               , NUM , VAR  , 8, Exposure At Default Under Reg Y, NLNUM, 20, 4";
put "CCF_REG_Y               , NUM , VAR  , 8, Credit Conversion Factor Reg Y , NLNUM, 20, 4";
put "REG_Y_CRM_VALUE         , NUM , VAR  , 8, Value of CRM for Reg Y , NLNUM, 20, 4";
run;

data RD_TEMP.regulatory_inst_var;
infile f1 delimiter = ',' dsd;
length NAME KIND ROLE TYPE GROUP FORMAT  $32.;
length LABEL $256.;
KIND  = 'INSTRUMENT';
GROUP = 'Regulatory Instrument Variables';
input NAME $ TYPE $ ROLE $ LENGTH LABEL $ FORMAT $ FORMATL FORMATD ;
run;

/*- these variables are needed for aggregation -*/
/*- datalines statement replaced with file infile statements while moving to MVA code -*/
data _null_; 
filename f1 temp;
file f1;
put "PD_BUCKET               , CHAR, CLASS,20, PD Bucket                           , $    , 20, 0";
put "LGD_BUCKET              , CHAR, CLASS,20, LGD Bucket                          , $    , 20, 0";
put "RW_BUCKET               , CHAR, CLASS,16, RW Bucket                           , $    , 20, 0";
put "HAIRCUT_EXP             , NUM , VAR  , 8, Exposure Haircut Applied            , NLNUM, 20, 4                       ";
put "HAIRCUT_CRM             , NUM , VAR  , 8, CRM Haircut Applied                 , NLNUM, 20, 4";
put "HAIRCUT_FX              , NUM , VAR  , 8, FX Haircut Applied                  , NLNUM, 20, 4";
put "FIRM_SIZE               , NUM , VAR  , 8, Counterparty Firm Size              , NLNUM, 20, 4";
put "PD_EXP_COUNTERPARTY     , NUM , VAR  , 8, PD for Exposure (Counterparty)      , NLNUM, 20, 4";
put "PD_EXP                  , NUM , VAR  , 8, PD for Exposure (Issue)             , NLNUM, 20, 4";
put "PD_EFF                  , NUM , VAR  , 8, Effective PD for Exposure           , NLNUM, 20, 4";
put "PD_CRM_COUNTERPARTY     , NUM , VAR  , 8, PD for CRM (Counterparty)           , NLNUM, 20, 4";
put "PD_CRM                  , NUM , VAR  , 8, PD for CRM (Issue)                  , NLNUM, 20, 4";
put "LGD_EFF                 , NUM , VAR  , 8, Exposure Effective LGD              , NLNUM, 20, 4";
put "LGD_EXP                 , NUM , VAR  , 8, Exposure LGD: IRBF/IRBA             , NLNUM, 20, 4";
put "LGD_EXP_OTHER           , NUM , VAR  , 8, Exposure LGD adjused for crm        , NLNUM, 20, 4";
put "LGD_CRM_SENIOR          , NUM , VAR  , 8, CRM LGD: Senior Claims              , NLNUM, 20, 4";
put "LGD_CRM_SUBORDINATED    , NUM , VAR  , 8, CRM LGD: Surbodinated Claims        , NLNUM, 20, 4";
put "C_STAR                  , NUM , VAR  , 8, Minimum Collateralization Level     , NLNUM, 20, 4";
put "C_STAR_STAR             , NUM , VAR  , 8, Minimum Collateralization Level     , NLNUM, 20, 4";
put "RW_EXP                  , NUM , VAR  , 8, Exposure RW                         , NLNUM, 20, 4";
put "RW_EXP_OTHER            , NUM , VAR  , 8, Exposure RW using LGD_OTHER         , NLNUM, 20, 4";
put "RW_EXP_COUNTERPARTY     , NUM , VAR  , 8, Exposure RW: STD (Counterparty)     , NLNUM, 20, 4";
put "RW_EXP_DILUTION         , NUM , VAR  , 8, Exposure RW (Dilution): IRBF/IRBA   , NLNUM, 20, 4";
put "RW_CRM                  , NUM , VAR  , 8, CRM RW                              , NLNUM, 20, 4";
put "RW_CRM_COUNTERPARTY     , NUM , VAR  , 8, CRM RW: STD                         , NLNUM, 20, 4";
put "EL                      , NUM , VAR  , 8, Expected Loss (Percent)             , NLNUM, 20, 4";
put "EL_EFF                  , NUM , VAR  , 8, Effective Expect Loss After CRM     , NLNUM, 20, 4 ";
put "EL_AMT                  , NUM , VAR  , 8, Expected Loss (Amount)              , NLNUM, 20, 4";
put "DILUTION_EL             , NUM , VAR  , 8, Expected Loss(Dilution Percent)     , NLNUM, 20, 4";
put "RW                      , NUM , VAR  , 8, Risk Weight                         , NLNUM, 20, 4";
put "RW_NO_CRM               , NUM , VAR  , 8, RW: No CRM Applied                  , NLNUM, 20, 4";
put "RWA                     , NUM , VAR  , 8, Risk Weighted Assets                , NLNUM, 20, 4";
put "RWA_SECURED             , NUM , VAR  , 8, RWA: Secured Portion                , NLNUM, 20, 4";
put "RWA_PD_LGD_EFFECT       , NUM , VAR  , 8, Effect of CD on RWA                 , NLNUM, 20, 4"; 
put "RWA_DBL_DEF_EFFECT      , NUM , VAR  , 8, RWA: Without Double Default         , NLNUM, 20, 4"; 
put "RWA_UNSECURED           , NUM , VAR  , 8, RWA: Unsecured Portion              , NLNUM, 20, 4";
put "RWA_NO_CRM              , NUM , VAR  , 8, RWA: No CRM Applied                 , NLNUM, 20, 4";
put "CAPITAL                 , NUM , VAR  , 8, Minimum Capital                     , NLNUM, 20, 4";
put "CAPITAL_NO_CRM          , NUM , VAR  , 8, Minimum Capital: No CRM Applied     , NLNUM, 20, 4";
put "PD_EFF                  , NUM , VAR  , 8, Effective PD after CRMs             , NLNUM, 20, 4";
put "LGD_EFF                 , NUM , VAR  , 8, Effective LGD after CRMs            , NLNUM, 20, 4";
put "CRM_USED_AMT            , NUM , VAR  , 8, Used CRM Amount                     , NLNUM, 20, 4";
put "CRM_USED_AMT_EFF        , NUM , VAR  , 8, Effective Used CRM Amount           , NLNUM, 20, 4";
/*put "EAD_ADJ                 , NUM , VAR  , 8, Adjusted EAD for RWA                , NLNUM, 20, 4"; */
put "RWA_SEG                 , NUM , VAR  , 8, RWA at Retail Segment level         , NLNUM, 20, 4";
put "ECL_SEG                 , NUM , VAR  , 8, Exp. Credit Loss at Retail Segment  , NLNUM, 20, 4";
put "RW_REG_Y                , NUM , VAR  , 8, Risk Weigh Under Reg Y              , NLNUM, 20, 4";
put "RW_SEG                  , NUM , VAR  , 8, RW : At Retail Segment level        , NLNUM, 20, 4";
put "PD_SEG                  , NUM , VAR  , 8, PD : At Retail Segment level        , NLNUM, 20, 4";
put "LGD_SEG                  , NUM , VAR  , 8, LGD : At Retail Segment level        , NLNUM, 20, 4";
put "ECL_SEG                  , NUM , VAR  , 8, ECL : At Retail Segment level        , NLNUM, 20, 4";
put "EAD_SEG                  , NUM , VAR  , 8, EAD : At Retail Segment level        , NLNUM, 20, 4";
put "EAD_TWO_YEARS                  , NUM , VAR  , 8, EAD : At Retail Segment level        , NLNUM, 20, 4";
put "CAPITAL_SEG              , NUM , VAR  , 8, CAPITAL : At Retail Segment level        , NLNUM, 20, 4";
run;

data RD_TEMP.rollup_inst_var;
infile f1 delimiter = ',' dsd ;
length NAME KIND ROLE TYPE GROUP FORMAT  $32.;
length LABEL $256.;
KIND    = 'INSTRUMENT';
GROUP   = 'Rollup Instrument Variables';
input NAME $ TYPE $ ROLE $ LENGTH LABEL $  FORMAT $ FORMATL FORMATD;
run;

/*- Concatenate data-driven instrument variable definition data sets -*/
data RD_TEMP.var_inst;
  set RD_TEMP.mtm_inst_var
      RD_TEMP.regulatory_inst_var
      RD_TEMP.rollup_inst_var;
run;

/*- Removing duplicates, keeping the variable with the "longest" length -*/
proc sort data=RD_TEMP.var_inst ;
by NAME  descending LENGTH ;
run;

proc sort data=RD_TEMP.var_inst nodupkey ;
by NAME;
run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from RD_TEMP.var_inst
where  upcase(NAME) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;
%mend c05_create_inst_var_usfinal;
