/*****************************************************************************
 * Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: calc_sec_tot_amt_orig_crd4.sas
 *
 * PURPOSE: Calculate the total amount of securitization originated 
 *          for a securitization pool. 
 *          
 *   USAGE: calc_sec_tot_amt_orig_crd4.sas
 *          
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

/*- total amount of securitization originated includes the sum of tranche face values   -*/
/*- of all sec tranches, the sum of face value of all supporting facilities, and the sum -*/
/*- of exposure values of all supporting derivatives for a securitization pool           -*/

/*- assume datasets needed have been generated already -*/
%macro calc_sec_tot_amt_orig_crd4 ;
     
      proc sort data= all_sec_tranches nodupkey;
         by SECURITIZATION_POOL_RK TRANCHE_SENIORITY_RANK ;
      run;   
         
      proc summary data = all_sec_tranches;
              by SECURITIZATION_POOL_RK ;
              var TRANCHE_FACE_VALUE_AMT ;
              output out= sec_tot_amt_tranches(keep=SECURITIZATION_POOL_RK SEC_TOTAL_AMT_TRANCHES )  
                     sum = SEC_TOTAL_AMT_TRANCHES ;
      run ; 
      
      proc sort data= all_sec_facility nodupkey;
               by SECURITIZATION_POOL_RK EXP_ID ;
      run;   
               
      proc summary data = all_sec_facility;
              by SECURITIZATION_POOL_RK ;
              var FACE_VALUE_AMT ;
              output out= sec_tot_amt_facility(keep=SECURITIZATION_POOL_RK SEC_TOTAL_AMT_FACILITY )  
                     sum = SEC_TOTAL_AMT_FACILITY ;
      run ;
      
      proc sort data= all_sec_deriv nodupkey;
                     by SECURITIZATION_POOL_RK EXP_ID ;
      run;   

      proc summary data = all_sec_deriv;
              by SECURITIZATION_POOL_RK ;
              var EXP_VALUE ;
              output out= sec_tot_amt_deriv(keep=SECURITIZATION_POOL_RK SEC_TOTAL_AMT_DERIV )  
                     sum = SEC_TOTAL_AMT_DERIV ;
      run ; 
      
      data sec_tot_amt_orig (keep = SECURITIZATION_POOL_RK SEC_TOTAL_AMT_ORIGINATED) ;
         merge sec_tot_amt_tranches sec_tot_amt_facility sec_tot_amt_deriv ;
         by SECURITIZATION_POOL_RK ;
         SEC_TOTAL_AMT_ORIGINATED = sum (SEC_TOTAL_AMT_TRANCHES, SEC_TOTAL_AMT_FACILITY, SEC_TOTAL_AMT_DERIV) ;
      run ;
    
    %mend calc_sec_tot_amt_orig_crd4 ;
    
