/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: create_instvar_def_data.sas
 *
 * PURPOSE: Stores code that creates instrument variable definition data set.
 *
 *   USAGE: %create_instvar_def_data(inds, outds);
 *          inds : (pos) exposure/crm position data set
 *          outds: (pos) instrument definition output data set
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro create_instvar_def_data(inds, outds);

    proc contents data = &inds
                  out  = &outds
                  noprint;
    run;

    data &outds ;

    format KIND $32.;
    format ROLE $32.;
    format TYPE $32.;

    label  KIND  = 'Kind of Variable';
    label  ROLE  = 'Role of Variable';
    label  TYPE  = 'Num or Char';

    KIND  = "INSTRUMENT" ;

    set &outds(rename=(TYPE=SASTYPE)) ;

    Keep KIND ROLE TYPE NAME LABEL LENGTH FORMAT FORMATL FORMATD;

    if LABEL = '' then LABEL = tranwrd(NAME, '_', ' ');

/*- make label proper case -*/
    LABEL = propcase(LABEL);

    if SASTYPE = 1 then TYPE = "Num";
    else if SASTYPE = 2 then TYPE = "Char";

    NAME = upcase(NAME);

    if NAME in ('COUNTERPARTY_GROUP', 'COUNTERPARTY_COUNTRY', 'COUNTERPARTY_TYPE', 'INDUSTRY', 'REGION', 'SECTOR',
                 'COUNTERPARTY_CLASS', 'COUNTERPARTY_SUBCLASS', 'STD_PRODUCT_CLASS', 'STD_PRODUCT_SUBCLASS',
                 'IRB_PRODUCT_CLASS', 'IRB_PRODUCT_SUBCLASS', 'PRODUCT', 'SUBPRODUCT', 'CRM_TYPE', 'CRM_SUBTYPE',
                 'APPROACH_CLASS', 'APPROACH', 'BUSINESS_UNIT', 'BUSINESS_LINE_TYPE_CD', 'BUSINESS_TYPE_CD',
                 'POSITION_CATEGORY',
                 'PD_BUCKET', 'LGD_BUCKET', 'RW_BUCKET') then
        ROLE = "CLASS";
    else
        ROLE = "VAR";

    run;

%mend create_instvar_def_data;
