/********************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: d00_pm_exposure_crd4.sas
 *
 * PURPOSE: Create pricing methods for exposure regulatory risk weight calculation.
 *
 *   USAGE: 
 *
 *   NOTES: Modeified to include new pricing methods for STD approach under CRD-IV.
 *          
 *
 *********************************************************************************/

%macro d00_pm_exposure_crd4;

proc compile outlib  = RD_TEMP.&RD_TEMPLATE
             inlib   = RD_TEMP.&RD_TEMPLATE
             package = regulatory_rw
             label   = "Regulatory Risk Weight Methods"
             env     = RD_TEMP.&RD_TEMPLATE ;


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for exposures under Basel I rules
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_BASEL_I kind = price 
                      desc = 'RW: Basel I' ;

  %pm_exp_basel_i;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:   method for exposures under Basel I rules
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for exposures in default under STD approach
 *
 *------------------------------------------------------------------------------
 */
method PM_EXP_DEFAULTED_STD_CRD4 kind = price 
                          desc = 'RW: Exposures in Default (STD)' ;

    %pm_exp_defaulted_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for exposures in default under STD approach
 *
 *------------------------------------------------------------------------------
 */

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for Central Government/Bank exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CENTGOV_STD_CRD4 kind = price 
                            desc = 'RW:Central Gov Exposures (STD)' ;

    %pm_exp_centgov_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for Central Government/Bank exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for Institution exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_INSTITUTION_STD_CRD4 kind = price 
                            desc = 'RW: Institution Exposures (STD)' ;

    %pm_exp_institution_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for Institution exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for Regional/Local Government exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_REGGOV_STD_CRD4 kind = price 
                            desc = 'RW:Regional Gov Exposures (STD)' ;

    %pm_exp_reggov_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for Regional/Local Government exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for PSE exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_PSE_STD_CRD4 kind = price 
                            desc = 'RW: PSE Exposures (STD)' ;

    %pm_exp_pse_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for PSE exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for Multilateral Development Bank exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_MDB_STD_CRD4 kind = price 
                            desc = 'RW: MDB Exposures (STD)' ;

    %pm_exp_mdb_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for Multilateral Development Bank exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for International Organization exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_INT_ORG_STD_CRD4 kind = price 
                            desc = 'RW: Intl Org Exposures (STD)' ;

    %pm_exp_int_org_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for International Organization exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 
 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 

method PM_EXP_CORPORATE_STD_CRD4 kind = price 
                            desc = 'RW: Corporate Exposures (STD)' ;

    %pm_exp_corporate_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CIU exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 

method PM_EXP_CIU_STD_CRD4 kind = price 
                            desc = 'RW: CIU Exposures (STD)' ;

    %pm_exp_ciu_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CIU exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for COV_BOND exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 

method PM_EXP_COV_BOND_STD_CRD4 kind = price 
                            desc = 'RW: COV_BOND Exposures (STD)' ;

    %pm_exp_cov_bond_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for COV_BOND exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */ 


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for SECURITIZATION exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_SECURITIZATION_STD_CRD4 kind = price 
                                 desc = 'RW: Sec. Exposures (STD)' ;

    %pm_exp_securitization_std_crd4;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for SECURITIZATION exposures under STD approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for claims secured by residential property under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_RME_STD_CRD4 kind = price 
                      desc = 'RW: Residential Mortgage (STD)' ;

    %pm_exp_rme_std_crd4;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for claims secured by residential property under STD approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for claims secured by commercial real estate under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CME_STD_CRD4 kind = price 
                      desc = 'RW: Commercial Mortgages (STD)' ;

    %pm_exp_cme_std_crd4;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for claims secured by commercial real estate under STD approach
 *
 *------------------------------------------------------------------------------
 */ 

 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for high risk exposures
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_HIGH_RISK_STD_CRD4 kind = price
                                  desc = 'RW: high risk exposures';

    %pm_exp_high_risk_std_crd4;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for high risk exposures 
 *
 *------------------------------------------------------------------------------
 */

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for lease residual values under STD approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_LEASE_RESIDUAL_STD_CRD4 kind = price 
                               desc = 'RW: Lease Residual Values(STD)' ;                               

    %pm_exp_lease_residual_std_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for lease residual values under STD approach
 *
 *------------------------------------------------------------------------------
 */
 
 /*------------------------------------------------------------------------------
  *
  * BEGIN:  method for other assets under STD approach
  *
  *------------------------------------------------------------------------------
  */
 
 method PM_EXP_OTHER_ASSETS_STD kind = price 
                                desc = 'RW: Other Assets (STD)' ;                               
 
     %pm_exp_other_assets_std;
     
 endmethod;
 
 /*------------------------------------------------------------------------------
  *
  * END:  method for other assets under STD approach
  *
  *------------------------------------------------------------------------------
 */
 
 /*------------------------------------------------------------------------------
  *
  * BEGIN:  method for Equity Exposures under STD approach of CRD4
  *
  *------------------------------------------------------------------------------
  */
 
 method PM_EXP_EQUITY_STD_CRD4 kind = price 
                             desc = 'RW:Equity Exposures (STD)' ;
 
     %pm_exp_equity_std_crd4 ; 
     
 endmethod;
 
 /*------------------------------------------------------------------------------
  *
  * END:  method for Equity Exposures under STD approach of CRD4
  *
  *------------------------------------------------------------------------------
  */
 
 /*------------------------------------------------------------------------------
  *
  * BEGIN:  method for Retail Exposures under STD approach of CRD4
  *
  *------------------------------------------------------------------------------
  */
 
 method PM_EXP_RETAIL_STD_CRD4 kind = price 
                             desc = 'RW:Retail Exposures (STD)' ;
 
     %pm_exp_retail_std_crd4 ; 
     
 endmethod;
 
 /*------------------------------------------------------------------------------
  *
  * END:  method for Retail Exposures under STD approach of CRD4
  *
  *------------------------------------------------------------------------------
  */
 
 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for SOVEREIGN exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_SOVEREIGN_IRBF kind = price 
                             desc = 'RW: Sovereign Exposures (IRBF)' ;

    %pm_exp_sovereign_irbf_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for SOVEREIGN exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for SOVEREIGN exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_SOVEREIGN_IRBA kind = price 
                             desc = 'RW: Sovereign Exposures (IRBA)' ;

    %pm_exp_sovereign_irba;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for SOVEREIGN exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for BANK exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_INSTITUTION_IRBF_CRD4 kind = price 
                        desc = 'RW: Bank Exposures (IRBF)' ;

    %pm_exp_bank_irbf_crd4;
    
endmethod;


/*------------------------------------------------------------------------------
 *
 * END:  method for BANK exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for BANK exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_INSTITUTION_IRBA_CRD4 kind = price 
                        desc = 'RW: Bank Exposures (IRBA)' ;

    %pm_exp_bank_irba_CRD4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for BANK exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */
 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CORPORATE_IRBF kind = price 
                             desc = 'RW: Corporate Exposures (IRBF)' ;

    %pm_exp_corporate_irbf_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CORPORATE_IRBA kind = price 
                             desc = 'RW: Corporate Exposures (IRBA)' ;

    %pm_exp_corporate_irba;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE (SL: HVCRE) exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CORPORATE_HVCRE_IRBF kind = price 
                                   desc = 'RW: HVCRE Exposures (IRBF)' ;

    %pm_exp_corp_hvcre_irbf_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE (SL: HVCRE) exposures under IRBF approach
 *
 *------------------------------------------------------------------------------
 */
 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE (SL: HVCRE) exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CORPORATE_HVCRE_IRBA kind = price 
                                   desc = 'RW: HVCRE Exposures (IRBA)' ;

    %pm_exp_corporate_hvcre_irba;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE (SL: HVCRE) exposures under IRBA approach
 *
 *------------------------------------------------------------------------------
 */

 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE (SL other than HVCRE) exposures under IRB: Supervisory Slotting
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_SL_IRB_SLOTTING kind = price 
                              desc = 'RW: SL Exposures(Slotting)' ;

    %pm_exp_sl_irb_slotting;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE (SL other than HVCRE) exposures under IRB: Supervisory Slotting
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for CORPORATE (SL: HVCRE) exposures under IRB: Supervisory Slotting
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_HVCRE_IRB_SLOTTING kind = price 
                                 desc = 'RW: SL Exposures(Slotting)' ;

    %pm_exp_hvcre_irb_slotting;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for CORPORATE (SL: HVCRE) exposures under IRB: Supervisory Slotting
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for RETAIL exposures under IRB
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_RETAIL_IRB_CRD4 kind = price 
                         desc = 'RW: Retail Exposures (IRB)' ;

    %pm_exp_retail_irb_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for RETAIL exposures under IRB
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for EQUITY exposures under IRB - Simple Risk Weight Approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_EQ_IRB_SIMPLE_RW kind = price
                               desc = 'RW: Equities (IRB-Simple)';

    %pm_exp_eq_irb_simple_rw;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for EQUITY exposures under IRB - Simple Risk Weight Approach
 *
 *------------------------------------------------------------------------------
 */
 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for EQUITY exposures under IRB - Internal Models Approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_EQ_IRB_INT_MODELS kind = price
                                desc = 'RW: Equities (IRB-Int. Models)';

    %pm_exp_eq_irb_int_models;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for EQUITY exposures under IRB - Internal Models Approach
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for EQUITY exposures under IRB - PD/LGD Approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_EQ_IRB_PD_LGD_CRD4 kind = price
                            desc = 'RW: Equities (IRB- PD/LGD Approach)';

    %pm_exp_eq_irb_pd_lgd_crd4;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for EQUITY exposures under IRB - PD/LGD Approach
 *
 *------------------------------------------------------------------------------
 */
 

/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for PURCHASED CORPORATE RECEIVABLES under IRBF
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CORPORATE_REC_IRBF kind = price 
                                 desc = 'RW: Purchased Corp Rec (IRBF)' ;

    %pm_exp_corporate_rec_irbf_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for PURCHASED CORPORATE RECEIVABLES under IRBF
 *
 *------------------------------------------------------------------------------
 */ 


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for PURCHASED CORPORATE RECEIVABLES under IRBA
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_CORPORATE_REC_IRBA kind = price 
                                 desc = 'RW: Purchased Corp Rec (IRBA)' ;

    %pm_exp_corporate_rec_irba;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for PURCHASED  CORPORATE RECEIVABLES under IRBA
 *
 *------------------------------------------------------------------------------
 */ 


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for PURCHASED RETAIL RECEIVABLES under IRB
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_RETAIL_REC_IRB kind = price 
                             desc = 'RW: Purchased Retail Rec (IRB)' ;

    %pm_exp_retail_rec_irb;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for PURCHASED RETAIL RECEIVABLES under IRB
 *
 *------------------------------------------------------------------------------
 */ 
 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for lease residual value under IRB
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_LEASE_RESIDUAL_IRB_CRD4 kind = price 
                                 desc = 'RW: LEASE RESIDUAL VALUE' ;

    %pm_exp_lease_residual_irb_crd4;
    
endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for lease residual value under IRB
 *
 *------------------------------------------------------------------------------


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for SECURITIZATION exposures under RBA/IAA approach
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_SECURITIZATION_IRB kind = price 
                                 desc = 'RW: Sec. Exposures(RBA/IAA)' ;

    %pm_exp_securitization_irb;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for SECURITIZATION exposures under RBA/IAA approach
 *
 *------------------------------------------------------------------------------
 */
 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for SECURITIZATION pool subject to special treatment 
 *         e.g. early amortization provision capital charge
 *
 *------------------------------------------------------------------------------
 */

method PM_EXP_SECURITIZATION_POOL kind = price 
                                  desc = 'RW: Sec. Exposures(RBA/IAA)' ;

    %pm_exp_securitization_pool;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for SECURITIZATION pool subject to special treatment 
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for Other non credit obligations under IRB 
 *
 *------------------------------------------------------------------------------
 */
 
method PM_EXP_IRB_OTHER_ASSETS_CRD4 kind = price 
                                  desc = 'RW: Other Non Credit obligations' ;

   %pm_exp_irb_other_assets_crd4;

endmethod;

/*------------------------------------------------------------------------------
 *
 * END:  method for Other non credit obligations under IRB
 *
 *------------------------------------------------------------------------------
 */
 
/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for Cash in hand, gold bullion exposures under IRB 
 *
 *------------------------------------------------------------------------------
 */
 
method PM_EXP_IRB_CASH_GOLD_CRD4 kind = price 
                                  desc = 'RW: Cash Gold bullion' ;

   %pm_exp_irb_cash_gold_crd4 ; 

endmethod;
 
/*------------------------------------------------------------------------------
 *
 * END:  method for Cash in hand, gold bullion exposures under IRB 
 *
 *------------------------------------------------------------------------------
 */


/*------------------------------------------------------------------------------
 *
 * BEGIN:  method for trade exposures cleared through CCP  
 *
 *------------------------------------------------------------------------------
 */
 
method PM_EXP_CCR_CCP_CRD4 kind = price 
                                  desc = 'RW: Trade Exp cleared thru CCP' ;

   %pm_exp_ccr_ccp_crd4 ; 

endmethod;
 
/*------------------------------------------------------------------------------
 *
 * END:  method for trade exposures cleared through CCP 
 *
 *------------------------------------------------------------------------------
 */
 
run;
%mend d00_pm_exposure_crd4;
