/*****************************************************************************
 * Copyright (c) 2014 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: d05_create_inst_types_crd4.sas
 *
 * PURPOSE: Create instrument type data set for input to RiskDimensions
 *
 *   USAGE: 
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro d05_create_inst_types_crd4;

/*- 1: variables common to MtM pricing -*/
/*- datalines statement replaced with file infile statements while moving to MVA code -*/
data _null_;
filename f1 temp;
file f1;
put "MTM_ROOT  , BASE    ,                ,  , .           ";
put "MTM_ROOT  , VAR     ,  HOLDING       ,  , .";
put "MTM_ROOT  , VAR     ,  CURRENCY      ,  ,  ";
put "MTM_ROOT  , VAR     ,  COLLATERAL    ,  ,  ";
put "MTM_ROOT  , VAR     ,  SHORTPOSITION ,  ,  ";
put "MTM_ROOT  , VAR     ,  COUNTERPARTYID,  ,  ";
put "MTM_ROOT  , DEFAULTN,  HOLDING       ,  , 1";
run;

data mtm_root;
infile f1 delimiter = ',' ;
length INSTTYPE $32.;
length TYPE $10.;
length CONTENT $256.;
length CVALUE $32.;
input INSTTYPE $ TYPE $ CONTENT $ CVALUE $ NVALUE;
run;


/*- datalines statement replaced with file infile statements while moving to MVA code -*/
data _null_;
filename f1 temp;
file f1;
put "MTM_ROOT  , VAR     ,  ISSUER_CPTY_CLASS   ,  , ";
put "MTM_ROOT  , VAR     ,  ISSUER_CPTY_SUBCLASS,  , ";
put "MTM_ROOT  , VAR     ,  RESIDUAL_MAT_REPO_CONTRACT,  , ";
run;

data mtm_root2;
infile f1 delimiter = ',' ;
length INSTTYPE $32.;
length TYPE $10.;
length CONTENT $256.;
length CVALUE $32.;
input INSTTYPE $ TYPE $ CONTENT $ CVALUE $ NVALUE;
run;

%macro add_mtm_root;
%if &ISSUE_CPTY_EXIST %then %do;
proc append base=mtm_root data=mtm_root2;
run;
%end;
%mend add_mtm_root;

%add_mtm_root;

/*- 2: variables for each type of MtM instruments -*/

/*- accounts -*/

/*- get all variables -*/
data mtm_account;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_ACCOUNT';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_account(keep=NAME rename=(NAME=CONTENT)) 
    RD_TEMP.instvar_crm_account(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Account';
    output;
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_ACCOUNT';
    output;
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_account nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_account as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- instruments -*/

/*- get all variables -*/
data mtm_instrument;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_INSTRUMENT';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_instrument(keep=NAME rename=(NAME=CONTENT)) 
    RD_TEMP.instvar_crm_instrument(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Instrument';
    output; 
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_INSTRUMENT';
    output;
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_instrument nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_instrument as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- only for testing purpose: trading book testing case -*/
%macro get_mtm_test_ccr;
%if &N_TRADING_BOOK_EXP GT 0 %then %do;
/*- get all variables -*/
data mtm_test_ccr;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_TEST_CCR';
TYPE = 'VAR';
set RD_TEMP.instvar_exposure_tb(keep=NAME rename=(NAME=CONTENT)) 
    RD_TEMP.instvar_crm_instrument_tb(keep=NAME rename=(NAME=CONTENT))
    RD_TEMP.instvar_crm_account_tb(keep=NAME rename=(NAME=CONTENT)) 
    RD_TEMP.instvar_crm_derivative_tb(keep=NAME rename=(NAME=CONTENT)) 
    ;
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Test CCR Only';
    output; 
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_TEST_CCR';
    output;
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_test_ccr nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from mtm_test_ccr as mtm
where upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable) and
upcase(CONTENT) not in ("COLLATERAL", "NETTINGSETID", "SHORTPOSITION");
quit;
%end;
%mend get_mtm_test_ccr;
%get_mtm_test_ccr;

/*- netting set exposures -*/
%macro get_mtm_exp_net;
%if &N_NETEXP GT 0 %then %do;
data mtm_exp_net;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_EXP_NET';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_netting_tb(keep=NAME rename=(NAME=CONTENT)) ;
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Exp Netting Set';
    output; 
    TYPE = 'PRICE';
    CONTENT = 'PM_EXP_NETTING';
    output;
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_exp_net nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_exp_net as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;
%end;
%mend get_mtm_exp_net;
%get_mtm_exp_net;

/*- receivables -*/

/*- get all variables -*/
data mtm_receivable;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_RECEIVABLE';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_receivable(keep=NAME rename=(NAME=CONTENT)) 
    RD_TEMP.instvar_crm_receivable(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Receivable';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_RECEIVABLE';
    output;    
end;    
run;

/*- remove duplicate variables -*/
proc sort data = mtm_receivable nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_receivable as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- facilities -*/

/*- get all variables -*/
data mtm_facility;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_FACILITY';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_facility(keep=NAME rename=(NAME=CONTENT))
    RD_TEMP.instvar_exp_facility_sec(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Facility';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_FACILITY';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_facility nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_facility as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- securitization -*/

/*- get all variables -*/
data mtm_securitization;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_SECURITIZATION';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_securitization(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Securitization';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_SECURITIZATION';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_securitization nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_securitization as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- get all variables -*/
data mtm_securitization_pool;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_SEC_POOL';
TYPE = 'VAR';
set RD_TEMP.instvar_exp_sec_pool (keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Securitization Pool';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_SEC_POOL';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_securitization_pool nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_securitization_pool as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- derivative -*/

/*- get all variables -*/
data mtm_derivative;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_DERIVATIVE';
TYPE = 'VAR';
set RD_TEMP.instvar_crm_derivative(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Derivative';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_DERIVATIVE';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_derivative nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_derivative as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- insurance -*/

/*- get all variables -*/
data mtm_insurance;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_INSURANCE';
TYPE = 'VAR';
set RD_TEMP.instvar_crm_insurance(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Insurance';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_INSURANCE';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_insurance nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_insurance as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- guarantee -*/

/*- get all variables -*/
data mtm_guarantee;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_GUARANTEE';
TYPE = 'VAR';
set RD_TEMP.instvar_crm_guarantee(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Guarantee';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_GUARANTEE';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_guarantee nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_guarantee as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- physical -*/

/*- get all variables -*/
data mtm_physical;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_PHYSICAL';
TYPE = 'VAR';
set RD_TEMP.instvar_crm_physical(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Physical';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_PHYSICAL';
    output;    
end;
run;

/*- remove duplicate variables -*/
proc sort data = mtm_physical nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_physical as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- general provision -*/

/*- get all variables -*/
data mtm_general_provision;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_GENERAL_PROVISION';
TYPE = 'VAR';
set RD_TEMP.instvar_general_provision(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM General Provision';
    output;
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_GENERAL_PROVISION';
    output;    
end;
run;

/*- get some redundant varibles so RiskDimensions won't complain -*/
data mtm_general_provision;
set mtm_general_provision  mtm_instrument(in=b where=(TYPE not in ('BASE', 'LABEL', 'PRICE')));
if b then INSTTYPE = 'MTM_GENERAL_PROVISION';
run;


/*- remove duplicate variables -*/
proc sort data = mtm_general_provision nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_general_provision as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- exposure provision -*/

/*- get all variables -*/
data mtm_exposure_provision;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_EXPOSURE_PROVISION';
TYPE = 'VAR';
set RD_TEMP.instvar_exposure_provision(keep=NAME rename=(NAME=CONTENT));
output;
if _N_=1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Exposure Provision';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_EXPOSURE_PROVISION';
    output;    
end;
run;

/*- get some redundant varibles so RiskDimensions won't complain -*/
data mtm_exposure_provision;
set mtm_exposure_provision  mtm_instrument(in=b where=(TYPE not in ('BASE', 'LABEL', 'PRICE')));
if b then INSTTYPE = 'MTM_EXPOSURE_PROVISION';
run;

/*- remove duplicate variables -*/
proc sort data = mtm_exposure_provision nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_exposure_provision as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- facility group -*/

/*- get all variables -*/
data mtm_facility_group;
length INSTTYPE $32. TYPE $10.;
INSTTYPE = 'MTM_FACILITY_GROUP';
TYPE = 'VAR';
set RD_TEMP.instvar_facility_group(keep=NAME rename=(NAME=CONTENT));
output;
if _N_ = 1 then do;
    TYPE = 'BASE';
    CONTENT = 'MTM_ROOT';
    output;
    TYPE = 'LABEL';
    CONTENT = 'MtM Facility Group';
    output;    
    TYPE = 'PRICE';
    CONTENT = 'PM_MTM_FACILITY_GROUP';
    output;    
end;
run;

/*- get some redundant varibles so RiskDimensions won't complain -*/
data mtm_facility_group;
set mtm_facility_group  mtm_instrument(in=b where=(TYPE not in ('BASE', 'LABEL', 'PRICE')));
if b then INSTTYPE = 'MTM_FACILITY_GROUP';
run;

/*- remove duplicate variables -*/
proc sort data = mtm_facility_group nodup;by CONTENT;run;

/* Remove any reserved Risk Dimensions variables */
proc sql;
delete from  mtm_facility_group as mtm
where  upcase(CONTENT) in (select upcase(VAR) from RD_ROOT.rd_vartable);
quit;

/*- bonds -*/
data mtm_bond;
set mtm_instrument;
INSTTYPE = 'MTM_BOND';
if TYPE = 'PRICE' then CONTENT = 'PM_MTM_BOND';
else if TYPE = 'LABEL' then CONTENT='MtM Fixed Coupon Bond';
run;

/*- equities -*/
/*- Need to add CCF information for equities  -*/
/*- under standardized approach -*/
data mtm_equity;
set mtm_instrument end = last ;
INSTTYPE = 'MTM_EQUITY';
if TYPE = 'PRICE' then CONTENT = 'PM_MTM_EQUITY';
else if TYPE = 'LABEL' then CONTENT = 'MtM Equity';
output ;
if last then do ;
    INSTTYPE = 'MTM_EQUITY' ;
    TYPE = 'VAR' ; 
    CONTENT = 'CCF_SET' ;  
    output ;  

    INSTTYPE = 'MTM_EQUITY' ; 
    TYPE = 'VAR' ; 
    CONTENT = 'CCF_SET_ID' ; 
    output ;  

    INSTTYPE = 'MTM_EQUITY' ; 
    TYPE = 'VAR' ;  
    CONTENT = 'CCF_TYPE' ;  
    output ;  
end ; 
run;


/*- CIUs -*/ 
data mtm_ciu;
set mtm_instrument;
INSTTYPE = 'MTM_CIU';
if TYPE = 'PRICE' then CONTENT = 'PM_MTM_CIU';
else if TYPE = 'LABEL' then CONTENT = 'MtM CIU';
run;

/*- 3: all MtM instruments except for mtm_root -*/
%macro get_mtm_all;
data mtm_all;
set mtm_account
    mtm_instrument
    %if &N_TRADING_BOOK_EXP GT 0 %then %do;
    mtm_test_ccr
    %end;
    %if &N_NETEXP GT 0 %then %do;
    mtm_exp_net
    %end;
    mtm_bond 
    mtm_equity
    mtm_ciu
    mtm_receivable
    mtm_facility
    mtm_securitization
    mtm_securitization_pool
    mtm_derivative
    mtm_insurance
    mtm_guarantee
    mtm_physical
    mtm_general_provision
    mtm_exposure_provision
    mtm_facility_group
    ;
run; 
%mend get_mtm_all;
%get_mtm_all;
/*- 4: regulatory root instrument -*/
/*- !!! to reduce the number of unnecessary variables -*/
data reg_root;
set RD_TEMP.regulatory_inst_var(keep=NAME rename=(NAME=CONTENT))
    mtm_all(where=(TYPE not in ('BASE', 'LABEL', 'PRICE')));
INSTTYPE = 'REG_ROOT';
TYPE     = 'VAR';
output;
if _N_ = 1 then do;
    /*- COUNTERPARTYID is needed ! -*/
    CONTENT ='COUNTERPARTYID';
    output;

    /*- SHORTPOSITION is needed for SEC reporting -*/
    CONTENT ='SHORTPOSITION';
    output;

    CONTENT = '';
    TYPE = 'BASE';
    output;
end;
run;

/*- 5: all regulatory instruments except for reg_root -*/
/*- datalines statement replaced with file infile statements while moving to MVA code -*/

data _null_;
filename f1 temp;
file f1;
put "EXP_BASEL_I              , LABEL  ,  Exposures Subject to Basel I Rules";
put "EXP_BASEL_I              , BASE   ,  REG_ROOT";
put "EXP_BASEL_I              , PRICE  ,  PM_EXP_BASEL_I";
put "EXP_CCR_CCP              , LABEL  ,  Trade Exposures to CCP";
put "EXP_CCR_CCP              , BASE   ,  REG_ROOT";
put "EXP_CCR_CCP              , PRICE  ,  PM_EXP_CCR_CCP_CRD4";
put "EXP_INSTITUTION_IRBF     , LABEL  ,  Bank Exposures Under IRBF";
put "EXP_INSTITUTION_IRBF     , BASE   ,  REG_ROOT";
put "EXP_INSTITUTION_IRBF     , PRICE  ,  PM_EXP_INSTITUTION_IRBF_CRD4";
put "EXP_INSTITUTION_IRBA     , LABEL  ,  Bank Exposures Under IRBA";
put "EXP_INSTITUTION_IRBA     , BASE   ,  REG_ROOT";
put "EXP_INSTITUTION_IRBA     , PRICE  ,  PM_EXP_INSTITUTION_IRBA_CRD4";
put "EXP_CORPORATE_STD        , LABEL  ,  Corporate Exposures Under STD";
put "EXP_CORPORATE_STD        , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_STD        , PRICE  ,  PM_EXP_CORPORATE_STD_CRD4";
put "EXP_CORPORATE_IRBF       , LABEL  ,  Corporate Exposures Under IRBF";
put "EXP_CORPORATE_IRBF       , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_IRBF       , PRICE  ,  PM_EXP_CORPORATE_IRBF";
put "EXP_CORPORATE_IRBA       , LABEL  ,  Corporate Exposures Under IRBA";
put "EXP_CORPORATE_IRBA       , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_IRBA       , PRICE  ,  PM_EXP_CORPORATE_IRBA";
put "EXP_CORPORATE_HVCRE_IRBF , LABEL  ,  HVCRE Exposures Under IRBF";
put "EXP_CORPORATE_HVCRE_IRBF , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_HVCRE_IRBF , PRICE  ,  PM_EXP_CORPORATE_HVCRE_IRBF";
put "EXP_CORPORATE_HVCRE_IRBA , LABEL  ,  HVCRE Exposures Under IRBA";
put "EXP_CORPORATE_HVCRE_IRBA , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_HVCRE_IRBA , PRICE  ,  PM_EXP_CORPORATE_HVCRE_IRBA";
put "EXP_DEFAULTED_STD        , LABEL  ,  Exposures in default Under STD";
put "EXP_DEFAULTED_STD        , BASE   ,  REG_ROOT";
put "EXP_DEFAULTED_STD        , PRICE  ,  PM_EXP_DEFAULTED_STD_CRD4";
put "EXP_CENTGOV_STD          , LABEL  ,  Central Gov Exposures Under STD";
put "EXP_CENTGOV_STD          , BASE   ,  REG_ROOT";
put "EXP_CENTGOV_STD          , PRICE  ,  PM_EXP_CENTGOV_STD_CRD4";
put "EXP_REGGOV_STD           , LABEL  ,  Regional Gov Exposures Under STD";
put "EXP_REGGOV_STD           , BASE   ,  REG_ROOT";
put "EXP_REGGOV_STD           , PRICE  ,  PM_EXP_REGGOV_STD_CRD4";
put "EXP_PSE_STD              , LABEL  ,  PSE Exposures Under STD";
put "EXP_PSE_STD              , BASE   ,  REG_ROOT";
put "EXP_PSE_STD              , PRICE  ,  PM_EXP_PSE_STD_CRD4";
put "EXP_MDB_STD              , LABEL  ,  MDB Exposures Under STD";
put "EXP_MDB_STD              , BASE   ,  REG_ROOT";
put "EXP_MDB_STD              , PRICE  ,  PM_EXP_MDB_STD_CRD4";
put "EXP_INT_ORG_STD          , LABEL  ,  Intl Org Exposures Under STD";
put "EXP_INT_ORG_STD          , BASE   ,  REG_ROOT";
put "EXP_INT_ORG_STD          , PRICE  ,  PM_EXP_INT_ORG_STD_CRD4";
put "EXP_INSTITUTION_STD      , LABEL  ,  Institution Exposures Under STD";
put "EXP_INSTITUTION_STD      , BASE   ,  REG_ROOT";
put "EXP_INSTITUTION_STD      , PRICE  ,  PM_EXP_INSTITUTION_STD_CRD4";
put "EXP_CIU_STD              , LABEL  ,  CIU Exposures Under STD";
put "EXP_CIU_STD              , BASE   ,  REG_ROOT";
put "EXP_CIU_STD              , PRICE  ,  PM_EXP_CIU_STD_CRD4";
put "EXP_COV_BOND_STD              , LABEL  ,  COV_BOND Exposures Under STD";
put "EXP_COV_BOND_STD              , BASE   ,  REG_ROOT";
put "EXP_COV_BOND_STD              , PRICE  ,  PM_EXP_COV_BOND_STD_CRD4";
put "EXP_SOVEREIGN_IRBF       , LABEL  ,  Sovereign Exposures Under IRBF";
put "EXP_SOVEREIGN_IRBF       , BASE   ,  REG_ROOT";
put "EXP_SOVEREIGN_IRBF       , PRICE  ,  PM_EXP_SOVEREIGN_IRBF";
put "EXP_SOVEREIGN_IRBA       , LABEL  ,  Sovereign Exposures Under IRBA";
put "EXP_SOVEREIGN_IRBA       , BASE   ,  REG_ROOT";
put "EXP_SOVEREIGN_IRBA       , PRICE  ,  PM_EXP_SOVEREIGN_IRBA";
put "EXP_EQUITY_STD           , LABEL  ,  Equity Exposures Under STD";
put "EXP_EQUITY_STD           , BASE   ,  REG_ROOT";
put "EXP_EQUITY_STD           , PRICE  ,  PM_EXP_EQUITY_STD_CRD4";
put "EXP_RETAIL_STD           , LABEL  ,  Retail Exposures Under STD";
put "EXP_RETAIL_STD           , BASE   ,  REG_ROOT";
put "EXP_RETAIL_STD           , PRICE  ,  PM_EXP_RETAIL_STD_CRD4";
put "EXP_RETAIL_IRB           , LABEL  ,  Retail Exposures Under IRB";
put "EXP_RETAIL_IRB           , BASE   ,  REG_ROOT";
put "EXP_RETAIL_IRB           , PRICE  ,  PM_EXP_RETAIL_IRB_CRD4";
put "EXP_RME_STD              , LABEL  ,  Residential Mortgage Under STD";
put "EXP_RME_STD              , BASE   ,  REG_ROOT";
put "EXP_RME_STD              , PRICE  ,  PM_EXP_RME_STD_CRD4";
put "EXP_CME_STD              , LABEL  ,  Commercial Mortgage Under STD";
put "EXP_CME_STD              , BASE   ,  REG_ROOT";
put "EXP_CME_STD              , PRICE  ,  PM_EXP_CME_STD_CRD4";
put "EXP_OTHER_ASSETS_STD     , LABEL  ,  Other Assets Under STD";
put "EXP_OTHER_ASSETS_STD     , BASE   ,  REG_ROOT";
put "EXP_OTHER_ASSETS_STD     , PRICE  ,  PM_EXP_OTHER_ASSETS_STD";
put "EXP_LEASE_RESIDUAL_STD   , LABEL  ,  Lease Residual Value Under STD";
put "EXP_LEASE_RESIDUAL_STD   , BASE   ,  REG_ROOT";
put "EXP_LEASE_RESIDUAL_STD   , PRICE  ,  PM_EXP_LEASE_RESIDUAL_STD_CRD4";
put "EXP_HIGH_RISK_STD        , LABEL  ,  High risk exposures under STD";
put "EXP_HIGH_RISK_STD        , BASE   ,  REG_ROOT";
put "EXP_HIGH_RISK_STD        , PRICE  ,  PM_EXP_HIGH_RISK_STD_CRD4";  
put "EXP_SL_IRB_SLOTTING      , LABEL  ,  SL Exposures Under Supervisory Slotting";
put "EXP_SL_IRB_SLOTTING      , BASE   ,  REG_ROOT";
put "EXP_SL_IRB_SLOTTING      , PRICE  ,  PM_EXP_SL_IRB_SLOTTING";
put "EXP_HVCRE_IRB_SLOTTING   , LABEL  ,  HVCRE Exposures Under Supervisory Slotting";
put "EXP_HVCRE_IRB_SLOTTING   , BASE   ,  REG_ROOT";
put "EXP_HVCRE_IRB_SLOTTING   , PRICE  ,  PM_EXP_HVCRE_IRB_SLOTTING";
put "EXP_EQ_IRB_SIMPLE_RW     , LABEL  ,  Equity Under IRB: Simple Risk Weight";
put "EXP_EQ_IRB_SIMPLE_RW     , BASE  ,   REG_ROOT";
put "EXP_EQ_IRB_SIMPLE_RW     , PRICE  ,  PM_EXP_EQ_IRB_SIMPLE_RW";
put "EXP_EQ_IRB_INT_MODELS    , LABEL  ,  Equity Under IRB: Internal Models";
put "EXP_EQ_IRB_INT_MODELS    , BASE  ,   REG_ROOT";
put "EXP_EQ_IRB_INT_MODELS    , PRICE  ,  PM_EXP_EQ_IRB_INT_MODELS";
put "EXP_EQ_IRB_PD_LGD        , LABEL  ,  Equity Under IRB: PD/LGD ";
put "EXP_EQ_IRB_PD_LGD        , BASE  ,   REG_ROOT";
put "EXP_EQ_IRB_PD_LGD        , PRICE  ,  PM_EXP_EQ_IRB_PD_LGD_CRD4";
put "EXP_SECURITIZATION_STD   , LABEL  ,  Securitization Exposures Under STD";
put "EXP_SECURITIZATION_STD   , BASE   ,  REG_ROOT";
put "EXP_SECURITIZATION_STD   , PRICE  ,  PM_EXP_SECURITIZATION_STD_CRD4";
put "EXP_SECURITIZATION_IRB   , LABEL  ,  Securitization Exposures Under IRBF";
put "EXP_SECURITIZATION_IRB   , BASE   ,  REG_ROOT";
put "EXP_SECURITIZATION_IRB   , PRICE  ,  PM_EXP_SECURITIZATION_IRB";
put "EXP_SECURITIZATION_POOL  , LABEL  ,  Securitization Pool Exposures (special treatment) ";
put "EXP_SECURITIZATION_POOL  , BASE   ,  REG_ROOT";
put "EXP_SECURITIZATION_POOL  , PRICE  ,  PM_EXP_SECURITIZATION_POOL";
put "EXP_CORPORATE_REC_IRBF   , LABEL  ,  Purchased Corporate Receivables Under IRBF";
put "EXP_CORPORATE_REC_IRBF   , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_REC_IRBF   , PRICE  ,  PM_EXP_CORPORATE_REC_IRBF";
put "EXP_CORPORATE_REC_IRBA   , LABEL  ,  Purchased Corporate Receivables Under IRBA";
put "EXP_CORPORATE_REC_IRBA   , BASE   ,  REG_ROOT";
put "EXP_CORPORATE_REC_IRBA   , PRICE  ,  PM_EXP_CORPORATE_REC_IRBA";
put "EXP_RETAIL_REC_IRB       , LABEL  ,  Purchased Retail Receivables Under IRB";
put "EXP_RETAIL_REC_IRB       , BASE   ,  REG_ROOT";
put "EXP_RETAIL_REC_IRB       , PRICE  ,  PM_EXP_RETAIL_REC_IRB";
put "EXP_LEASE_RESIDUAL_VALUE , LABEL  ,  Lease Residual Value Under IRB";
put "EXP_LEASE_RESIDUAL_VALUE , BASE   ,  REG_ROOT";
put "EXP_LEASE_RESIDUAL_VALUE , PRICE  ,  PM_EXP_LEASE_RESIDUAL_IRB_CRD4";
put "CRM_FINANCIAL            , LABEL  ,  Financial Collateral";
put "CRM_FINANCIAL            , BASE   ,  REG_ROOT";
put "CRM_FINANCIAL            , PRICE  ,  PM_CRM_FINANCIAL_CRD4";  
put "CRM_PHYSICAL_STD         , LABEL  ,  STD Physical Collateral";
put "CRM_PHYSICAL_STD         , BASE   ,  REG_ROOT";
put "CRM_PHYSICAL_STD         , PRICE  ,  PM_CRM_PHYSICAL_STD_CRD4";  
put "CRM_IRB                  , LABEL  ,  IRB Collateral";
put "CRM_IRB                  , BASE   ,  REG_ROOT";
put "CRM_IRB                  , PRICE  ,  PM_CRM_IRB";
put "CRM_GUARANTEE            , LABEL  ,  Guarantee";
put "CRM_GUARANTEE            , BASE   ,  REG_ROOT";
put "CRM_GUARANTEE            , PRICE  ,  PM_CRM_GUARANTEE_CRD4";
put "CRM_NETTING              , LABEL  ,  Netting Collateral";
put "CRM_NETTING              , BASE   ,  REG_ROOT";
put "CRM_NETTING              , PRICE  ,  PM_CRM_NETTING_CRD4";  
put "CRM_DERIVATIVE           , LABEL  ,  Credit Derivative";
put "CRM_DERIVATIVE           , BASE   ,  REG_ROOT";
put "CRM_DERIVATIVE           , PRICE  ,  PM_CRM_DERIVATIVE_CRD4";
put "CRM_INSURANCE            , LABEL  ,  Insurance";
put "CRM_INSURANCE            , BASE   ,  REG_ROOT";
put "CRM_INSURANCE            , PRICE  ,  PM_CRM_INSURANCE";
put "EXP_IRB_OTHER_ASSETS       , LABEL  ,  Other Non-Credit Exposures Under IRB";
put "EXP_IRB_OTHER_ASSETS       , BASE   ,  REG_ROOT";
put "EXP_IRB_OTHER_ASSETS       , PRICE  ,  PM_EXP_IRB_OTHER_ASSETS_CRD4";
put "EXP_IRB_CASH_GOLD       , LABEL  ,  Cash in Hand, gold Bullion Exposures Under IRB";
put "EXP_IRB_CASH_GOLD       , BASE   ,  REG_ROOT";
put "EXP_IRB_CASH_GOLD       , PRICE  ,  PM_EXP_IRB_CASH_GOLD_CRD4";

run;

data reg_all;
infile f1 delimiter = ',' ;
length INSTTYPE $32.;
length TYPE $10.;
length CONTENT $256.;
input INSTTYPE $ TYPE $ CONTENT $;
run;

/*- 6: rollup instrument -*/
data rollup_all;
set RD_TEMP.rollup_inst_var(keep=NAME rename=(NAME=CONTENT))
    reg_root(where=(TYPE not in ('BASE', 'LABEL', 'PRICE')));
INSTTYPE = 'ROLLUP';
TYPE     = 'VAR';
output;
if _N_ = 1 then do;
    CONTENT = 'Rollup Instrument';
    TYPE = 'LABEL';
    output;
    TYPE = 'PRICE';
    CONTENT = 'PM_ROLLUP';
    output;        
end;
run;

/*- 7: all instrument types of interest -*/
data RD_TEMP.inst_types;
set mtm_root mtm_all reg_root reg_all rollup_all;
run;

proc sort data = RD_TEMP.inst_types nodup;
by INSTTYPE CONTENT;
run;
/*- 8: remove unnecessary instvars (subset) if required -*/
%macro subset_varlist;
%if "&SUBSET_INSTVARS" = "YES" %then %do;

  data insttype_vars;
  merge RD_TEMP.inst_types(in=all where=(TYPE='VAR')) 
        RD_ROOT.insttype_vardef(in=filter rename=(INSTVAR=CONTENT));
  by INSTTYPE CONTENT;
  if all and filter;
  run;

  data RD_TEMP.inst_types;
  set RD_TEMP.inst_types(where=(TYPE NE 'VAR'))
      insttype_vars
    ;
  by INSTTYPE;
  run;
%end;
%mend;

%subset_varlist;

/*- 9: clean WORK library -*/
%clean_lib;
%mend d05_create_inst_types_crd4;
