/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: enrich_exp_fac_crd4.sas
 *
 * PURPOSE: Stores code for enriching facilities in CRD-IV.
 *
 *   USAGE: %enrich_exp_fac_crd4(posds, issueds, outposds);
 *          posds    : (pos) input position data set
 *          issueds  : (pos) input issue data set
 *          outposds : (pos) output position data set
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro enrich_exp_fac_crd4(posds, issueds, outposds);
   %local SEGMENT_EXIST;
/*- enrich data with issue attributes and ratings and further processing -*/
    proc sort data = &posds out = &outposds ;
    by ISSUE_KEY;
    run;

    data &outposds;
    merge &outposds(in = a) RD_POS.issue_ratings RD_POS.issue_int_ratings 
                            RD_POS.issue_ratings_incep (KEEP = ISSUE_KEY EXT_ISSUE_INCEP_:) 
                            RD_POS.issue_int_ratings_incep (KEEP=ISSUE_KEY INT_ISSUE_INCEP_RATING) 
          &issueds(in=c);
    by ISSUE_KEY;
    if a ;
    run;

/*- check if DAYS_PAST_DUE_NO available -*/
    %let DAYS_EXIST = %varexist(&outposds, DAYS_PAST_DUE_NO);
    
/*- check if SEGMENT exists for Retail exposures-*/
   %let SEGMENT_EXIST = %varexist(&outposds, SEGMENT_ID);
   
   /*-Check is the retail data is available at ind. exposure level and configuration is USFinal
   then do the merging on segment_id on segment_mart table*/
   %if &SEGMENT_EXIST %then %do;
      %if &RETAIL_DATA_LOAD_USFINAL = YES %then %do;
         %if &RETAIL_EXP_IND_LOAD_USFINAL = YES %then %do;
         proc sort data= &outposds; 
         by SEGMENT_ID;
         run;
         data &outposds;
         merge &outposds(in = a) RD_STAGE.SEGMENT_MART;
         by SEGMENT_ID;
         if a;
         run;
         %end;
      %end;
   %end;


/*- enrich data with counterparty types -*/
    proc sort data = &outposds;
    by COUNTERPARTY_RK;
    run;

    data &outposds;
    merge &outposds(in=a) 
          RD_POS.counterparty_dim
          ;
    by COUNTERPARTY_RK;
    if a;
    run;

/*- enrich data with internal organization attributes -*/
    proc sort data = &outposds;
    by INTERNAL_ORG_RK;
    run;

    data &outposds(drop = INVALID_APPROACH_FLG CCF_BUCKET_CD
                          %if &NUM_AGENCIES_ISSUE>0 %then %do; EXT_ISSUE_RATING_: EXT_ISSUE_MAP_RATING_:
                          EXT_ISSUE_INCEP_RATING_: EXT_ISSUE_INCEP_MAP_RATING_:
                          CRM_ADJUSTED_FLG_: SHORT_TERM_ASSESS_FLG_: %end; 
                          LOCATION ORIGINAL_APPROACH REASON INT_ISSUE_RATING
                          INVALID_COMPONENT_FLG CPTY_PD_FLG PD_FLG LGD_FLG
                          BASELI_CCY_FLAG BASELI_ST_TYPE BASELI_PRODUCT_CLASS 
                          BASELI_PRODUCT_SUBCLASS BASELI_PRODUCT ELIGIBLE_DD_TREAT_GUARANTOR)
         &outposds._sec(drop = INVALID_APPROACH_FLG LOCATION ORIGINAL_APPROACH REASON INVALID_COMPONENT_FLG
                               CPTY_PD_FLG PD_FLG LGD_FLG INT_: ELIGIBLE_DD_TREAT_GUARANTOR)
         facilties_securitization
         invalid_approach(keep = INSTID COUNTERPARTY_CLASS STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS IRB_PRODUCT_CLASS 
                   IRB_PRODUCT_SUBCLASS APPROACH_CLASS APPROACH )
         invalid_components(keep=INSTID LOCATION ORIGINAL_APPROACH APPROACH REASON CPTY_PD_MODEL_ID CPTY_PD_RATING_GRADE PD_MODEL_ID 
                                 PD_MODEL_RATING_GRADE LGD_MODEL_ID LGD_MODEL_RATING_GRADE PD_PCT LGD_PCT CPTY_PD_PCT)
         ;

    merge &outposds(in =a) RD_STAGE.internal_org_mart(in = b);
    by INTERNAL_ORG_RK;
    if a;

    length STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS 
           APPROACH_CLASS INSTTYPE OFF_BALANCE_SHEET_TYPE CCF_SET CCF_TYPE 
           POSITION_CATEGORY BASELI_RW_CLASS 
           LOCATION  REASON $32. ORIGINAL_APPROACH APPROACH BASELI_CCY_FLAG $16.;
    length EXT_ISSUE_MAP_RATING INT_ISSUE_MAP_RATING EXT_ISSUE_INCEP_MAP_RATING INT_ISSUE_INCEP_MAP_RATING
           STD_RW_BUCKET IRB_RW_BUCKET BASELI_ST_TYPE        
           $8.;    
    length SEC_ACCTING_TREATMENT SEC_RETENTION_TYPE SEC_PORTFOLIO_TYPE SECURITIZATION_TREATMENT_TYPE $1.;  
    length OFF_BALANCE_SHEET_FLG 8.  EXP_NOT_OWNED_FLG 8. ;
   
/*- check on currency -*/
    if  CURRENCY = '' then CURRENCY="&REPORT_CCY" ;

/*- Create a flag which identifies exposure as a facility -*/
/*- so it can be conditioned on in later processing -*/
    FACILITY_FLG = 1 ;

/*- flag exposures not owned by the reporting institution -*/
     EXP_NOT_OWNED_FLG = put(FINANCIAL_BOOK_RK, MAP_EXP_NOT_OWNED_FLG.) ;   
       
/*- get seniority flag -*/
    %get_seniority_flg;

/*- flag exposures underlying securitization pools -*/ 
    %get_securitized_exposure_flg;

/*- get original and residual maturity -*/
    %get_maturity(INCEPTION_DATE, MATURITY_DATE);

/*- determine if it is considered past due: more than &DAYS_PAST_DUE_THRESHOLD days -*/
    %if &DAYS_EXIST %then %do;
        PAST_DUE_CLAIM_FLG = (DAYS_PAST_DUE_NO > &DAYS_PAST_DUE_THRESHOLD);
    %end;

/*- get product class and subclass -*/
    %get_product_class;
    
/*- get LE product class and OBSI type -*/
    %get_le_exposure_type_crd4;
    
/*- get regulatory approach -*/
    %get_regulatory_approach;   
       
/*- check proper approach assignment -*/
    %check_asset_class_approach;
    
  
    if INVALID_APPROACH_FLG EQ 1 then 
       output invalid_approach;  
    
/*- process the following only for valid approaches -*/
    else do;                
       %get_position_type;
 
       COLLATERAL = 0; 
 
/*- flag for covering securitization pool and output for further processing -*/
       if COVER_SECURITIZATION_POOL_RK NE . and 
          (STD_PRODUCT_CLASS='SECURITIZATION' or STD_PRODUCT_CLASS='SEC' or IRB_PRODUCT_CLASS='SECURITIZATION' or IRB_PRODUCT_CLASS='SEC') 
          and APPROACH NE 'BASEL_I' then do;
             SECURITIZATION_EXPOSURE_FLG = 1;
             SEC_UNDERLYING_EXP_FLG = 0;   
             output facilties_securitization;
       end;
       else do;
          SECURITIZATION_EXPOSURE_FLG = 0;   

/*- check necessary component for IRB aproaches -*/
          %check_component;    
    
          LOCATION="&outposds";
          if INVALID_COMPONENT_FLG = 1 then
             output invalid_components;
/*- determine if it is a short-term claim: original maturity of 3 months or less -*/
          %get_shortterm_claim_flg_crd4; 
          
/*- get instrument type for MtM pricing -*/
          %get_mtm_insttype;

/*- get off-balance-sheet type -*/
          %get_obsi_type;
          if not missing(OFF_BALANCE_SHEET_TYPE) then OFF_BALANCE_SHEET_FLG=1;
          
/*- get LE off-balance-sheet type -*/
    %get_le_obsi_type_crd4;

/*- get haircut info -*/
          %get_haircut_info;

/*- get ccf info -*/
          %get_ccf_info(OWN_ESTIMATE_ALLOWED=1);
    
/*- get mapped issue rating: either from second best or from specified rating agency -*/
       %get_mapped_ratings_crd4(RATING_TYPE=ISSUE, RATING_TIME=CURRENT);
       %get_mapped_ratings_crd4(RATING_TYPE=ISSUE, RATING_TIME=INCEPTION);

          if IRB_PRODUCT_CLASS = 'SL' then do;
             INT_ISSUE_MAP_RATING = put(INT_ISSUE_RATING, $INT.);
             INT_ISSUE_MAP_RATING = put(INT_ISSUE_INCEP_RATING, $INT.);
           end;

/*- get risk weight buckets -*/
          %get_std_rw_buckets_crd4; 
          %get_irb_rw_buckets;
       
/*- get Basel I risk weight mapping -*/
          %get_basel_i_rw;
       
/*- direct to the output data set -*/
          if SEC_UNDERLYING_EXP_FLG EQ 1 then 
             output &outposds._sec;
          else 
             output &outposds;
       end;
    end;
    run;

/*- get pool attributes for facilities covering securitization pools -*/
    proc sql;
    create table &outposds._securitization as
    select fac.*, pool.*
    from facilties_securitization(drop=SECURITIZATION_POOL_RK) as fac, RD_STAGE.securitization_pool_mart as pool
    where fac.COVER_SECURITIZATION_POOL_RK = pool.SECURITIZATION_POOL_RK;
    quit;
    
    data &outposds._securitization(drop = INVALID_APPROACH_FLG CCF_BUCKET_CD
                          %if &NUM_AGENCIES_ISSUE>0 %then %do; EXT_ISSUE_RATING_: EXT_ISSUE_MAP_RATING_:
                          EXT_ISSUE_INCEP_RATING_: EXT_ISSUE_INCEP_MAP_RATING_:
                          CRM_ADJUSTED_FLG_: SHORT_TERM_ASSESS_FLG_: %end; 
                          LOCATION ORIGINAL_APPROACH REASON
                          INVALID_COMPONENT_FLG CPTY_PD_FLG PD_FLG LGD_FLG
                          SECURITIZ_STRUC_TYPE_CD SECURITIZ_STRUC_SUBTYPE_CD);
    set &outposds._securitization;
    
    PRIMARY_BANK_ROLE = put(PRIMARY_BANK_ROLE_CD, $MAP_SEC_BANK_ROLE.);

    SEC_STRUCTURE_TYPE    = put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_SEC_STRUCTURE_TYPE.);
    SEC_STRUCTURE_SUBTYPE = put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_SEC_STRUCTURE_SUBTYPE.);
    SEC_ACCTING_TREATMENT = put(ACCTING_TREATMENT_CD,$MAP_SEC_ACCTING_TREATMENT.) ;  
    SECURITIZATION_TREATMENT_TYPE = put(FINANCIAL_BOOK_TYPE_CD,$MAP_FINANCIAL_BOOK_TYPE.); 
    SEC_RETENTION_TYPE= put(RETENTION_TYPE_CD,$MAP_SEC_RETENTION_TYPE.); 
    SEC_PORTFOLIO_TYPE = put(SEC_PORTFOLIO_TYPE_CD,$MAP_SEC_PORTFOLIO_TYPE.); 

    CORRELATION_TRADING_PORT_FLG = put(FINANCIAL_BOOK_RK,MAP_CORR_TRADING_FLG.) ;
   
/*- get instrument type for MtM pricing -*/
    %get_mtm_insttype;

/*- get off-balance-sheet type -*/
    %get_obsi_type;
    if not missing(OFF_BALANCE_SHEET_TYPE) then OFF_BALANCE_SHEET_FLG=1;
    
/*- get LE off-balance-sheet type -*/
    %get_le_obsi_type_crd4;

/*- get haircut info -*/
    %get_haircut_info;
    
/*- get mapped issue rating: either from second best or from specified rating agency -*/
    %get_mapped_ratings(RATING_TYPE=ISSUE);
    
/*- get internal issue ratings -*/
    if SHORT_TERM_CLAIM_FLG = 1 then do;
       if INT_SHORT_TERM_ASSESS_FLG = 1 then INT_ISSUE_MAP_RATING =  put(INT_ISSUE_RATING, $INT_ST.);
       else INT_ISSUE_MAP_RATING = 'MISS';
    end;
    else do;
       if INT_SHORT_TERM_ASSESS_FLG = 1 then INT_ISSUE_MAP_RATING = 'MISS';
       else INT_ISSUE_MAP_RATING = put(INT_ISSUE_RATING, $INT.);
    end;
    
/*- get risk weight buckets -*/
    %get_std_rw_buckets_crd4;  
    %get_irb_rw_buckets;
       
/*- get Basel I risk weight mapping -*/
    %get_basel_i_rw;
    
/*- get ccf info -*/
    %get_ccf_info(OWN_ESTIMATE_ALLOWED=0);
 
/*- update approach for seuritization treatment -*/
    if APPROACH in ('IRB', 'IRBA', 'IRBF') then APPROACH = 'IRB_RBA';

    if SEC_STRUCTURE_SUBTYPE = 'ABCP' and  EXT_ISSUE_MAP_RATING = 'MISS' and 
       INT_ISSUE_MAP_RATING NE 'MISS' then do;
       if APPROACH = 'IRB_RBA' then APPROACH = 'IRB_IAA';
       if APPROACH ='STD' and "&STD_RATED_ABCP_USE_IAA" = "YES" then APPROACH = 'STD_IAA';

       if INT_SHORT_TERM_ASSESS_FLG = 1 then
          IRB_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_IRB_RW_BUCKET_SEC_SHORT.);
       else
          IRB_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_IRB_RW_BUCKET_SEC.); 
       CRM_ADJUSTED_FLG = INT_RATING_CRM_ADJUSTED_FLG;
    end;        
       
/*- update the ccf_type for eligible liquidity facility if external rating is to be used -*/
    if STD_PRODUCT_SUBCLASS = 'ELQD_FACILITY' or IRB_PRODUCT_SUBCLASS = 'ELQD_FACILITY' then do;
       if EXT_ISSUE_MAP_RATING NE 'MISS' then CCF_TYPE='CCF_ELF_EXT_RATING';  
    end;   
    run;
    
/*- append invalid approach data set -*/
    %if %attrn(invalid_approach, NOBS) GT 0 %then %do;
       proc append base=RD_POS.invalid_approach data=invalid_approach;
       run;
    %end;
    
/*- append invalid component data set -*/
    %if %attrn(invalid_components, NOBS) GT 0 %then %do;
       proc append base=RD_POS.all_exp_with_invalid_components data=invalid_components force;
       run;
    %end;

/* Redirect the rows which doesn't have valid Instrument Type */     
   data &outposds  invalid_insttypes ;
        set &outposds; 
        if INVALID_INSTTYPE_FLG eq 1 then output invalid_insttypes ;
        else output 
            &outposds; 
       run ;  
   
      data &outposds._securitization    invalid_insttypes_sec ;
        set &outposds._securitization; 
        if INVALID_INSTTYPE_FLG eq 1 then output invalid_insttypes_sec ;
        else output 
            &outposds._securitization; 
       run ;      
/*- append invalid Instrument Type data set -*/
    %if %attrn(invalid_insttypes, NOBS) GT 0 %then %do;
       proc append base=RD_POS.all_exp_invalid_insttypes data=invalid_insttypes force nowarn;
       run;
    %end;

/*- append invalid Instrument sec Type data set -*/
    %if %attrn(invalid_insttypes_sec, NOBS) GT 0 %then %do;
       proc append base=RD_POS.all_exp_invalid_insttypes_sec data=invalid_insttypes_sec force nowarn;
       run;
    %end;
      

%mend enrich_exp_fac_crd4;
