/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: enrich_exposures_sec_crd4.sas
 *
 * PURPOSE: Stores code for enriching securitization exposures.
 *
 *   USAGE: %enrich_exposures_sec_crd4(posds, issueds, outposds);
 *          posds    : (pos) input position data set
 *          issueds  : (pos) input issue data set
 *          outposds : (pos) output position data set
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro enrich_exposures_sec_crd4(posds, issueds, poolds, outposds, outpoolds);
    
/*- enrich data with issue attributes and ratings -*/
    proc sort data = &posds out = &outposds ;
    by ISSUE_KEY;
    run;

    data &outposds;        
    merge &outposds(in = a) RD_POS.issue_ratings RD_POS.issue_int_ratings 
                            RD_POS.issue_ratings_incep (KEEP = ISSUE_KEY EXT_ISSUE_INCEP_:) 
                            RD_POS.issue_int_ratings_incep (KEEP=ISSUE_KEY INT_ISSUE_INCEP_RATING)
                            &issueds;
    by ISSUE_KEY;
    if a;    
    run; 

/*- check if DAYS_PAST_DUE_NO available -*/
    %let DAYS_EXIST = %varexist(&outposds, DAYS_PAST_DUE_NO);
    
/*- adding pool information -*/
    proc sort data=&outposds;
    by SECURITIZATION_POOL_RK;
    run;
   
    proc sort data=&poolds;
    by SECURITIZATION_POOL_RK ;
    run ;
 
    data &outposds;
    merge &outposds (in=a)
          &poolds (drop=COMM_OTHER_REVOLV_FACE_AMT COMM_RETAIL_REVOLV_FACE_AMT UNCOMM_OTHER_REVOLV_FACE_AMT
                        UNCOMM_RETAIL_REVOLV_FACE_AMT INVESTORS_INTEREST_PCT EARLY_AMORTIZATION_TYPE_CD
                        AVG_THREE_MONTH_EXCESS_SPREAD EXCESS_SPREAD_TRAPPING_POINT);
    by SECURITIZATION_POOL_RK;
    if a;
    run;

/*- enrich data with counterparty dimensional data -*/
    proc sort data = &outposds;
    by COUNTERPARTY_RK;
    run;

    data &outposds;
    merge &outposds(in=a) 
          RD_POS.counterparty_dim
          ;
    by COUNTERPARTY_RK;
    if a;
    run;
   
/*- enrich data with internal organization attributes -*/
    proc sort data = &outposds;
    by INTERNAL_ORG_RK;
    run;

    data &outposds(drop = PRIMARY_BANK_ROLE_CD CLEAN_UP_CALL_TYPE_CD 
                          %if &NUM_AGENCIES_ISSUE>0 %then %do; EXT_ISSUE_RATING_: EXT_ISSUE_MAP_RATING_:
                          EXT_ISSUE_INCEP_RATING_: EXT_ISSUE_INCEP_MAP_RATING_:
                          CRM_ADJUSTED_FLG_: SHORT_TERM_ASSESS_FLG_: %end; 
                          SECURITIZ_STRUC_TYPE_CD SECURITIZ_STRUC_SUBTYPE_CD
                          SECURITIZATION_POSITION BASELI_CCY_FLAG BASELI_ST_TYPE 
                          BASELI_PRODUCT_CLASS BASELI_PRODUCT_SUBCLASS BASELI_PRODUCT
                          ELIGIBLE_DD_TREAT_GUARANTOR INVALID_APPROACH_FLG
                  )
         invalid_approach(keep = INSTID COUNTERPARTY_CLASS STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS IRB_PRODUCT_CLASS 
                          IRB_PRODUCT_SUBCLASS APPROACH_CLASS APPROACH )         
         ;

    merge &outposds(in =a) RD_STAGE.internal_org_mart(in = b);
    by INTERNAL_ORG_RK;
    if a;
         
    length STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS POSITION_CATEGORY
           APPROACH_CLASS INSTTYPE OFF_BALANCE_SHEET_TYPE 
           HAIRCUT_SET HAIRCUT_TYPE SEC_STRUCTURE_TYPE SEC_STRUCTURE_SUBTYPE PRIMARY_BANK_ROLE
           BASELI_RW_CLASS  
           $32. APPROACH BASELI_CCY_FLAG $16.;
    length EXT_ISSUE_MAP_RATING INT_ISSUE_MAP_RATING 
           EXT_ISSUE_INCEP_MAP_RATING INT_ISSUE_INCEP_MAP_RATING
           HAIRCUT_RATING_BUCKET STD_RW_BUCKET IRB_RW_BUCKET 
           HAIRCUT_RES_MAT_BAND CLEAN_UP_CALL_TYPE BASELI_ST_TYPE
           $8. ELIGIBLE_SECURITIZATION $1.
           EXP_NOT_OWNED_FLG 8. ;
           
    length SEC_ACCTING_TREATMENT SEC_RETENTION_TYPE SEC_PORTFOLIO_TYPE SECURITIZATION_TREATMENT_TYPE $1.;  

    POSITION_CATEGORY = "EXPOSURE";

/*- check on currency -*/
    if  CURRENCY = '' then CURRENCY="&REPORT_CCY" ;

/*- get seniority flag -*/
    %get_seniority_flg;

    SECURITIZATION_EXPOSURE_FLG = 1;
    
/*- flag indicating the securitization exposure is not owend by the reporting institution -*/        
    EXP_NOT_OWNED_FLG = put(FINANCIAL_BOOK_RK,MAP_EXP_NOT_OWNED_FLG.) ;
    
    PRIMARY_BANK_ROLE = put(PRIMARY_BANK_ROLE_CD, $MAP_SEC_BANK_ROLE.);

    SEC_STRUCTURE_TYPE    = put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_SEC_STRUCTURE_TYPE.);
    SEC_STRUCTURE_SUBTYPE = put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_SEC_STRUCTURE_SUBTYPE.);
    SEC_ACCTING_TREATMENT = put(ACCTING_TREATMENT_CD,$MAP_SEC_ACCTING_TREATMENT.) ;  
    SECURITIZATION_TREATMENT_TYPE = put(FINANCIAL_BOOK_TYPE_CD,$MAP_FINANCIAL_BOOK_TYPE.); 
    SEC_RETENTION_TYPE= put(RETENTION_TYPE_CD,$MAP_SEC_RETENTION_TYPE.); 
    SEC_PORTFOLIO_TYPE = put(SEC_PORTFOLIO_TYPE_CD,$MAP_SEC_PORTFOLIO_TYPE.); 
    
    CORRELATION_TRADING_PORT_FLG = put(FINANCIAL_BOOK_RK,MAP_CORR_TRADING_FLG.) ;
        
    ELIGIBLE_SECURITIZATION = put(compress(SECURITIZ_STRUC_TYPE_CD || SECURITIZ_STRUC_SUBTYPE_CD), $MAP_ELIGIBLE_SECURITIZATION.);
    CLEAN_UP_CALL_TYPE = put(CLEAN_UP_CALL_TYPE_CD, $MAP_CLEAN_UP_CALL_TYPE.);
    ELIGIBLE_CLEAN_UP_CALL_FLG = input(put(CLEAN_UP_CALL_TYPE_CD, $MAP_ELIGIBLE_CLEAN_UP_CALL_FLG.), 1.);

/*- get position type -*/
       %get_position_type;

/*- flag securitization position -*/
    SECURITIZATION_POSITION = put(POSITION_TYPE_CD, $MAP_SECURITIZATION_POSITION.);
    if upcase(SECURITIZATION_POSITION) = "Y" then
       POSITION_CATEGORY = "SECURITIZATION_POSITION";
          
/*- get original and residual maturity -*/ 
    %get_maturity(INCEPTION_DATE, MATURITY_DATE);

/*- determine if it is considered past due: more than &DAYS_PAST_DUE_THRESHOLD days -*/
    %if &DAYS_EXIST %then %do;
        PAST_DUE_CLAIM_FLG = (DAYS_PAST_DUE_NO > &DAYS_PAST_DUE_THRESHOLD);
    %end;
    
/*- determine if it is a short-term claim: original maturity of 1 year or less -*/
    %get_shortterm_claim_flg_crd4;  

/*- get product class and subclass -*/
    %get_product_class;

/*- get LE product class -*/
    %get_le_exposure_type_crd4;

/*- get regulatory approach -*/
    %get_regulatory_approach;   
    
/*- check proper approach assignment -*/
    %check_asset_class_approach;
    
    if INVALID_APPROACH_FLG EQ 1 then 
       output invalid_approach;
/*- process the following only for valid approaches -*/
    else do;
   
/*- get instrument type for MtM pricing -*/
       %get_mtm_insttype;

/*- get off-balance-sheet type -*/
       %get_obsi_type;
       
/*- get LE off-balance-sheet type -*/
    %get_le_obsi_type_crd4;

/*- get mapped issue rating: either from second best or from specified rating agency -*/
       %get_mapped_ratings_crd4(RATING_TYPE=ISSUE, RATING_TIME=CURRENT);
       %get_mapped_ratings_crd4(RATING_TYPE=ISSUE, RATING_TIME=INCEPTION);

/*- get internal issue ratings -*/
       if SHORT_TERM_CLAIM_FLG = 1 then do;
          if INT_SHORT_TERM_ASSESS_FLG = 1 then do;
            INT_ISSUE_MAP_RATING =  put(INT_ISSUE_RATING, $INT_ST.);
            INT_ISSUE_INCEP_MAP_RATING =  put(INT_ISSUE_INCEP_RATING, $INT_ST.);
          end;
          else do; 
            INT_ISSUE_MAP_RATING = 'MISS';
            INT_ISSUE_INCEP_MAP_RATING = 'MISS';
          end;
         
       end;
       else do;
          if INT_SHORT_TERM_ASSESS_FLG = 1 then do;
            INT_ISSUE_MAP_RATING = 'MISS';
            INT_ISSUE_INCEP_MAP_RATING = 'MISS';

          end;
          else do;
            INT_ISSUE_MAP_RATING = put(INT_ISSUE_RATING, $INT.);
            INT_ISSUE_INCEP_MAP_RATING = put(INT_ISSUE_INCEP_RATING, $INT.);

          end;
       end;
/*- redefine for SL using slotting -*/
       if IRB_PRODUCT_CLASS='SL' and APPROACH = 'IRB_SLOTTING' then
          INT_ISSUE_MAP_RATING = put(INT_ISSUE_RATING, $INT.);
    
/*- get risk weight buckets -*/
       %get_std_rw_buckets_crd4;  
       %get_irb_rw_buckets;
       
/*- get Basel I risk weights mapping -*/
  %get_basel_i_rw;

/*- for exposures to ABCP programs, IAA is eligible -*/
       if SEC_STRUCTURE_SUBTYPE = 'ABCP' and  EXT_ISSUE_MAP_RATING = 'MISS' and INT_ISSUE_MAP_RATING NE 'MISS' then do;
         if APPROACH = 'IRB_RBA' then APPROACH = 'IRB_IAA';
          if APPROACH ='STD' and "&STD_RATED_ABCP_USE_IAA" = "YES" then APPROACH = 'STD_IAA'; 
          
          if INT_SHORT_TERM_ASSESS_FLG = 1 then
            IRB_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_IRB_RW_BUCKET_SEC_SHORT.);
          else
            IRB_RW_BUCKET = put(INT_ISSUE_MAP_RATING, $MAP_IRB_RW_BUCKET_SEC.);   
          CRM_ADJUSTED_FLG = INT_RATING_CRM_ADJUSTED_FLG;
       end;        
        
/*- get haircut info -*/
       %get_haircut_info;
               
       COLLATERAL = 0;

       output &outposds;
    end;
    run;
    
/* Redirect the rows which doesn't have valid Instrument Type */     
   data &outposds  invalid_insttypes ;
        set &outposds; 
        if INVALID_INSTTYPE_FLG eq 1 then output invalid_insttypes ;
        else output 
            &outposds; 
       run ;

/*- append invalid Instrument Type data set -*/
    %if %attrn(invalid_insttypes, NOBS) GT 0 %then %do;
       proc append base=RD_POS.all_exp_invalid_insttypes data=invalid_insttypes force nowarn;
       run;
    %end;
    
/*- for securitisations of revolving exposures with early amortisation provisions,  -*/
/*- there are additional own funds requirements: CRR Article 256.                   -*/
/*- Create pool positions to calculate the additional required capital.             -*/
    proc sort data= &outposds out=eap_pool nodupkey;
    by SECURITIZATION_POOL_RK;
    
    data eap_pool( drop=MASTER_NETTING_AGRMNT_FLG REFERENCED_ISSUE_KEY OFF_BALANCE_SHEET_TYPE_CD
                        EAD_AMT NETTING_SET_RK CRM_ADJUSTED_FLG INT_:
                        TRANCHE_: ISSUE_FACE_VALUE_AMT PD_: LGD_: HOLDING_PERIOD_DAYS HAIRCUT_: REVALUATION_FREQ_DAYS
                        RISK_WEIGHT IN_DEFAULT_FLG GRACE_PERIOD_DAYS EXPECTED_LOSS_PERCENT VALUE_AMT
                        SENIORITY_CD CREDIT_ENHANCEMENT_LEVEL EXT_: OFF_BALANCE_SHEET_TYPE
                        STD_RW_BUCKET IRB_RW_BUCKET SHORT_TERM_CLAIM_FLG
                        SHORT_TERM_ASSESS_FLG ISSUE_KEY CURRENT_POOL_FACTOR 
                        SENIORITY_FLG
                  );
    set eap_pool (where=(upcase(PRIMARY_BANK_ROLE)= 'ORIGINATOR' 
                            and POSITION_CATEGORY = "SECURITIZATION_POSITION" 
                         and APPROACH NE 'BASEL_I'));
   
    
    run;
    
    data &outpoolds (drop=EARLY_AMORTIZATION_TYPE_CD EAP_CAPITAL_REQUIRED);
    merge eap_pool(in=a) 
          &poolds (drop = PRIMARY_BANK_ROLE_CD CLEAN_UP_CALL_TYPE_CD                         
                          SECURITIZ_STRUC_TYPE_CD SECURITIZ_STRUC_SUBTYPE_CD
                  );
    by SECURITIZATION_POOL_RK; 
    
    length CCF_SET CCF_TYPE CCF_SET_ID $32.;
    if a; 
    
    /*- get flag for early amortization capital required -*/
    EAP_CAPITAL_REQUIRED = put(EARLY_AMORTIZATION_TYPE_CD, $MAP_EAP_CAPITAL_REQUIRED.);
    /*- get early amortization type -*/
    EARLY_AMORTIZATION_TYPE = put(EARLY_AMORTIZATION_TYPE_CD, $MAP_SEC_EAP_TYPE.);
    
/*- for exposures with early amortization provisions -*/        
    if EARLY_AMORTIZATION_TYPE NE '' and upcase(EAP_CAPITAL_REQUIRED) = 'Y' then do;
       /*- total revolving amt -*/ 
        TOTAL_REVOLVING = sum(UNCOMM_RETAIL_REVOLV_FACE_AMT, COMM_RETAIL_REVOLV_FACE_AMT, 
                          UNCOMM_OTHER_REVOLV_FACE_AMT , COMM_OTHER_REVOLV_FACE_AMT );
    
       /*- originator's interest: CRR article 256(2) -*/
       INSTID = compress('EAP_POOL_OI'||put(SECURITIZATION_POOL_RK, 29.)); 
       STD_PRODUCT_CLASS = 'SECURITIZATION';
       IRB_PRODUCT_CLASS = 'SECURITIZATION';
       STD_PRODUCT_SUBCLASS = 'EAP_ORIGINATOR_INT';
       IRB_PRODUCT_SUBCLASS = 'EAP_ORIGINATOR_INT';
       SECURITIZATION_EXPOSURE_FLG = 1;
       EXP_NOT_OWNED_FLG = 0 ; 
       POSITION_CATEGORY = "SEC_POOL";
       INCEPTION_DATE = .;
       MATURITY_DATE  = LONGEST_MATURITY_DATE;
       HOLDING =1;
       EFFECTIVE_MATURITY_YEAR = .;
       SHORTPOSITION = 0;
       INSTTYPE = 'MTM_SEC_POOL';
       
       %get_maturity(INCEPTION_DATE, MATURITY_DATE);
       output;
       
       /*- investors' interest: CRR articl 256(4) -*/
       INSTID = compress('EAP_POOL_II'||put(SECURITIZATION_POOL_RK, 29.)); 
              STD_PRODUCT_CLASS = 'SECURITIZATION';
              IRB_PRODUCT_CLASS = 'SECURITIZATION';
              STD_PRODUCT_SUBCLASS = 'EAP_INVESTORS_INT';
              IRB_PRODUCT_SUBCLASS = 'EAP_INVESTORS_INT';
              SECURITIZATION_EXPOSURE_FLG = 1;
              EXP_NOT_OWNED_FLG = 0 ;
              POSITION_CATEGORY = "SEC_POOL";
              INCEPTION_DATE = .;
              MATURITY_DATE  = LONGEST_MATURITY_DATE;
              HOLDING =1;
              EFFECTIVE_MATURITY_YEAR = .;
              SHORTPOSITION = 0;
              INSTTYPE = 'MTM_SEC_POOL';
              
              %get_maturity(INCEPTION_DATE, MATURITY_DATE);
              
              CCF_SET_ID = "&CCF_SET_EAP";
       /*- assign default trapping point if not supplied -*/
              if missing(EXCESS_SPREAD_TRAPPING_POINT) then
                 EXCESS_SPREAD_TRAPPING_POINT = &REG_EXCESS_SPREAD_TRAPPING_POINT;
       /*- assign a small spread if missing -*/
              if missing(AVG_THREE_MONTH_EXCESS_SPREAD) then
                 AVG_THREE_MONTH_EXCESS_SPREAD = 0;
              CCF_TYPE = put(AVG_THREE_MONTH_EXCESS_SPREAD/EXCESS_SPREAD_TRAPPING_POINT*100, MAP_CCF_SEC_EAP_BUCKET_TYPE.);
           
              CCF_SET = "CCF_Set_EAP";
       output;
    end;
    
/*- deduction: CRR Article 32(1) -*/
    if CRDT_ENHNC_INT_ONLY_STRIP_AMT > 0 or GAIN_ON_SALE_AMT > 0 then do;
       INSTID = compress('POOL'||put(SECURITIZATION_POOL_RK, 29.));  
       STD_PRODUCT_CLASS = 'SECURITIZATION';
       IRB_PRODUCT_CLASS = 'SECURITIZATION';
       STD_PRODUCT_SUBCLASS = 'DEDUCTION';
       IRB_PRODUCT_SUBCLASS = 'DEDUCTION';
       SECURITIZATION_EXPOSURE_FLG = 1;
       EXP_NOT_OWNED_FLG = 0 ;
       POSITION_CATEGORY = "SEC_POOL";
       INCEPTION_DATE = .;
       MATURITY_DATE  = .;
       HOLDING =1;
       EFFECTIVE_MATURITY_YEAR = .;
       SHORTPOSITION = 0;
       INSTTYPE = 'MTM_SEC_POOL';
           
       output;
    end;
    run; 
    
/*- append invalid approach data set -*/
    %if %attrn(invalid_approach, NOBS) GT 0 %then %do;
       proc append base=RD_POS.invalid_approach data=invalid_approach;
       run;
    %end;
%mend enrich_exposures_sec_crd4;
