/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_haircut.sas
 *
 * PURPOSE: Store code for getting haircut in mtm methods.
 *
 *   USAGE: %get_haircut;
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro get_haircut(SCALE_ONLY=N,REPO_EXP=N);

    length HAIRCUT_NAME $32;
    length HAIRCUT_COLUMN $32;
    

/*- haircut scaling factor -*/
    OUTV_HAIRCUT_SCALE = 1;
    
    if REVALUATION_FREQ_DAYS NE . and 
    /*- MIN_REVALUATION_FREQ_DAYS NE . and -- assumed to be 1 */
       HOLDING_PERIOD_DAYS NE . then
       OUTV_HAIRCUT_SCALE = sqrt((REVALUATION_FREQ_DAYS - 1) / HOLDING_PERIOD_DAYS + 1);    
     
    %if "&SCALE_ONLY"='Y' %then %goto EXIT;
    
/*- the usual case: from haircut table -*/
    if HAIRCUT_TYPE NE '' and HAIRCUT_SET NE '_#_' then do;
/*- set default haircut value -*/
        if HAIRCUT_RATING_BUCKET = '' or HAIRCUT_RES_MAT_BAND = '' then
            OUTV_HAIRCUT = .;
        else do;
        /*- get the scale adjustment for the haircut -*/
        /*- get haircut matrix row name and column name -*/       
        /*- repo-style transaction applies the haircut approriate for the security involved -*/
            if not missing(ISSUER_CPTY_CLASS) and "&REPO_EXP"='Y' then 
               call GET_HAIRCUT_NAME(HAIRCUT_TYPE, ISSUER_CPTY_CLASS, HAIRCUT_RATING_BUCKET, 
                                  HAIRCUT_RES_MAT_BAND, HAIRCUT_NAME, HAIRCUT_COLUMN);
            else
               call GET_HAIRCUT_NAME(HAIRCUT_TYPE, COUNTERPARTY_CLASS, HAIRCUT_RATING_BUCKET, 
                                  HAIRCUT_RES_MAT_BAND, HAIRCUT_NAME, HAIRCUT_COLUMN);
                                  
        /*- get haircut value -*/
            call PMXELEM(HAIRCUT_PARM_REF.HAIRCUT_SET, HAIRCUT_NAME, HAIRCUT_COLUMN, OUTV_HAIRCUT);
        /*- get revaluation and holding days for haircut adjustment -*/                              
        /* call PMXELEM(HAIRCUT_PARM_REF.HAIRCUT_SET, HAIRCUT_NAME, "REVALUATION_FREQ_DAYS", MIN_REVALUATION_FREQ_DAYS); 
           -- not really necessary because it is assumed to be 1 anyway */
            call PMXELEM(HAIRCUT_PARM_REF.HAIRCUT_SET, HAIRCUT_NAME, "HOLDING_PERIOD_DAYS", EST_HOLDING_DAYS);       
        end;
    end;

  /*- CRMs under financial collateral comprehensive method always get haircuts.                                        -*/
  /*- Exposures under financial collateral comprehensive method do not always get haircuts.                            -*/
  /*- Except for OTC derivatives, only  exposures with volatile market values should get haircuts: CRR Article 223(3)  -*/
  /*- Set haircuts for OTC derivative exposures and exposures with non-volatile market values to 0.                    -*/
  /*if "&REPO_EXP"='N' and COLLATERAL = 0 then do; */
    if COLLATERAL = 0 then do ;
    
        if InstType in ('MTM_ACCOUNT','MTM_FACILITY','MTM_FACILITY_GROUP','MTM_RECEIVABLE','MTM_SEGMENT','MTM_SEC_POOL') then OUTV_HAIRCUT = 0;
        
        else if InstType in ('MTM_INSTRUMENT', 'MTM_TEST_CCR') and (STD_PRODUCT_CLASS = 'DERIVATIVE' or IRB_PRODUCT_CLASS = 'DERIVATIVE') then 
                OUTV_HAIRCUT = 0;
    
    end;
    
/*- all other cases: no haircut or other user-specified haircut constant -*/    
    if missing(OUTV_HAIRCUT) then do;
        OUTV_HAIRCUT = &ALL_OTHER_HAIRCUT_PCT;
        EST_HOLDING_DAYS = &OTHER_HAIRCUT_EST_HOLDING_DAYS; 
    end;
    
/*- adjust haircut for min holding period and/or remargining/revaluation frequency -*/
/*- REVALUATION_FREQ_DAYS in the position data refers to the actual business days for the position. -*/
/*- HOLDING_PERIOD_DAYS in the position data refers to the min holding period for the transaction.  -*/ 
/*- EST_HOLDING_PERIOD_DAYS is the holding period days assumed for the haircut estimation.          -*/
    SCALE = 1;         
    if HOLDING_PERIOD_DAYS NE . and EST_HOLDING_DAYS NE . then do;
        SCALE = OUTV_HAIRCUT_SCALE * sqrt ( HOLDING_PERIOD_DAYS / EST_HOLDING_DAYS );     
        OUTV_HAIRCUT = OUTV_HAIRCUT * SCALE;   
    end;
/*- the case of given haircut value -*/
/*- assume adjustment already made for minimum holding period and remargining/revaluation frequency -*/
    if HAIRCUT_VALUE NE . then do;
    
        OUTV_HAIRCUT = HAIRCUT_VALUE;

    end;
    
   
    %EXIT : 
%mend get_haircut;
