/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_mapped_ratings_crd4.sas
 *
 * PURPOSE: Get mapped ratings and associated flags.
 *
 *   USAGE: %get_mapped_ratings(RATING_TYPE=);
 *          RATING_TYPE: CPTY|ISSUE, whether issue or counterparty rating
 *          
 *
 *   NOTES: 1. called from enrich_*.sas macros.
 *          2. assumes all variables related to external ratings and flags 
 *             available in the data.
 *
 *
 *****************************************************************************/

%macro get_mapped_ratings_crd4(RATING_TYPE=, RATING_TIME=);
  %if &RATING_TIME= INCEPTION %then %let rating_tm = _INCEP; %else  %let rating_tm =; ;  


%if &NUM_AGENCIES_ISSUE NE 0 %then %do;
/*- get mapped issue rating: either from second best or from specified rating agency -*/
/*- also keep the following flags for the chosen rating -*/
/*- CRM_ADJUSTED_FLG and SHORT_TERM_ASSESS_FLG   -*/
    if "&STD_USE_SECOND_BEST_RATING" = "YES" then do;
        %second_best_rating(EXT_ISSUE&RATING_TM._RATING, EXT_ISSUE&RATING_TM._MAP_RATING, &RATING_TYPE);            
    end;
    else do; 
/*- only short-term claims can have short-term assessment: Basel II - 103 -*/            
        if SHORT_TERM_CLAIM_FLG = 1 then do;
            if SHORT_TERM_ASSESS_FLG_&RATING_AGENCY_ST = 1 then
               EXT_ISSUE&RATING_TM._MAP_RATING = put(EXT_ISSUE&RATING_TM._RATING_&RATING_AGENCY_ST, $&RATING_AGENCY_ST._ST.);
            else
               EXT_ISSUE&RATING_TM._MAP_RATING = put(EXT_ISSUE&RATING_TM._RATING_&RATING_AGENCY, $&RATING_AGENCY..); 
            if EXT_ISSUE&RATING_TM._MAP_RATING NE 'MISS' then do;
               CRM_ADJUSTED_FLG = CRM_ADJUSTED_FLG_&RATING_AGENCY_ST;
               SHORT_TERM_ASSESS_FLG = SHORT_TERM_ASSESS_FLG_&RATING_AGENCY_ST;
            end;
            else do;
               CRM_ADJUSTED_FLG = .;
               SHORT_TERM_ASSESS_FLG = .;
            end;            
        end;
        else do;
            if SHORT_TERM_ASSESS_FLG_&RATING_AGENCY = 1 then
               EXT_ISSUE&RATING_TM._MAP_RATING = 'MISS' ;
            else
               EXT_ISSUE&RATING_TM._MAP_RATING = put(EXT_ISSUE&RATING_TM._RATING_&RATING_AGENCY, $&RATING_AGENCY..); 
            if EXT_ISSUE&RATING_TM._MAP_RATING NE 'MISS' then do;
               CRM_ADJUSTED_FLG = CRM_ADJUSTED_FLG_&RATING_AGENCY;
               SHORT_TERM_ASSESS_FLG = SHORT_TERM_ASSESS_FLG_&RATING_AGENCY;
            end;
            else do;
               CRM_ADJUSTED_FLG = .;
               SHORT_TERM_ASSESS_FLG = .;
            end;            
        end;
    end;
%end;
%else %do;
    EXT_ISSUE&RATING_TM._MAP_RATING = 'MISS' ;
    CRM_ADJUSTED_FLG = .;
    SHORT_TERM_ASSESS_FLG = .;
%end;
%mend get_mapped_ratings_crd4;
