/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: get_std_rw_buckets_crm_crd4.sas
 *
 * PURPOSE: Get RW buckets for CRMs under standardized approach.
 *
 *   USAGE: %get_std_rw_buckets_crm_crd4;
 * 
 *
 *   NOTES: 
 *
 *
 *****************************************************************************/

%macro get_std_rw_buckets_crm_crd4;
       
       /*-  cash and gold: CRR Article 197   -*/
       if STD_PRODUCT_SUBCLASS in ('CASH','GOLD') then do ;
          STD_RW_BUCKET = put(STD_PRODUCT_SUBCLASS, $MAP_STD_RW_BUCKET_OTHERS_ASSETS.);
       end ;
       
       /*- CIU: CRR Articles 197 and 198  -*/
       else if CRM_SUBTYPE eq 'CIU' then do ;
          STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_CIU.);
       end ;

       /*- Covered bond: CRR Article 207  -*/
       else if CRM_SUBTYPE eq 'COVERED_BOND' then do ;
             STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_COV_BOND.);
       end ;
       
       /*- residential and commercial immovable properties: CRR Articles 124-126 -*/
       else if STD_PRODUCT_CLASS ='IMM_PROPERTY' then do;
       
               if STD_PRODUCT_SUBCLASS = 'RESIDENTIAL' then
                   STD_RW_BUCKET = put(REGULATORY_PRODUCT_CD, $MAP_STD_RW_BUCKET_RME.);
               else if STD_PRODUCT_SUBCLASS = 'COMMERCIAL' then
                   STD_RW_BUCKET = put(REGULATORY_PRODUCT_CD, $MAP_STD_RW_BUCKET_CME.);
       
       end;
       
       else do ; 
       
          if SHORT_TERM_ASSESS_FLG = 1 then do;
                  STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_SHORT.);
          end;
          
          else do ;
            select (COUNTERPARTY_CLASS);
                when ('SOVEREIGN')
                    STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_SOVEREIGN.);
                
                when ('INSTITUTION')
                    STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_INSTITUTION.);  
                
                when ('CORPORATE')
                    STD_RW_BUCKET = put(EXT_ISSUE_MAP_RATING, $MAP_STD_RW_BUCKET_CORPORATE.);
                                 
                otherwise

           end;
         end ;  
        end ;
    
%mend get_std_rw_buckets_crm_crd4;
