/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_bank_irbf_crd4.sas
 *
 * PURPOSE: Method program code for bank exposures under IRBF approach.
 *
 *   USAGE: %pm_exp_bank_irbf_crd4;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_bank_irbf_crd4;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;

   /*- Get weight for CVA standardized approach: Art. 374 -*/
   %get_cva_std_wgt_crd4 ; 

/*- initialize exposure PD as counterparty PD -*/
    OUTV_PD_COUNTERPARTY = PD_CPTY;
/*- repo_style use counterparty PD assessment if available -*/
    if IRB_PRODUCT_CLASS = 'REPO_STYLE' and (not missing(OUTV_PD_COUNTERPARTY)) then
       OUTV_PD_ISSUE = OUTV_PD_COUNTERPARTY;
    else do;
       %get_pd_issue;
    end;
       
    if  OUTV_PD_ISSUE NE . then OUTV_PD_ISSUE = max(OUTV_PD_ISSUE, &IRB_PD_FLOOR);

    %get_lgd_irbf;

/*- CRR Article 153 1 (ii) :if PD = 1,  i.e., for defaulted exposures:
      where institutions apply the LGD values set out in Article 161(1), RW shall be 0;  -*/      
    if OUTV_PD_ISSUE = 100 then do;

        OUTV_RW_ISSUE = 0;
    end;
/*CRR Article 153 1(i): if PD = 0, RW shall be 0; */    
    else if OUTV_PD_ISSUE = 0 then do;
        OUTV_EL = 0;
        OUTV_RW_ISSUE = 0;
    end;        
    else do;
        OUTV_EL      = OUTV_PD_ISSUE * OUTV_LGD / 100;    
        OUTV_RW_ISSUE = IRB_RW_BANK_CRD4(OUTV_PD_ISSUE, OUTV_LGD, MAT_EFF, IRB_SCALING_FACTOR,LARGE_FI_ENTITY_FLG);
    end;

    OUTV_FIRM_SIZE = COUNTERPARTY_SIZE;
    
    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_bank_irbf_crd4;
