/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_corporate_rec_irbf_crd4.sas
 *
 * PURPOSE: Method program code for coporate receivables exposures under IRBF approach.
 *          
 *
 *   USAGE: %pm_exp_corporate_rec_irbf_crd4;
 *
 *   NOTES: 
 *          
 *
 *****************************************************************************/

%macro pm_exp_corporate_rec_irbf_crd4;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;
    
    /*- top-down approach -*/
    if RECEIVABLE_POOL_FLG = 1 then do;

        %get_lgd_irbf;
 
        %get_el_irb ;    

        OUTV_PD_ISSUE = OUTV_EL * 100 / OUTV_LGD;

        OUTV_PD_ISSUE = max(OUTV_PD_ISSUE, &IRB_PD_FLOOR);

/*        OUTV_EL = EXPECTED_LOSS_PERCENT; */

        OUTV_FIRM_SIZE = WA_CPTY_FIRM_SIZE * GET_FX_SPOT(WA_CPTY_FIRM_SIZE_CURRENCY_CD);

    end;
    
    /*- bottom-up approach -*/
    else do;
    
        OUTV_PD_COUNTERPARTY = PD_CPTY;
        %get_pd_issue;

        %get_lgd_irbf;
    
        if OUTV_PD_ISSUE = 100 then OUTV_EL = EXPECTED_LOSS_PERCENT;
        else OUTV_EL = OUTV_PD_ISSUE * OUTV_LGD / 100;

        OUTV_FIRM_SIZE = COUNTERPARTY_SIZE;

    end;

    if OUTV_FIRM_SIZE in (., 0) then OUTV_FIRM_SIZE = &IRB_SME_MAX_FIRM_SIZE;    
    
/*- CRR Article 153 1 (ii) :if PD = 1,  i.e., for defaulted exposures:
      where institutions apply the LGD values set out in Article 161(1), RW shall be 0;  -*/      
    if OUTV_PD_ISSUE = 100 then do;
        OUTV_RW_ISSUE = 0;
    end;
    else do;
        OUTV_RW_ISSUE = IRB_RW_CORPORATE(OUTV_PD_ISSUE, OUTV_LGD, MAT_EFF, OUTV_FIRM_SIZE,
                                       &IRB_SME_MIN_FIRM_SIZE, &IRB_SME_MAX_FIRM_SIZE, IRB_SCALING_FACTOR);
    end;
    
/*- dilution RW -*/
    OUTV_LGD_DILUTION = IRB_LGD_REC_DILUTION;
    OUTV_EL_DILUTION = DILUTION_EXPECTED_LOSS_PERCENT;
    
/*- corporate risk weight function must be used for dilution risk: Basel II - 369 -*/
    OUTV_RW_DILUTION = IRB_RW_CORPORATE(OUTV_EL_DILUTION, OUTV_LGD_DILUTION, &IRB_M_REC_DILUTION, &IRB_SME_MAX_FIRM_SIZE,
                                        &IRB_SME_MIN_FIRM_SIZE, &IRB_SME_MAX_FIRM_SIZE, IRB_SCALING_FACTOR);

    _VALUE_ = EXP_VALUE ;    
    
%mend pm_exp_corporate_rec_irbf_crd4;
