/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: pm_exp_corporate_std_crd4.sas
 *
 * PURPOSE: Method program code for corporate exposures under STD approach.
 *
 *   USAGE: %pm_exp_corporate_std_crd4;
 *
 *   NOTES: 5/22/2013 updated to remove the single risk weight treatment from CRD-IV.
 *          
 *
 *****************************************************************************/

%macro pm_exp_corporate_std_crd4;

/*- initialize outvars -*/
    %initialize_regulatory_outvars;

/*- by default, get the RW associated with the counterparty -*/
    OUTV_RW_COUNTERPARTY = STD_RW_CPTY;

   /*- Get weight for CVA standardized approach: Art. 384 -*/
   %get_cva_std_wgt_crd4 ; 

/*- single risk weight no longer applies in CRD-IV           -*/   
/*- if single risk weight for corporate exposure is allowed  -*/
/*   if upcase("&STD_CORP_SINGLE_RW_TREATMENT") = "YES" then -*/
/*      OUTV_RW_ISSUE = &STD_CORP_SINGLE_RW;                 -*/
       
/*- get RW based on issue rating -*/
    if STD_RW_BUCKET NE '_#_' and EXT_ISSUE_MAP_RATING NE 'MISS' then do;
        if SHORT_TERM_ASSESS_FLG = 1 then
            OUTV_RW_ISSUE = STD_RW_SHORT_REF.STD_RW_BUCKET;
        else 
            OUTV_RW_ISSUE = STD_RW_CORPORATE_REF.STD_RW_BUCKET;
    end;
    
    else do ;
        OUTV_RW_ISSUE = OUTV_RW_COUNTERPARTY ; 
        if CPTY_RW_FROM_CENTGOV_FLG =1 then OUTV_RW_FROM_CENTGOV_FLG = 1 ;
    end ;            
    _VALUE_ = EXP_VALUE ;
    
%mend pm_exp_corporate_std_crd4;
