/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: prep_data_for_le_cap_chrg_crd4.sas
 *
 * PURPOSE: Prepares exposure-level data for le capital charge calculation
 *
 *   USAGE: 
 *
 *   NOTES: assumes input data set has the same format as crm_allocation_*_detail table; 
            output data is: work.prepped_data_cpty_grp_&cpty_grp_flg.
 *
 *          
 *
 *****************************************************************************/

%macro prep_data_for_le_cap_chrg_crd4(dsname=, cpty_grp_flg=, TOT_ELIG_CAP=);
    data exp_for_prep;
        set &dsname;
        if %if &CPTY_GRP_FLG eq Y %then COUNTERPARTY_GROUP NE ''; %else COUNTERPARTY_GROUP EQ ''  ;;

    run;
    
    proc sort data=exp_for_prep;
            by EXP_ID;
    run;
    
    /*- create dataset with all exposures, direct exposures only, indirect exposures only -*/
    data direct(drop= LE_CRM_VALUE) 
        indirect 
        exp_crm (keep=EXP_ID LE_CRM_VALUE);
        set exp_for_prep;
    
        
        /*- columns 260 - 320: calculate CRM amount for LE purposes -*/
        If CRM_TYPE IN ('FINANCIAL_COLLATERAL') and ELIGIBLE_CRM_TYPE EQ 'FINANCIAL_COMPREHENSIVE' 
                    and "&STD_CRM_APPROACH" NE "SIMPLE" then /* column 310 */
                LE_CRM_VALUE = CRM_USED_AMT_EFF;
        else if CRM_SUBTYPE in( 'CRE' , 'RRE') then 
            LE_CRM_VALUE = CRM_USED_AMT_EFF; /* column 320 */
        else LE_CRM_VALUE = CRM_USED_AMT_EFF; /* columns 260 - 300 */
    
        
        if DIRECT_EXP_FLG = 'Y' then do; 
           
            if RW_EXP = 0 then LE_EXEMPT_AM = LE_ORIG_EXPOSURE_AMT;
            
            if TRADE_EXP_FLG = 1  then LE_EXEMPT_AM = LE_ORIG_EXPOSURE_AMT;
            if (COUNTERPARTY_SUBCLASS ='CCP' and BANKRUPTCY_REMOTE_FLG = '1') then LE_EXEMPT_AM = LE_ORIG_EXPOSURE_AMT;

            if CCF = 0 then LE_EXEMPT_AM = LE_ORIG_EXPOSURE_AMT; /* column 330 */
        end;
        else do; 
            /* columns 150 - 190: indirect exposures - Large exposure amount is equal to the CRM amount */
            LE_CRM_VALUE = 0;
            SPECIFIC_PROVISION = 0;
            if RW_CRM = 0 then LE_EXEMPT_AM = LE_ORIG_EXPOSURE_AMT; /* column 330 */

        end;
    
        
        if CRM_ID NE '' then do;
            output indirect;
            output exp_crm;
        end;
        else output direct;
    
    run;
    
    /* assume that we should only use direct exposures for capital charge calculation as indirect exposures
       should not have any market or settlement charge associated with them */
    data all_exp_for_prep;
        merge direct exp_crm;
        by EXP_ID;
    run;
    
    /*
    proc append base = all_exp_for_prep
        data = indirect
        force;
    run;
    */
      
    
    data le_cap_charge_&cpty_grp_flg;
        set all_exp_for_prep;
        LE_EXPOSURE_AMT = max(0,sum(LE_ORIG_EXPOSURE_AMT, -LE_CRM_VALUE, -LE_EXEMPT_AM, -SPECIFIC_PROVISION, UNDERLYING_EXP_EAD));
        
        /*Calculate the sum of Market and Stt Risk Charges*/
        TOT_RISK_CHG = SUM(MKT_RISK_CHG_AMT,SETT_RISK_CHG_AMT);

        KEEP COUNTERPARTY_GROUP LE_COUNTERPARTY_RK EXP_ID CRM_ID DIRECT_EXP_FLG LE_ORIG_EXPOSURE_AMT 
             LE_CRM_VALUE LE_EXPOSURE_AMT SPECIFIC_PROVISION UNDERLYING_EXP_EAD MKT_RISK_CHG_AMT SETT_RISK_CHG_AMT TOT_RISK_CHG;
    run;
    
  
       
    /*For every LE_COUNTERPARTY_RK arrange by Descending TOT_RISK_CHG*/
    proc sort data=le_cap_charge_&cpty_grp_flg;
        by %if &CPTY_GRP_FLG eq Y %then COUNTERPARTY_GROUP; %else LE_COUNTERPARTY_RK ;  TOT_RISK_CHG; 
    run;
    
    /*Compute Running Total of LE_EXPOSURE_AMT and % of TOT_ELIG_CAP */
    data le_cap_charge_&cpty_grp_flg._1;
        set le_cap_charge_&cpty_grp_flg;
        length CUM_EXP_AMT 8;
        format PCT_OF_ELIGC PERCENT12.1 MKT_RISK_CHG_AMT SETT_RISK_CHG_AMT TOT_RISK_CHG COMMA10.1;
        by %if &CPTY_GRP_FLG eq Y %then COUNTERPARTY_GROUP; %else LE_COUNTERPARTY_RK ; ;
        if %if &CPTY_GRP_FLG eq Y %then first.COUNTERPARTY_GROUP ; %else first.LE_COUNTERPARTY_RK  ;       then do;
            CUM_EXP_AMT = 0.0;
            PCT_OF_ELIGC = 0;
        end;
            CUM_EXP_AMT + LE_EXPOSURE_AMT;
            if &TOT_ELIG_CAP NE . and &TOT_ELIG_CAP. NE 0 then
                PCT_OF_ELIGC = CUM_EXP_AMT/&TOT_ELIG_CAP.;
            else PCT_OF_ELIGC = .;
    run;
    
    
    /* Get the number of days each counterparty has been in excess from rd_stage.counteparty_mart */
    data days_excess;
        set rd_stage.counterparty_mart (rename = (COUNTERPARTY_RK = LE_COUNTERPARTY_RK));
        if LE_EXCESS_DAYS_NUM eq . then LE_EXCESS_DAYS_NUM = 0;
        keep LE_COUNTERPARTY_RK LE_EXCESS_DAYS_NUM;
    RUN;
    
    proc sort data = days_excess;
        by LE_COUNTERPARTY_RK;
    run;
    
    %if &CPTY_GRP_FLG eq Y %then %do;
            proc sort data = le_cap_charge_&cpty_grp_flg._1 ;
                by LE_COUNTERPARTY_RK;
            run;
    %end;
    
    data prepped_data_cpty_grp_&cpty_grp_flg.;
        merge le_cap_charge_&cpty_grp_flg._1 (in = a) days_excess;
        by LE_COUNTERPARTY_RK;
        if a;
    run;
%mend prep_data_for_le_cap_chrg_crd4;
