
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_mitigation_0.sas
 *
 * PURPOSE: Postprocessing results from mitigantion by rank and the 
 *          aggregated results 
 *
 *
 *   USAGE: 
 *
 *   NOTES:  
 *
 * UPDATES: 
 *      1)   Under BY_RANK method, create empty 'ALLMITIGATION' dataset when this dataset is not present. 
 *	2)   Under BY_RANK method, update tables as per actual haircut exposures 
 *                                stored in 'exposure_crm' link table
 *          
 *****************************************************************************/
 option notes;

%macro r00_post_mitigation_0;

    %if %dsexist(&RESLIB1..allmitigation) = 0  %then %do;

    /** Create &RESLIB1..allmitigation **/
        data &RESLIB1..allmitigation;
	       	attrib ADJEXPOSURE length = 8;
			attrib EXPOSURE length = 8;
			attrib EXPOSUREID length = $15.;
			attrib LGD_WEIGHTED_SUM length = 8;
			attrib MITIGANTID length = $15.;
			attrib MITIGANT_ADJVAL length = 8;
			attrib MITIGANT_VAL length = 8;
			attrib OUTV_CAPITAL_NO_CRM length = 8;
			attrib OUTV_CRM_USED_AMT length = 8;
			attrib OUTV_CRM_USED_AMT_EFF length = 8;
			attrib OUTV_EAD length = 8;
			attrib OUTV_EL_AMT length = 8;
			attrib OUTV_EXPOSURE_PROVISION length = 8;
			attrib OUTV_LGD length = 8;
			attrib OUTV_MIT_RWA length = 8;
			attrib OUTV_MIT_USED_AMT length = 8;
			attrib OUTV_MIT_USED_AMT_EFF length = 8;
			attrib OUTV_PD length = 8;
			attrib OUTV_RWA_NO_CRM length = 8;
			attrib OUTV_RWA_SECURED length = 8;
			attrib OUTV_RWA_UNSECURED length = 8;
			attrib OUTV_VALUE length = 8;
			attrib PD_WEIGHTED_SUM length = 8;
			stop;
      run;
	%end;
/*******************************************/
/*- 1: post-process CRM_ALLOATION -*/
    data allmitigation
         (index=(EXPCRM=(EXP_ID CRM_ID) EXPCRMUSED=(EXP_ID OUTV_CRM_USED_AMT_EFF)));
    length EXP_ID CRM_ID $32.;
    set &RESLIB1..allmitigation(rename=(EXPOSUREID=EXP_ID MITIGANTID=CRM_ID));
    run;
    
    proc sql;
    create table covered as 
    select a.OUTV_MIT_USED_AMT as CRM_USED_AMT,
           a.OUTV_MIT_USED_AMT_EFF as CRM_USED_AMT_EFF,
           a.OUTV_MIT_RWA as RWA,
           a.OUTV_MIT_USED_AMT_EFF as EAD_PORTION,
           b.*
    from allmitigation as a
    inner join "&REGPATH&PATHSEP.exposure_crm" as b
    on (a.EXP_ID=b.EXP_ID and a.CRM_ID=b.CRM_ID);
    quit;

    data after_crm(rename=(OUTV_RWA_NO_CRM=RWA_NO_CRM OUTV_RWA_SECURED=RWA_SECURED
                           OUTV_RWA_UNSECURED=RWA_UNSECURED OUTV_CRM_USED_AMT=CRM_USED_AMT
                           OUTV_CRM_USED_AMT_EFF=CRM_USED_AMT_EFF OUTV_EXPOSURE_PROVISION=EXPOSURE_PROVISION
                           PD_WEIGHTED_SUM=PD_WEIGHTED_SUM LGD_WEIGHTED_SUM=LGD_WEIGHTED_SUM
                           ADJEXPOSURE=EAD_PORTION));
    set allmitigation;
    by EXP_ID OUTV_CRM_USED_AMT_EFF;
    if last.EXP_ID then output;
    run;
  
/* add uncovered or uncovered portions of exposure */
    data allpricebase (keep=INSTID VALUE OUTV_EAD OUTV_RWA_NO_CRM OUTV_RWA_SECURED OUTV_RWA_UNSECURED
                            OUTV_CRM_USED_AMT OUTV_CRM_USED_AMT_EFF PD_WEIGHTED_SUM LGD_WEIGHTED_SUM
                            EAD_PORTION
                       rename=(INSTID=EXP_ID OUTV_RWA_NO_CRM=RWA_NO_CRM
                               OUTV_RWA_SECURED=RWA_SECURED OUTV_RWA_UNSECURED=RWA_UNSECURED
                               OUTV_CRM_USED_AMT=CRM_USED_AMT OUTV_CRM_USED_AMT_EFF=CRM_USED_AMT_EFF
                              )
                       index=(EXP_ID)
                      );
    length INSTID $32.;
    merge &RESLIB1..allprice_v(where=(STATENUMBER=0)) &RESLIB1..allprice_p;
    by INSTNUMBER;
    EAD_PORTION=VALUE;
    run;


    /* allexposures will contain exposure level results after mitigation */
    data allexposures;
    merge allpricebase (in = a)
          after_crm ;
    by EXP_ID;
    if a;
    run;  
    
    data notcovered;
    merge allexposures(in=a keep=EXP_ID RWA_UNSECURED EAD_PORTION rename=(RWA_UNSECURED=RWA))
          "&REGPATH&PATHSEP.all_exposures"(in=b);
    by EXP_ID;
    if a and b;
    CRM_USED_AMT = 0;
    CRM_USED_AMT_EFF = 0;
    run;

    data &RESLIB1..crm_allocation_by_rank_detail
         "&OUTPATH.&PATHSEP.crm_allocation_by_rank"
         (label="CRM Allocation by Rank Information"
          keep = /*- brief exposure information -*/
                 EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS STD_PRODUCT_: IRB_PRODUCT_: APPROACH CCY 
                 REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD OFF_BALANCE_SHEET_TYPE_CD
                 INCEPTION_DATE MATURITY_DATE EXP_VALUE EAD HAIRCUT_EXP PD_EXP LGD_EXP RW_EXP RESMAT_EXP 
                 ORIGINAL_MATURITY RESIDUAL_MATURITY EXT_MAP_RATING EXT_ISSUE_MAP_RATING PAST_DUE_CLAIM_FLG 
                 CCF HAIRCUT_FX 
                 /*- brief crm information -*/
                 CRM_ID CRM_COUNTERPARTY_CLASS CRM_COUNTERPARTY_SUBCLASS CRM_TYPE CRM_SUBTYPE ELIGIBLE_CRM_TYPE CRM_CCY
                 CRM_EFFECTIVE_DATE CRM_EXPIRATION_DATE CRM_INCEPTION_DATE CRM_MATURITY_DATE CRM_VALUE_DISCOUNT_FLG
                 CRM_VALUE HAIRCUT_CRM PD_CRM LGD_CRM RW_CRM RW_CRM_COUNTERPARTY RESMAT_CRM 
                 CRM_ORIGINAL_MATURITY CRM_RESIDUAL_MATURITY LINK_RESIDUAL_MATURITY
                 /*- brief crm allocation information -*/
                 MAT_MISMATCH_WEIGHT_CRM _WEIGHT_ _MULT_ CRM_USED_AMT CRM_USED_AMT_EFF RWA
         );
    set covered notcovered ;
    by EXP_ID;
    run;

/*- 2: post-process CAPITAL_DETAIL -*/
    data "&OUTPATH.&PATHSEP.capital_detail_by_rank" (label="Capital Requirement for all Exposures (by Rank)"
          drop=VALUE PD_WEIGHTED_SUM LGD_WEIGHTED_SUM);
    merge allexposures 
          (in=a 
           keep=EXP_ID VALUE PD_WEIGHTED_SUM LGD_WEIGHTED_SUM
                RWA_NO_CRM RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF 
          ) 
          "&REGPATH&PATHSEP.all_exposures" 
          (in=b 
           keep=EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS APPROACH EXP_VALUE
                EAD HAIRCUT_EXP ADD_ON CCF LGD_EXP PD_EXP SPECIFIC_PROVISION
                EL EXPECTED_LOSS_PERCENT RW_EXP CCY COUNTERPARTY_COUNTRY COUNTERPARTY_RK CPTY_PD_MODEL_ID
                CPTY_PD_RATING_GRADE EARLY_AMORTIZATION_TYPE EXPECTED_LOSS_PERCENT EXT_ISSUE_MAP_RATING
                EXT_MAP_RATING INCEPTION_DATE IRB_PRODUCT_CLASS IRB_PRODUCT_SUBCLASS MATURITY_DATE
                MAT_EFF OFF_BALANCE_SHEET_TYPE_CD ORIGINAL_MATURITY PAST_DUE_CLAIM_FLG PRIMARY_BANK_ROLE
                REGULATORY_COUNTERPARTY_TYPE_CD REGULATORY_PRODUCT_CD RESIDUAL_MATURITY SECTOR
                STD_PRODUCT_CLASS STD_PRODUCT_SUBCLASS TRANCHE_FACE_VALUE_AMT TRANCHE_LOSS_RANK
                TRANCHE_SENIORITY_RANK            
          )
          ;
    by EXP_ID;
    if a and b;

    RWA = sum(RWA_SECURED, RWA_UNSECURED);
    RW_NO_CRM = RW_EXP;
    CAPITAL = RWA * &CAPITAL_RATIO;
    CAPITAL_NO_CRM = RWA_NO_CRM * &CAPITAL_RATIO;
   
    if VALUE = 0 then do;
       PD_EFF = PD_EXP;
       LGD_EFF = LGD_EXP;
       RW = RW_EXP;
    end;
    else do;
       PD_EFF = PD_WEIGHTED_SUM / VALUE ;
       LGD_EFF = LGD_WEIGHTED_SUM / VALUE;
       RW = RWA / VALUE * 100;
    end;
    EL_EFF = PD_EFF * LGD_EFF /100;
    run;            


/**************************************************
	update tables as per actual haircut exposures 
         stored in 'exposure_crm' link table 
**************************************************/
   data exp_haircut_adj;
     set "&REGPATH&PATHSEP.exposure_crm" (keep=EXP_ID HAIRCUT_EXP) ;
   run;

   proc sort data=exp_haircut_adj  nodup;
     by exp_id;
   run;

   proc sql;
     update &RESLIB1..crm_allocation_by_rank_detail a
     set haircut_exp=(select haircut_exp from exp_haircut_adj b where a.exp_id= b.exp_id);

   update "&OUTPATH.&PATHSEP.crm_allocation_by_rank" a
     set haircut_exp=(select haircut_exp from exp_haircut_adj b where a.exp_id= b.exp_id);

   update "&OUTPATH.&PATHSEP.capital_detail_by_rank" a
     set haircut_exp=(select haircut_exp from exp_haircut_adj b where a.exp_id= b.exp_id);
   quit;

/***********************************************/

/* If the exposures with zero EAD are to be included in the reporting, then combine their information */
/* into a data set and append that data set to capital_detail_by_rank */
    %if "&REPORT_ZERO_EAD" = "YES" %then %do ;

        data "&OUTPATH.&PATHSEP.capital_detail_by_rank";
          set "&OUTPATH.&PATHSEP.capital_detail_by_rank"
              "&VALPATH.&PATHSEP.exposures_with_zero_ead"(drop=NOTE INSTSOURCE) ;
        run ;
    %end ;


    /*- 3: post-process SUMMARY data -*/
    /*** %SUMMARY : ***/
    /* get number of exposures */
    %local NEXP; 
    proc sql noprint;
    select count(*) into :NEXP
    from "&REGPATH&PATHSEP.all_exposures"(keep=EXP_ID);
    quit;

    /*- get all crossclass variables from the summary data set -*/
    data _ccvars_;
    do i = 1 to &CCNVAR;
        ccvars = compress(scan("&ccvars", i, " ") || '=' || "'+'");
        output;
    end;
    run;

    %local TOPCELL;
    proc sql noprint;
    select ccvars into : TOPCELL separated by " and "
    from _ccvars_;
    run;

/*- get the total firm wide risk measures -*/
    data _total_;
    set &RESLIB1..summary;
    where &topcell;
    run;

    %local TOTAL_EAD TOTAL_RWA TOTAL_CAPITAL TOTAL_RWA_NO_CRM TOTAL_CAP_NO_CRM TOTAL_VALUE;    
    data _null_;
    set _total_;
  
    call symput("TOTAL_EAD", OUTV_EAD);
    call symput("TOTAL_RWA", OUTV_RWA_PV);
    call symput("TOTAL_CAPITAL", OUTV_CAPITAL_PV);
    call symput("TOTAL_RWA_NO_CRM", OUTV_RWA_NO_CRM);
    call symput("TOTAL_CAP_NO_CRM", OUTV_CAPITAL_NO_CRM);
    call symput("TOTAL_VALUE", OUTV_VALUE);
    run;

    /*- compute concentration measures -*/
    data &RESLIB1..summary;
    set &RESLIB1..summary;
  
    OUTV_VALUE_CON          = OUTV_VALUE/&TOTAL_VALUE;
    OUTV_EAD_CON            = OUTV_EAD/&TOTAL_EAD;
    OUTV_RWA_CON            = OUTV_RWA_PV/&TOTAL_RWA;
    OUTV_RWA_NO_CRM_CON     = OUTV_RWA_NO_CRM / &TOTAL_RWA_NO_CRM;
    OUTV_CAPITAL_CON        = OUTV_CAPITAL_PV/&TOTAL_CAPITAL;
    OUTV_CAPITAL_NO_CRM_CON = OUTV_CAPITAL_NO_CRM / &TOTAL_CAP_NO_CRM;
  
    run;

/*- 4: clean work library -*/
    %clean_lib;   
    
%mend r00_post_mitigation_0;

 
