/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: r00_post_regulatory_5_crd4.sas
 *
 * PURPOSE: process securitization exposures subject to supervisory formula approach.
 *
 *
 *   USAGE: 
 *
 *   NOTES:  It is assumed that CRMs for exposures underlying securitization
 *           pools are not shared with regular exposures.
 *          
 *   UPDATES: 
 * 
 *
 *****************************************************************************/


%macro r00_post_regulatory_5_crd4;

%global N_EXP_CRM N_NETWORK;

/*- 1: underlying exposures for unrated securitization exposures subject to SFA  -*/    
/*- &RESLIB1..all_exp_sec_underlying_irb from the previous step                  -*/ 
/*- only need to do crm allocation for pools where K_IRB is not supplied         -*/
    /*- all unrated securitization exposures without K_IRB supplied -*/
    data all_sec_pool_no_kirb(keep=SECURITIZATION_POOL_RK);
    set &RESLIB1..all_exp_ur_sec_irb all_exp_pool_irb;
    where K_IRB = . ;
    run;

    proc sort data=all_sec_pool_no_kirb nodup;by SECURITIZATION_POOL_RK;run;

    data all_exp_sec_underlying_irb(index=(EXP_ID));
    merge &RESLIB1..all_exp_sec_underlying_irb(in=underlying) all_sec_pool_no_kirb(in=pool);   
    by SECURITIZATION_POOL_RK;
    if underlying and pool;    
    run;

/*- 2: get crm links -*/
    /*- links between underlying exposures for unrated sec. exposures under IRB and crms -*/
    data exp_sec_underlying_irb_crm(index=(CRM_ID));
    merge &RESLIB1..exposure_crm_sec_underlying(in=link) 
          all_exp_sec_underlying_irb(keep=EXP_ID in=sec_underlying_irb);
    by EXP_ID;
    if link and sec_underlying_irb;
    run;

    proc sort data=&RESLIB1..all_crms; by CRM_ID; run;
    
    /*- all crms for underlying exposures for unrated securitization exposures under IRB -*/
    data all_crm_sec_underlying_irb;
    merge &RESLIB1..all_crms exp_sec_underlying_irb_crm(in=link_sec_underling keep=CRM_ID);
    by CRM_ID;
    if link_sec_underling;
    run;

/*- if there are no underlying exposures, stop -*/
    %local N_UNDERLYING_IRB;
    %let N_UNDERLYING_IRB=%attrn(all_exp_sec_underlying_irb, NOBS);

    %if &N_UNDERLYING_IRB = 0 %then %goto UPDATE_SFA;

/*- 3: prepare crm allocation -*/
    %prepare_crm_allocation_crd4(EXPCRMDS = exp_sec_underlying_irb_crm, 
                            EXPDS    = all_exp_sec_underlying_irb, 
                            CRMDS    = all_crm_sec_underlying_irb, 
                            NODEDS   = &RESLIB1..node0_sec_underlying_irb, 
                            ARCDS    = &RESLIB1..arc0_sec_underlying_irb, 
                            EXPNOCRM = &RESLIB1..sec_underlying_irb_no_crm, 
                            EXP1CRM1 = &RESLIB1..unique_sec_underlying_irb_crm,
                            METHOD   = OPTIMAL /*- BY_RANK is not impemented for unrated securitization exposures under IRB -*/
                           );


/*- 4: allocate crm optimally -*/    
    %allocate_crm_optimal(EXPCRMDS = exp_sec_underlying_irb_crm, 
                          EXPDS    = all_exp_sec_underlying_irb, 
                          NODEDS   = %if &N_NETWORK > 0 %then %do; &RESLIB1..node0_sec_underlying_irb %end;, 
                          ARCDS    = %if &N_NETWORK > 0 %then %do; &RESLIB1..arc0_sec_underlying_irb %end;, 
                          EXPNOCRM = &RESLIB1..sec_underlying_irb_no_crm, 
                          EXP1CRM1 = %if &N_EXP_CRM > 0 %then %do; &RESLIB1..unique_sec_underlying_irb_crm %end;,
                          CONDS    = &RESLIB1..condata_sec_underlying_irb, 
                          CONOUTDS = intpoint_out1, 
                          OUTDS    = arcout_full
                         );
    
    data &RESLIB1..crm_alloc_detail_opt_ur_sec_irb
         (label="Detailed Optimal CRM Allocation Information for Unrated Securitization Exposures Under IRB"
          drop = _SUPPLY_ _DEMAND_ _VALUE_ _VALUE_0 _FCOST_
         ) /*- detailed information -*/
         &RESLIB1..crm_alloc_opt_ur_sec_irb  
         (label="Optimal CRM Allocation Information for Unrated Securitization Exposures Under IRB"
          keep = /*- brief exposure information -*/
                 EXP_ID COUNTERPARTY_CLASS COUNTERPARTY_SUBCLASS APPROACH CCY 
                 INCEPTION_DATE MATURITY_DATE EXP_VALUE EAD HAIRCUT_EXP PD_EXP LGD_EXP RW_EXP RESMAT_EXP HAIRCUT_FX
                 /*- brief crm information -*/
                 CRM_ID CRM_COUNTERPARTY_CLASS CRM_COUNTERPARTY_SUBCLASS CRM_TYPE CRM_SUBTYPE ELIGIBLE_CRM_TYPE CRM_CCY
                 CRM_EFFECTIVE_DATE CRM_EXPIRATION_DATE CRM_INCEPTION_DATE CRM_MATURITY_DATE CRM_VALUE_DISCOUNT_FLG
                 CRM_VALUE HAIRCUT_CRM PD_CRM LGD_CRM RW_CRM RW_CRM_COUNTERPARTY RESMAT_CRM 
                 /*- brief crm allocation information -*/
                 MAT_MISMATCH_WEIGHT_CRM _COST_ _MULT_ CRM_USED_AMT CRM_USED_AMT_EFF RWA
         ) /*- brief information -*/
         ;    

    set arcout_full;

    label EAD_ADJ = "Adjusted EAD in RWA calculation";
    
    EAD_ADJ = _DEMAND_;
    
    RWA = _FCOST_ / 100;

    if CRM_TYPE = '' then CRM_TYPE = 'NOT_COVERED';

    if CRM_ID NE 'NOT_COVERED' then do;
        CRM_USED_AMT     = _VALUE_0;
        CRM_USED_AMT_EFF = _VALUE_;
    end;
    else do;
        CRM_USED_AMT     = 0;
        CRM_USED_AMT_EFF = 0;
    end;

    if CRM_ID = 'NOT_COVERED' then do;
        RWA_SECURED   = 0;
        RWA_UNSECURED = RWA;
    end;
    else do;
        RWA_SECURED   = RWA;
        RWA_UNSECURED = 0;
    end;

    run;

/*- 5: aggregate over each exposure -*/
/*- get totals for each exposure -*/
    proc summary data = &RESLIB1..crm_alloc_detail_opt_ur_sec_irb;
    by EXP_ID;
    var RWA RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF;
    output out  = total_by_exp(keep = EXP_ID RWA RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF)
           sum  = RWA RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF;
    run;

/*- contains one observation per EXP_ID -*/
/*- crm info dropped since meaningless  -*/

    /*- get crm-related variable list -*/
    %local CRM_VARLIST;
    %let CRM_VARLIST = %dsvarlist(&RESLIB1..all_crms);    

    data  &RESLIB1..capital_detail_opt_ur_sec_irb         
          (keep = EXP_ID SECURITIZATION_POOL_RK EAD K_ALL)
          ;
    merge &RESLIB1..crm_alloc_detail_opt_ur_sec_irb
          (in = detail
           drop = &CRM_VARLIST /*- crm information -*/
                  RWA RWA_SECURED RWA_UNSECURED CRM_USED_AMT CRM_USED_AMT_EFF
          )
          total_by_exp (in = total);
    by EXP_ID;

    if EAD > 0 then  K_ALL = sum(RWA * &CAPITAL_RATIO / EAD, EL / 100 );

    if first.EXP_ID then output;

    run;

/*- 6: get K_IRB -*/
    proc sort data = &RESLIB1..capital_detail_opt_ur_sec_irb;
    by SECURITIZATION_POOL_RK;
    run;

    proc summary data = &RESLIB1..capital_detail_opt_ur_sec_irb;
    var K_ALL;
    weight EAD;
    by SECURITIZATION_POOL_RK;
    output out = kirb(keep=SECURITIZATION_POOL_RK K_IRB_1) mean = K_IRB_1;
    run;

/*- update K_IRB where it is missing -*/   
    data all_exp_pool_irb (drop=K_IRB_1);
    merge all_exp_pool_irb (in=a) kirb;
    by SECURITIZATION_POOL_RK;
    if a;
        
    if K_IRB = . and K_IRB_1 NE . then K_IRB = K_IRB_1;
    run;
    
/*- only keep those with all necessary components for SFA calculation -*/
    data &RESLIB1..all_exp_ur_sec_irb (drop=K_IRB_1);
    merge &RESLIB1..all_exp_ur_sec_irb (in=ur_sec) kirb;
    by SECURITIZATION_POOL_RK;   
    if ur_sec;
    if K_IRB = . and K_IRB_1 NE . then K_IRB = K_IRB_1;
    run;

    %UPDATE_SFA:
/*- 7: assign risk weights -*/ 
/*- pools with eap and liquidity facilities -*/
  data all_exp_pool_irb 
         facility_no_rw_irb;
    set all_exp_pool_irb;

    
    RW_EXP = K_IRB / &CAPITAL_RATIO * 100; 

    if RW_EXP = . then do;
       if not missing(COVER_SECURITIZATION_POOL_RK) then do;
   /*- liquidity facility may use look through approach in irb if permitted (to be processed later) -*/
          if "&IRB_LIQUIDITY_FAC_LOOK_THRU" = "YES" then
             output facility_no_rw_irb;
   /*- otherwise deduct -*/
          else do; 
             RW_EXP = &RW_DEDUCT;
             APPROACH = 'IRB_SFA';
             output all_exp_pool_irb;
          end;
       end;
    end;
    else do;  
       APPROACH = 'IRB_SFA';
       output all_exp_pool_irb;
       end;
    run;
    
    proc append base=&RESLIB1..all_exposures data=all_exp_pool_irb; run;
    proc sort data=&RESLIB1..all_exposures; by EXP_ID; run;
    proc append base=all_exp_pool_std data=facility_no_rw_irb; run;
    
/*- Need to catch the case if there are no unrated IRB. This can happen if all have a rating, -*/
/*- or if securitizations are done using standardized -*/

%if %dsexist(&RESLIB1..crm_alloc_detail_opt_ur_sec_irb) %then %do ;
/*- Join the CRM information for the calculations to the exposure table -*/
    proc sql ;
        create table &RESLIB1..all_exp_ur_sec_irb as
        select a.*, b.CRM_USED_AMT_EFF, b.RW_CRM, b.UNFUNDED_FLG, b.EAD_ADJ
            from &RESLIB1..all_exp_ur_sec_irb as a left join
                 &RESLIB1..crm_alloc_detail_opt_ur_sec_irb as b
            on upcase(a.EXP_ID) = upcase(b.EXP_ID) ;
    quit ;

    /*- Find the sum of the EAD for the underlying. This is needed for  -*/
    /*- the calculations below -*/
    proc summary data = &RESLIB1..all_exp_sec_underlying_irb ;
       by SECURITIZATION_POOL_RK ;
       var EAD ;
       output out  = &RESLIB1..sec_underlying_ead_sum(keep=SECURITIZATION_POOL_RK SEC_SUM_UNDER_EAD)
          sum = SEC_SUM_UNDER_EAD ;
    run;

    /*- Join this information to the exposure table -*/
    proc sql ;
        create table &RESLIB1..all_exp_ur_sec_irb as
        select a.*, b.SEC_SUM_UNDER_EAD
            from &RESLIB1..all_exp_ur_sec_irb as a left join
                 &RESLIB1..sec_underlying_ead_sum as b
            on a.SECURITIZATION_POOL_RK = b.SECURITIZATION_POOL_RK ;
    quit ;
%end ;

/*- unrated securitization exposures -*/
    data &RESLIB1..all_exp_ur_sec_irb (index=(EXP_ID));
    set &RESLIB1..all_exp_ur_sec_irb;

    length S_LT S_L 8.;

/*- if any necessary component for SF calculation is missing then deduct -*/
    if LGD_EXP = . or THICKNESS = . or CREDIT_ENHANCEMENT_LEVEL = . or K_IRB = . or 
       EFFECTIVE_NUMBER_OF_EXPOSURES = . then
       RW_EXP=&RW_DEDUCT;
    
/*- 8: calculate RW for such exposures with necessary input -*/    
    else do;
       %irb_sf(K_IRB, (CREDIT_ENHANCEMENT_LEVEL + THICKNESS), EFFECTIVE_NUMBER_OF_EXPOSURES, LGD_EXP, S_LT);
       %irb_sf(K_IRB, (CREDIT_ENHANCEMENT_LEVEL), EFFECTIVE_NUMBER_OF_EXPOSURES, LGD_EXP, S_L);
       APPROACH = 'IRB_SFA';

      /*- Calculation of the RWA for securtizations under SFA. (Articles 262-264) -*/
      /*- Check if CRM exists and process accordingly -*/
      if not missing(CRM_USED_AMT_EFF) and CRM_USED_AMT_EFF ne 0 then do ;
          if CRM_USED_AMT_EFF >= EAD then do ;
             /*- Apply the RW floor based on type of securitization -*/
             if RESECURITIZATION_FLG = 1 then
                RW_EXP = max(20,(12.5*(S_LT-S_L)/THICKNESS)*100) ;
             else
                RW_EXP = max(7,(12.5*(S_LT-S_L)/THICKNESS)*100) ;
   
             /*- Application of the RW depends on if the CRM is funded -*/
             /*- or unfunded. -*/
             if UNFUNDED_FLG ne 1 then
                RWA = (EAD_ADJ*RW_EXP)/100 ;
             else
                RWA = ((EAD-CRM_USED_AMT_EFF)*RW_EXP + RW_CRM*CRM_USED_AMT_EFF)/100 ;
          end ;
          else do ;
             /*- For partial coverage, the risk weight calculation differs. Also depends on if the CRM -*/
             /*- is funded or unfunded.  -*/
             if UNFUNDED_FLG ne 1 then
                e_star = EAD_ADJ/POOL_FACE_VALUE_AMT - CRM_USED_AMT_EFF/SEC_SUM_UNDER_EAD ;
             else
                e_star = EAD_ADJ/POOL_FACE_VALUE_AMT ;
   
             /*- Apply the RW floor based on type of securitization -*/
             if RESECURITIZATION_FLG = 1 then
                RW_EXP = max(20,(12.5*(S_LT-S_L)/e_star)*100) ;
             else
                RW_EXP = max(7,(12.5*(S_LT-S_L)/e_star)*100) ;
   
             /*- Apply the alternative RW to the uncovered portion, while the -*/
             /*- covered portion receives the RW of the protection provider -*/
             RWA = ((EAD-CRM_USED_AMT_EFF)*RW_EXP + RW_CRM*CRM_USED_AMT_EFF)/100 ;
          end ;
       end ;
      else do ;
       /*- Apply the RW floor based on type of securitization -*/
             if RESECURITIZATION_FLG = 1 then
                RW_EXP = max(20,(12.5*(S_LT-S_L)/THICKNESS)*100) ;
             else
                RW_EXP = max(7,(12.5*(S_LT-S_L)/THICKNESS)*100) ;

          RWA = (EAD*RW_EXP)/100 ;
       end ;

    end;
drop e_star ;
run;

/*- 9: update exposure info -*/
    data &RESLIB1..all_exposures;
    merge &RESLIB1..all_exposures 
          &RESLIB1..all_exp_ur_sec_irb(keep=EXP_ID APPROACH K_IRB RW_EXP)
          ;
    by EXP_ID;
    run;
   
/*- 10: update the link table -*/
    data &RESLIB1..exposure_crm;
    merge &RESLIB1..exposure_crm (in=exp_crm)
          &RESLIB1..all_exp_ur_sec_irb(in=exp_update keep=EXP_ID APPROACH RW_EXP)
          ;
    by EXP_ID;
    if exp_crm;
    run;

/*- report -*/
    %local N_SEC_SFA;
    proc sql noprint;
    select count(*) into :N_SEC_SFA
    from &RESLIB1..all_exp_ur_sec_irb;
    quit;

    %if &N_SEC_SFA > 0 %then %do;
        %put ;
        %print_msg(note,2,73);
        %print_msg(note,2,74);
        %put ;
    %end;

    %EXIT :

%mend r00_post_regulatory_5_crd4;
