/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME: r03_reportmartload_regrpts.sas
* PURPOSE: Loads Regulatory project data into reporting data model
*
*
*
*   NOTES:
*        Modified for V4.2 10/05/05
*
*   UPDATES:
*	1) 12Aug2008  : Added code to idenfify which fact table is loaded
*	2) 12Aug2008  : Removed reference of LANGUAGE_CD
*
*
*****************************************************************************/
%macro r03_reportmartload_regrpts;
%u00_recreate_macro_definitions;
%global ERRCODE CURRENT_SK;
options notes;
%let errcode=0;
 
%macro varlen(    indata=,
                        invar=);
      %let dsid=%sysfunc(open(%str(&indata)));
      %if &dsid gt 0 %then %do;
            %let xid=%sysfunc(varnum(&dsid,&invar));
            %if &xid = 0 %then %do;
                  %put ERROR: The variable &invar does not exists in dataset &indata;
            %end;
            %let xlen = %sysfunc(varlen(&dsid,&xid));
            %let rc=%sysfunc(close(&dsid));
      %end;
      &xlen
%mend varlen;


%macro statusCheck();
/* &syserr seems to be reset at every step boundary.
We'll assign its current value when the macro is invoked to
a global var named errcode. Then if errcode is ever > 0,
we can print a suitable message.
If syserr = 4, execution was successful, but warnings occurred.
Keep track of those separately.*/
 
 
%*initialize it once;
%if &errcode eq %then %let errcode = 0;
 
%* if syserr ever not zero then set errcode to that value.;
%if (&syserr ne 0 and &syserr ne 4) %then %let errcode = &syserr;
 
%global WARNCODE;
%*initialize it once;
%if &warncode eq %then %let warncode = 0;
 
%* if syserr ever = 4 then set warncode to that value.;
%if &syserr = 4 %then %let warncode = &syserr;
%mend statusCheck;
 
%macro statusPrint;
/* Assure that errors print. If no errors, but warnings, then print them.
* If neither of the above, print success!
*/
%if (&errcode ne 0) %then
%print_msg(error,2,86);
%if &warncode ne 0 %then
%print_msg(note,2,87);
%if (&errcode eq 0 and &warncode eq 0) %then
%print_msg(note,2,88);
 
%mend statusPrint;
 
 
 
%macro append_fact (fact_table=,dsn_to_append=);
/*- APPEND new data from summary to fact table -*/
/*- FACT_TABLE: MARK_TO_MARKET, REGULATORY -*/
proc contents data=&LIBREF_NM..&FACT_TABLE out=work._fact (keep=name type length format formatl formatd)
noprint;
run;

filename xfm catalog 'work.temp.xfm.source';  

/*- Write code for transpose -*/
data _null_;
 set work._fact end=eof;
 file xfm;
 if _n_=1 then do;
  put 'data work._fact_xfmrd;';
 end;
 if type=1 then  do;
  if format = '' then
   put 'length ' name ' 8.  ;';
    else do;
      if format eq 'DATE' and (formatl or formatd eq 0) then 
  put 'format ' name ' date. ;';
   else do;
          y=compress (format || formatl || '.' || formatd);
          put 'format ' name ' ' y ' ;';
         end; 
      end;
  put ' ' name '=-999;';
 end;else
 if type=2 then do;
   x= compress('$' ||  length  || '.');
   put 'format ' name ' ' x ';';
   put ' ' name '="DUMMY";';

end;
if eof then 
  put 'run;';
run;

options nosource2;

%inc xfm;

options source2;

 proc sql noprint;
     select  name
      into : namestoinc separated by ' '
      from work._fact as fact
          ;
quit;

data work.include_fact (keep= &namestoinc);
 set work._fact_xfmrd work.&dsn_to_append ;
 where CLASSIFICATION_SK ne -999;
run;

 /*******************************************************************  
	  code added due to introducing a new column 'ANALYSIS_RESULT_SK' 
      as a part of integrity constraint in RRR 1.3                    
  ********************************************************************/ 
/* %if %UPCASE("&FACT_TABLE")=%STR("FINANCIAL_FACT") %then %do; */
     data work.include_fact;
       set work.include_fact;
       ANALYSIS_RESULT_SK=1;
     run;
/* %end; */
/********************************************************************/

         
 proc append base=&LIBREF_NM..&FACT_TABLE  data=work.include_fact force;run;


%mend append_fact;

 
 
%macro classvar;
data _null_;
call symput ('numclass',left(put(maxrec,4.)));
stop;
if 1 = 0 then set rd_rpt.CLASS_VAR_REFERENCE nobs=maxrec;
run;
%print_msg(note,2,89);
proc sort data=rd_rpt.CLASS_VAR_REFERENCE out=work.class_var_dim ; by class_var;run;
proc sort data=work.ccvars out=work.ccvars; by class_var;run;
 
/* list of keys that are not in the data mart */
DATA cc_ids_needtoload
cc_inmart;
MERGE work.class_var_dim (in=inmart)
work.ccvars (in=recentprj);
by  class_var;
if recentprj AND NOT inmart then output cc_ids_needtoload ;
else;
if inmart and recentprj then output cc_inmart;
RUN;
 
/* Get the number of cross-class need to load */
data _null_;
call symput ("needtoload",left(put(maxrec,best4.)));
stop;
if 1 = 0 then  set work.cc_ids_needtoload nobs=maxrec;
run;
 
/* Get the new class_var_id numbers */
data cc_ids_needtoload (keep=class_var_id class_var VALID_FROM_DTTM VALID_TO_DTTM processed_dttm var_index_no CLASS_VAR_TYPE_NM);
set cc_ids_needtoload;
class_var_id='Class_var'||trim(left(_n_+&numclass))||'_id';
processed_dttm=dhms(today(),0,0,time());
VALID_FROM_DTTM=datetime();
VALID_TO_DTTM=dhms('01Jan9999'd,00,00,00);
*language_cd="&REPORTING_LANGUAGE";/* reference to LANGUAGE_CD removed */
run;
 
/* Merge back with data mart */
proc append base=rd_rpt.class_var_reference data=work.cc_ids_needtoload force;quit;

proc sort data=rd_rpt.CLASS_VAR_REFERENCE out=work.class_var_dim ; by class_var;run;
 
/* Create a list of the class_var_ids needed for the rest of the loading */
data work.class_vars (keep=class_var_id class_var ccorder);
merge  work.ccvars (in=inproject) work.class_var_dim;
by class_var;
if inproject then output class_vars;
run;
 
proc sort data=work.class_vars out=work.class_vars ; by ccorder;run;
 
 
/* Grab the list of class_var_ids used for the project */
data work.class_var_id (keep= ORDER_OF_CLASS_VARS_TXT );
length  ORDER_OF_CLASS_VARS_TXT $300. ;
retain ORDER_OF_CLASS_VARS_TXT ;
set class_vars end=eof;
ORDER_OF_CLASS_VARS_TXT=trim(left(trim(left(ORDER_OF_CLASS_VARS_TXT))||' '||class_var_id));
if eof then output;
run;
 
%mend classvar;


%macro loadhier;
%print_msg(note,2,97);
%let nexthiersk=0;
/* Grab a sequential list of the class_var_ids we need */
data _null_;                   
set work.class_vars end=eof;
call symput ("classvarid"||left(trim(put(_n_,3.))),trim(left(class_var_id)));
call symput ("classvar"||left(trim(put(_n_,3.))),trim(left(class_var)));
if eof then call symput ("numcc",trim(left(put(_n_,3.))));
run;

 data work.hierarchy_1 (keep=ORDER_OF_CLASS_VARS_TXT CLASS_VARS_VALUES_TXT processed_dttm 
        CLASS_VARS_CNT 
       %do ccvarnum = 1  %to &numcc ;
        &&classvarid&ccvarnum
       %end;) ;
   length ORDER_OF_CLASS_VARS_TXT $300. ;
   length CLASS_VARS_VALUES_TXT $100.; 
   length  %do ccvarnum = 1  %to &numcc ; 
      &&classvar&ccvarnum $%qsysfunc(cat(%varlen(indata=_results.summary,invar= &&classvar&ccvarnum),.))
     %end; ;
   set _results.summary;
    if _n_=1 then ORDER_OF_CLASS_VARS_TXT=' ';
    

    %do ccvarnum = 1  %to &numcc ;
       &&classvarid&ccvarnum=&&classvar&ccvarnum;

    %end;
     %do ccvarnum = 1  %to &ccrptnvar ;
       label &&classvarid&ccvarnum="&&classvar&ccvarnum";
       if &&classvarid&ccvarnum='' then &&classvarid&ccvarnum='Missing';
        
     %end;

    %do ccvarnum = &numcc %to 1 %by -1;
     ORDER_OF_CLASS_VARS_TXT="&&Classvarid&ccvarnum"||' '||ORDER_OF_CLASS_VARS_TXT;
     CLASS_VARS_VALUES_TXT=trim(left(&&classvarid&ccvarnum))||' '||CLASS_VARS_VALUES_TXT;
    %end;

  processed_dttm=dhms(today(),0,0,time());

  CLASS_VARS_CNT=&ccrptnvar;

run;

 /*Generate unique key for the hierarchy */
data work.hierarchy_2(drop=desc) ;     
  set work.hierarchy_1;
     length CLASS_ENCODING_SK hiersk_md5 $32. desc $400. CLASS_VARS_CNT 6. ;      
  desc= trim(trim(CLASS_VARS_VALUES_TXT)||' || '||trim(ORDER_OF_CLASS_VARS_TXT));
/* Make a temp variable to encode and then drop */
     hiersk_md5 = MD5(desc);    
  CLASS_ENCODING_SK =put(hiersk_md5, hex32.);  
run;

%let numobs=0;

 data hierarchy_vars_dim ;  
   set rd_rpt.CLASSIFICATION_DIM end=eof;
   where CLASSIFICATION_SK ne .;
  run;
 

proc sort data=work.hierarchy_2 out=work.hierarchy_sorted;
by CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT;

proc sort data=work.hierarchy_vars_dim out=work.hierarchy_vars_dim;
by CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT;
run;

proc sort data=work.hierarchy_vars_dim (keep=CLASSIFICATION_SK) out=work.sorted_hier_sk;
by descending CLASSIFICATION_SK;
run;

data _null_;
set work.sorted_hier_sk (obs=1);
call symput ("nexthiersk", CLASSIFICATION_SK+1);
run;


/* list of keys that are not in the data mart */
 DATA inmart_sk (drop=hiersk_md5) 
  var_sks_needtoload (drop=hiersk_md5);   
       MERGE  work.hierarchy_vars_dim (in=inmart)
        work.hierarchy_sorted (in=recentprj);
  by CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT; 
  if recentprj AND NOT inmart then output var_sks_needtoload;
  else;
/* generate a list that is in the mart for other table loads */
if (inmart=1) and (recentprj=1) then output inmart_sk;
RUN;


 data var_sks_needtoload;             /* Generate a list of vars_sk for new ccs */
 set var_sks_needtoload;
 CLASSIFICATION_SK=&nexthiersk + _n_;
 run;

 data hierarchy_3;
 set work.inmart_sk work.var_sks_needtoload;
 run;

 %print_msg(note,2,91);
    data rd_rpt.CLASSIFICATION_DIM ;
    set rd_rpt.CLASSIFICATION_DIM work.var_sks_needtoload;
    run;

%mend loadhier;


%macro loadregfact ;
%let proj_idsk=.;   /* Set in case something happens to the project id */
%let proj_user=.;
 
 
data reg_md5 ( drop=ninst nmissing instn instmean inststd instmin instmax mtm exposure expnonet collateral
);;
merge _results.summary hierarchy_2 (keep=CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT );
processed_dttm=dhms(today(),0,0,time());
project_sk=&current_sk;
run;
 
data work.hierarchy_4 (keep=CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT CLASSIFICATION_SK) ;
set work.hierarchy_3;
run;
 
proc sort data=work.reg_md5 out=work.reg_md5; by CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT;
proc sort data=work.hierarchy_4 out=work.hierarchy_4; by CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT;
 
data reg_fact_sk;
merge work.hierarchy_4 work.reg_md5;
by CLASS_ENCODING_SK ORDER_OF_CLASS_VARS_TXT/*hier_sk hierarchy_vars*/;
run;
 
/*---------------------------------------------------------------------------
* Look to see if we have any new output variables from Risk Dimensions
* -------------------------------------------------------------------------*/
 
%if %symglobl(_FIN_FACT) %then %do;
%if &_FIN_FACT EQ YES %then
    %let _factname=financial_fact ; %else
    %let _factname=regulatory_fact;
 
%end;%else
    %let _factname=regulatory_fact;
 
 

data rd_conf.report_options_&REPORTING_LANGUAGE;  
      set rd_nls.report_options_&REPORTING_LANGUAGE ;
   length FACT_TBL $ 32;
%if %symglobl(_FIN_FACT) %then
    FACT_TBL="FINANCIAL"; %else
    FACT_TBL="REGULATORY";;  
run; 
	


     proc contents data=&LIBREF_NM..&_FACTNAME out=work._fact (keep=name type
        label length format formatl formatd) noprint;
     run;
 
 
proc contents data=work.reg_fact_sk out=work._newfact (keep=name type
label) noprint;
run;
 
proc sort data=work._fact out=_sfact;
by name;
run ;

/* Only new variables beginning with OUTV_ */
/* will be copied to the *_FACT tables     */
/*
data work._newfact ;
set work._newfact(where=(substr(name,1,5) EQ 'OUTV_'));
name=upcase(name);
run;
 */
proc sort data=work._newfact;
by name;
run ;
 
 
/*---------------------------------------------------------------------------
* Create a dataset of output variables not included in the current fact
* table
* -------------------------------------------------------------------------*/
 
data work.newoutputvars (rename=(name=newname));
merge work._sfact (in=a) work._newfact (in=b);
if b and not a then output work.newoutputvars ;
by name;
where type=1;
run;


%let NEWOUTPUTVARS=0;
/*- Check to see if we have any new output variables -*/
data _null_;
call symput ("newoutputvars",trim(left(put(maxrec,best4.))));
stop;
if 1 = 0 then  set work.newoutputvars nobs=maxrec;
run;
 
 
%if %EVAL(&NEWOUTPUTVARS) > 0 %then %do;
%print_msg(NOTE, 2, 350); 
 
filename check catalog 'work.temp.outv_check.source';

data _null_ ;
set work.newoutputvars end=eof;
file check;
if _n_=1 then do;
put "data &LIBREF_NM..&_factname;";
end;
put '  length ' newname '8. ;';
put '  format ' newname "&FORMAT_NUMERIC ;";
if eof then do;
put "set &LIBREF_NM..&_factname;";
put 'run;';
end;
run;
 
%inc check;

%end;
 
 
%append_fact (fact_table=&_FACTNAME,dsn_to_append=reg_fact_sk);
 
 
%mend loadregfact;

 
%macro loadprj_id;


%local numids;
%let projsk_exists=NO;
%let SOURCE_SYSTEM_CD=CRISKM;

 data _null_;
 set work.class_var_id ;
 call symput ("ORDER_OF_CLASS_VARS_TXT",trim(left(ORDER_OF_CLASS_VARS_TXT)));
 run;

 %let PROJECT_TYPE = &REPORTS_PROJECT_TYPE;          
 
/* ensure we have the right project id based on the user type */
%if %upcase(&usertype) eq MASTER %then
%let project_id =
%upcase(%trim(%left( &PROJECT_SET._&PROJECT_TYPE._&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id)));
%else %let project_id =
%upcase(%trim(%left( &PROJECT_SET._&PROJECT_TYPE._&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username)));

 %if %attrn(rd_rpt.project_dim, NOBS) EQ 0 %then %do;
  %let CURRENT_SK = 1;
 %end;
 %else %do;
   proc sql noprint;select max(project_sk) into :max_sk from rd_rpt.project_dim;quit;
   %let CURRENT_SK = %eval(&max_sk + 1); 
 %end;

/* Create macro variable for the column CONFIGURATION_ID & PROJECT_USER_SK */
 %if %upcase(&usertype) eq MASTER %then %do; 
  proc sql noprint;
  select PROJECT_OPTION_SET_SK into :PROJ_OPTION_SK 
  from rd_rpt.PROJECT_OPTION_SET
  where upcase(compress(CONFIGURATION_ID))=upcase(compress("&CONFIG_SET")) and
  upcase(compress(CURRENCY_CD))=upcase(compress("&REPORT_CCY")) and
  upcase(compress(RATING_AGENCY_NM))= upcase(compress("&RATING_AGENCY")) and
  upcase(compress(LANGUAGE_CD))=upcase(compress("&REPORTING_LANGUAGE")) and
  upcase(compress(PORTFOLIO_NM))=upcase(compress("&REGPROJECTNAME._&SYSTEM_ID"));
  quit;
  %end;

  %else %do;
  proc sql noprint;
  select PROJECT_OPTION_SET_SK into :PROJ_OPTION_SK 
  from rd_rpt.PROJECT_OPTION_SET
  where upcase(compress(CONFIGURATION_ID))=upcase(compress("&CONFIG_SET")) and
  upcase(compress(CURRENCY_CD))=upcase(compress("&REPORT_CCY")) and
  upcase(compress(RATING_AGENCY_NM))= upcase(compress("&RATING_AGENCY")) and
  upcase(compress(LANGUAGE_CD))=upcase(compress("&REPORTING_LANGUAGE")) and
  upcase(compress(PORTFOLIO_NM))=upcase(compress("&REGPROJECTNAME._&USERNAME"));
  quit;
  %end;

  %if %upcase(&usertype) eq MASTER %then %do;
  %let PROJ_USER_SK=.;
  %end;
  %else %do;
  proc sql noprint;
  select PROJECT_USER_SK into :PROJ_USER_SK from rd_rpt.PROJECT_USER
  where upcase(compress(PROJECT_USER_ID))=upcase(compress("&username"));
  quit;
  %end;

 
 %print_msg(note,2,92);
  
  data work.project_id;
  length project_id PROJECT_GROUP_NM $100. project_id_desc $1024. LIBREF_NM $8. BASE_TM 5. VAL_TM  5.  PROJECT_TYPE_CD $15. SOURCE_SYSTEM_CD $10. ORDER_OF_CLASS_VARS_TXT $300. TIME_BUCKET_TYPE_NM $20. VERSION_ID $10. ENTITY_ID $32. PROMOTED_FLG $1.;
length ADJ_FOR_IGT_FLG $1. CAPITAL_TYPE_CD $20. CAPITAL_ADD_ON_DT 8. CAPITAL_ADD_ON_REASON_TXT $100. CALCULATION_METHOD_CD $10.;  

  set work.class_var_id;

/*    length project_id $100. project_id_desc $1024. FACT_TABLE_NM $40. LIBREF_NM $8. BASE_TM 5. VAL_TM  5. TIME_UOM_CD $3. PROJECT_TYPE_CD $15. SOURCE_SYSTEM_CD $10.; */
    project_sk=%eval(&CURRENT_SK );
    project_id=upcase("%trim(%left(&PROJECT_ID))");
    project_id_desc=
"Project '%lowcase( &PROJECT_SET._&PROJECT_TYPE)' and Entity '%lowcase(&system_id)' and User '%lowcase(&username)'";
    processed_dttm=dhms(today(),0,0,time());
    base_dt=&rundate;
    base_tm=dhms(&rundate,0,0,time());
    VAL_DT=today();
    VAL_TM=dhms(today(),0,0,time());
/*    %if %symglobl(_FIN_FACT) %then
    fact_table_nm="FINANCIAL";%else
    fact_table_nm="REGULATORY";; */
    SOURCE_SYSTEM_CD="&SOURCE_SYSTEM_CD";
    LIBREF_NM="&LIBREF_NM";
    PROJECT_OPTION_SET_SK=&PROJ_OPTION_SK;
    ORDER_OF_CLASS_VARS_TXT="&ORDER_OF_CLASS_VARS_TXT";
    PROJECT_USER_SK=&PROJ_USER_SK;
*    TIME_UOM_CD="";
    PROJECT_TYPE_CD="";
    VERSION_ID="";
    TIME_BUCKET_TYPE_NM="";
    ENTITY_ID ="";	
    PROJECT_GROUP_NM="";
    PROMOTED_FLG="";
	ADJ_FOR_IGT_FLG="";
	CAPITAL_TYPE_CD="";
	CAPITAL_ADD_ON_DT="";
	CAPITAL_ADD_ON_REASON_TXT="";
	CALCULATION_METHOD_CD="";	
	
    output;
  run;
 
  proc append base=rd_rpt.project_dim data=work.project_id force;
  run;

%mend;

 
%macro timestamp ;

 data work.currentdate;           /* Check for existing date */
 set rd_rpt.date_reference;
 where base_dt eq &rundate;
 run;
 %let dateexists=0;
     data _null_;
      call symput ("dateexists",left(put(maxrec,best4.)));
      stop;
      if 1 = 0 then  set work.currentdate nobs=maxrec;
     run;

  %if &dateexists^=0 %then %return;        /* Date exists already - return */
  data work.timestamp (drop=endofmonth day_of_year);
    length date_desc $100. month_nm day_of_week_nm $40. language_cd $3. day_of_year_no day_of_month_no day_of_week_no Week_no Month_no quarter_no 3. year_no 4.;
    format processed_dttm NLDATM21. base_dt DATE9.;
    day_of_year=put(&rundate,JULDAY3.);
    day_of_year_no=input(&rundate,best8.);
    Week_no=week(&rundate);
    Month_no=Month(&rundate);
    year_no=Year(&rundate);
    quarter_no=qtr(&rundate);
    day_of_week_nm=put(&rundate,downame9.);
    month_nm=put(&rundate,nldatemn.);
    day_of_week_no=weekday(&rundate);
    day_of_month_no=day(&rundate);
    date_desc="Results ran on: "||put(&rundate,worddate18.);
    processed_Dttm=dhms(today(),0,0,time());
    base_dt=&rundate;
    endofmonth=Mdy(Mod(Month(&rundate),12)+1,1,Year(&rundate)+Int(Month(&rundate)/12.0))-1;
    language_cd="&REPORTING_LANGUAGE";
    if &rundate eq endofmonth then last_day_of_month_flg ="Y";else;
    if &rundate ne endofmonth then last_day_of_month_flg="N";
  run;
  proc append base=rd_rpt.date_reference data=work.timestamp force;
  run;

%mend timestamp;

 
 
%macro configuration;
 %if %attrn(rd_rpt.project_option_set, NOBS) EQ 0 %then %do;
  %let CURRENT_SK = 1;
 %end;
 %else %do;
   proc sql noprint;select max(project_option_set_sk) into :max_sk from rd_rpt.project_option_set;quit;
   %let CURRENT_SK = %eval(&max_sk + 1); 
 %end;
 
 data configuration;
  length CONFIGURATION_id rating_agency_nm  $32.  PORTFOLIO_NM  $40.;
  format processed_dttm  NLDATM21. currency_cd language_cd $3.;
  CONFIGURATION_ID=upcase("&config_set");
  language_cd="&REPORTING_LANGUAGE";
  PROJECT_OPTION_SET_SK = %eval(&CURRENT_SK );
  rating_agency_nm=upcase("&rating_agency_st");
  processed_dttm=dhms(today(),0,0,time());

 %if %upcase(&usertype) eq MASTER %then %do; 
   portfolio_nm=upcase("&REGPROJECTNAME._&SYSTEM_ID");
 %end;
 %else %do;
   portfolio_nm=upcase("&REGPROJECTNAME._&USERNAME");
 %end;

  currency_cd="&report_ccy";
  VALID_FROM_DTTM=dhms(today(),0,0,time());
  VALID_TO_DTTM=dhms('01Jan9999'd,00,00,00);
  PROJECT_SET_NM ="&PROJECT_SET";
 run;
 
   proc sort data=rd_rpt.PROJECT_OPTION_SET out=work.PROJECT_OPTION_SET;
   by CONFIGURATION_ID CURRENCY_CD LANGUAGE_CD RATING_AGENCY_NM PORTFOLIO_NM;
   run;
   proc sort data=work.configuration out=work.configuration;
   by CONFIGURATION_ID CURRENCY_CD LANGUAGE_CD RATING_AGENCY_NM PORTFOLIO_NM;
   run;

   data need_to_load not_loaded;
   merge work.PROJECT_OPTION_SET (In=A)
   work.configuration (in=B);
   by CONFIGURATION_ID CURRENCY_CD LANGUAGE_CD RATING_AGENCY_NM PORTFOLIO_NM;
   if B AND NOT A then output need_to_load;
   else;
   if B and A then output not_loaded;
   run;

   data need_to_load;
   set need_to_load(keep=PROJECT_OPTION_SET_SK VALID_FROM_DTTM CONFIGURATION_ID LANGUAGE_CD CURRENCY_CD RATING_AGENCY_NM PORTFOLIO_NM PROJECT_SET_NM VALID_TO_DTTM PROCESSED_DTTM PROJECT_OPTION_SET_ENCODING_SK CONFIGURATION_SK);
   run;

   proc append base=rd_rpt.PROJECT_OPTION_SET data=work.need_to_load force;
   run;
%mend configuration;

 
%macro project_user;

%let projuser_exists=NO;
%let numusers=1;
data proj_user;
set rd_rpt.project_user ;
CALL SYMPUT ("projuser_exists","YES");
call symput ("proj_usersk",trim(left(project_user_sk)));
call symput ("numusers",trim(left(project_user_sk)));
where upcase(project_user_id) eq upcase("&username");
run;
 
%if &projuser_exists=NO %then %do;
data _null_;
call symput ("numusers",left(put(maxrec+1,best4.)));
stop;
if 1 = 0 then  set rd_rpt.project_dim nobs=maxrec;
run;

data proj_user;
length project_user_id  $32. project_user_desc $40.;
format processed_dttm  NLDATM21. ;
processed_dttm=dhms(today(),0,0,time());
project_user_id=upcase("&username");
project_user_sk=&numusers;
project_user_desc=upcase("&username");
run;

proc append base=rd_rpt.project_user data=work.proj_user force;
run;
 
%end;

%mend project_user;

 
%macro loaddatamart;
 %global LIBREF_NM; /* For storing the libref name*/
%if %upcase(&RISKREPO) eq YES or %upcase(&RISKREPO) EQ Y %then %do;
%let PROJECT_TYPE = &REPORTS_PROJECT_TYPE;

libname _results "&outpath&pathsep&project_set._&project_type";


/* Finding out whether there are matching Project_ID by taking the count*/

    proc sql noprint;
     select count(PROJECT_SET),compress(LIBREF_NM) into :RRRCOUNT,:LIBREF_NM from 
     RD_ROOT.RRR_LOAD_PROJECT_OPTIONS where
      compress(upcase(project_type)) = compress(upcase("&project_type")) and
      compress(upcase(project_set)) = compress(upcase("&project_set")) and
      compress(upcase(crm_allocation)) = compress(upcase("&mitigants_allocation_method"));
     quit;
     /* Assign the macro variable using %let so as to avoid trailing blanks*/
    %let LIBREF_NM=&LIBREF_NM;

     /* If no matching PROJECT_ID/LIBREF_NM not found then error out*/
     %if (&RRRCOUNT eq 0) %then %do;
      %print_msg(note,  2 ,  310 ) ;
      %goto mexit ;
     %end;

      /* If LIBREF_NM is a missing value then assign LIBREF_NM=rd_rpt*/
     %else %if ("&LIBREF_NM" = "") %then %do;
      %let LIBREF_NM = rd_rpt;
     %end;

     %else %do;
     /* Finding out whether there is matching LIBREF_NM in LIBREF_MAPPING_DIM*/
      proc sql noprint;
       select count(LIBREF_NM),PATH_TXT into :MAPCOUNT,:PATH from RD_RPT.LIBREF_MAPPING_DIM
       where compress(upcase(LIBREF_NM))= compress(upcase("&LIBREF_NM"));
      quit;
     /* Assign the macro variable using %let so as to avoid trailing blanks*/
     %let PATH=&PATH;
      %if (&MAPCOUNT eq 0) %then %do;
        %print_msg( WARNING, 2 , 314 ) ;
       %goto mexit ;
      %end;

      %else %do;
        libname &LIBREF_NM "&PATH";
      %end;
     %end;
/*End of code for identifying LIBREF_DIM*/
%cvars (&outpath&pathsep&project_set._&project_type);

/*Re-order ccvars - don't drop the first cc for the rollup project*/
%reviseccrptvars (0);
/* Need to rename because RD creates read-only ccvar macro names */
data ccvars;
/* Dumping to a dataset to avoid issues with nested macros inside of zlist within RD */
set ccvars end=eof;
length class_var $32.;
call symput ("ccrptvar"||trim(left(put(_n_,2.))),trim(left(ccrptvar)));
call symput ("ccrptnvar",trim(left(ccrptnvar)));
if eof then call symput ("ccrptvars",trim(left(ccrptvarlist)));
class_var=ccrptvar;
run;
%print_msg(note,2,94);
 
 
/* Creates and loads class var table */
%classvar;
%statuscheck;
/* Loads configuration table */
%configuration;
%statuscheck;
/* Creates project user id and loads into table project_user_dim */
%project_user;
%statuscheck;
/* Creates and loads project id information*/
%loadprj_id;
%statuscheck;
/* Creates and checks hierarchy then loads missing hierarchies into hierarchy_vars table */
%loadhier;
%statuscheck;
/* Creates a timestamp for each project run */
%timestamp;
%statuscheck;
/* Creates and loads rollup data into regulatory_fact */
%loadregfact;
%statuscheck;
/* Prints status message */
%statusprint;

/*Update the labels of the rd_rpt.classification_dim table  */
/*NOTE: In the WHERE statement that subsets the 
        rd_rpt.class_var_refecrence below, you can also use
        the the val_dt and val_tm instead of the datetime() */

filename upd_lbl catalog 'work.temp.upd_lbl.source';

/*data _null_;
  file upd_lbl;
  set rd_rpt.class_var_reference (where=(
  (upcase(language_cd) eq "%upcase(&reporting_language)") and
  (datetime() between valid_from_dttm and valid_to_dttm)));
  lbl=quote(compress(class_var));
  put "label " class_var_id "=" lbl ";";
run;
*/
/* reference to LANGUAGE_CD from above code removed */

data _null_;
  file upd_lbl;
  set rd_rpt.class_var_reference (where=((datetime() between valid_from_dttm and valid_to_dttm)));
  lbl=quote(compress(class_var));
  put "label " class_var_id "=" lbl ";";
run;

proc datasets lib = rd_rpt nolist nodetails;
  contents data =classification_dim noprint; 
  modify classification_dim;
  %inc upd_lbl;
  quit; 
run;

 %mexit:
%end;
%else
%print_msg(note,2,96);
 
%mend loaddatamart;
 
%loaddatamart;
%mend r03_reportmartload_regrpts;
