/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
* NAME: regrpt_capital_ca_crd4.sas
*
* PURPOSE: Runs regulatory report for CA template
*
* NOTES:
* Created: 7/30/13
*****************************************************************************/

%macro regrpt_capital_ca_crd4;

/* Create Data for Report */
%regrpt_d0_capital_ca_crd4;
 
/* Creates CA report body */
%macro display_regrpt_ca;
 
 
/* Sort the CA report values by varname */
proc sort data=work.cavalues;
by name;
run;
 
/* Sort the report layout by varname */
/* needs error check */
proc sort data=rd_nls.regrpt_capital_ca_crd4_&reporting_language out=work.calayout;
by name;
run;
 
/* Join these data sets by varname */
data work.cafinal (where=(outline ne ""));
merge  work.calayout work.cavalues;
by name;
if (amount NE . and amount LE 1e-9) then amount = 0;
run;
 
/* Resort the final output by outline key
to restore the outline order */
proc sort data=work.cafinal;
by outlinekey;
run;
 
/* Devide the report into the three sections of the template */
data work.ca_1 work.ca_2 work.ca_3;
set work.cafinal;
section = substr (outline, 1, 1);
if section = "1" then
output work.ca_1;
if section = "2" then
output work.ca_2;
if section = "3" then
output work.ca_3;
run;
 
 
/* Produce the report for each section */
%do x=1 %to 3;
 
%if %eval(&x) > 1 %then %do;
%if %upcase(&REPORT_TYPE)=%upcase(PDF) %then %do;
ODS PDF STARTPAGE=YES;
%end;
%end;
 
proc report data=work.ca_&x nowd missing LS=160 PS=50 SPLIT="_" contents=''
style(report)={ bordercolor=gray }
style(column)={ bordercolor=#FAF8ED cellspacing=1}
style(header)={cellheight=0  cellspacing=1 };
column outline _label_ amount ;
define outline / display  "Item";
define _label_ / display  width = 50  "LABEL";
define amount  / display  format=NLNUM18.  "AMOUNT";

    compute outline;
       if (outline ) in 
	   ('1' '1.1' '1.1.1' '1.1.2' '1.1.3' '1.2' '1.2.1' '1.2.2' '1.3' '1.3.1'
	     '1.3.2' '1.4' '1.4.1' '1.4.2' '1.4.3' '1.5' '1.6' '1.6.1' '1.6.2' '1.6.3' '1.7' '1.8' '1.8.1'
		 '1.8.2' '1.8.3' '1.8.4' ) 
	   then do;
         call define(_row_,"Style", "Style=[ font_weight=bold ]");  

       end;
    endcomp;


run;
 
%end;
 
%mend;
 
 
/* Controls the report production */
%macro create_regrpt_ca;
 
data work.current_financial;
set work.current_financial;
if class_vars_values_txt eq '+' then output;
run;
 
 
/* Get a unique list of the hierarchy vars */
proc sort data=work.current_financial out=work.hierlist (keep=classification_sk);
by classification_sk;
run;
 
/* Get a distinct count */
data _null_;
set work.hierlist nobs=maxobs;
call symput ('hiercount', maxobs);
stop;
run;
 
/* For each hierarchy : */
%do i=1 %to &hiercount;
 
/* Get the hierarchy value */
data work.temp;
obsnum=&i;
set work.current_financial point=obsnum;
call symput ('hier', classification_sk);
stop;
run;
 
/* Transpose the report data with the current hierarchy value */
proc transpose data=work.current_financial (where=(CLASSIFICATION_SK=&hier))
out=work.cavalues (rename=(_name_=name col1=Amount));
run;
 
/*Merge with data from CRIRBA, CRIRBF, SA, EQU, SEC */
data work.cavalues2;
length name $39.;
set cavalues
_ca_data_ (rename=(OUTV_rwa = Amount));
run;
 
/*Create the pricing methods code for the second and third part of the reports*/
filename final_pm catalog 'work.temp.final.source' LRECL=32760;
 
proc sort data= Rd_root.Capmethods_cr_crd4;
by descending depth ;
run; 
data _null_;
set Rd_root.Capmethods_cr_crd4 nobs=maxobs;
if length(name) GE 32 then NAME=compress(name,'_');
file final_pm;
if  pmethod ne '' then
do;
line = "  " || trim(left(name)) || "=" || trim(left(pmethod)) || ";";
put line;
put;
end;
run;
 
proc transpose data=work.cavalues2
out=work.cavalues3(drop =_LABEL_) ;
id name;
run;
 
data work.allcavalues;
set cavalues3;
%include final_pm;
run;
 
proc transpose data = allcavalues out = work.cavalues(rename=(_NAME_ = NAME));
run;
 
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
 
   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="CA - OWN FUNDS"
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;  
 
/* Call the regulatory report header */
%regulatory_reportheaders (dsn=work.current_financial);
 
/* Call the report body */
%display_regrpt_ca;
 
%end;
 
%mend;
 
%create_regrpt_ca;
 
 
 
 
 
 
 
 
%mend regrpt_capital_ca_crd4;
