/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_capital_crgb_3_crd4.sas
*
* PURPOSE: Creates report for the CRGB 3 report
*
*
*   USAGE: This is a draft
*
*   Macro Options:
*****************************************************************************/
 
%macro regrpt_capital_crgb_3_crd4;

/* Create Data for Report */
%regrpt_d0_cap_crgb_3_crd4;
 


proc format;
	value $Aggregate
				"+"="Aggregate Total"
				;
run;	
	
**********************************************************;
* Format exclusively for CRGB-3 Reporting               *;
**********************************************************;

proc sort data=RD_MAP.MAP_NATIONAL_DISCRETION nodupkey out=fmt(keep=COUNTRY_CD COUNTRY_NM);
by COUNTRY_CD;
run;
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $60. HLO $8. TYPE SEXCL EEXCL $1.;
if _n_ =1 then do;
START   = "+";
END     = "+";
LABEL   = "Aggregate Total";
TYPE    = 'C' ;
FMTNAME = 'ccvar';
output;
end;
set fmt end = lastobs ;
FMTNAME = 'ccvar';
      START            = compress(COUNTRY_CD);
      END              = START          ;
      LABEL            = COUNTRY_NM ;
      TYPE             = 'C' ;
output ;
/*
if lastobs then do;
     START            ='**OTHER**' ;
     END              = START;
	 HLO = 'O';
	 LABEL = "OTHER";
	 output;
end;
*/
run;
 
proc format cntlin=fmt  ; run;
**********************************************************;
* Create Local macros for CRGB-SA Reporting                 *;
**********************************************************;
/*%let style_type=%str(style=Data[Tagattr='format:#,##0' fontweight=bold background=#CED3D6]);  */
%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  


/* Creates basic  template report */
%macro report_page (dsn);
 
 
proc report data=&DSN nowd missing LS=160 PS=50 SPLIT="*" contents=""

style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={background=#CED3D6 cellheight=0  cellspacing=0 fontweight=bold};

 
column  CLASS_CRGB_3  
		OUTV_CAPITAL   /* Col 010 */
		;
        
    define CLASS_CRGB_3                /display   "";
    define OUTV_CAPITAL      /display &style_type.    ""  "Amount"      ;
 
    compute CLASS_CRGB_3;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#E6EDFF]");
       end;
    endcomp;
 
run;
 
%mend report_page;
 
 
%macro generate_report;
 
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.&regprojectname._1))
or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
%print_msg(warning,3,10);
%print_msg(warning,3,15);
%regulatory_reportnopage();
%return;
%goto FINAL;
%end;
 
/* Get number of report pages */
%let pages=%attrn(report_pages,NOBS);
 
%do this_page=1 %to &PAGES ;
 
/*Change to &pages */
/*If data is not available for the report page then do no run report content */
%if NOT %sysfunc(exist(work.&regprojectname._&this_page)) %then %do;
%print_msg(warning,3,19);
%print_msg(note,3,20);
%regulatory_reportnopage();
%goto NOPAGE;
%end;

  %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;
     %let ccf_crm_msg=%print_msg(,3,110,1); 
     
     footnote "&ccf_crm_msg";
  %end;
 
/* Displays the titles for the cross-classification variables */
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
	data _null_;
		ID = open("report_pages");
		Var_name = upcase(varname(ID,1));
		RC = close(ID);
		call symputx("class_gb_lev1",var_name);
	run;
   data _null_;
    set report_pages(firstobs=&this_page obs=&this_page);
	call symputx("sheet_name",put(&class_gb_lev1,$ccvar.));
   run;
%put sheet_name=&sheet_name;

   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="&sheet_name."
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;
 
%regulatory_reportheaders(work.&regprojectname._&this_page);
 
%report_page (work.&regprojectname._&this_page);

/* subroutine for no data available for report page */
%NOPAGE:
 
%end;
 
%FINAL:
footnote ;
 
%mend generate_report; /* end reportbody macro */
 
%generate_report;
 
 
 
 
 
 
 
 
 
%mend regrpt_capital_crgb_3_crd4;
