/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_capital_crsa_crd4.sas
*
* PURPOSE: Creates report for the CR SA report
*
*
*   USAGE: This is a draft
*
*   NOTES: Modified for V4.8
*   Macro Options:
*****************************************************************************/
 
%macro regrpt_capital_crsa_crd4;

/* Create Data for Report */
%regrpt_d0_capital_crsa_crd4;
 
proc format;
value $exp_type (default=256)
          /*'NETTING'       =   " &CRSA_L_80."*/
            'OFF_BALANCE'   =   " &CRSA_L_80."
            'REPOS'         =   " &CRSA_L_90."
            'DERIVATIVES'   =   " &CRSA_L_110."
            'ON_BALANCE'    =   " &CRSA_L_70."
            'UNDEFINED'     =   " &MISSING"   
            'DILUTION_RISK' =   " &DILUTION_RSK"
			'PRM'="&CRSA_L_50"
			'TMP'="&CRSA_L_60";
run;
proc format;
	value $Aggregate
				"+"="Aggregate Total"
				;
run;				
**********************************************************;
* Format exclusively for CRSA Reporting                  *;
**********************************************************;

proc sort data=rd_map.map_sa_class nodupkey out=fmt(keep=SA_CLASS_DESCRIPTION SA_CLASS);
by sa_class;
run;
data fmt (keep=FMTNAME START END LABEL TYPE HLO SEXCL EEXCL);
length FMTNAME  START END $32. LABEL $100. HLO $8. TYPE SEXCL EEXCL $1.;
if _n_ =1 then do;
START   = "+";
END     = "+";
LABEL   = "Aggregate Total";
TYPE    = 'C' ;
FMTNAME = 'ccvar';
output;
START   = "PAST_DUE";
END     = "PAST_DUE";
LABEL   = "Exposures In Default";
TYPE    = 'C' ;
FMTNAME = 'ccvar';
output;
START   = "SHORT_CLAIM";
END     = "SHORT_CLAIM";
LABEL   = "Exposures to Corporate and Institutions with a  Short Term Credit Assessment";
TYPE    = 'C' ;
FMTNAME = 'ccvar';
output;

end;
set work.fmt  end=lastobs;
FMTNAME = 'ccvar';
START   = SA_CLASS;
END     = SA_CLASS;
LABEL   = SA_CLASS_DESCRIPTION;
TYPE    = 'C' ;
output ;
if lastobs then do;
HLO = 'O';
LABEL = "OTHER";
output;
end;
run;
 
proc format cntlin=fmt ; run;

		
**********************************************************;
* Create Local macros for CRSA Reporting                 *;
**********************************************************;
/*%let style_type=%str(style=Data[Tagattr='format:#,##0' fontweight=bold background=#CED3D6]);  */
%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  


/* Creates basic  template report */
%macro report_page (dsn);
 
proc report data=&dsn nowd missing LS=160 PS=50 /*SPLIT="*"*/ contents=""
style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={background=#CED3D6 cellheight=0  cellspacing=0 fontweight=bold};


column  
     (CLASS_CR_SA)
     ( "&orig_exp_preccf" outv_exp_pre_ccf_pre_crm(   						/* Col 010 */		
      OUTV_EAD_FUND_CCP_AMT ))								/* Col 020 */
     (OUTV_VALUE_ADJ_AMT 								/* Col 030*/
	 outv_exposure_net_amt)								/* Col 040*/
     ("&credit_risk_mit_tech" 
		("&unfunded_credit_protection"
			outv_guarantee_unfunded_amt 				/* Col 050*/
			outv_credit_deriv_unfunded_amt)				/* Col 060*/
		("&funded_cp" 
			outv_elig_fin_collateral_amt 				/* Col 070*/
			outv_credit_protect_funded_amt )			/* Col 080*/
		("&sub_exposure_crm" 
			outv_outflow_within_sa_amt 					/* Col 090*/
			outv_inflow_within_sa_amt ))				/* Col 100*/
		("&exp_post_crm_preccf" 
			outv_exp_pre_ccf_after_crm )				/* Col 110*/
		("&_credit_risk_mit_tech_coll_methd"  
			OUTV_VOL_ADJ_EXP_AMT						/* Col 120*/
			("&_fin_collateral_adj_value" 
				outv_fin_coll_adj_val_amt 				/* Col 130*/
				outv_vol_mat_adj_amt ))					/* Col 140*/
	("&outv_fully_adj_exp_amt" 
		outv_fully_adj_exp_amt)							/* Col 150*/
    ("&breakdown_ccf_off_bal"
		%do ii=1 %to %eval(&numccfbuckets-2); 			
			outv_ccf&ii 								/* Col 160 to 190 */
		%end;)
    outv_ead_rollup (											/* Col 200*/
	outv_ead_ccr)	  									/* Col 210*/
	rwa_pre_sme_amt										/* Col 215*/
	outv_rwa ( 											/* Col 220*/
	OUTV_RW_ECAI_AMT										/* Col 230*/
	OUTV_RW_GOVT_AMT);										/* Col 240*/
    
    
 
        
    define CLASS_CR_SA              /display format=$exp_type.  style=[font_weight=bold  ]     ""              ;
    define outv_exp_pre_ccf_pre_crm         /display &style_type.      ""      ;
    define OUTV_EAD_FUND_CCP_AMT         /display &style_type.      "&OUTV_EAD_FUND_CCP"      ;
    define outv_ead_ccr             /display &style_type.       "&ead_from_ccr"      ;
    define OUTV_VALUE_ADJ_AMT           /display &style_type.           "&OUTV_VALUE_ADJ_AMT"       ;
    define outv_exposure_net_amt            /display &style_type.       "&outv_exposure_net_amt"    ;
    define outv_fin_coll_adj_val_amt        /display &style_type.       ""              ;
    define outv_vol_mat_adj_amt         /display &style_type.       "&outv_vol_mat_adj_amt"     ;
    define OUTV_VOL_ADJ_EXP_AMT         /display &style_type.       "&OUTV_VOL_ADJ_EXP_AMT"     ;
    define outv_ead_rollup                    /display &style_type.       "&OUTV_EAD"         ;

  /*  define outv_ead                 /display &style_type.       "&OUTV_EAD"         ;*/
    
    define outv_exp_pre_ccf_after_crm       /display &style_type.       ""              ;
    define outv_credit_protect_funded_amt       /display &style_type.       "&CRSA_FUNDED_CREDIT_PROC"       ;
    define outv_elig_fin_collateral_amt     /display &style_type.       "&CRSA_ELIG_FIN_COLLATERAL_AMT" ;
    define rwa_pre_sme_amt                 /display &style_type.       "&CRSA_RWA_PRE_SME_AMT"         ;
    define outv_rwa                 /display &style_type.       "&CRSA_RWA_AFT_SME_AMT"         ;
    define  outv_guarantee_unfunded_amt     /display &style_type.       "&CRSA_GUARANTEES"           ;
    define  outv_credit_deriv_unfunded_amt      /display &style_type.       "&CRSA_CRD_DERIV"            ;
    define outv_fully_adj_exp_amt           /display &style_type.       ""              ;   
    define outv_outflow_within_sa_amt       /display &style_type.       "&total_outflow"        ;
    define outv_inflow_within_sa_amt        /display &style_type.       "&total_inflow"         ;
/*  define outv_capital             /display &style_type.       "&OUTV_CAPITAL"         ;*/
    define OUTV_RW_ECAI_AMT             /display &style_type.       "&OUTV_RW_ECAI"      ;
    define OUTV_RW_GOVT_AMT             /display &style_type.       "&OUTV_RW_GOVT"      ;
     
    compute class_cr_sa;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#ffffff]");
       end;
    endcomp;

run;
 
 
%mend report_page;
 
 
%macro generate_report;
 
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.&regprojectname._1))
or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
%print_msg(warning,3,10);
%print_msg(warning,3,15);
%regulatory_reportnopage();
%return;
%goto FINAL;
%end;
 
/* Get number of report pages */
%let pages=%attrn(report_pages,NOBS);
 
%do this_page=1 %to &PAGES ;
 
/*Change to &pages */
/*If data is not available for the report page then do no run report content */
%if NOT %sysfunc(exist(work.&regprojectname._&this_page)) %then %do;
%print_msg(warning,3,19);
%print_msg(note,3,20);
%regulatory_reportnopage();
%goto NOPAGE;
%end;

  %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;
     %let ccf_crm_msg=%print_msg(,3,110,1); 
     
     footnote "&ccf_crm_msg";
  %end;
 
/* Displays the titles for the cross-classification variables */
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
	data _null_;
		ID = open("report_pages");
		Var_name = upcase(varname(ID,2));
		RC = close(ID);
		call symputx("class_sa_lev1",var_name);
	run;
   data _null_;
    set report_pages(firstobs=&this_page obs=&this_page);
	call symputx("sheet_nm",put(&class_sa_lev1,$aggregate.));
   run;

   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="&sheet_nm"
		sheet_interval='none' autofit_height="yes");

		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;
 
%regulatory_reportheaders(work.&regprojectname._&this_page);

 
%report_page (work.&regprojectname._&this_page);

/* subroutine for no data available for report page */
%NOPAGE:
 
%end;
 
%FINAL:
footnote ;
 
%mend generate_report; /* end reportbody macro */
 
%generate_report;
 

%mend regrpt_capital_crsa_crd4;
