/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 * NAME: regrpt_capital_crsec_irb_crd4.sas
 *
 * PURPOSE: Runs regulatory report for securitization reports - IRB
 * 
 * NOTES: 
 * Created: 30/01/2014
 *****************************************************************************/
%macro regrpt_capital_crsec_irb_crd4;

/* Create Data for Report */
%regrpt_d0_capital_crsec_irb_crd4;
%get_classdepth;
/* Creates basic CAPITAL_CRSEC_IRB template report */  
%macro regulatory_reportcontents (dsn);         

%let style_type=%str(style=Data[Tagattr='format:#,##0.00' ]);  
data work.&dsn ;
 set work.&dsn ;
 outv_rw_sfa=.;
run;
proc report data=work.&dsn nowd missing LS=160 PS=50 /*SPLIT="*" */ contents=''
    style(column)={ bordercolor=#FAF8ED cellspacing=0}
    style(header)={ cellheight=0  cellspacing=0 };
column
/*(*/
label
        outv_tranche_nominal_amt
        ("&syn_sec"

        (outv_sec_funded_amt
        ("&outv_outflow_irb_amt" outv_sec_unfunded_amt)
        outv_retained_amt)
        )
        ("&sec_pos" outv_exposure_orig_amt)
        
        ("&credit_risk_mit_tech"
        (outv_sec_unfunded_und_amt
        outv_sec_funded_und_amt)
	 ("SUBSTITUTION OF THE EXPOSURE DUE TO CRM"
		 TOTAL_OUTFLOW_CRM_SUB_AMT
		 TOTAL_INFLOW_CRM_SUB_AMT
		)
        )
        
        outv_pre_ccf_after_crm
        outv_fin_coll_adj_val_amt
        outv_exposure_adj_amt
        ("&_breakdown_full_exp_val"
        (outv_exp_adj_ccf_0
        outv_exp_adj_ccf_0_20
        outv_exp_adj_ccf_20_50
        outv_exp_adj_ccf_50_100))

/*        ( "&outv_ead_crequ"*/
		( "&SECIRB_EXP_VAL"
        (outv_ead
        (outv_ded_own_funds
        outv_sub_rw)))

        /*Unique to IRB*/
        
        ("&_breakdown_by_exp_val_st_rw"
        ("&SECIRB_RBM_CQS"
        (
        		EAD_RW_7  
				EAD_RW_8  
				OUTV_EAD_RW_10 
				EAD_RW_12 
				EAD_RW_20 
				outv_ead_rw_35  
				ead_rw_60       
				outv_ead_rw_100 
				outv_ead_rw_250 
				outv_ead_rw_425 
				outv_ead_rw_650 
				outv_ead_rw_1250_rated
        ))

        ("&SECIRB_EAD_RW_1250" (    
        outv_ead_rw_1250_unrated))
        )

        ( "&sfm"
        (outv_ead_sfa
        outv_rw_sfa
))

          ("&SEC_SA_LOOK_THRU" (outv_ead_lookthrough_amt
        	EAD_LOOK_THRU_AVG_RW_PCT))

        ("&int_assm_app" 
        (EAD_SEC_IAA_AMT
    EAD_IAA_AVG_RW_PCT
))

        outv_value_adj_amt

        /*Unique to IRB*/
       (" &SECIRB_RW_EXP_AMT" outv_rwa
		RWA_SYNTHETIC_SEC_AMT)
		RWA_ADJ_INFRINGEMENT_AMT
		RWA_ADJ_MATURITY_MISMATCH_AMT
		("&SECIRB_TOT_RWA_EXP_AMT "
		RWA_BEFORE_CAP_AMT
	    RWA_AFTER_CAP_AMT)

        RWA_SEC_OUTFLOW_OTHER_EXP_AMT

/*)*/
;

        define label                            / display      style=[font_weight=bold  ] width=150                       " ";
        define outv_tranche_nominal_amt         / display       format=&FORMAT_NUMERIC          "&SECIRB_TOT_AMT_EXP_ORIG";
        define outv_sec_funded_amt              / display       format=&FORMAT_NUMERIC          "&SECIRB_SYNT_SEC_FUNDED_CRD_PROT";
        define outv_sec_unfunded_amt            / display       format=&FORMAT_NUMERIC          "&SECIRB_SEC_SYNT_UNFND_PROT";
        define outv_retained_amt                / display       format=&FORMAT_NUMERIC          "&SECIRB_AMT_REPUR_ADJ_VAL";
        define outv_exposure_orig_amt           / display       format=&FORMAT_NUMERIC          "&SECIRB_ORIG_EXP_PRE_CON_FACTR";

        define outv_sec_unfunded_und_amt        / display       format=&FORMAT_NUMERIC          "&SECIRB_CRM_UNFUND_ADJ_VAL ";
        define outv_sec_funded_und_amt          / display       format=&FORMAT_NUMERIC          "&SECIRB_CRM_FUND_CRED_PROT";     
	    	define TOTAL_OUTFLOW_CRM_SUB_AMT    / display       format=&FORMAT_NUMERIC         "&SECIRB_CRM_TO_OUTFLOW";	
		    define TOTAL_INFLOW_CRM_SUB_AMT     / display       format=&FORMAT_NUMERIC         "&SECIRB_CM_TOT_INFLOW"	;
        define outv_pre_ccf_after_crm           / display       format=&FORMAT_NUMERIC          "&SECIRB_EXP_AFT_CTM";

        define outv_fin_coll_adj_val_amt        / display       format=&FORMAT_NUMERIC          "&SECIRB_CRM_CVAM";
        define outv_exposure_adj_amt            / display       format=&FORMAT_NUMERIC          "&SECIRB_FULLY_ADJ_EXP_VAL ";
        define outv_exp_adj_ccf_0               / display       format=&FORMAT_NUMERIC          "&SECIRB_CCF_0_PCT "; 
        define outv_exp_adj_ccf_0_20            / display       format=&FORMAT_NUMERIC          "&SECIRB_CCF_20_PCT";
        define outv_exp_adj_ccf_20_50           / display       format=&FORMAT_NUMERIC          "&SECIRB_CCF_50_PCT";
        define outv_exp_adj_ccf_50_100          / display       format=&FORMAT_NUMERIC          "&SECIRB_CCF_100_PCT";

        define outv_ead                         / display       format=&FORMAT_NUMERIC          " &SECIRB_EXP_VAL";
        define outv_ded_own_funds               / display       format=&FORMAT_NUMERIC          "&SECIRB_DEDC_OWN_FNDS";
        define outv_sub_rw                      / display       format=&FORMAT_NUMERIC          "&SECIRB_SUBJ_RW ";

/***For IRB***/
        define EAD_RW_7                         / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_1";
        define EAD_RW_8                         / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_2";
        define OUTV_EAD_RW_10                   / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_3";
        define EAD_RW_12                        / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_4";
        define EAD_RW_20                        / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_5";
        define outv_ead_rw_35                   / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_6";
        define ead_rw_60                        / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_7";
        define outv_ead_rw_100                  / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_8";
        define outv_ead_rw_250                  / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_9";
        define outv_ead_rw_425                  / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_10";
        define outv_ead_rw_650                  / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_11";

        define outv_ead_rw_1250_rated           / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_OTHER";
        define outv_ead_rw_1250_unrated         / display       format=&FORMAT_NUMERIC          "&SECIRB_CQS_UNRATED";

        define outv_ead_sfa                     / display       format=&FORMAT_NUMERIC          " ";
        define outv_rw_sfa                      / display       format=&FORMAT_NUMERIC          "&avg_rw  ";
        define outv_ead_lookthrough_amt         / display       format=&FORMAT_NUMERIC          " ";
        define EAD_LOOK_THRU_AVG_RW_PCT	        / display       format=&FORMAT_NUMERIC          "&avg_rw";
        define EAD_SEC_IAA_AMT                  / display       format=&FORMAT_NUMERIC          " ";
        define EAD_IAA_AVG_RW_PCT                      / display       format=&FORMAT_NUMERIC          "&avg_rw ";

        define outv_value_adj_amt               / display       format=&FORMAT_NUMERIC          "&SECIRB_RED_RW_EXP_AMT_ADJ_PRO";       
/************/

        define outv_rwa                         / display        format=&FORMAT_NUMERIC         /* "&SEC_SA_RW_EXP_AMT" */ "";
        define RWA_SYNTHETIC_SEC_AMT            / display        format=&FORMAT_NUMERIC          "&SECIRB_RW_EXP_AMT_SEC_OFWHICH";
        define RWA_ADJ_INFRINGEMENT_AMT         / display        format=&FORMAT_NUMERIC          "&SECIRB_DUE_DELIGNCE";
        define  RWA_ADJ_MATURITY_MISMATCH_AMT   / display        format=&FORMAT_NUMERIC          "&SECIRB_ADJ_RW_MAT_MISMATCH";
        define RWA_BEFORE_CAP_AMT               / display        format=&FORMAT_NUMERIC          "&SECIRB_RWA_BEFORE_CAP";
        define RWA_AFTER_CAP_AMT                / display        format=&FORMAT_NUMERIC          "&SECIRB_RWA_AFT_CAP";
/* Memorandum Items */
        define RWA_SEC_OUTFLOW_OTHER_EXP_AMT    / display        format=&FORMAT_NUMERIC          "&SECIRB_MEMO_RWA_SEC_EXP";


      /*  title "&regrpt_crsec_irb_title";
        title2 "&secz_type: &&sec&currpage" ;*/
  run;

%mend regulatory_reportcontents; /* end reportcontents */

%macro regulatory_reportbody ;

/* Test for data before producing report */
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.page1))
  or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
        %print_msg(warning,3,10);
  %print_msg(warning,3,15);
  %return;
    %goto FINAL;
%end;

/* Iterate thought the number of sec types and produce report pages */

%do currpage=1 %to &numberofsec;

/* If data is not available for the report page then do no run report content */
  %if NOT %sysfunc(exist(work.page&currpage)) %then %do;
      %print_msg(warning,3,19);
      %print_msg(note,3,20);
      %goto NOPAGE;
  %end; 
  
  %if &APPLY_CCF_AFTER_CRM EQ NO %then %do;
     %let ccf_crm_msg=%print_msg(,3,111,1); 
     
     footnote "&ccf_crm_msg";
  %end;

  /* Produce the report */
/* Displays the titles for the cross-classification variables */
%if %upcase(&REPORT_TYPE)=%upcase(XLS) %then %do;
	/*
	data _null_;
		ID = open("report_pages");
		Var_name = upcase(varname(ID,2));
		RC = close(ID);
		call symputx("class_sa_lev1",var_name);
	run;
	*/ 
/*   data _null_;*/
/*    set report_pages(firstobs=&this_page obs=&this_page);*/
	/* call symputx("sheet_nm",put(&class_sa_lev1,$aggregate.));*/ 
/*	call symputx("sheet_nm",&this_page);*/
	
/*   run;*/

   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="CRSEC-IRB"
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO");

%end;  
  %regulatory_reportheaders (page&currpage);
  %regulatory_reportcontents (page&currpage);
  /* subroutine for no data available for report page */
  %NOPAGE:      

%end; /* end report page generation from cross classes */

%FINAL: 
footnote ;

%mend regulatory_reportbody; /* end reportbody macro */                            

/* Invoke the report */
%regulatory_reportbody;





%mend regrpt_capital_crsec_irb_crd4;
