/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_capital_LR4.sas
*
* PURPOSE: Creates report for the Leverage Ratio report
*
*
*   USAGE: This is a draft
*
*   NOTES: Modified for V4.8
*   Macro Options:
*****************************************************************************/
 
%macro regrpt_capital_lr4;

/* Create Data for Report */
 proc format ;
 	 value CORP_rank_A
 	  240="CORP_FINANCIAL"
 	  250="CORP_NONFINANCIAL"
 	  260="CORP_NONFINANCIAL"
 	  270="CORP_NONFINANCIAL"
 	  ;
 	 run; 
 proc format ;
 	 value CORP_rank_b
 	  240="+"
 	  250="+"
 	  260="CORP_SME"
 	  270="CORP_NONSME"
 	  ;
 	 run; 
 
%regrpt_d0_capital_lr4;
 
/* Creates basic  template report */
%macro report_page_1 (dsn);
 
proc report data=&dsn nowd missing LS=160 PS=50 SPLIT="*" contents=""
style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={cellheight=0  cellspacing=0 };


column  
     CLASS_CR_LR4
	 ("COLUMN"
	 OUTV_EAD
	 OUTV_RWA);
        
    define CLASS_CR_LR4                /display /*format=$exp_type.*/      "Off-balance sheet items, derivatives, SFTs and trading book"              ;
    define OUTV_EAD            /display format=&FORMAT_VALUE       "Leverage Ratio Exposure Value"      ;
    define OUTV_RWA            /display format=&FORMAT_VALUE       "RWA"      ;
     
    compute CLASS_CR_LR4;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#ffffff]");
       end;
    endcomp;

run;
 
 
%mend report_page_1;

%macro report_page_2 (dsn);
 
proc report data=&dsn nowd missing LS=160 PS=50 SPLIT="*" contents=""
style(column)={ /*bordercolor=#FAF8ED*/ cellspacing=0}
style(header)={cellheight=0  cellspacing=0 };


column  
     CLASS_CR_LR4
	 ("COLUMN"
	 	("Leverage Ratio Exposure Value "
	 OUTV_EAD_STD_AMT
	 OUTV_EAD_IRB_AMT)
	  ("RWAs"
	 OUTV_RWA_STD_AMT
	 OUTV_RWA_IRB_AMT)
	 ) ;
        
    define CLASS_CR_LR4                  /display /*format=$exp_type.*/      "Other non-trading book exposures"              ;
    define OUTV_EAD_STD_AMT              /display format=&FORMAT_VALUE       "SA Exposures"      ;
    define OUTV_EAD_IRB_AMT              /display format=&FORMAT_VALUE       "IRB Exposures"      ;
    define OUTV_RWA_STD_AMT              /display format=&FORMAT_VALUE       "SA Exposures"       ;
    define OUTV_RWA_IRB_AMT              /display format=&FORMAT_VALUE       "IRB Exposures"       ;
     
    compute CLASS_CR_LR4;
       count+1;
       if mod(count,2) then do;
         call define(_row_,"Style", "Style=[background=#ffffff]");
       end;
    endcomp;

run;
 
 
%mend report_page_2;
 
 
%macro generate_report;
 
%if NOT %sysfunc(exist(work.current_regulatory)) or NOT %sysfunc(exist(work.&regprojectname._RPT_SET2)) NOT %sysfunc(exist(work.&regprojectname._RPT_SET1))
or %upcase(&SYSTEM_FATAL_ERROR) = %upcase (Y) %then %do;
%print_msg(warning,3,10);
%print_msg(warning,3,15);
%regulatory_reportnopage();
%return;
%goto FINAL;
%end;
 
/* Get number of report pages */
 
 
/*Change to &pages */
/*If data is not available for the report page then do no run report content */
%if NOT %sysfunc(exist(work.&regprojectname._RPT_SET2)) %then %do;
%print_msg(warning,3,19);
%print_msg(note,3,20);
%regulatory_reportnopage();
%goto NOPAGE;
%end;
%if &REPORT_TYPE=XLS %then %do;
   ods tagsets.ExcelXP_Mod 
 		options(
		sheet_name="&rpt_cd."
		sheet_interval='none' autofit_height="yes");
		%_Report_Title(REPORT_TITLE_CD=rpt_cd2,REPORT_TITLE=rpt_title1);
   ods tagsets.ExcelXP_Mod 
 		options(
		autofit_height="NO"); 
%end; 
 
 
%report_page_1 (work.&regprojectname._RPT_SET1);
%report_page_2 (work.&regprojectname._RPT_SET2);
 
/* subroutine for no data available for report page */
%NOPAGE:
 

 
%FINAL:
footnote ;
 
%mend generate_report; /* end reportbody macro */
 
%generate_report;

%mend regrpt_capital_lr4;
