/*****************************************************************************
* Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_capital_crsa_crd4.sas
*
* PURPOSE: Creates data for the CR SA report
*
*
*   USAGE:
*
*   NOTES: Modified for V4.8
*   Macro Options:
*****************************************************************************/

%macro regrpt_d0_capital_crsa_crd4;

/*---------------------------------------------------------------------------
* Step 0.
* Initialize parameters and temporary code storage
* -------------------------------------------------------------------------*/
%global numccfbuckets;
%let numccfbuckets=6;
%let class_depth=2;
%let number_of_headers = %eval(&class_depth);
%let starting_class = %eval(1 + &class_depth);
%let fact_table=regulatory;;
%let report_name=CRSA; 
 
 
filename page catalog 'work.temp.pages.source';
filename lgd catalog 'work.temp.lgd.source';
filename ccf catalog 'work.temp.ccf.source';
 
/* 
proc format;
value $rw_fmt   'RW_SA_0'   =   "   0%                                                 "
            'RW_SA_2'  		=   "   2%                                                 "
			'RW_SA_10'  	=   "   10%                                                "
            'RW_SA_20'  	=   "   20%                                                "
            'RW_SA_35'  	=   "   35%                                                "
            'RW_SA_50'  	=   "   50%                                                "
            'RW_SA_70'  	=   "   70%                                                "
			'RW_SA_75'  	=   "   75%                                                "
            'RW_SA_100' 	=   "   100%                                               "
            'RW_SA_150' 	=   "   150%                                               "
            'RW_SA_200' 	=   "   200%                                               "
            'RW_SA_250' 	=   "   250%                                               "
            'RW_SA_1250' 	=   "   1250%                                              ";
run;
 */
proc format;
value $rw_ofwhich   'PAST_DUE'  =   "   &ofwhichpastdue                                    "
            'COMM_REAL_EST' =   "   &comm_realestate                                   "
            'REAL_EST'  =   "   &_realestate                                       "
            'NO_CR_ASSESS'  =   "   &_nocreditassessment                               "
        ;
run;
 
proc format;
value $exptype_ofwhich   
			'SME'  =   "   &_ofwhichsme                                    "
            'RME' =   "   &_ofwhichrme                                   "
            'CCP'  =   "   &_ofwhichccp                                  "
            'SME_SUPPORT'  =   "&CRSA_L_30 "
			
        ;
run;
 
proc format;
value $memo_rank   
			'CRE_290'  		=   'COMM_REAL_EST' 						/*Commercial Real Estate*/
            'RW_SA_100_300' =   'PAST_DUE'
			'RRE_310'		=	'REAL_EST'							/* Other Mortgage Exposures */
			'RW_SA_150_320'	=	'PAST_DUE'
        ;
run; 
 
%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;
 
/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=&fact_table);
 
data work.current_regulatory;
set work.current_regulatory;
label outv_ccf1 = "0%";
label outv_ccf2 = "20%";
label outv_ccf3 = "50%";
label outv_ccf4 = "100%";
label outv_ccf5 = "&regport_undef";
run;

/*Create Report_line_seq_CRSA dataset*/

    proc sort   data=rd_root.report_line_seq (WHERE=(report_name="&report_name" and CONFIG_ID = "&CONFIG_SET" )) 
            out=work.report_line_seq_&report_name ;
            by report_line_no;
    run;

/* Create sequence dataset for Totals and Of which */
data _all_type_rank (KEEP=REPORT_LINE_NO VARIABLE_VALUE _all_type_table);
	set work.report_line_seq_&report_name ;
	where variable_name='TOTAL_OFWHICH';
	_all_type_table='_all_type_'||compress(report_line_no);
RUN;
data _all_type_rank_usage (KEEP=REPORT_LINE_NO VARIABLE_VALUE _all_type_table);
	set work.report_line_seq_&report_name ;
	where variable_name='TOTAL_OFWHICH_USAGE';
	_all_type_table='_all_type_'||compress(report_line_no);
RUN;

/* Create Sequence dataset for Risk Weights */
data RW_rank (KEEP=REPORT_LINE_NO VARIABLE_VALUE rw_type_table);
	set work.report_line_seq_&report_name ;
	where variable_name='RISK_WEIGHTS';
	rw_type_table='_rw_type_'||compress(report_line_no);
RUN;


/* Create sequence dataset for Exposure type Of which */
data _exp_type_rank1 (KEEP=REPORT_LINE_NO VARIABLE_VALUE _exp_type_table);
	set work.report_line_seq_&report_name ;
	where variable_name='EXP_OFWHICH';
	_exp_type_table='_exp_type_'||compress(report_line_no);
RUN;

/* Create sequence dataset for Memorandum Items */
data _memo_rank (KEEP=REPORT_LINE_NO VARIABLE_VALUE memo_table memo_product_class);
	set work.report_line_seq_&report_name ;
	where variable_name='MEMO_OFWHICH';
	memo_table='_memo_type_'||compress(report_line_no);
	_memo_class = compress(variable_value || "_" || report_line_no);
	memo_product_class = put(_memo_class,$memo_rank.);
	mvar=compress("_"||put(report_line_no,8.));
	call symputx(mvar,memo_product_class);	
RUN;


%macro create_class_column (class_var=,new_class_var=,whereclause=,rptrank=,newline=,hier_order=,dsn=);
/*---------------------------------------------------------------------------
* Step 3.
* Create the classification column that is used in the report
* This column runs down the left-hand side of the report
* Create a rank variable to help sort in the order specified by the report
* -------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------
* Get the first line in the report - represents everything rolled up
* -------------------------------------------------------------------------*/
 
%if &class_var=TOTALS %then %do;

	
    data work._all  (where=(&new_class_var ne ""));
        set work.current_&fact_table
        (where=(&rptvar3 eq '+' %do ii=4 %to &Nrptvar; and &&RPTVAR&ii eq '+' %end;));
        attrib &new_class_var length = $256;
            &new_class_var = "&TOTAL_EXPOSURES";
            rank=&rptrank;
    run;
 
/*---------------------------------------------------------------------------
* Create an empty line as a header for some items
* -------------------------------------------------------------------------*/
 
%end;%else
%if &class_var=LINE %then %do;
    data work.newline;
        attrib &new_class_var length = $256 ;
        &new_class_var="&newline";
        BLANK_LINE='YES';
        rank=&rptrank;
    run;
 
    data work.&dsn;
        set work.&dsn work.newline;
    run;
 
%end;%else
 
/*---------------------------------------------------------------------------
* Create a breakdown by exposure type - On,Off balance,Derviatives,Repos etc
* -------------------------------------------------------------------------*/
%if &class_var=EXP_TYPE %then %do;
	data _exp_type_rank (KEEP=REPORT_LINE_NO VARIABLE_VALUE);
	set work.report_line_seq_&report_name ;
	where variable_name='EXP_TYPE';
	RUN;
	
    data work._exp_type (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
        if &rptvar3 NE '+' %do ii=4 %to &Nrptvar; and &&RPTVAR&ii eq '+' %end; then do;
            &new_class_var = &rptvar3;
			rank=&rptrank;
        end;
    run;
	proc sql;
		create table _exp_type1 as
		select a.*,b.report_line_no as rank1 from _exp_type a, _exp_type_rank b
		where a.CLASS_CR_SA=b.VARIABLE_VALUE;
	quit;
	data _exp_type (rename=(rank1=rank));
	set _exp_type1(drop=rank);
	run;
	
	
%end;%else
/*---------------------------------------------------------------------------
* Create a breakdown by Risk Weights
* -------------------------------------------------------------------------*/
%if &class_var=RISK_WEIGHTS %then %do;
    data work._rw_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
            &new_class_var = put (&rptvar5,$rw_fmt.);
	rank=&rptrank;
    where (&rptvar5 in &whereclause) and &rptvar3 eq '+' and &rptvar4 eq '+'
    %do ii=6 %to &Nrptvar; and &&RPTVAR&ii eq '+' %end;;
    
    run;
%end;
 
%else %if &class_var=RW_OFWHICH %then %do;
    data work._rw_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
            &new_class_var = put (&rptvar6,$rw_ofwhich.);
            rank=&rptrank;
    where (&rptvar5 in &whereclause) and &rptvar3 eq '+' and &rptvar4 eq '+' and
    &rptvar6 in ('PAST_DUE','COMM_REAL_EST','REAL_EST','NO_CR_ASSESS')
    %do ii=7 %to &Nrptvar; and &&RPTVAR&ii eq '+' %end;;
    
    run;
%end;

/*---------------------------------------------------------------------------
* Create a breakdown by Total exposure type 
* -------------------------------------------------------------------------*/

%else %if &class_var=TOTAL_OFWHICH %then 
%do;

    data work._all_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
        rank=&rptrank; 
	%if &whereclause="SME" %then 
	%do;
        &new_class_var = put (&rptvar7,$exptype_ofwhich.);
		where (&rptvar7 in &whereclause) and &rptvar2 in ('+','CORPORATES','RETAIL','RETAIL_SEC_IMOV') 
		%do ii=3 %to 6; 
			and	&&RPTVAR&ii eq '+'
		%end;
		%do ii=8 %to &Nrptvar; 
			and	&&RPTVAR&ii eq '+'
		%end;;
	%end;;
    
	%if &whereclause="RME" %then 
	%do;
        &new_class_var = put (&rptvar8,$exptype_ofwhich.);
		where (&rptvar8 in &whereclause) and &rptvar2 in ('+','RETAIL_SEC_IMOV')
		%do ii=3 %to 7; 
			and	&&RPTVAR&ii eq '+'
		%end;
		%do ii=9 %to &Nrptvar; 
			and	&&RPTVAR&ii eq '+'
		%end;;
	%end;;

	%if &whereclause="SME_SUPPORT" %then 
	%do;
        &new_class_var = put (&rptvar9,$exptype_ofwhich.);
		where (&rptvar9 in &whereclause) and &rptvar2 in ('+','CORPORATES','RETAIL','RETAIL_SEC_IMOV') 
		%do ii=3 %to 8; 
			and	&&RPTVAR&ii eq '+'
		%end;
		%do ii=10 %to &Nrptvar; 
			and	&&RPTVAR&ii eq '+'
		%end;;
	%end;;
    run;
%end;
%else %if &class_var=TOTAL_OFWHICH_USAGE %then 
%do;

    data work._all_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
            &new_class_var = &rptvar11;
            rank=&rptrank; 
    where (&rptvar11 in &whereclause) and &rptvar3 eq '+' 
	%do ii=4 %to 10; 
		and	&&RPTVAR&ii eq '+'
	%end;;
    
    run;
%end;


/*---------------------------------------------------------------------------
* Create a breakdown by exposure type - CCP
* -------------------------------------------------------------------------*/

%else %if &class_var=EXP_OFWHICH %then %do;

    data work._exp_type_&rptrank (where=(&new_class_var ne ""));
        set work.current_&fact_table;
        attrib &new_class_var length = $256 ;
            &new_class_var = put (&rptvar7,$exptype_ofwhich.);
            rank=&rptrank; 
    where (&rptvar3 in &whereclause) %do ii=4 %to 8; and &&RPTVAR&ii eq '+' %end; and &rptvar10 eq 'CCP'
    %do ii=11 %to &Nrptvar; 
		and	&&RPTVAR&ii eq '+'
	%end;;
    
    run;
%end;

/*---------------------------------------------------------------------------
* Memorandum Items
* -------------------------------------------------------------------------*/
%else %if &class_var=MEMO_OFWHICH %then 
%do;
	%if (&&_&rptrank = COMM_REAL_EST OR &&_&rptrank = REAL_EST ) %then 
	%do;
		data work._memo_type_&rptrank (where=(&new_class_var ne ""));
			set work.current_&fact_table;
			attrib &new_class_var length = $256 ;
				&new_class_var = "&&CRSA_L_&rptrank";
				rank=&rptrank; 
		where (&rptvar8 in &whereclause) and &rptvar3 eq '+' and &rptvar4 eq '+'  and &rptvar5 eq '+' and &rptvar7 eq '+' and &rptvar6 eq 'COMM_REAL_EST'   
		%do ii=9 %to &Nrptvar; 
			and	&&RPTVAR&ii eq '+'
		%end;;
		
		run;
	%end;
	%else %if &&_&rptrank=PAST_DUE %then
	%do;
		data work._memo_type_&rptrank (where=(&new_class_var ne ""));
			set work.current_&fact_table;
			attrib &new_class_var length = $256 ;
				&new_class_var = "&&CRSA_L_&rptrank";
				rank=&rptrank; 
		where (&rptvar5 in &whereclause) and &rptvar4 eq '+' and &rptvar3 eq '+' and &rptvar2 IN ("&&_&rptrank",'+') AND &rptvar6 eq 'PAST_DUE'  
		%do ii=7 %to &Nrptvar; 
			and	&&RPTVAR&ii eq '+'
		%end;;
		
		run;
	%end;
%end;

%mend;

/*---------------------------------------------------------------------------
* TOTAL EXPOSURES SECTION
* -------------------------------------------------------------------------*/

%create_class_column (class_var=TOTALS,new_class_var=CLASS_CR_SA,whereclause=,rptrank=10);

/*---------------------------------------------------------------------------
* OF WHICH SECTION UNDER TOTAL EXPOSURES
* -------------------------------------------------------------------------*/
data _null_;
set _all_type_rank;
call execute ('%create_class_column (class_var=TOTAL_OFWHICH,new_class_var=CLASS_CR_SA,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;

data _null_;
set _all_type_rank_usage;
call execute ('%create_class_column (class_var=TOTAL_OFWHICH_USAGE,new_class_var=CLASS_CR_SA,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;

/*---------------------------------------------------------------------------
* TOTAL EXPOSURES BY EXPOSURE TYPE SECTION
* -------------------------------------------------------------------------*/

%create_class_column (class_var=EXP_TYPE,new_class_var=CLASS_CR_SA,whereclause=ALL,rptrank=11);

/* OF WHICH SECTION UNDER TOTAL BY EXPOSURE TYPE */
data _null_;
set _exp_type_rank1;
call execute ('%create_class_column (class_var=EXP_OFWHICH,new_class_var=CLASS_CR_SA,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;

/*---------------------------------------------------------------------------
* TOTAL EXPOSURES BY RISK WEIGHT SECTION
* -------------------------------------------------------------------------*/

data _null_;
set RW_rank;
call execute ('%create_class_column (class_var=RISK_WEIGHTS,new_class_var=CLASS_CR_SA,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;

/*---------------------------------------------------------------------------
* Memorandum Items
* -------------------------------------------------------------------------*/
/* MEMORANDUM ITEMS */
data _null_;
set _memo_rank;
call execute ('%create_class_column (class_var=MEMO_OFWHICH,new_class_var=CLASS_CR_SA,whereclause=("'||compress(variable_value)||'"),rptrank='||report_line_no||')');
run;
/*---------------------------------------------------------------------------
* Merge all results back into one data table
* -------------------------------------------------------------------------*/

/* Total Exposure and of which tables */
proc sql noprint;
select _all_type_table into: _all_type separated by ' '
from _all_type_rank;
quit;

proc sql noprint;
select _all_type_table into: _all_type_usage separated by ' '
from _all_type_rank_usage;
quit;

proc sql noprint;
select _exp_type_table into: _exp_type_ separated by ' '
from _exp_type_rank1;
quit;

/* Risk Weight Type tables */
proc sql noprint;
select RW_type_table into: rw_sa_table separated by ' '
from RW_rank;
quit;

/* Memorandum tables */
proc sql noprint;
select memo_table into: memo_sa_table separated by ' '
from _memo_rank;
quit;

/* Final Merge */
data work.report_data;
set work._all &_all_type &_all_type_usage work._exp_type &_exp_type_ &rw_sa_table &memo_sa_table;
run;
 
%macro createReportPages;
 
 
 
 
/*- Create empty lines in the report as needed for headers -*/
 
/*
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_SA,whereclause=,rptrank=19,
             newline=&_breakdown_exptype,dsn=report_data);

%create_class_column (class_var=LINE,new_class_var=CLASS_CR_SA,whereclause=,rptrank=31,
             newline=&_breakdown_exp_ccr,dsn=report_data);

 
 
%create_class_column (class_var=LINE,new_class_var=CLASS_CR_SA,whereclause=,rptrank=81,
             newline=&_breakdown_riskweights,dsn=report_data);
*/ 

%create_class_column (class_var=LINE,new_class_var=CLASS_CR_SA,whereclause=,rptrank=999,
             newline=&_breakdown_memorandum,dsn=report_data);

 
 
/*- get the report data into the right order for the report -*/
    proc sort data=work.report_data;
        by rank;
        where rank ne .;
    run;
 
    proc sort   data=work.report_data (WHERE=(blank_line NE 'yes') keep=&rptvar1 &rptvar2 blank_line) nodupkeys
            out=report_pages;
            by &rptvar1 &rptvar2;
			where &rptvar1='+';			
    run;
 
     proc sort   data=work.report_data (WHERE=(blank_line NE 'yes') keep=&rptvar1 &rptvar2 blank_line) nodupkeys
            out=report_pages_orig;
            by &rptvar1 &rptvar2;
    run;
	
    proc sort   data=rd_root.report_line_seq (WHERE=(report_name="&report_name" and CONFIG_ID = "&CONFIG_SET" )) 
            out=work.report_line_seq_&report_name (rename=(report_line_no=rank));
            by report_line_no;
    run;
 
 
/*---------------------------------------------------------------------------
* Create seperate page tables for the report
* Also, create CCF output values using the CCF cross-classification
* -------------------------------------------------------------------------*/
 
 
    data _null_;
       set work.report_pages (where=(&rptvar1 ne '' or &rptvar2 ne ""));
       file page;
        put "data &regprojectname._"  _n_  ";";
        put ' set work.report_data;';
        put " where &rptvar1 eq '" &rptvar1 "' and &rptvar2 eq '" &rptvar2 "' OR blank_line eq 'YES';";
        put 'run;';

		put 'data work._blank_lines_(drop=OUTV_CCF1 OUTV_CCF2 OUTV_CCF3 OUTV_CCF4 OUTV_CCF5) ;';
		put "set &regprojectname._"  _n_  ";";
		put "where blank_line eq 'YES';";
		put 'run;';
/*		put 'data work._aggregate_ccf_(drop=OUTV_CCF1 OUTV_CCF2 OUTV_CCF3 OUTV_CCF4 OUTV_CCF5) ;';
		put "set &regprojectname._"  _n_  ";";
		put "where &rptvar4 eq '+';";
		put 'run;';
 
		put 'data work._blank_lines_(drop=OUTV_CCF1 OUTV_CCF2 OUTV_CCF3 OUTV_CCF4 OUTV_CCF5) ;';
		put "set &regprojectname._"  _n_  ";";
		put "where blank_line eq 'YES';";
		put 'run;';
		 
		put 'proc sort data=work._aggregate_ccf_;';
		put 'by CLASS_CR_SA;';
		put 'run;';
		 
		put 'proc sql;';
		put 'create table work._other_ccf_ as';
		put 'select f1.*, f2.OUTV_CCF1, f2.OUTV_CCF2, f2.OUTV_CCF3, f2.OUTV_CCF4, f2.OUTV_CCF5';
		put 'from work._aggregate_ccf_ as f1,';
		put "&regprojectname._"  _n_  " as f2";
		put 'where';
		put 'f1.&rptvar1 = f2.&rptvar1 and';
		put 'f1.&rptvar2 = f2.&rptvar2 and';
		put 'f1.&rptvar3 = f2.&rptvar3 and';
		put 'f1.&rptvar5 = f2.&rptvar5 and';
		put 'f1.&rptvar6 = f2.&rptvar6 and';
		put 'f1.&rptvar7 = f2.&rptvar7 and';
		put 'f1.&rptvar8 = f2.&rptvar8 and';
		put 'f1.&rptvar9 = f2.&rptvar9';
		put 'order by class_cr_sa, rank ;';
		put 'quit;';
		 
		put 'proc summary data=work._other_ccf_;';
		put 'by class_cr_sa rank ;';
		put 'var OUTV_CCF1 OUTV_CCF2 OUTV_CCF3 OUTV_CCF4 OUTV_CCF5;';
		put 'output out=work._ccf_values_ max(OUTV_CCF1 OUTV_CCF2 OUTV_CCF3 OUTV_CCF4 OUTV_CCF5)= OUTV_CCF1-OUTV_CCF5;';
		put 'run;';
		 
		put "data &regprojectname._"  _n_  ";";
		put 'merge work._aggregate_ccf_';
		put 'work._ccf_values_(keep=CLASS_CR_SA OUTV_CCF1 OUTV_CCF2 OUTV_CCF3 OUTV_CCF4 OUTV_CCF5);';
		put 'OUTV_EAD_ROLLUP = sum(OUTV_FULLY_ADJ_EXP_AMT, -OUTV_CCF1, -0.8*OUTV_CCF2, -0.5*OUTV_CCF3);';
		put 'by CLASS_CR_SA;';
		put 'run;';
*/
		 
		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  ";";
		put "if PROJECT_SK=. then delete;";
		put 'run;';
		 
		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  " /* _blank_lines_*/ ;";
		put 'run;';
 
		put "proc sort  data=&regprojectname._"  _n_  ";";
		put 'by rank;run;';

		put "data &regprojectname._"  _n_  ";";
		put "merge report_line_seq_&report_name. &regprojectname._"  _n_ ";";
		put 'by rank;';
		put 'run;';

		put "data &regprojectname._"  _n_  ";";
		put "set &regprojectname._"  _n_  ";";
		put 'if missing(class_cr_sa) and not missing(report_line_id)then class_cr_sa=symget(report_line_id);';
		put 'run;';
  
run;
run;
 
%inc page;
 
%mend createReportPages;
%createReportPages;
 
%mend regrpt_d0_capital_crsa_crd4;
