/*****************************************************************************
 * Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *    NAME: regrpt_d0_capital_crsec_sa_crd4
 *
 * PURPOSE: Creates data for Regulatory report template for Securitization report - SA
 *                        
 *
 *   NOTES: 06/29/07 - Creation
 *          
 *
 *****************************************************************************/
%macro regrpt_d0_capital_crsec_sa_crd4;

%global numberof_rw rpath rwvar subclassvar pastduevar ratingvar where numberofsec numberofexptype;

%macro capital_crsec_sa_etl;

/**************************************************************/
%macro create_rowwhere(sectype, page);

data work._rowwhere_clause_&page (keep=where_clause3 rownum label );
        set work._rowcond;
length where_clause3 $500;

label = symget( compress("CRSEC_SA_L_" || put(rownum,8.)));
RANK=rownum;

where_clause3= "&rptvar1 eq '+'"
%do numcc=2 %to &nrptvar-3;
  || " and &&rptvar&numcc eq '"|| trim(&&rptvar&numcc) || "'"
%end;
|| " and &&rptvar6 eq '+' and &&rptvar7 eq '+' and &&rptvar8 eq '+';";
run;

%mend create_rowwhere;

%macro get_rows_by_cqs_incep(rowclause);
/*This macro rearranges the CQS columns according to CQS at inception for reporting of 
rows 250 to 290 */

data hold1;
set current_regulatory;
where &rowclause;

	OUTV_EAD_RW_20 = 0;								/* Col.220 */
	OUTV_EAD_RW_50 = 0;								/* Col.230 */
	OUTV_EAD_RW_100 = 0;								/* Col.240 */
	OUTV_EAD_RW_350 = 0;								/* Col.250 */
	OUTV_EAD_RW_1250_RATED = 0;				/* Col.260 */
	OUTV_EAD_RW_1250_UNRATED = 0;			/* Col.270 */

    if &rptvar5 = "CQS1" then
        OUTV_EAD_RW_20 = OUTV_EAD;								/* Col.220 */
    else if &rptvar5 = "CQS2" then
        OUTV_EAD_RW_50 = OUTV_EAD;								/* Col.230 */
    else if &rptvar5 = "CQS3" then
        OUTV_EAD_RW_100 = OUTV_EAD;								/* Col.240 */
    else if &rptvar5 = "CQS4" then
        OUTV_EAD_RW_350 = OUTV_EAD;								/* Col.250 */
    else if &rptvar5 = "OTHER" then
        do;
            if RATING_STATUS = "RATED" then
                OUTV_EAD_RW_1250_RATED = OUTV_EAD;				/* Col.260 */
            else OUTV_EAD_RW_1250_UNRATED = OUTV_EAD;			/* Col.270 */
        end;

run;
%mend;

/**************************************************************/
%macro getrows(rowclause, rownum, rowlabel, rank);

%if  &rank ge 250 %then
%do;
	%get_rows_by_cqs_incep(&rowclause);
%end;
%else
%do;
data work.hold1;
        set work.current_regulatory;
        where &rowclause;
run;    
%end;

data work.hold2;
        length label $100;
        label="&rowlabel";
		RANK=&rank;
run;
 
data work.finalrptrowdata_&rownum;
merge
        work.hold1
        work.hold2;
run;

%mend getrows;

/********************************************************************************/
%macro pageto(num);
data work.Page&num;
        set
        %do rn=1 %to 29;
                work.finalrptrowdata_&rn        
        %end;
        ;
run;

proc sort data=rd_root.report_line_Seq(where=(upcase(REPORT_NAME)="CRSEC_SA" and upcase(config_id)=upcase("&config_set"))) out=report_line_seq_secsa;
 by report_line_no;
run;
 
data work.Page&num;
 merge work.Page&num (in=a) report_line_seq_secsa(in=b rename=(REPORT_LINE_NO=RANK ) keep=REPORT_LINE_NO report_line_id) ;
 by RANK;
 if missing(LABEL) and not missing(REPORT_LINE_ID)then LABEL=symget(REPORT_LINE_ID);
 run; 

%mend pageto;

/********************************************************************************/
/* MAIN BODY OF REPORT DATA CREATION*/
/* Recreate user settings from previous run */        
%u00_recreate_macro_definitions;                                       

/* Create SQL views into datamart with no history */
%if %upcase(&usertype) eq MASTER %then 
  %let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
  %else
  %let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username)) ;
 
/* Create SQL views into datamart with no history */

%create_risk_repository_views 
   (Project_name=&projectview,Fact_table=REGULATORY,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
data work.current_regulatory ; 
 set work.current_regulatory ; 
 if OUTV_EAD_LOOKTHROUGH_AMT ne 0 then do;
  EAD_LOOK_THRU_AVG_RW_PCT = EAD_LOOK_THRU_NUMERATOR_AMT/ OUTV_EAD_LOOKTHROUGH_AMT; 
 end;
 if  EAD_SEC_IAA_AMT ne 0 then do;
  EAD_IAA_AVG_RW_PCT = EAD_IAA_NUMERATOR_AMT/ EAD_SEC_IAA_AMT;
 end; 
run; 
/* Check for report data else stop report processing */
%if NOT %sysfunc(exist(work.current_regulatory)) %then %do;
        %let SYSTEM_FATAL_ERROR=Y;
        %print_msg(warning,3,7);        
        %return;
%end;

data _NULL_;
           length path $256;
           path = pathname("work");
           call symput( "rpath", trim(path) );
run;

%create_types_crd4;


/* Creating the where clause for each row based on the possible values of ccvar*/
filename tmprpt1  "&rpath&pathsep.sec_pages_clause.txt";
data _null_;      
 file tmprpt1 ; 
 set work._types_sec1;
 
put '%create_rowwhere("NULL",' _n_ ');';
run;

%inc "&rpath&pathsep.sec_pages_clause.txt";
filename tmprpt1 clear;

%let numberofsec=%attrn(work._types_sec1,NOBS);

data _null_;
%do k=1 %to &numberofsec;

filename tmprpt2  "&rpath&pathsep.sec_row_clause.txt";
data _null_;   
 file tmprpt2 ;  
 set work._rowwhere_clause_&k;

put '%getrows(' where_clause3 ',' _n_ ',' LABEL ',' rownum ');';
run;
%inc "&rpath&pathsep.sec_row_clause.txt";
filename tmprpt2 clear;
%pageto( &k );
%end; /*do loop*/
run;



/* Check to see if the dataset was created */
/* Checks for the project_id if dataset exists */
/* Returns error if either condition is false */
%exist (current_regulatory); 
/*%clean_lib;*/


%mend; /*capital_crequ_sa_etl macro*/

%capital_crsec_sa_etl;
%mend regrpt_d0_capital_crsec_sa_crd4;
