/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_capital_le4_crd4.sas
*
* PURPOSE: Creates data for the LE 4 report
*
*
*   USAGE:
*
*   NOTES: Modified for V4.8
*   Macro Options:
*****************************************************************************/
%macro regrpt_d0_capital_le4_crd4;

%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
%put projectview=&projectview;
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;

/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=Regulatory);

/*EXTRACTING DATA FOR GROUP COUNTERPARTIES*/
proc sort data=current_regulatory ( where=(upcase(&rptvar3.) NOT IN ("+") and upcase(&rptvar2) not in ("MISSING")))
		  out=LE4_GROUP;
by &RPTVAR2 &RPTVAR1;
run;


%if %attrn(LE4_GROUP, NOBS) NE 0 %then %do;
%put "Data for Counterparty Group exist";
/*TRANSPOSING DATASET TO GET MATURITY BUCKETS AS VARIABLE NAMES*/
data _null_;
 call symputx("GROUP_FLAG","YES");
run;

proc transpose data=LE4_GROUP out=le_4_input_grp;

by &RPTVAR2 &RPTVAR1;
id &RPTVAR3;
var  MATURITY_EXP ;
run;


proc summary data=le_4_input_grp   ; 
var _numeric_;
by &rptvar2;
output out=LE_4_INPUT_GRP_FINAL1
	sum(_numeric_)=;
run;

/*ONCE AGAIN USING TRANSPOSE TO GET ALL THE MATURITY BUCKETS AS VARIABLE NAMES*/
PROC TRANSPOSE DATA=rd_map.map_mat_buckets_le_regrpt OUT=map_le(DROP=_NAME_);
ID mat_description;
VAR ;
RUN;

DATA LE4_GRP_FINAL ;
SET  LE_4_INPUT_GRP_FINAL1 map_le;
RUN;

proc sort data=rd_root.counterparty_details(rename=(COUNTERPARTY_GROUP=&rptvar2)) 
		  out=COUNTERPARTY_CHARS
			  (Keep=&rptvar2  CPTY_CD  )nodupkey;
 by &rptvar2;
run;

/*MAP CPTY_CD TO  COUNTERPARTY_GROUP;*/
proc sort data=LE4_GRP_FINAL;
 by &rptvar2;
run;
data LE4_GRP_FINAL;
 merge LE4_GRP_FINAL(in=a) COUNTERPARTY_CHARS(in=b);
 by &rptvar2;
  if a*b;
run;

/*Check if variable UNDEFINED_MATURITY exist or not*/
%let dsid = %sysfunc(open(LE4_GRP_FINAL));
%let le4_grp_var_chk = %sysfunc(varnum(&dsid, UNDEFINED_MATURITY));
%let rc = %sysfunc(close(&dsid));
%put &le4_grp_var_chk;

%if &le4_grp_var_chk eq 0 %then %do;
	DATA LE4_GRP_FINAL ;
	SET  LE4_GRP_FINAL;
	UNDEFINED_MATURITY=.;
	RUN;
%end;
%symdel le4_grp_var_chk /nowarn; 


/*AGGREGATIONS AT GROUP LEVEL COMPLETED*/
%end; /* data for counterparty available*/
%else %do;/* data for counterparty Not Available*/
%put "Data for Counterparty Groups Not available";
data _null_;
 call symputx("GROUP_FLAG","NO");
run;

%end;     /* data for counterparty Not Available*/

/*EXTRACTING DATA FOR INDIVIDUAL COUNTERPARTIES*/
proc sort data=current_regulatory ( where=(upcase(&rptvar3.) NOT IN ("+") and upcase(&rptvar2)  in ("MISSING"))) 
		  out=LE4_IND;
by &RPTVAR2 &RPTVAR1;
run;

/*CODE TO CHECK IF INDIVIDUAL COUNTERPARTIES EXIST OR NOT*/

%if %attrn(LE4_IND, NOBS) NE 0 %then %do;
%put "Data for Individual Exposures found";

data _null_;
 call symputx("IND_FLAG","YES");
run;

proc transpose data=LE4_IND out=LE4_INPUT_IND;

by &RPTVAR2 &RPTVAR1;
id &RPTVAR3;
var  MATURITY_EXP ;
run;

/*USING TRANSPOSE TO GET ALL THE MATURITY BUCKETS AS VARIABLE NAMES*/
PROC TRANSPOSE DATA=rd_map.map_mat_buckets_le_regrpt OUT=map_le(DROP=_NAME_);
ID mat_description;
VAR ;
RUN;

DATA LE4_INPUT_IND_final ;
SET  LE4_INPUT_IND map_le;
RUN;

proc sort data=rd_root.counterparty_details(where=(COUNTERPARTY_GROUP EQ " " ) rename=(LECPTYID=&rptvar1)) 
		  out=COUNTERPARTY_CHARS
			  (Keep=&rptvar1  CPTY_CD  )nodupkey;
 by &rptvar1;
run;

/*MAP CPTY_CD TO  COUNTERPARTY_GROUP;*/
proc sort data=LE4_INPUT_IND_FINAL;
 by &rptvar1;
run;

data LE4_IND_FINAL;
 merge LE4_INPUT_IND_FINAL(in=a) COUNTERPARTY_CHARS(in=b);
 by &rptvar1;
 if a*b;
run;
/*Check if variable UNDEFINED_MATURITY exist or not*/
%let dsid = %sysfunc(open(LE4_IND_FINAL));
%let le4_ind_var_chk = %sysfunc(varnum(&dsid, UNDEFINED_MATURITY));
%let rc = %sysfunc(close(&dsid));
%put &le4_ind_var_chk;

%if &le4_ind_var_chk eq 0 %then %do;
	DATA LE4_IND_FINAL ;
	SET  LE4_IND_FINAL;
	UNDEFINED_MATURITY=.;
	RUN;
%end;
%symdel le4_ind_var_chk;

%end;
%else %do;
%put "No Data for Individual Exposures found";
data _null_;
 call symputx("IND_FLAG","NO");
run;
%end;

 


DATA LE4_RPT_FINAL ;
SET  
%if "&GROUP_FLAG" EQ "YES" %then %do;
  LE4_GRP_FINAL
%end;
%if "&IND_FLAG" EQ "YES" %then %do; 
  LE4_IND_FINAL
%end;
;
RUN;


%mend regrpt_d0_capital_le4_crd4;
