/*****************************************************************************
* Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
*    NAME:regrpt_d0_capital_le5_crd4.sas
*
* PURPOSE: Creates data for the LE 5 report
*
*
*   USAGE:
*
*   NOTES: Modified for V4.8
*   Macro Options:
*****************************************************************************/
%macro regrpt_d0_capital_le5_crd4;

%macro createRegulatoryView (fact_table=);
/*---------------------------------------------------------------------------
* Step 1.
* Check for data in the repository and create a dataset for the project
* the dataset is work.current_regulatory
* -------------------------------------------------------------------------*/
%if %upcase(&usertype) eq MASTER %then
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id));
%else
%let projectview=%trim(%left(&PROJECT_SET))_%trim(%left(&REGPROJECTNAME))_%trim(%left(&MITIGANTS_ALLOCATION_METHOD))_%trim(%left(&system_id))_%trim(%left(&username));
%put projectview=&projectview;
/* Create SQL views into datamart with no history */
%create_risk_repository_views
(Project_name=&projectview,Fact_table=&fact_table,Current=YES,Year=NO,Allhistory=NO, where=NONE, obs=0);
 
%mend createRegulatoryView;

/* Create views of fact table with cross-class macro names */
%createRegulatoryView (fact_table=Regulatory);

/*EXTRACTING DATA FOR GROUP COUNTERPARTIES*/
proc sort data=current_regulatory ( where=(upcase(&rptvar2.) NOT IN ("MISSING" "+") ))
		  out=LE5_GROUP;
by &RPTVAR1 ;
run;


%if %attrn(LE5_GROUP, NOBS) NE 0 %then %do;
%put "Data for Counterparty Group exist";
/*TRANSPOSING DATASET TO GET MATURITY BUCKETS AS VARIABLE NAMES*/
data _null_;
 call symputx("GROUP_FLAG","YES");
run;

proc transpose data=LE5_GROUP out=le5_input_grp;

by &RPTVAR1 ;
id &RPTVAR2  ;
var  MATURITY_EXP ;
run;

/*ONCE AGAIN USING TRANSPOSE TO GET ALL THE MATURITY BUCKETS AS VARIABLE NAMES*/
PROC TRANSPOSE DATA=rd_map.map_mat_buckets_le_regrpt OUT=map_le(DROP=_NAME_);
ID mat_description;
VAR ;
RUN;

DATA LE5_GRP_FINAL ;
SET  le5_input_grp map_le;
RUN;

proc sort data=rd_root.counterparty_details(rename=(LECPTYID=&rptvar1)) 
		  out=COUNTERPARTY_CHARS
			  (Keep=&rptvar1  CPTY_CD CPTY_NM  )nodupkey;
 by &rptvar1;
run;

/*MAP CPTY_CD TO  COUNTERPARTY_GROUP;*/
proc sort data=LE5_GRP_FINAL;
 by &rptvar1;
run;
data LE5_GRP_FINAL;
 merge LE5_GRP_FINAL(in=a) COUNTERPARTY_CHARS(in=b);
 by &rptvar1;
  if a*b;
run;


/*AGGREGATIONS AT GROUP LEVEL COMPLETED*/
%end; /* data for counterparty available*/
%else %do;/* data for counterparty Not Available*/
%put "Data for Counterparty Groups Not available";
data _null_;
 call symputx("GROUP_FLAG","NO");
run;

%end;     /* data for counterparty Not Available*/

/*Check if variable UNDEFINED_MATURITY exist or not*/
%let dsid = %sysfunc(open(LE5_GRP_FINAL));
%let var_chk = %sysfunc(varnum(&dsid, UNDEFINED_MATURITY));
%let rc = %sysfunc(close(&dsid));
%put &var_chk;

%if &var_chk eq 0 %then %do;
	DATA LE5_GRP_FINAL ;
	SET  LE5_GRP_FINAL;
	UNDEFINED_MATURITY=.;
	RUN;
%end;
%symdel le4_grp_var_chk;

%mend regrpt_d0_capital_le5_crd4;
